--
--
--
--    filename:	dbstruktur-sichten.sql
--
--    version:	1.3
--
--    Definition des Datenbankmodells 'Virtuelles Fahrzeug' - vf
--    > Sichten <
--
--
--
-- ----------------------------------------------------------------------------------------
--
--
--    Copyright (C) 2007-2011  Michael Bellair
--
--    This program is free software: you can redistribute it and/or modify
--    it under the terms of the GNU General Public License as published by
--    the Free Software Foundation, either version 3 of the License, or
--    (at your option) any later version.
--
--    This program is distributed in the hope that it will be useful,
--    but WITHOUT ANY WARRANTY; without even the implied warranty of
--    MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
--    GNU General Public License for more details.
--
--    You should have received a copy of the GNU General Public License
--    along with this program.  If not, see <http://www.gnu.org/licenses/>.
--
--    Michael Bellair
--    Sportplatzstrasse 11
--    01259 Dresden
--
--    E-Mail:	bellair@freenet.de
--    homepage:	http://vf.michaelbellair.de/index.html
--
--
-- ----------------------------------------------------------------------------------------
--




-- ---------------------------------------------------------------------------------------
-- ---------------------------------------------------------------------------------------
-- ---------------------------------------------------------------------------------------
--
--  Hinweise zum Festlegen der Namen der Sichten - siehe Abschn. 2 'Das Datenbankmodell' 
--  der DB-Dokumentation
--
-- ---------------------------------------------------------------------------------------
-- ---------------------------------------------------------------------------------------
-- ---------------------------------------------------------------------------------------



-- ---------------------------------------------------------------------------------------
-- ---------------------------------------------------------------------------------------
-- ---------------------------------------------------------------------------------------
--							----------------------------------
-- >intern< als Sonderfall am Anfang definieren		----------------------------------
--							----------------------------------
-- ---------------------------------------------------------------------------------------
-- ---------------------------------------------------------------------------------------
-- ---------------------------------------------------------------------------------------

-- ---------------------------------------------------------------------------------------
-- ---------------------------------------------------------------------------------------
--						------------------------------------------
--	intern.zeige__fremdschluessel		------------------------------------------
--						------------------------------------------
-- ---------------------------------------------------------------------------------------
-- ---------------------------------------------------------------------------------------
CREATE OR REPLACE VIEW intern.zeige__fremdschluessel
AS
	SELECT
		pg_constraint.conname AS fk
		, start_n.nspname || '.' || start_c.relname || '.' || start_a.attname AS spstart
		, ziel_n.nspname || '.' || ziel_c.relname || '.' || ziel_a.attname AS spziel
	FROM
		pg_constraint
		, pg_namespace start_n
		, pg_namespace ziel_n
		, pg_class start_c
		, pg_class ziel_c
		, pg_attribute start_a
		, pg_attribute ziel_a
	WHERE
		-- Startspalte
		start_c.relnamespace = start_n.oid
	AND
		pg_constraint.conrelid = start_c.oid
	AND
		start_a.attrelid = start_c.oid
	AND
		pg_constraint.conkey[1] = start_a.attnum
	AND
		-- Zielspalte
		ziel_c.relnamespace = ziel_n.oid
	AND
		pg_constraint.confrelid = ziel_c.oid
	AND
		ziel_a.attrelid = ziel_c.oid
	AND
		pg_constraint.confkey[1] = ziel_a.attnum
	AND
		pg_constraint.contype = 'f'
	ORDER BY
		start_c.relname;
SELECT intern.nimm__TLKommentarSicht( 'intern.zeige__fremdschluessel'
, ARRAY[
'fk'
, 'spstart'
, 'spziel'
] 
, ARRAY[
'Namen der Fremdschlussel in der Datenbank'
, 'Schema.Tabelle.Name der Startspalte des Fremdschlssels'
, 'Schema.Tabelle.Name der Zielspalte des Fremdschlssels'
], 
'Es werden alle im System vorhandenen Fremdschlssel einschlielich der Start- und Zielspalten aufgelistet.' );
--
-- Standardverhalten:
-- ..................
--
--SELECT * FROM intern.zeige__fremdschluessel;
--


-- ---------------------------------------------------------------------------------------
-- ---------------------------------------------------------------------------------------
--					--------------------------------------------------
--	intern.zeige__spaltenanzahl	--------------------------------------------------
--					--------------------------------------------------
-- ---------------------------------------------------------------------------------------
-- ---------------------------------------------------------------------------------------
CREATE OR REPLACE VIEW intern.zeige__spaltenanzahl
AS
SELECT 
	intern.gib__stsname( 'schtab', spname ) AS tabname
	, count( intern.gib__stsname( 'schtab', spname ) ) AS spanz
FROM
	intern.zeige__tabspInformationen
GROUP BY 
	tabname
ORDER BY
	tabname
;
SELECT intern.nimm__TLKommentarSicht( 'intern.zeige__spaltenanzahl'
, ARRAY[
	'tabname'
	, 'spanz'
] 
, ARRAY[
'Tabellenname'
, 'Anzahl der Spalten der Tabelle'
], 
'Es wird die Anzahl der in der Tabelle enthaltenen Spalten (ohne Systemspalten) aufgelistet.' );
--
-- Standardverhalten:
-- ..................
--
--SELECT * FROM intern.zeige__spaltenanzahl;
--


-- ---------------------------------------------------------------------------------------
-- ---------------------------------------------------------------------------------------
--						------------------------------------------
--	intern.zeige__tabspInformationen	------------------------------------------
--						------------------------------------------
-- ---------------------------------------------------------------------------------------
-- ---------------------------------------------------------------------------------------
CREATE OR REPLACE VIEW intern.zeige__tabspInformationen
AS
	SELECT 
		pg_namespace.nspname || '.' || pg_class.relname || '.' || pg_attribute.attname AS spname
		, pg_type.typname AS dtyp
		, attnum AS spnr
		, beschr_tab.description AS beschr_tabelle
		, beschr_sp.description AS beschr_spalte
	FROM 
		pg_namespace, pg_type, pg_attribute NATURAL JOIN pg_class LEFT OUTER JOIN pg_description beschr_tab ON ( beschr_tab.objoid = pg_class.oid AND beschr_tab.objsubid = 0 ) LEFT OUTER JOIN pg_description beschr_sp ON ( beschr_sp.objoid = pg_class.oid AND pg_attribute.attnum = beschr_sp.objsubid )

	WHERE 
		pg_class.relnamespace = pg_namespace.oid	-- Schema - Tabelle
	AND
		pg_attribute.attrelid = pg_class.oid		-- Spalte - Tabelle
	AND
		pg_attribute.atttypid = pg_type.oid		-- Spalte - Datentyp
	AND
		NOT( pg_class.relname LIKE( 'sql_%' )		-- Systemtabellen beginnen mit
		OR pg_class.relname LIKE( 'pg_%' ) )		-- >sql_< oder >pg_<
	AND
		pg_class.relkind = 'r'				-- normale Tabelle
	AND
		pg_attribute.attnum > 0				-- > 0 keine Systemspalten
	ORDER BY 
		pg_namespace.nspname
		, pg_class.relname
		, CASE WHEN( pg_attribute.attname IN( 'id', 'idfrei', 'notizen' )  ) THEN '.' ELSE '' END || pg_attribute.attname
;
SELECT intern.nimm__TLKommentarSicht( 'intern.zeige__tabspInformationen
'
, ARRAY[
'spname'
, 'dtyp'
, 'spnr'
, 'beschr_spalte'
, 'beschr_tabelle'
] 
, ARRAY[
'Schema.Tabelle.Name der Spalte'
, 'pg_type.typname'
, 'pg_attribute.attnum'
, 'pg_description.description fr die Spalte'
, 'pg_description.description fr die Tabelle'
], 
'Es werden alle im System vorhandenen Spalten (einschlielich Schema- und Tabellennamen) und deren Beschreibung aufgelistet.' );
--
-- Standardverhalten:
-- ..................
--
--SELECT * FROM intern.zeige__tabspInformationen;
--



-- ---------------------------------------------------------------------------------------
-- ---------------------------------------------------------------------------------------
-- ---------------------------------------------------------------------------------------
--			------------------------------------------------------------------
-- dok - Dokumente	------------------------------------------------------------------
--			------------------------------------------------------------------
-- ---------------------------------------------------------------------------------------
-- ---------------------------------------------------------------------------------------
-- ---------------------------------------------------------------------------------------



-- ---------------------------------------------------------------------------------------
-- ---------------------------------------------------------------------------------------
-- ---------------------------------------------------------------------------------------
--			------------------------------------------------------------------
-- prj - Projekte	------------------------------------------------------------------
--			------------------------------------------------------------------
-- ---------------------------------------------------------------------------------------
-- ---------------------------------------------------------------------------------------
-- ---------------------------------------------------------------------------------------

-- ---------------------------------------------------------------------------------------
-- ---------------------------------------------------------------------------------------
--				----------------------------------------------------------
--	prj.zeige__dokdoku	----------------------------------------------------------
--				----------------------------------------------------------
-- ---------------------------------------------------------------------------------------
-- ---------------------------------------------------------------------------------------
DROP VIEW prj.zeige__dokdoku;
CREATE OR REPLACE VIEW prj.zeige__dokdoku
AS
  SELECT
	--
	-- --	dok.doku	----------------------------------------------------------
	--
	dok.doku.id AS dok__doku__id
	, dok.doku.aspekt AS dok__doku__aspekt
	, dok.doku.notizen AS dok__doku__notizen
	, dok.doku.dok_typ_id AS dok__doku__dok_typ_id
	, dok.doku.spr_uebvar_id_kb AS dok__doku__spr_uebvar_id_kb
	--
	-- --	prj.pl_prtdokdoku	----------------------------------------------------------
	--
	, prj.pl_prtdokdoku.id AS prj__pl_prtdokdoku__id
	, prj.pl_prtdokdoku.prj_projekte_id AS prj__pl_prtdokdoku__prj_projekte_id
	, prj.pl_prtdokdoku.prt_protokoll_id AS prj__pl_prtdokdoku__prt_protokoll_id
	, prj.pl_prtdokdoku.notizen AS prj__pl_prtdokdoku__notizen
	, prj.pl_prtdokdoku.logdatuhrz AS prj__pl_prtdokdoku__logdatuhrz
	, prj.pl_prtdokdoku.logdqok AS prj__pl_prtdokdoku__logdqok
	, prj.pl_prtdokdoku.logdquelle AS prj__pl_prtdokdoku__logdquelle
	, prj.pl_prtdokdoku.logentfernt AS prj__pl_prtdokdoku__logentfernt
	, prj.pl_prtdokdoku.logname AS prj__pl_prtdokdoku__logname
	--
	-- --	prj.pl_dokausgabe	--------------------------------------------------
	--
	, prj.pl_dokausgabe.id AS prj__pl_dokausgabe__id
	, prj.pl_dokausgabe.prj_projekte_id AS prj__pl_dokausgabe__prj_projekte_id
	, prj.pl_dokausgabe.stand AS prj__pl_dokausgabe__stand
	, prj.pl_dokausgabe.datum AS prj__pl_dokausgabe__datum
	, prj.pl_dokausgabe.istfrei AS prj__pl_dokausgabe__istfrei
	, prj.pl_dokausgabe.notizen AS prj__pl_dokausgabe__notizen
	, prj.pl_dokausgabe.nr AS prj__pl_dokausgabe__nr
	, prj.pl_dokausgabe.logdatuhrz AS prj__pl_dokausgabe__logdatuhrz
	, prj.pl_dokausgabe.logdqok AS prj__pl_dokausgabe__logdqok
	, prj.pl_dokausgabe.logdquelle AS prj__pl_dokausgabe__logdquelle
	, prj.pl_dokausgabe.logentfernt AS prj__pl_dokausgabe__logentfernt
	, prj.pl_dokausgabe.logname AS prj__pl_dokausgabe__logname
	, prj.pl_dokausgabe.spr_uebvar_id AS prj__pl_dokausgabe__spr_uebvar_id
	--
	-- --	prj.ppl_dokdoku	----------------------------------------------------------
	--
	, prj.ppl_dokdoku.id AS prj__ppl_dokdoku__id
	, prj.ppl_dokdoku.prj_personen_id AS prj__ppl_dokdoku__prj_personen_id
	, prj.ppl_dokdoku.prj_projekte_id AS prj__ppl_dokdoku__prj_projekte_id
	, prj.ppl_dokdoku.notizen AS prj__ppl_dokdoku__notizen
	, prj.ppl_dokdoku.logdatuhrz AS prj__ppl_dokdoku__logdatuhrz
	, prj.ppl_dokdoku.logdqok AS prj__ppl_dokdoku__logdqok
	, prj.ppl_dokdoku.logdquelle AS prj__ppl_dokdoku__logdquelle
	, prj.ppl_dokdoku.logentfernt AS prj__ppl_dokdoku__logentfernt
	, prj.ppl_dokdoku.logname AS prj__ppl_dokdoku__logname
	--
	-- --	prj.p_dokstrkt	----------------------------------------------------------
	--
	, prj.p_dokstrkt.id AS prj__p_dokstrkt__id
	, prj.p_dokstrkt.notizen AS prj__p_dokstrkt__notizen
	, prj.p_dokstrkt.prj_projekte_id AS prj__p_dokstrkt__prj_projekte_id
	, prj.p_dokstrkt.str_strkt_id AS prj__p_dokstrkt__str_strkt_id
  FROM
	dok.doku
		--
		-- prj.pl_prtdokdoku
		--
		LEFT OUTER JOIN prj.pl_prtdokdoku ON ( 
		         dok.doku.id = prj.pl_prtdokdoku.dok_doku_id
		     AND prj.pl_prtdokdoku.idfrei = 0 )
		--
		-- prj.pl_dokausgabe
		--
		LEFT OUTER JOIN prj.pl_dokausgabe ON ( 
		         dok.doku.id = prj.pl_dokausgabe.dok_doku_id
		     AND prj.pl_dokausgabe.idfrei = 0 )
		--
		-- prj.ppl_dokdoku
		--
		LEFT OUTER JOIN prj.ppl_dokdoku ON ( 
		         dok.doku.id = prj.ppl_dokdoku.dok_doku_id
		     AND prj.ppl_dokdoku.idfrei = 0 )
		--
		-- prj.p_dokstrkt
		--
		LEFT OUTER JOIN prj.p_dokstrkt ON ( 
		         dok.doku.id = prj.p_dokstrkt.dok_doku_id
		     AND prj.p_dokstrkt.idfrei = 0 )
  WHERE
	dok.doku.idfrei = 0
;
SELECT intern.nimm__TLKommentarSicht( 'prj.zeige__dokdoku'
, ARRAY[
   'dok__doku__id'
 , 'dok__doku__aspekt'
 , 'dok__doku__notizen'
 , 'dok__doku__dok_typ_id'
 , 'dok__doku__spr_uebvar_id_kb'
 , 'prj__pl_prtdokdoku__id'
 , 'prj__pl_prtdokdoku__prj_projekte_id'
 , 'prj__pl_prtdokdoku__prt_protokoll_id'
 , 'prj__pl_prtdokdoku__notizen'
 , 'prj__pl_prtdokdoku__logdatuhrz'
 , 'prj__pl_prtdokdoku__logdqok'
 , 'prj__pl_prtdokdoku__logdquelle'
 , 'prj__pl_prtdokdoku__logentfernt'
 , 'prj__pl_prtdokdoku__logname'
 , 'prj__pl_dokausgabe__id'
 , 'prj__pl_dokausgabe__prj_projekte_id'
 , 'prj__pl_dokausgabe__stand'
 , 'prj__pl_dokausgabe__datum'
 , 'prj__pl_dokausgabe__istfrei'
 , 'prj__pl_dokausgabe__notizen'
 , 'prj__pl_dokausgabe__nr'
 , 'prj__pl_dokausgabe__logdatuhrz'
 , 'prj__pl_dokausgabe__logdqok'
 , 'prj__pl_dokausgabe__logdquelle'
 , 'prj__pl_dokausgabe__logentfernt'
 , 'prj__pl_dokausgabe__logname'
 , 'prj__pl_dokausgabe__spr_uebvar_id'
 , 'prj__ppl_dokdoku__id'
 , 'prj__ppl_dokdoku__prj_personen_id'
 , 'prj__ppl_dokdoku__prj_projekte_id'
 , 'prj__ppl_dokdoku__notizen'
 , 'prj__ppl_dokdoku__logdatuhrz'
 , 'prj__ppl_dokdoku__logdqok'
 , 'prj__ppl_dokdoku__logdquelle'
 , 'prj__ppl_dokdoku__logentfernt'
 , 'prj__ppl_dokdoku__logname'
 , 'prj__p_dokstrkt__id'
 , 'prj__p_dokstrkt__notizen'
 , 'prj__p_dokstrkt__prj_projekte_id'
 , 'prj__p_dokstrkt__str_strkt_id'
] 
, ARRAY[
   E'siehe \\texttt{dok.doku.id}'
 , E'siehe \\texttt{dok.doku.aspekt}'
 , E'siehe \\texttt{dok.doku.notizen}'
 , E'siehe \\texttt{dok.doku.dok_typ_id}'
 , E'siehe \\texttt{dok.doku.spr_uebvar_id_kb}'
 , E'siehe \\texttt{prj.pl_prtdokdoku.id}'
 , E'siehe \\texttt{prj.pl_prtdokdoku.prj_projekte_id}'
 , E'siehe \\texttt{prj.pl_prtdokdoku.prt_protokoll_id}'
 , E'siehe \\texttt{prj.pl_prtdokdoku.notizen}'
 , E'siehe \\texttt{prj.pl_prtdokdoku.logdatuhrz}'
 , E'siehe \\texttt{prj.pl_prtdokdoku.logdqok}'
 , E'siehe \\texttt{prj.pl_prtdokdoku.logdquelle}'
 , E'siehe \\texttt{prj.pl_prtdokdoku.logentfernt}'
 , E'siehe \\texttt{prj.pl_prtdokdoku.logname}'
 , E'siehe \\texttt{prj.pl_dokausgabe.id}'
 , E'siehe \\texttt{prj.pl_dokausgabe.prj_projekte_id}'
 , E'siehe \\texttt{prj.pl_dokausgabe.stand}'
 , E'siehe \\texttt{prj.pl_dokausgabe.datum}'
 , E'siehe \\texttt{prj.pl_dokausgabe.istfrei}'
 , E'siehe \\texttt{prj.pl_dokausgabe.notizen}'
 , E'siehe \\texttt{prj.pl_dokausgabe.nr}'
 , E'siehe \\texttt{prj.pl_dokausgabe.logdatuhrz}'
 , E'siehe \\texttt{prj.pl_dokausgabe.logdqok}'
 , E'siehe \\texttt{prj.pl_dokausgabe.logdquelle}'
 , E'siehe \\texttt{prj.pl_dokausgabe.logentfernt}'
 , E'siehe \\texttt{prj.pl_dokausgabe.logname}'
 , E'siehe \\texttt{prj.pl_dokausgabe.spr_uebvar_id}'
 , E'siehe \\texttt{prj.ppl_dokdoku.id}'
 , E'siehe \\texttt{prj.ppl_dokdoku.prj_personen_id}'
 , E'siehe \\texttt{prj.ppl_dokdoku.prj_projekte_id}'
 , E'siehe \\texttt{prj.ppl_dokdoku.notizen}'
 , E'siehe \\texttt{prj.ppl_dokdoku.logdatuhrz}'
 , E'siehe \\texttt{prj.ppl_dokdoku.logdqok}'
 , E'siehe \\texttt{prj.ppl_dokdoku.logdquelle}'
 , E'siehe \\texttt{prj.ppl_dokdoku.logentfernt}'
 , E'siehe \\texttt{prj.ppl_dokdoku.logname}'
 , E'siehe \\texttt{prj.p_dokstrkt.id}'
 , E'siehe \\texttt{prj.p_dokstrkt.notizen}'
 , E'siehe \\texttt{prj_projekte_id}'
 , E'siehe \\texttt{prj.p_dokstrkt.str_strkt_id}'
], 
E'Es werden die Dokumente (siehe \\texttt{dok.doku}, \\texttt{prj.pl_prtdokdoku}, \\texttt{prj.pl_dokausgabe}, \\texttt{prj.ppl_dokdoku}) angezeigt.' );
--
-- Standardverhalten:
-- ..................
--
--SELECT * FROM prj.zeige__dokdoku;
--



-- ---------------------------------------------------------------------------------------
-- ---------------------------------------------------------------------------------------
--					--------------------------------------------------
--	prj.zeige__p_prtverbindung	--------------------------------------------------
--					--------------------------------------------------
-- ---------------------------------------------------------------------------------------
-- ---------------------------------------------------------------------------------------
DROP VIEW prj.zeige__p_prtverbindung;
CREATE OR REPLACE VIEW prj.zeige__p_prtverbindung
AS
	SELECT DISTINCT
		prj.p_prtverbindung.id AS prj__p_prtverbindung__id
		, prj.p_prtverbindung.prj_projekte_id
		, prj.p_prtverbindung.notizen AS notizen_nachf
		, prj.p_prtverbindung.prt_protokoll_id_nachf
		, prt.protokoll.prt_typ_id AS prt_typ_id_nachf
		, vorg.prt_protokoll_id_vorg
	FROM
		prj.p_prtverbindung
			--
			-- Vorgnger zum Protokolleintrag anzeigen
			--
			LEFT OUTER JOIN prj.p_prtverbindung AS vorg
				ON (
					prj.p_prtverbindung.prt_protokoll_id_vorg = vorg.prt_protokoll_id_vorg
				AND
					prj.p_prtverbindung.prj_projekte_id = vorg.prj_projekte_id
				)
		, prt.protokoll
	WHERE
		prj.p_prtverbindung.idfrei = 0
	AND
		prj.p_prtverbindung.prt_protokoll_id_nachf = prt.protokoll.id
	ORDER BY
		prj.p_prtverbindung.prj_projekte_id
		, prj.p_prtverbindung.prt_protokoll_id_nachf
		, vorg.prt_protokoll_id_vorg
;
SELECT intern.nimm__TLKommentarSicht( 'prj.zeige__p_prtverbindung'
, ARRAY[
  'prj__p_prtverbindung__id'
, 'prj_projekte_id'
, 'notizen_nachf'
, 'prt_protokoll_id_nachf'
, 'prt_typ_id_nachf'
, 'prt_protokoll_id_vorg'
]
, ARRAY[
E'siehe \\texttt{prj.p_prtverbindung.id}'
, E'siehe \\texttt{prj.p_prtverbindung.prj_projekte_id}'
, E'siehe \\texttt{prj.p_prtverbindung.notizen}'
, E'siehe \\texttt{prj.p_prtverbindung.prt_protokoll_id_nachf}'
, E'siehe \\texttt{prt.protokoll.prt_typ_id}'
, E'siehe \\texttt{prt.prt_protokoll_id_vorg}'
], 
E'Es werden die projektspezifischen Vorgnger / Nachfolger der Sicherheitsanforderungen, Gefahrenprotokolleintrge und Terminplaneintrge angezeigt (siehe \\texttt{prj.p_prtverbindung}).' );
--
-- Standardverhalten:
-- ..................
--
--SELECT * FROM prj.zeige__p_prtverbindung;
--


-- ---------------------------------------------------------------------------------------
-- ---------------------------------------------------------------------------------------
--					--------------------------------------------------
--	prj.zeige__pl_dokausgabe_le	--------------------------------------------------
--					--------------------------------------------------
-- ---------------------------------------------------------------------------------------
-- ---------------------------------------------------------------------------------------
DROP VIEW prj.zeige__pl_dokausgabe_le;
CREATE OR REPLACE VIEW prj.zeige__pl_dokausgabe_le
AS
  SELECT
	dokausg.id AS prj__pl_dokausgabe__id
	--
	-- Kontrolle
	--
--	, dokausg.dok_doku_id AS prj__pl_dokausgabe__dok_doku_id
--	, dokausg.prj_projekte_id AS prj__pl_dokausgabe__prj_projekte_id
--	, dokausg.logdatuhrz
--	, dokausg.logentfernt
  FROM
	prj.pl_dokausgabe
		LEFT OUTER JOIN prj.pl_dokausgabe AS dokausg
			ON (
				prj.pl_dokausgabe.dok_doku_id = dokausg.dok_doku_id
			   AND
				prj.pl_dokausgabe.prj_projekte_id = dokausg.prj_projekte_id
			   AND
				prj.pl_dokausgabe.idfrei = 0
			   AND
				dokausg.idfrei = 0
			)
  GROUP BY
	  dokausg.id
	, dokausg.logdatuhrz
	--
	-- Kontrolle
	--
--	, dokausg.dok_doku_id
--	, dokausg.prj_projekte_id
--	, dokausg.logentfernt
  HAVING
	--
	-- Abfrage auf letzte nderung beschrnken 
	--
	max( prj.pl_dokausgabe.logdatuhrz ) = dokausg.logdatuhrz
  ORDER BY
	dokausg.id
	--
	-- Kontrolle
	--
--	, dokausg.dok_doku_id
--	, dokausg.prj_projekte_id
;
SELECT intern.nimm__TLKommentarSicht( 'prj.zeige__pl_dokausgabe_le'
, ARRAY[
   'prj__pl_dokausgabe__id'
] 
, ARRAY[
   E'siehe \\texttt{prj.pl_dokausgabe.id}'
], 
E'Zu jedem in der Tabelle \\texttt{prj.pl_dokausgabe} enthaltenen Dokument wird unter Bercksichtigung des Projektes die Identifikationsnummer \\texttt{prj.pl_dokausgabe.id} der jeweils letzten zugeordneten Ausgabe angezeigt (Logbuchfunktion).' );
--
-- Standardverhalten:
-- ..................
--
--SELECT * FROM prj.zeige__pl_dokausgabe_le;
--


-- ---------------------------------------------------------------------------------------
-- ---------------------------------------------------------------------------------------
--					--------------------------------------------------
--	prj.zeige__pl_psgefabk		--------------------------------------------------
--					--------------------------------------------------
-- ---------------------------------------------------------------------------------------
-- ---------------------------------------------------------------------------------------
DROP VIEW prj.zeige__pl_psgefabk;
CREATE OR REPLACE VIEW prj.zeige__pl_psgefabk
AS
  SELECT
	  prj.pl_psgefabk.id
	, prj.pl_psgefabk.notizen
	, prj.pl_psgefabk.logdatuhrz
	, prj.pl_psgefabk.logdqok
	, prj.pl_psgefabk.logdquelle
	, prj.pl_psgefabk.logentfernt
	, prj.pl_psgefabk.logname
	, prj.pl_psgefabk.prj_projekte_id
	, prj.pl_psgefabk.ps_abk_id
	, prj.pl_psgefabk.ps_gefszenario_id
	, prj.pl_psgefabk.spr_uebvar_id_zus
  FROM
	prj.pl_psgefabk
  WHERE
	prj.pl_psgefabk.idfrei = 0
;
SELECT intern.nimm__TLKommentarSicht( 'prj.zeige__pl_psgefabk'
, ARRAY[
  'id'
, 'notizen'
, 'logdatuhrz'
, 'logdqok'
, 'logdquelle'
, 'logentfernt'
, 'logname'
, 'prj_projekte_id'
, 'ps_abk_id'
, 'ps_gefszenario_id'
, 'spr_uebvar_id_zus'
] 
, ARRAY[
  E'siehe \\texttt{prj.pl_psgefabk.id }'
, E'siehe \\texttt{prj.pl_psgefabk.notizen }'
, E'siehe \\texttt{prj.pl_psgefabk.logdatuhrz }'
, E'siehe \\texttt{prj.pl_psgefabk.logdqok }'
, E'siehe \\texttt{prj.pl_psgefabk.logdquelle }'
, E'siehe \\texttt{prj.pl_psgefabk.logentfernt }'
, E'siehe \\texttt{prj.pl_psgefabk.logname }'
, E'siehe \\texttt{prj.pl_psgefabk.prj_projekte_id }'
, E'siehe \\texttt{prj.pl_psgefabk.ps_abk_id }'
, E'siehe \\texttt{prj.pl_psgefabk.ps_gefszenario_id }'
, E'siehe \\texttt{prj.pl_psgefabk.spr_uebvar_id_zus }'
], 
E'Es werden die projektspezifischen (siehe \\texttt{prj.pl_psgefabk}) Abkrzungen angezeigt, die den Gefahrenszenarien zugeordnet sind.' );
--
-- Standardverhalten:
-- ..................
--
--SELECT * FROM prj.zeige__pl_psgefabk;
--


-- ---------------------------------------------------------------------------------------
-- ---------------------------------------------------------------------------------------
--					--------------------------------------------------
--	prj.zeige__pl_psgefabk_le	--------------------------------------------------
--					--------------------------------------------------
-- ---------------------------------------------------------------------------------------
-- ---------------------------------------------------------------------------------------
DROP VIEW prj.zeige__pl_psgefabk_le;
CREATE OR REPLACE VIEW prj.zeige__pl_psgefabk_le
AS
  SELECT
	gefabk.id AS prj__pl_psgefabk__id
	--
	-- Kontrolle
	--
--	, gefabk.logdatuhrz
--	, gefabk.logentfernt AS prj__pl_psgefabk__logentfernt
--	, gefabk.ps_abk_id
--	, gefabk.prj_projekte_id
--	, gefabk.ps_gefszenario_id
  FROM
	prj.pl_psgefabk
		LEFT OUTER JOIN prj.pl_psgefabk AS gefabk
			ON (
				prj.pl_psgefabk.ps_gefszenario_id = gefabk.ps_gefszenario_id
			   AND
				prj.pl_psgefabk.ps_abk_id = gefabk.ps_abk_id
			   AND
				prj.pl_psgefabk.prj_projekte_id = gefabk.prj_projekte_id
			   AND
				prj.pl_psgefabk.idfrei = 0
			   AND
				gefabk.idfrei = 0
			)
  GROUP BY
	gefabk.id
	, gefabk.logdatuhrz
	--
	-- Kontrolle
	--
--	, gefabk.logentfernt
--	, gefabk.ps_abk_id
--	, gefabk.prj_projekte_id
--	, gefabk.ps_gefszenario_id
  HAVING
	--
	-- Abfrage auf letzte nderung beschrnken 
	--
	max( prj.pl_psgefabk.logdatuhrz ) = gefabk.logdatuhrz
  ORDER BY
	gefabk.id
;
SELECT intern.nimm__TLKommentarSicht( 'prj.zeige__pl_psgefabk_le'
, ARRAY[
  'prj__prj.pl_psgefabk__id'
] 
, ARRAY[
  E'siehe \\texttt{prj.pl_psgefabk.id}'
], 
E'Zu jedem in der Tabelle \\texttt{prj.pl_psgefabk} enthaltenen Aspekt wird die jeweils letzte zugeordnete in \\texttt{ps} verwendete Abkrzung angezeigt (Logbuchfunktion). Die unterschiedlichen Aspekte, zu denen das Logbuch gefhrt wird, werden anhand der Spalten \\texttt{prj.pl_psgefabk.prj_projekte_id, prj.pl_psgefabk.ps_gefszenario_id, prj.pl_psgefabk.ps_abk_id} unterschieden.' );
--
-- Standardverhalten:
-- ..................
--
--SELECT * FROM prj.zeige__pl_psgefabk_le;
--


-- ---------------------------------------------------------------------------------------
-- ---------------------------------------------------------------------------------------
--				----------------------------------------------------------
--	prj.zeige__pl_psgefanm	----------------------------------------------------------
--				----------------------------------------------------------
-- ---------------------------------------------------------------------------------------
-- ---------------------------------------------------------------------------------------
DROP VIEW prj.zeige__pl_psgefanm;
CREATE OR REPLACE VIEW prj.zeige__pl_psgefanm
AS
  --
  -- projektabhngige Daten auslesen
  --
  SELECT DISTINCT
	  id
	, notizen
	, logdatuhrz
	, logdqok
	, logdquelle
	, logentfernt
	, logname
	, prj_projekte_id
	, ps_anmerkung_id
	, ps_gefszenario_id
	, spr_uebvar_id
  FROM
	prj.pl_psgefanm
  WHERE
	prj.pl_psgefanm.idfrei = 0
;
SELECT intern.nimm__TLKommentarSicht( 'prj.zeige__pl_psgefanm'
, ARRAY[
  'id'
, 'notizen'
, 'logdatuhrz'
, 'logdqok'
, 'logdquelle'
, 'logentfernt'
, 'logname'
, 'prj_projekte_id'
, 'ps_anmerkung_id'
, 'ps_gefszenario_id'
, 'spr_uebvar_id'
] 
, ARRAY[
  E'siehe \\texttt{prj.pl_psgefanm.id}'
, E'siehe \\texttt{prj.pl_psgefanm.notizen}'
, E'siehe \\texttt{prj.pl_psgefanm.logdatuhrz}'
, E'siehe \\texttt{prj.pl_psgefanm.logdqok}'
, E'siehe \\texttt{prj.pl_psgefanm.logdquelle}'
, E'siehe \\texttt{prj.pl_psgefanm.logentfernt}'
, E'siehe \\texttt{prj.pl_psgefanm.logname}'
, E'siehe \\texttt{prj.pl_psgefanm.prj_projekte_id}'
, E'siehe \\texttt{prj.pl_psgefanm.ps_anmerkung_id}'
, E'siehe \\texttt{prj.pl_psgefanm.ps_gefszenario_id}'
, E'siehe \\texttt{prj.pl_psgefanm.spr_uebvar_id}'
], 
E'Es werden die projektspezifischen (siehe \\texttt{prj.pl_psgefanm}) Anmerkungen angezeigt.' );
--
-- Standardverhalten:
-- ..................
--
--SELECT * FROM prj.zeige__pl_psgefanm;
--


-- ---------------------------------------------------------------------------------------
-- ---------------------------------------------------------------------------------------
--					--------------------------------------------------
--	prj.zeige__pl_psgefanm_le	--------------------------------------------------
--					--------------------------------------------------
-- ---------------------------------------------------------------------------------------
-- ---------------------------------------------------------------------------------------
DROP VIEW prj.zeige__pl_psgefanm_le;
CREATE OR REPLACE VIEW prj.zeige__pl_psgefanm_le
AS
  SELECT
	gefanm.id AS prj__pl_psgefanm__id
	--
	-- Kontrolle
	--
--	, gefanm.logdatuhrz
--	, gefanm.logentfernt AS prj__pl_psgefanm__logentfernt
--	, gefanm.prj_projekte_id
--	, gefanm.ps_anmerkung_id
--	, gefanm.ps_gefszenario_id
  FROM
	prj.pl_psgefanm
		LEFT OUTER JOIN prj.pl_psgefanm AS gefanm
			ON (
				prj.pl_psgefanm.ps_gefszenario_id = gefanm.ps_gefszenario_id
			   AND
				prj.pl_psgefanm.ps_anmerkung_id = gefanm.ps_anmerkung_id
			   AND
				prj.pl_psgefanm.prj_projekte_id = gefanm.prj_projekte_id
			   AND
				prj.pl_psgefanm.idfrei = 0
			   AND
				gefanm.idfrei = 0
			)
  GROUP BY
	gefanm.id
	, gefanm.logdatuhrz
	--
	-- Kontrolle
	--
--	, gefanm.logentfernt
--	, gefanm.prj_projekte_id
--	, gefanm.ps_anmerkung_id
--	, gefanm.ps_gefszenario_id
  HAVING
	--
	-- Abfrage auf letzte nderung beschrnken 
	--
	max( prj.pl_psgefanm.logdatuhrz ) = gefanm.logdatuhrz
  ORDER BY
	gefanm.id
;
SELECT intern.nimm__TLKommentarSicht( 'prj.zeige__pl_psgefanm_le'
, ARRAY[
  'prj__pl_psgefanm__id'
] 
, ARRAY[
  E'siehe \\texttt{prj.pl_psgefanm.id}'
], 
E'Zu jedem in der Tabelle \\texttt{prj.pl_psgefanm} enthaltenen Aspekt wird die jeweils letzte zugeordnete in \\texttt{ps} verwendete Abkrzung angezeigt (Logbuchfunktion). Die unterschiedlichen Aspekte, zu denen das Logbuch gefhrt wird, werden anhand der Spalten \\texttt{prj.pl_psgefanm.prj_projekte_id, prj.pl_psgefanm.ps_gefszenario_id} unterschieden.' );
--
-- Standardverhalten:
-- ..................
--
--SELECT * FROM prj.zeige__pl_psgefanm_le;
--


-- ---------------------------------------------------------------------------------------
-- ---------------------------------------------------------------------------------------
--					--------------------------------------------------
--	prj.zeige__pl_psgefstrkt	--------------------------------------------------
--					--------------------------------------------------
-- ---------------------------------------------------------------------------------------
-- ---------------------------------------------------------------------------------------
--DROP VIEW prj.zeige__pl_psgefstrkt;
CREATE OR REPLACE VIEW prj.zeige__pl_psgefstrkt
AS
  SELECT DISTINCT
	  id
	, notizen
	, logdatuhrz
	, logdqok
	, logdquelle
	, logentfernt
	, logname
	, prj_projekte_id
	, ps_gefszenario_id
	, str_strkt_id
  FROM
	prj.pl_psgefstrkt
  WHERE
	prj.pl_psgefstrkt.idfrei = 0
;
SELECT intern.nimm__TLKommentarSicht( 'prj.zeige__pl_psgefstrkt'
, ARRAY[
  'id'
, 'notizen'
, 'logdatuhrz'
, 'logdqok'
, 'logdquelle'
, 'logentfernt'
, 'logname'
, 'prj_projekte_id'
, 'ps_gefszenario_id'
, 'str_strkt_id'
] 
, ARRAY[
  E'siehe \\texttt{prj.pl_psgefstrkt.id}'
, E'siehe \\texttt{prj.pl_psgefstrkt.notizen}'
, E'siehe \\texttt{prj.pl_psgefstrkt.logdatuhrz}'
, E'siehe \\texttt{prj.pl_psgefstrkt.logdqok}'
, E'siehe \\texttt{prj.pl_psgefstrkt.logdquelle}'
, E'siehe \\texttt{prj.pl_psgefstrkt.logentfernt}'
, E'siehe \\texttt{prj.pl_psgefstrkt.logname}'
, E'siehe \\texttt{prj.pl_psgefstrkt.prj_projekte_id}'
, E'siehe \\texttt{prj.pl_psgefstrkt.ps_gefszenario_id}'
, E'siehe \\texttt{prj.pl_psgefstrkt.str_strkt_id}'
], 
E'Es werden die projektspezifischen Strukturpunkte angezeigt (siehe \\texttt{prj.pl_psgefstrkt}).' );
--
-- Standardverhalten:
-- ..................
--
--SELECT * FROM prj.zeige__pl_psgefstrkt;
--


-- ---------------------------------------------------------------------------------------
-- ---------------------------------------------------------------------------------------
--					--------------------------------------------------
--	prj.zeige__pl_psgefstrkt_le	--------------------------------------------------
--					--------------------------------------------------
-- ---------------------------------------------------------------------------------------
-- ---------------------------------------------------------------------------------------
DROP VIEW prj.zeige__pl_psgefstrkt_le;
CREATE OR REPLACE VIEW prj.zeige__pl_psgefstrkt_le
AS
  SELECT
	gefstrkt.id AS prj__pl_psgefstrkt__id
	--
	-- Kontrolle
	--
--	, gefstrkt.logdatuhrz
--	, gefstrkt.logentfernt AS prj__pl_psgefstrkt__logentfernt
--	, gefstrkt.prj_projekte_id
--	, gefstrkt.ps_gefszenario_id
  FROM
	prj.pl_psgefstrkt
		LEFT OUTER JOIN prj.pl_psgefstrkt AS gefstrkt
			ON (
				prj.pl_psgefstrkt.ps_gefszenario_id = gefstrkt.ps_gefszenario_id
			   AND
				prj.pl_psgefstrkt.str_strkt_id = gefstrkt.str_strkt_id
			   AND
				prj.pl_psgefstrkt.prj_projekte_id = gefstrkt.prj_projekte_id
			   AND
				prj.pl_psgefstrkt.idfrei = 0
			   AND
				gefstrkt.idfrei = 0
			)
  GROUP BY
	gefstrkt.id
	, gefstrkt.logdatuhrz
	--
	-- Kontrolle
	--
--	, gefstrkt.logentfernt
--	, gefstrkt.prj_projekte_id
--	, gefstrkt.ps_gefszenario_id
  HAVING
	--
	-- Abfrage auf letzte nderung beschrnken 
	--
	max( prj.pl_psgefstrkt.logdatuhrz ) = gefstrkt.logdatuhrz
  ORDER BY
	gefstrkt.id
;
SELECT intern.nimm__TLKommentarSicht( 'prj.zeige__pl_psgefstrkt_le'
, ARRAY[
  'prj__pl_psgefstrkt__id'
] 
, ARRAY[
  E'siehe \\texttt{prj.pl_psgefstrkt.id}'
], 
E'Zu jedem in der Tabelle \\texttt{prj.pl_psgefstrkt} enthaltenen Aspekt wird der jeweils letzte zugeordnete in \\texttt{ps} verwendete Strukturpunkt angezeigt (Logbuchfunktion). Die unterschiedlichen Aspekte, zu denen das Logbuch gefhrt wird, werden anhand der Spalten \\texttt{prj.pl_psgefstrkt.prj_projekte_id, prj.pl_psgefstrkt.str_strkt_id, prj.pl_psgefstrkt.ps_gefszenario_id} unterschieden.' );
--
-- Standardverhalten:
-- ..................
--
--SELECT * FROM prj.zeige__pl_psgefstrkt_le;
--


-- ---------------------------------------------------------------------------------------
-- ---------------------------------------------------------------------------------------
--					--------------------------------------------------
--	prj.zeige__pp_psgefszenario	--------------------------------------------------
--					--------------------------------------------------
-- ---------------------------------------------------------------------------------------
-- ---------------------------------------------------------------------------------------
DROP VIEW prj.zeige__pp_psgefszenario;
CREATE OR REPLACE VIEW prj.zeige__pp_psgefszenario
AS
  SELECT DISTINCT
	  prj.pp_psgefszenario.id
	, prj.pp_psgefszenario.notizen
	, prj.pp_psgefszenario.prj_personen_id
	, prj.pp_psgefszenario.prj_projekte_id
	, prj.pp_psgefszenario.ps_gefszenario_id
	, prj.pp_psgefszenario.spr_uebvar_id
	, prj.pp_psgefszenario.spr_uebvar_id_reprgefszen
	, prj.pp_psgefszenario.spr_uebvar_id_ursp
  FROM
	prj.pp_psgefszenario
  WHERE
	prj.pp_psgefszenario.idfrei = 0
;
SELECT intern.nimm__TLKommentarSicht( 'prj.zeige__pp_psgefszenario'
, ARRAY[
  'id'
, 'notizen'
, 'prj_personen_id'
, 'prj_projekte_id'
, 'ps_gefszenario_id'
, 'spr_uebvar_id'
, 'spr_uebvar_id_reprgefszen'
, 'spr_uebvar_id_ursp'
] 
, ARRAY[
  E'siehe \\texttt{prj.pp_psgefszenario.id}'
, E'siehe \\texttt{prj.pp_psgefszenario.notizen}'
, E'siehe \\texttt{prj.pp_psgefszenario.prj_personen_id}'
, E'siehe \\texttt{prj.pp_psgefszenario.prj_projekte_id}'
, E'siehe \\texttt{prj.pp_psgefszenario.ps_gefszenario_id}'
, E'siehe \\texttt{prj.pp_psgefszenario.spr_uebvar_id}'
, E'siehe \\texttt{prj.pp_psgefszenario.spr_uebvar_id_reprgefszen}'
, E'siehe \\texttt{prj.pp_psgefszenario.spr_uebvar_id_ursp}'
], 
E'Es werden die projektspezifischen Gefahrenszenarien angezeigt (siehe \\texttt{prj.pp_psgefszenario}).' );
--
-- Standardverhalten:
-- ..................
--
--SELECT * FROM prj.zeige__pp_psgefszenario;
--


-- ---------------------------------------------------------------------------------------
-- ---------------------------------------------------------------------------------------
--					--------------------------------------------------
--	prj.zeige__pl_prtdokdoku_le	--------------------------------------------------
--					--------------------------------------------------
-- ---------------------------------------------------------------------------------------
-- ---------------------------------------------------------------------------------------
DROP VIEW prj.zeige__pl_prtdokdoku_le;
CREATE OR REPLACE VIEW prj.zeige__pl_prtdokdoku_le
AS
  SELECT
	dokdoku.id AS prj__pl_prtdokdoku__id
	--
	-- Kontrolle
	--
--	, dokdoku.dok_doku_id
--	, dokdoku.prj_projekte_id
--	, dokdoku.prt_protokoll_id
--	, dokdoku.logdatuhrz
--	, dokdoku.logentfernt
  FROM
	prj.pl_prtdokdoku
		LEFT OUTER JOIN prj.pl_prtdokdoku AS dokdoku
			ON (
				prj.pl_prtdokdoku.dok_doku_id = dokdoku.dok_doku_id
			   AND
				prj.pl_prtdokdoku.prj_projekte_id = dokdoku.prj_projekte_id
			   AND
				prj.pl_prtdokdoku.prt_protokoll_id = dokdoku.prt_protokoll_id
			   AND
				prj.pl_prtdokdoku.idfrei = 0
			   AND
				dokdoku.idfrei = 0
			)
  GROUP BY
	  dokdoku.id
	, dokdoku.logdatuhrz
	--
	-- Kontrolle
	--
--	, dokdoku.dok_doku_id
--	, dokdoku.prj_projekte_id
--	, dokdoku.prt_protokoll_id
--	, dokdoku.logentfernt
  HAVING
	--
	-- Abfrage auf letzte nderung beschrnken 
	--
	max( prj.pl_prtdokdoku.logdatuhrz ) = dokdoku.logdatuhrz
  ORDER BY
	dokdoku.id
	--
	-- Kontrolle
	--
--	, dokdoku.prt_protokoll_id
--	, dokdoku.prj_projekte_id
--	, dokdoku.dok_doku_id
;
SELECT intern.nimm__TLKommentarSicht( 'prj.zeige__pl_prtdokdoku_le'
, ARRAY[
   'prj__pl_prtdokdoku__id'
] 
, ARRAY[
   E'siehe \\texttt{prj.pl_prtdokdoku.id}'
], 
E'Zu jeder Sicherheitsanforderung, Protokolleintrag, Terminplaneintrag (siehe Tabelle \\texttt{prt.protokoll}) werden unter Bercksichtigung  des Projektes \\texttt{prj.pl_prtdokdoku.id} die zugeordneten Dokumente (siehe \\texttt{dok.doku})  angezeigt (Logbuchfunktion).' );
--
-- Standardverhalten:
-- ..................
--
--SELECT * FROM prj.zeige__pl_prtdokdoku_le;



--
-- ---------------------------------------------------------------------------------------
-- ---------------------------------------------------------------------------------------
--					--------------------------------------------------
--	prj.zeige__pl_prtpsgefszenario	--------------------------------------------------
--					--------------------------------------------------
-- ---------------------------------------------------------------------------------------
-- ---------------------------------------------------------------------------------------
DROP VIEW prj.zeige__pl_prtpsgefszenario;
CREATE OR REPLACE VIEW prj.zeige__pl_prtpsgefszenario
AS
  SELECT DISTINCT
	  prj.pl_prtpsgefszenario.id
	, prj.pl_prtpsgefszenario.notizen
	, prj.pl_prtpsgefszenario.logdatuhrz
	, prj.pl_prtpsgefszenario.logdqok
	, prj.pl_prtpsgefszenario.logdquelle
	, prj.pl_prtpsgefszenario.logentfernt
	, prj.pl_prtpsgefszenario.logname
	, prj.pl_prtpsgefszenario.prj_projekte_id
	, prj.pl_prtpsgefszenario.prt_protokoll_id
	, prj.pl_prtpsgefszenario.ps_gefszenario_id
  FROM
	prj.pl_prtpsgefszenario
  WHERE
	prj.pl_prtpsgefszenario.idfrei = 0
;
SELECT intern.nimm__TLKommentarSicht( 'prj.zeige__pl_prtpsgefszenario'
, ARRAY[
  'id'
, 'notizen'
, 'logdatuhrz'
, 'logdqok'
, 'logdquelle'
, 'logentfernt'
, 'logname'
, 'prj_projekte_id'
, 'prt_protokoll_id'
, 'ps_gefszenario_id'
] 
, ARRAY[
  E'siehe \\texttt{prj.pl_prtpsgefszenario.id}'
, E'siehe \\texttt{prj.pl_prtpsgefszenario.notizen}'
, E'siehe \\texttt{prj.pl_prtpsgefszenario.logdatuhrz}'
, E'siehe \\texttt{prj.pl_prtpsgefszenario.logdqok}'
, E'siehe \\texttt{prj.pl_prtpsgefszenario.logdquelle}'
, E'siehe \\texttt{prj.pl_prtpsgefszenario.logentfernt}'
, E'siehe \\texttt{prj.pl_prtpsgefszenario.logname}'
, E'siehe \\texttt{prj.pl_prtpsgefszenario.prj_projekte_id}'
, E'siehe \\texttt{prj.pl_prtpsgefszenario.prt_protokoll_id}'
, E'siehe \\texttt{prj.pl_prtpsgefszenario.ps_gefszenario_id}'
], 
E'Es werden die projektspezifischen Sicherheitsanforderungen, Gefahrenprotokolleintrge bzw. Terminplaneintrge angezeigt (siehe \\texttt{prj.pl_prtpsgefszenario}).' );
--
-- Standardverhalten:
-- ..................
--
--SELECT * FROM prj.zeige__pl_prtpsgefszenario;


-- ---------------------------------------------------------------------------------------
-- ---------------------------------------------------------------------------------------
--					--------------------------------------------------
--	prj.zeige__ppl_dokdoku_le	--------------------------------------------------
--					--------------------------------------------------
-- ---------------------------------------------------------------------------------------
-- ---------------------------------------------------------------------------------------
DROP VIEW prj.zeige__ppl_dokdoku_le;
CREATE OR REPLACE VIEW prj.zeige__ppl_dokdoku_le
AS
  SELECT
	dokdoku.id AS prj__ppl_dokdoku__id
	--
	-- Kontrolle
	--
--	, dokdoku.dok_doku_id
--	, dokdoku.prj_projekte_id
--	, dokdoku.prj_personen_id
--	, dokdoku.logdatuhrz
--	, dokdoku.logentfernt
  FROM
	prj.ppl_dokdoku
		LEFT OUTER JOIN prj.ppl_dokdoku AS dokdoku
			ON (
				prj.ppl_dokdoku.dok_doku_id = dokdoku.dok_doku_id
			   AND
				prj.ppl_dokdoku.prj_projekte_id = dokdoku.prj_projekte_id
			   AND
				prj.ppl_dokdoku.idfrei = 0
			   AND
				dokdoku.idfrei = 0
			)
  GROUP BY
	  dokdoku.id
	, dokdoku.logdatuhrz
	--
	-- Kontrolle
	--
--	, dokdoku.dok_doku_id
--	, dokdoku.prj_projekte_id
--	, dokdoku.prj_personen_id
--	, dokdoku.logentfernt
  HAVING
	--
	-- Abfrage auf letzte nderung beschrnken 
	--
	max( prj.ppl_dokdoku.logdatuhrz ) = dokdoku.logdatuhrz
  ORDER BY
	dokdoku.id
	--
	-- Kontrolle
	--
--	, dokdoku.dok_doku_id
--	, dokdoku.prj_projekte_id
--	, dokdoku.prj_personen_id
;
SELECT intern.nimm__TLKommentarSicht( 'prj.zeige__ppl_dokdoku_le'
, ARRAY[
   'prj__ppl_dokdoku__id'
] 
, ARRAY[
   E'siehe \\texttt{prj.ppl_dokdoku.id}'
], 
E'Zu jedem in der Tabelle \\texttt{prj.ppl_dokdoku} enthaltenen Dokument wird unter Bercksichtigung des Projektes die Identifikationsnummer  \\texttt{prj.ppl_dokdoku.id} des Ansprechpartners (ggf. der verantw. Person) angezeigt (Logbuchfunktion).' );
--
-- Standardverhalten:
-- ..................
--
--SELECT * FROM prj.zeige__ppl_dokdoku_le;
--



--
-- ---------------------------------------------------------------------------------------
-- ---------------------------------------------------------------------------------------
--						------------------------------------------
--	prj.zeige__pl_prtpsgefszenario_le	------------------------------------------
--						------------------------------------------
-- ---------------------------------------------------------------------------------------
-- ---------------------------------------------------------------------------------------
--DROP VIEW prj.zeige__pl_prtpsgefszenario_le;
CREATE OR REPLACE VIEW prj.zeige__pl_prtpsgefszenario_le
AS
  SELECT
	gefprot.id AS prj__pl_prtpsgefszenario__id
	--
	-- Kontrolle
	--
--	, gefprot.logdatuhrz
--	, gefprot.logentfernt AS prj__pl_prtpsgefszenario__logentfernt
--	, gefprot.prj_projekte_id
--	, gefprot.ps_gefszenario_id
  FROM
	prj.pl_prtpsgefszenario
		LEFT OUTER JOIN prj.pl_prtpsgefszenario AS gefprot
			ON (
				prj.pl_prtpsgefszenario.ps_gefszenario_id = gefprot.ps_gefszenario_id
			   AND
				prj.pl_prtpsgefszenario.prj_projekte_id = gefprot.prj_projekte_id
			   AND
				prj.pl_prtpsgefszenario.prt_protokoll_id = gefprot.prt_protokoll_id
			   AND
				prj.pl_prtpsgefszenario.idfrei = 0
			   AND
				gefprot.idfrei = 0
			)
  GROUP BY
	gefprot.id
	, gefprot.logdatuhrz
	--
	-- Kontrolle
	--
--	, gefprot.logentfernt
--	, gefprot.prj_projekte_id
--	, gefprot.ps_gefszenario_id
  HAVING
	--
	-- Abfrage auf letzte nderung beschrnken 
	--
	max( prj.pl_prtpsgefszenario.logdatuhrz ) = gefprot.logdatuhrz
  ORDER BY
	gefprot.id
;
SELECT intern.nimm__TLKommentarSicht( 'prj.zeige__pl_prtpsgefszenario_le'
, ARRAY[
  'prj__pl_prtpsgefszenario__id'
] 
, ARRAY[
  E'siehe \\texttt{prj.pl_prtpsgefszenario.id}'
], 
E'Zu jedem in der Tabelle \\texttt{prj.pl_prtpsgefszenario} enthaltenen Aspekt wird der jeweils letzte zugeordnete in \\texttt{ps} verwendete Protokolleintrag angezeigt (Logbuchfunktion). Die unterschiedlichen Aspekte, zu denen das Logbuch gefhrt wird, werden anhand der Spalten \\texttt{prj.pl_prtpsgefszenario.prj_projekte_id, prj.pl_prtpsgefszenario.prt_protokoll_id, prj.pl_prtpsgefszenario.ps_gefszenario_id} unterschieden.' );
--
-- Standardverhalten:
-- ..................
--
--SELECT * FROM prj.zeige__pl_prtpsgefszenario_le;
--


-- ---------------------------------------------------------------------------------------
-- ---------------------------------------------------------------------------------------
--				----------------------------------------------------------
--	prj.zeige__prtprotokoll	----------------------------------------------------------
--				----------------------------------------------------------
-- ---------------------------------------------------------------------------------------
-- ---------------------------------------------------------------------------------------
DROP VIEW prj.zeige__prtprotokoll;
CREATE OR REPLACE VIEW prj.zeige__prtprotokoll
AS
  SELECT DISTINCT
	--
	-- --	prt.typ	------------------------------------------------------------------
	--
	prt.typ.id AS prt__typ__id
	, prt.typ.notizen AS prt__typ__notizen
	, prt.typ.aspekt AS prt__typ__aspekt
	, prt.typ.spr_uebvar_id AS prt__typ__spr_uebvar_id
	--
	-- --	prt.protokoll	----------------------------------------------------------
	--
	, prt.protokoll.id AS prt__protokoll__id
	, prt.protokoll.notizen AS prt__protokoll__notizen
	--
	-- --	prj.pp_prtprotokoll	--------------------------------------------------
	--
	, prj.pp_prtprotokoll.id AS prj__pp_prtprotokoll__id
	, prj.pp_prtprotokoll.notizen AS prj__pp_prtprotokoll__notizen
	, prj.pp_prtprotokoll.datuhrz AS prj__pp_prtprotokoll__datuhrz
	, prj.pp_prtprotokoll.duanfrage AS prj__pp_prtprotokoll__duanfrage
	, prj.pp_prtprotokoll.erledigt AS prj__pp_prtprotokoll__erledigt
	, prj.pp_prtprotokoll.intern AS prj__pp_prtprotokoll__intern
	, prj.pp_prtprotokoll.prj_personen_id AS prj__pp_prtprotokoll__prj_personen_id
	, prj.pp_prtprotokoll.prj_projekte_id AS prj__pp_prtprotokoll__prj_projekte_id
	, prj.pp_prtprotokoll.spr_uebvar_id AS prj__pp_prtprotokoll__spr_uebvar_id
	, prj.pp_prtprotokoll.teilnehmer AS prj__pp_prtprotokoll__teilnehmer
	, prj.pp_prtprotokoll.termin AS prj__pp_prtprotokoll__termin
  FROM
	prt.typ
	, prt.protokoll
	, prj.pp_prtprotokoll
  WHERE
	prt.typ.id = prt.protokoll.prt_typ_id
  AND
	prt.protokoll.idfrei = 0
  AND
	prt.protokoll.id = prj.pp_prtprotokoll.prt_protokoll_id
  AND
	prj.pp_prtprotokoll.idfrei = 0
;
SELECT intern.nimm__TLKommentarSicht( 'prj.zeige__prtprotokoll'
, ARRAY[
  'prt__typ__id'
, 'prt__typ__notizen'
, 'prt__typ__aspekt'
, 'prt__typ__spr_uebvar_id'
, 'prt__protokoll__id'
, 'prt__protokoll__notizen'
, 'prj__pp_prtprotokoll__id'
, 'prj__pp_prtprotokoll__notizen'
, 'prj__pp_proto
koll__datuhrz'
, 'prj__pp_prtprotokoll__duanfrage'
, 'prj__pp_prtprotokoll__erledigt'
, 'prj__pp_prtprotokoll__intern'
, 'prj__pp_prtprotokoll__prj_personen_id'
, 'prj__pp_prtprotokoll__prj_projekte_id'
, 'prj__pp_prtprotokoll__spr_uebvar_id'
, 'prj__pp_prtprotokoll__teilnehmer'
, 'prj__pp_prtprotokoll__termin'
] 
, ARRAY[
  E'siehe \\texttt{prt.typ.id}'
, E'siehe \\texttt{prt.typ.notizen}'
, E'siehe \\texttt{prt.typ.aspekt}'
, E'siehe \\texttt{prt.typ.spr_uebvar_id}'
, E'siehe \\texttt{prt.protokoll.id}'
, E'siehe \\texttt{prt.protokoll.notizen}'
, E'siehe \\texttt{prj.pp_prtprotokoll.id}'
, E'siehe \\texttt{prj.pp_prtprotokoll.notizen}'
, E'siehe \\texttt{prj.pp_prtprotokoll.datuhrz}'
, E'siehe \\texttt{prj.pp_prtprotokoll.duanfrage}'
, E'siehe \\texttt{prj.pp_prtprotokoll.erledigt}'
, E'siehe \\texttt{prj.pp_prtprotokoll.intern}'
, E'siehe \\texttt{prj.pp_prtprotokoll.prj_personen_id}'
, E'siehe \\texttt{prj.pp_prtprotokoll.prj_projekte_id}'
, E'siehe \\texttt{prj.pp_prtprotokoll.spr_uebvar_id}'
, E'siehe \\texttt{prj.pp_prtprotokoll.teilnehmer}'
, E'siehe \\texttt{prj.pp_prtprotokoll.termin}'
], 
E'Es werden die projektspezifischen Sicherheitsanforderungen, Gefahrenprotokolleintrge und Terminplaneintrge angezeigt (siehe \\texttt{prj.pp_prtprotokoll}).' );
--
-- Standardverhalten:
-- ..................
--
--SELECT * FROM prj.zeige__prtprotokoll;
--


-- ---------------------------------------------------------------------------------------
-- ---------------------------------------------------------------------------------------
--					--------------------------------------------------
--	prj.zeige__prtprotokolltabellen	--------------------------------------------------
--					--------------------------------------------------
-- ---------------------------------------------------------------------------------------
-- ---------------------------------------------------------------------------------------
DROP VIEW prj.zeige__prtprotokolltabellen;
CREATE OR REPLACE VIEW prj.zeige__prtprotokolltabellen
AS
  --
  -- projektabhngige Daten auslesen
  --
  SELECT
	--
	-- --	prt.protokoll	----------------------------------------------------------
	--
	prt.protokoll.id AS prt__protokoll__id
	--
	-- --	prj.p_prtstrstrkt	----------------------------------------------------------
	--
	, prj.p_prtstrstrkt.id AS prj__p_prtstrstrkt__id
	, prj.p_prtstrstrkt.notizen AS prj__p_prtstrstrkt__notizen
	, prj.p_prtstrstrkt.prj_projekte_id AS prj__p_prtstrstrkt__prj_projekte_id
	, prj.p_prtstrstrkt.str_strkt_id AS prj__p_prtstrstrkt__str_strkt_id
	--
	-- --	prj.p_prtverbindung	----------------------------------------------------------
	--
	, prj.p_prtverbindung.id AS prj__p_prtverbindung__id
	, prj.p_prtverbindung.notizen AS prj__p_prtverbindung__notizen
	, prj.p_prtverbindung.prj_projekte_id AS prj__p_prtverbindung__prj_projekte_id
	, prj.p_prtverbindung.prt_protokoll_id_vorg AS prj__p_prtverbindung__prt_protokoll_id_vorg
  FROM
	prt.protokoll	LEFT OUTER JOIN prj.p_prtstrstrkt ON ( 
					prt.protokoll.id = prj.p_prtstrstrkt.prt_protokoll_id 
					AND prj.p_prtstrstrkt.idfrei = 0 )
			LEFT OUTER JOIN prj.p_prtverbindung ON (
			     	   	prt.protokoll.id = prj.p_prtverbindung.prt_protokoll_id_nachf
					AND prj.p_prtverbindung.idfrei = 0 )
  WHERE
	prt.protokoll.idfrei = 0
;
SELECT intern.nimm__TLKommentarSicht( 'prj.zeige__prtprotokolltabellen'
, ARRAY[
  'prt__protokoll__id'
, 'prj__p_prtstrstrkt__id'
, 'prj__p_prtstrstrkt__notizen'
, 'prj__p_prtstrstrkt__prj_projekte_id'
, 'prj__p_prtstrstrkt__str_strkt_id'
, 'prj__p_prtverbindung__id'
, 'prj__p_prtverbindung__notizen'
, 'prj__p_prtverbindung__prj_projekte_id'
, 'prj__p_prtverbindung__prt_protokoll_id_vorg'
] 
, ARRAY[
  E'siehe \\texttt{prt.protokoll.id} bzw. \\texttt{prj.p_prtverbindung.prt_protokoll_id_nachf}'
, E'siehe \\texttt{prj.p_prtstrstrkt.id}'
, E'siehe \\texttt{prj.p_prtstrstrkt.notizen}'
, E'siehe \\texttt{prj.p_prtstrstrkt.prj_projekte_id}'
, E'siehe \\texttt{prj.p_prtstrstrkt.str_strkt_id}'
, E'siehe \\texttt{prj.p_prtverbindung.id}'
, E'siehe \\texttt{prj.p_prtverbindung.notizen}'
, E'siehe \\texttt{prj.p_prtverbindung.prj_projekte_id}'
, E'siehe \\texttt{prj.p_prtverbindung.prt_protokoll_id_vorg}'
], 
E'Es werden die projektspezifischen Zusatzinformationen (siehe \\texttt{prj.p_prtstrstrkt}, \\texttt{prj.p_prtverbindung}) zu den Sicherheitsanforderungen, Gefahrenprotkolleintrgen bzw. Terminplaneintrge angezeigt.' );
--
-- Standardverhalten:
-- ..................
--
--SELECT * FROM prj.zeige__prtprotokolltabellen;
--


-- ---------------------------------------------------------------------------------------
-- ---------------------------------------------------------------------------------------
--					--------------------------------------------------
--	prj.zeige__psabk		--------------------------------------------------
--					--------------------------------------------------
-- ---------------------------------------------------------------------------------------
-- ---------------------------------------------------------------------------------------
DROP VIEW prj.zeige__psabk;
CREATE OR REPLACE VIEW prj.zeige__psabk
AS
  --
  -- projektabhngige Daten auslesen
  --
  SELECT
	--
	-- --	ps.abk	------------------------------------------------------------------
	--
	ps.abk.id AS ps__abk__id
	, ps.abk.notizen AS ps__abk__notizen
	, ps.abk.typ AS ps__abk__typ
	--
	-- --	prj.p_psabk	----------------------------------------------------------
	--
	, prj.p_psabk.id AS prj__p_psabk__id
	, prj.p_psabk.notizen AS prj__p_psabk__notizen
	, prj.p_psabk.prj_projekte_id AS prj__p_psabk__prj_projekte_id
	, prj.p_psabk.spr_uebvar_id AS prj__p_psabk__spr_uebvar_id
	, prj.p_psabk.spr_uebvar_id_l AS prj__p_psabk__spr_uebvar_id_l
	, prj.p_psabk.spr_uebvar_id_zus AS prj__p_psabk__spr_uebvar_id_zus
  FROM
	ps.abk
	, prj.p_psabk
  WHERE
	ps.abk.id = prj.p_psabk.ps_abk_id
  AND
	ps.abk.idfrei = 0
  AND
	prj.p_psabk.idfrei = 0
;
SELECT intern.nimm__TLKommentarSicht( 'prj.zeige__psabk'
, ARRAY[
  'ps__abk__id'
, 'ps__abk__notizen'
, 'ps__abk__typ'
, 'prj__p_psabk__id'
, 'prj__p_psabk__notizen'
, 'prj__p_psabk__prj_projekte_id'
, 'prj__p_psabk__spr_uebvar_id'
, 'prj__p_psabk__spr_uebvar_id_l'
, 'prj__p_psabk__spr_uebvar_id_zus'
] 
, ARRAY[
  E'siehe \\texttt{ps.abk.id}'
, E'siehe \\texttt{ps.abk.notizen}'
, E'siehe \\texttt{ps.abk.typ}'
, E'siehe \\texttt{prj.p_psabk.id}'
, E'siehe \\texttt{prj.p_psabk.notizen}'
, E'siehe \\texttt{prj.p_psabk.prj_projekte_id}'
, E'siehe \\texttt{prj.p_psabk.spr_uebvar_id}'
, E'siehe \\texttt{prj.p_psabk.spr_uebvar_id_l}'
, E'siehe \\texttt{prj.p_psabk.spr_uebvar_id_zus}'
], 
E'Es werden die projektspezifischen (siehe \\texttt{prj.p_psabk}) Abkrzungen angezeigt.' );
--
-- Standardverhalten:
-- ..................
--
--SELECT * FROM prj.zeige__psabk;
--


-- ---------------------------------------------------------------------------------------
-- ---------------------------------------------------------------------------------------
--				----------------------------------------------------------
--	prj.zeige__strstrkt	----------------------------------------------------------
--				----------------------------------------------------------
-- ---------------------------------------------------------------------------------------
-- ---------------------------------------------------------------------------------------
DROP VIEW prj.zeige__strstrkt;
CREATE OR REPLACE VIEW prj.zeige__strstrkt
AS
  --
  -- projektabhngige Daten auslesen
  --
  SELECT
	--
	-- --	str.name	----------------------------------------------------------
	--
	str.name.id AS str__name__id
	, str.name.name AS str__name__name
	, str.name.name_k AS str__name__name_k
	, str.name.notizen AS str__name__notizen
	--
	-- --	str.strkt	----------------------------------------------------------
	--
	, str.strkt.id AS str__strkt__id
	, str.strkt.notizen AS str__strkt__notizen
	, str.strkt.nr AS str__strkt__nr
	--
	-- --	prj.pp_strstrkt	--------------------------------------------------
	--
	, prj.pp_strstrkt.id AS prj__pp_strstrkt__id
	, prj.pp_strstrkt.notizen AS prj__pp_strstrkt__notizen
	, prj.pp_strstrkt.fbereignis AS prj__pp_strstrkt__fbereignis
	, prj.pp_strstrkt.prj_personen_id AS prj__pp_strstrkt__prj_personen_id
	, prj.pp_strstrkt.prj_projekte_id AS prj_projekte_id
	, prj.pp_strstrkt.spr_uebvar_id AS prj__pp_strstrkt__spr_uebvar_id
	--
	-- --	prj.p_strverbindung	--------------------------------------------------
	--
	, prj.p_strverbindung.id AS prj__p_strverbindung__id
	, prj.p_strverbindung.notizen AS prj__p_strverbindung__notizen
	, prj.p_strverbindung.fbtor AS prj__p_strverbindung__fbtor
	, prj.p_strverbindung.str_strkt_id_nachf AS prj__p_strverbindung__str_strkt_id_nachf
  FROM
	str.name
	, str.strkt
	, prj.pp_strstrkt
		--
		-- prj.p_strverbindung
		--
		LEFT OUTER JOIN prj.p_strverbindung ON (
		     	prj.pp_strstrkt.str_strkt_id = prj.p_strverbindung.str_strkt_id_vorg
		     AND
		        prj.pp_strstrkt.prj_projekte_id = prj.p_strverbindung.prj_projekte_id
		     AND
			prj.p_strverbindung.idfrei = 0 )
  WHERE
	str.name.id = str.strkt.str_name_id
  AND
	str.strkt.id = prj.pp_strstrkt.str_strkt_id
  AND
	str.name.idfrei = 0
  AND
	str.strkt.idfrei = 0
  AND
	prj.pp_strstrkt.idfrei = 0
;
SELECT intern.nimm__TLKommentarSicht( 'prj.zeige__strstrkt'
, ARRAY[
  'str__name__id'
, 'str__name__name'
, 'str__name__name_k'
, 'str__name__notizen'
, 'str__strkt__id'
, 'str__strkt__notizen'
, 'str__strkt__nr'
, 'prj__pp_strstrkt__id'
, 'prj__pp_strstrkt__notizen'
, 'prj__pp_strstrkt__fbereignis'
, 'prj__pp_strstrkt__prj_personen_id'
, 'prj_projekte_id'
, 'prj__pp_strstrkt__spr_uebvar_id'
, 'prj__p_strverbindung__id'
, 'prj__p_strverbindung__notizen'
, 'prj__p_strverbindung__fbtor'
, 'prj__p_strverbindung__str_strkt_id_nachf'
] 
, ARRAY[
  E'siehe \\texttt{str.name.id}'
, E'siehe \\texttt{str.name.name}'
, E'siehe \\texttt{str.name.name_k}'
, E'siehe \\texttt{str.name.notizen}'
, E'siehe \\texttt{str.strkt.id}'
, E'siehe \\texttt{str.strkt.notizen}'
, E'siehe \\texttt{str.strkt.nr}'
, E'siehe \\texttt{prj.pp_strstrkt.id UND prj.p_strverbindung.str_strkt_id_vorg}'
, E'siehe \\texttt{prj.pp_strstrkt.notizen}'
, E'siehe \\texttt{prj.pp_strstrkt.fbereignis}'
, E'siehe \\texttt{prj.pp_strstrkt.prj_personen_id}'
, E'siehe \\texttt{prj.pp_strstrkt.prj_projekte_id UND prj.p_strverbindung.prj_projekte_id}'
, E'siehe \\texttt{prj.pp_strstrkt.spr_uebvar_id}'
, E'siehe \\texttt{prj.p_strverbindung.id}'
, E'siehe \\texttt{prj.p_strverbindung.notizen}'
, E'siehe \\texttt{prj.p_strverbindung.fbtor}'
, E'siehe \\texttt{prj.p_strverbindung.str_strkt_id_nachf}'
], 
E'Es werden die projektbergreifend gltigen (siehe \\texttt{str.name}, \\texttt{str.strkt}) und die projektspezifischen Strukturpunkte (siehe \\texttt{prj.pp_strstrkt}, \\texttt{prj.p_strverbindung}) angezeigt.' );
--
-- Standardverhalten:
-- ..................
--
--SELECT * FROM prj.zeige__strstrkt;
--



-- ---------------------------------------------------------------------------------------
-- ---------------------------------------------------------------------------------------
-- ---------------------------------------------------------------------------------------
--			------------------------------------------------------------------
-- prt - Protokoll	------------------------------------------------------------------
--			------------------------------------------------------------------
-- ---------------------------------------------------------------------------------------
-- ---------------------------------------------------------------------------------------
-- ---------------------------------------------------------------------------------------



-- ---------------------------------------------------------------------------------------
-- ---------------------------------------------------------------------------------------
-- ---------------------------------------------------------------------------------------
--				----------------------------------------------------------
-- ps - Produktsicherheit	----------------------------------------------------------
--				----------------------------------------------------------
-- ---------------------------------------------------------------------------------------
-- ---------------------------------------------------------------------------------------
-- ---------------------------------------------------------------------------------------

-- ---------------------------------------------------------------------------------------
-- ---------------------------------------------------------------------------------------
--					--------------------------------------------------
--	ps.zeige__risikomatrix_en50126	--------------------------------------------------
--					--------------------------------------------------
-- ---------------------------------------------------------------------------------------
-- ---------------------------------------------------------------------------------------
DROP VIEW ps.zeige__risikomatrix_en50126;
CREATE OR REPLACE VIEW ps.zeige__risikomatrix_en50126
AS
  --
  -- 
  --
  SELECT DISTINCT
	hfg.id AS ps__abk__id_hfg
	, gefstufe.id AS ps__abk__id_gstufe
	, rstufe.id AS ps__abk__id_rstufe
  FROM
	ps.abk AS hfg
		--
		-- Gefahrenstufe
		--
		LEFT OUTER JOIN ps.abk AS gefstufe ON ( gefstufe.typ = 'RG' )
		--
		-- Risikostufe
		--
		LEFT OUTER JOIN ps.abk AS rstufe ON ( rstufe.typ = 'RR' )
  WHERE
	--
	-- Hufigkeit
	--
	hfg.typ = 'RH'
  AND (
	--
	-- Risikostufe: intolerabel
	--
	( hfg.id = 7 AND gefstufe.id IN( 15, 14, 13 ) AND rstufe.id = 17 )
	OR
	( hfg.id = 8 AND gefstufe.id IN( 14, 13 ) AND rstufe.id = 17 )
	OR
	( hfg.id = 9 AND gefstufe.id = 13 AND rstufe.id = 17 )
	--
	-- Risikostufe: unerwnscht
	--
	OR
	( hfg.id = 7 AND gefstufe.id = 16 AND rstufe.id = 18 )
	OR
	( hfg.id IN( 8, 9 ) AND gefstufe.id = 15 AND rstufe.id = 18 )
	OR
	( hfg.id IN( 9, 10 ) AND gefstufe.id = 14 AND rstufe.id = 18 )
	OR
	( hfg.id = 10 AND gefstufe.id = 13 AND rstufe.id = 18 )
	--
	-- Risikostufe: tolerabel
	--
	OR
	( hfg.id IN( 8, 9 ) AND gefstufe.id = 16 AND rstufe.id = 19 )
	OR
	( hfg.id = 10 AND gefstufe.id = 15 AND rstufe.id = 19 )
	OR
	( hfg.id = 11 AND gefstufe.id IN( 14, 13 ) AND rstufe.id = 19 )
	--
	-- Risikostufe: vernachlssigbar
	--
	OR
	( hfg.id = 10 AND gefstufe.id = 16 AND rstufe.id = 20 )
	OR
	( hfg.id = 11 AND gefstufe.id IN( 16, 15 ) AND rstufe.id = 20 )
	OR
	( hfg.id = 12 AND gefstufe.id IN( 16, 15, 14, 13 ) AND rstufe.id = 20 )
  )
;
SELECT intern.nimm__TLKommentarSicht( 'ps.zeige__risikomatrix_en50126'
, ARRAY[
  'ps__abk__id_hfg'
, 'ps__abk__id_gstufe'
, 'ps__abk__id_rstufe'
] 
, ARRAY[
  E'siehe \\texttt{ps.abk.id} der Hufigkeit des Gefahrenszenarios'
, E'siehe \\texttt{ps.abk.id} der Auswirkung des Gefahrenszenarios (Gefahrenstufe)'
, E'siehe \\texttt{ps.abk.id} der Risikobewerttung des Gefahrenszenarios (Risikostufe)'
], 
E'Es werden die Identifikationsnummern der Abkrzungen \\texttt{ps.abk.id} zur Risikobewertung nach EN~50~126-1 ausgelesen.' );
--
-- Standardverhalten:
-- ..................
--
--SELECT * FROM ps.zeige__risikomatrix_en50126;
--





-- ---------------------------------------------------------------------------------------
-- ---------------------------------------------------------------------------------------
-- ---------------------------------------------------------------------------------------
--			------------------------------------------------------------------
-- spr - Sprachen	------------------------------------------------------------------
--			------------------------------------------------------------------
-- ---------------------------------------------------------------------------------------
-- ---------------------------------------------------------------------------------------
-- ---------------------------------------------------------------------------------------

-- ---------------------------------------------------------------------------------------
-- ---------------------------------------------------------------------------------------
--				----------------------------------------------------------
--	spr.zeige__wgelemente	----------------------------------------------------------
--				----------------------------------------------------------
-- ---------------------------------------------------------------------------------------
-- ---------------------------------------------------------------------------------------
CREATE OR REPLACE VIEW spr.zeige__wgelemente
AS
	SELECT
		spr.uebersetzung.id AS spr_uebersetzung_id
		, spr.uebersetzung.spr_uebvar_id
		, spr.uebersetzung.spr_sprachen_id
		, spr.uebersetzung.spr_wgruppe_id
		, CASE WHEN( spr.pos.intern_abczk_id = 0 ) 
			THEN intern.restzk.restzk 
			ELSE intern.abczk.abczk 
			END AS wgelement
	FROM
		spr.uebersetzung, spr.pos, spr.wgruppe, intern.abczk, intern.restzk
	WHERE
	--
	-- gelschte Werte drfen nicht verwendet werden
	--
		spr.wgruppe.idfrei = 0
	AND
		spr.uebersetzung.idfrei = 0
	AND
		spr.pos.idfrei = 0
	AND
		intern.abczk.idfrei = 0
	AND
		intern.restzk.idfrei = 0
	--
	-- Fremdschlsselbeziehungen auswerten
	--
	AND
		spr.uebersetzung.spr_wgruppe_id = spr.wgruppe.id
	AND
		spr.pos.spr_wgruppe_id = spr.wgruppe.id
	AND
		spr.pos.intern_abczk_id = intern.abczk.id
	AND
		spr.pos.intern_restzk_id = intern.restzk.id
	ORDER BY
		spr.uebersetzung.spr_uebvar_id
		, spr.uebersetzung.spr_sprachen_id
		, spr.pos.id
	;
SELECT intern.nimm__TLKommentarSicht( 'spr.zeige__wgelemente'
, ARRAY[
  'spr_uebersetzung_id'
, 'spr_uebvar_id'
, 'spr_sprachen_id'
, 'spr_wgruppe_id'
, 'wgelement'
] 
, ARRAY[
  E'siehe \\texttt{spr.uebersetzung.id}'
, E'siehe \\texttt{spr.uebvar.id}'
, E'siehe \\texttt{spr.sprachen.id}'
, E'siehe \\texttt{spr.wgruppe.id}'
, E'siehe \\texttt{intern.abczk.id ODER intern.restzk.id}'
], 
'Es werden die Elemente der Wortgruppen zurckgegeben.' );
--
-- Standardverhalten:
-- ..................
--
--SELECT * FROM spr.zeige__wgelemente;
--



-- ---------------------------------------------------------------------------------------
-- ---------------------------------------------------------------------------------------
--				----------------------------------------------------------
--	spr.zeige__wgruppe	----------------------------------------------------------
--				----------------------------------------------------------
-- ---------------------------------------------------------------------------------------
-- ---------------------------------------------------------------------------------------
DROP VIEW spr.zeige__wgruppe;
CREATE OR REPLACE VIEW spr.zeige__wgruppe
AS
	SELECT
		 max( spr_uebvar_id ) AS spr_uebvar_id
		, max( spr_sprachen_id ) AS spr_sprachen_id
		, spr_wgruppe_id
		, intern.aggregat__zk( wgelement ) AS wgruppe
	FROM
		spr.zeige__wgelemente
	GROUP BY 
		spr_wgruppe_id 
	ORDER BY
		spr_uebvar_id
		, spr_sprachen_id
		, spr_wgruppe_id;
SELECT intern.nimm__TLKommentarSicht( 'spr.zeige__wgruppe'
, ARRAY[
 'spr_uebvar_id'
, 'spr_sprachen_id'
, 'spr_wgruppe_id'
, 'wgelement'
] 
, ARRAY[
E'siehe \\texttt{spr.zeige__wgelemente.spr_uebvar_id}'
, E'siehe \\texttt{spr.zeige__wgelemente.spr_sprachen_id}'
, E'siehe \\texttt{spr.zeige__wgelemente.spr_wgruppe_id}'
, E'siehe \\texttt{spr.zeige__wgelemente.wgelement}'
], 
'Es werden die vollstndigen Wortgruppen zurckgegeben.' );
--
-- Standardverhalten:
-- ..................
--
--SELECT * FROM spr.zeige__wgruppe;
--




-- ---------------------------------------------------------------------------------------
-- ---------------------------------------------------------------------------------------
-- ---------------------------------------------------------------------------------------
--			------------------------------------------------------------------
-- str - Strukturen	------------------------------------------------------------------
--			------------------------------------------------------------------
-- ---------------------------------------------------------------------------------------
-- ---------------------------------------------------------------------------------------
-- ---------------------------------------------------------------------------------------
