--
--
--
--    filename:	dbstruktur-tabellen.sql
--
--    version:	1.3
--
--    Definition des Datenbankmodells 'Virtuelles Fahrzeug' - vf
--    > Schemas, Tabellen, Schlssel, Bedingungen <
--
--
--
-- ----------------------------------------------------------------------------------------
--
--
--    Copyright (C) 2007-2011  Michael Bellair
--
--    This program is free software: you can redistribute it and/or modify
--    it under the terms of the GNU General Public License as published by
--    the Free Software Foundation, either version 3 of the License, or
--    (at your option) any later version.
--
--    This program is distributed in the hope that it will be useful,
--    but WITHOUT ANY WARRANTY; without even the implied warranty of
--    MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
--    GNU General Public License for more details.
--
--    You should have received a copy of the GNU General Public License
--    along with this program.  If not, see <http://www.gnu.org/licenses/>.
--
--    Michael Bellair
--    Sportplatzstrasse 11
--    01259 Dresden
--
--    E-Mail:	bellair@freenet.de
--    homepage:	http://vf.michaelbellair.de/index.html
--
--
-- ----------------------------------------------------------------------------------------
--


-- ---------------------------------------------------------------------------------------
-- ---------------------------------------------------------------------------------------
-- ---------------------------------------------------------------------------------------
--
-- Offene Punkte / Aufgaben
--
-- ---------------------------------------------------------------------------------------
-- ---------------------------------------------------------------------------------------
-- ---------------------------------------------------------------------------------------
--
--
-- -> Plausibilittsprfung der zul. Verbindungen zwischen Protokolleintrgen in >prj.nimm__tabwerte()< implementieren ?
--
--
--
--







-- ---------------------------------------------------------------------------------------
-- ---------------------------------------------------------------------------------------
-- ---------------------------------------------------------------------------------------
--
-- Hinweise zur Zuordnung von Vorgabewerten - siehe Abschn. 2 'Das Datenbankmodell' 
--  der DB-Dokumentation
--
-- ---------------------------------------------------------------------------------------
-- ---------------------------------------------------------------------------------------
-- ---------------------------------------------------------------------------------------



-- ---------------------------------------------------------------------------------------
-- ---------------------------------------------------------------------------------------
--
-- 1.) Kommentar der Datenbank setzen
--
-- ---------------------------------------------------------------------------------------
-- ---------------------------------------------------------------------------------------
SELECT intern.nimm__TLKommentar( 'DATABASE vf', E'Innerhalb eines Schemas knnen die Tabellen aufeinander referenzieren (Fremdschlssel), wobei keine Kreisreferenz (Zirkelbezug) angewendet wird.\\\\
Unter dieser Vorraussetzung sind stets Tabellen vorhanden
\\begin{itemize}
  \\item auf die referenziert wird und die selbst {\\bf nicht} auf eine weitere Tabelle verweisen (Referenztabellen),
  \\item auf die {\\bf nicht} referenziert wird und die selbst auf Referenztabellen verweisen (Konsumtabellen),
  \\item auf die referenziert wird und die selbst auf Referenztabellen verweisen (RefKonTabellen) und
  \\item auf die {\\bf nicht} referenziert wird und die selbst {\\bf nicht} auf Referenztabellen verweisen (Trivialtabellen).
\\end{itemize}
Zur Darstellung der Datenbankstruktur (Abhngigkeiten der Tabellen) werden Konsumtabellen am rechten Rand (rechte Spalte), Referenztabellen am linken Rand (linke Spalte) und RefKonTabellen in den dazwischenliegenden Spalten angeordnet.\\\\
Sollte eine RefKonTabelle aus mehreren Spalten referenziert werden, so wird sie so weit wie mglich nach Links verschoben.
\\\\
\\\\
Die Sortierfolge der Tabellen in einer Spalte erfolgt lexikalisch.
\\\\
Die Sortierfolge der Spalten einer Tabelle erfolgt ebenfalls lexikalisch, ausgenommen die Spalten \\texttt{id}, \\texttt{idfrei} und \\texttt{notizen}.\\\\
Die Spalte \\texttt{id} ist stets die erste, \\texttt{idfrei} die zweite und \\texttt{notizen} die dritte Spalte einer Tabelle.
\\\\
\\\\
Als Datenbankmanagementsystem kommt PostgreSQL zum Einsatz.
\\\\
Unter der Vorraussetzung, da der Benutzer \\texttt{micha} angelegt ist, kann die Datenbank \\texttt{vf} vom Benutzer \\texttt{micha (-U)} fr den Eigentmer \\texttt{micha (-O)} mit der Zeichensatzcodierung \\texttt{MULE_INTERNAL} mittels Postgres-Befehl
\\begin{verbatim}
createdb -U micha -O micha -E MULE_INTERNAL vf ''Datenbank des Virtuellen Fahrzeugs''
\\end{verbatim}
angelegt werden.
\\\\
Die aktuell gltigen Versionen der Datenbank lauten
\\begin{verbatim}
createdb -U micha -O micha -E MULE_INTERNAL vf_1_0 ''Freigegebene, nicht mehr vernderliche Version der Datenbank des Virtuellen Fahrzeugs''
createdb -U micha -O micha -E MULE_INTERNAL vf_1_1 ''Aktuelle Entwicklerversion der Datenbank des Virtuellen Fahrzeugs''
\\end{verbatim}

\\noindent Innerhalb des Datenbankmodells gelten die folgenden allgemeinen Konzepte:
\\begin{itemize}
  \\item Aus dem Schema \\texttt{intern} darf auf keine Tabellen eines anderen Schemas referenziert werden. Auf das Schema \\texttt{prj} darf aus keinem anderen Schema referenziert werden.
  \\item Alle Spalten (neben \\texttt{id} und \\texttt{idfrei} aus \\texttt{intern.alle}) welche mittels Fremdschlssel auf andere Tabellen verweisen, mssen mit einem Vorgabewert (\\texttt{DEFAULT 0}) versehen und drfen nicht leer (\\texttt{NOT NULL}) sein. Somit knnen Referenztabellen in der \\texttt{SELECT - WHERE} - Anweisung mittels \\texttt{AND} ausgelesen werden.
  \\item Alle anderen Spalten drfen keinen Vorgabewert haben und drfen leer sein. Auf diese Weise knnen mittels \\texttt{COALESCE} leere Werte entfernt werden
  \\item Kommentare werden im Klartext eingegeben. Sie knnen mittels beliebiger {\\TeX}/\\LaTeX{}-Schlsselworte formatiert werden.
  \\item Plausibilittsprfungen werden innerhalb der Funktionen durchgefhrt. Um die Geschwindigkeit der Funktionen mglicht gro zu halten, werden Standardprfungen (z.B. Einhalten von Fremdschlsselbeziehungen, Typumwandlungen) von Postgres durchgefhrt (derartige Fehlermeldungen unterscheiden sich sehr von den selbst implementierten Fehlermeldungen). Es gilt das Prinzip: Prfungen, welche von Postgres ausgefhrt werden mssen nicht nocheinmal implementiert werden !
  \\item Die Funktionsparameter (einschl. Rckgabewerte) werden vom Datentyp \\texttt{varchar} oder \\texttt{varchar[]} ausgefhrt.
\\end{itemize}


\\noindent Funktionsnamen werden wie folgt festgelegt:
\\begin{itemize}
  \\item \\texttt{aktualisiere__...} --- Werte aktualisieren (\\texttt{UPDATE})
  \\item \\texttt{erzeuge__...} --- ein Ergebnis mittels komplexer Operationen erzeugen
  \\item \\texttt{gib__...} --- Einzelwerte oder Liste zurckgeben (\\texttt{SELECT})
  \\item \\texttt{ist__...} --- Werte prfen (Aspekt, Forderung, ... erfllt ?)
  \\item \\texttt{loesche__...} --- Werte lschen (\\texttt{DELETE})
  \\item \\texttt{nimm__...} --- Werte bernehmen (\\texttt{INSERT})
  \\item \\texttt{pruefe__...} --- Werte anhand vorgegebener Randbedingungen auf Plausibilitt prfen
\\end{itemize}


\\noindent Die Namen der Sichten werden wie folgt festgelegt:
\\begin{itemize}
  \\item \\texttt{zeige__...} --- Listen zurckgeben
\\end{itemize}
' );




-- ---------------------------------------------------------------------------------------
-- ---------------------------------------------------------------------------------------
--
-- 2.) Schemas / Tabellen definieren
--
-- ---------------------------------------------------------------------------------------
-- ---------------------------------------------------------------------------------------

-- ---------------------------------------------------------------------------------------
--
-- 2.1) Schema- / Tabellendefinition
--	ACHTUNG Spalten mssen lexikalisch sortiert sein
--
-- ---------------------------------------------------------------------------------------

-- ---------------------------------------------------------------------------------------
-- dok - Dokumente	------------------------------------------------------------------
-- ---------------------------------------------------------------------------------------
CREATE SCHEMA dok;
SELECT intern.nimm__TLKommentarSTS( 'dok', 'Im Schema "`Dokumente"'' werden die in der Datenbank verwendeten Dokumentenreferenzen gehalten.');
--
-- Layout:
-- -------
--
-- dok.typ	<----------- dok.doku *1)
--
--
CREATE TABLE dok.doku (
	LIKE intern.alle INCLUDING DEFAULTS,
	aspekt VARCHAR DEFAULT 'BEWEIS' NOT NULL;
--	intern_firma_id INT DEFAULT 0 NOT NULL,
	dok_typ_id INT DEFAULT 0 NOT NULL,
	spr_uebvar_id_kb INT DEFAULT 0 NOT NULL
) 
WITHOUT OIDS;
INSERT INTO dok.doku VALUES( 0 );

CREATE TABLE dok.typ (
	LIKE intern.alle INCLUDING DEFAULTS,
	spr_uebvar_id INT DEFAULT 0 NOT NULL
) 
WITHOUT OIDS;
INSERT INTO dok.typ VALUES( 0 );



-- ---------------------------------------------------------------------------------------
-- intern - Intern	------------------------------------------------------------------
-- ---------------------------------------------------------------------------------------
CREATE SCHEMA intern; 
SELECT intern.nimm__TLKommentarSTS( 'intern', E'Das Schema \\texttt{Intern} dient der Bereitstellung von Tabellen, Datenstrukturen, usw. welche in allen Schemas verwendet werden knnen. Weiterhin wird die Basis der Logbuch-Funktionalitt einschlielich der Logbuch-Funktion der Tabellen
\\begin{itemize}
  \\item \\texttt{abczk},
  \\item \\texttt{restzk}
\\end{itemize}
bereitgestellt.');
--
-- Layout:
-- -------
--
-- intern.abczk
--
-- intern.alle
--
-- intern.allewlog
--
-- intern.firma
--
-- intern.restzk
--
CREATE TABLE intern.abczk (
	LIKE intern.alle INCLUDING DEFAULTS,
	abczk VARCHAR
) WITHOUT OIDS;
INSERT INTO intern.abczk VALUES( 0 );
ALTER TABLE intern.abczk ALTER COLUMN notizen DROP DEFAULT;
ALTER TABLE intern.abczk ALTER COLUMN notizen DROP NOT NULL;

CREATE TABLE intern.alle (
	id INT DEFAULT 0 NOT NULL,
	idfrei INT DEFAULT 0 NOT NULL,
	notizen VARCHAR SET DEFAULT '-- bleibt leer --' NOT NULL;
) WITHOUT OIDS;
INSERT INTO intern.alle VALUES( 0, DEFAULT, 'In diese Tabelle sollen keine Werte eingefuegt werden !' );

CREATE TABLE intern.allewlog (
	LIKE intern.alle INCLUDING DEFAULTS,
	logdatuhrz TIMESTAMP DEFAULT CAST( timeofday() AS timestamp ) NOT NULL,
	logdqok BOOLEAN,
	logdquelle VARCHAR,
	logentfernt BOOLEAN DEFAULT false NOT NULL,
	logname VARCHAR DEFAULT CAST( current_user AS text ) NOT NULL
) WITHOUT OIDS;
INSERT INTO intern.allewlog VALUES( 0, DEFAULT, 'In diese Tabelle sollen keine Werte eingefuegt werden !' );

CREATE TABLE intern.firma (
	LIKE intern.alle INCLUDING DEFAULTS,
	name VARCHAR,
	name_k VARCHAR
) 
WITHOUT OIDS;
INSERT INTO intern.firma VALUES( 0 );

CREATE TABLE intern.restzk (
	LIKE intern.alle INCLUDING DEFAULTS,
	restzk VARCHAR
) WITHOUT OIDS;
INSERT INTO intern.restzk VALUES( 0 );
ALTER TABLE intern.restzk ALTER COLUMN notizen DROP DEFAULT;
ALTER TABLE intern.restzk ALTER COLUMN notizen DROP NOT NULL;


-- ---------------------------------------------------------------------------------------
-- prj - Projekte	------------------------------------------------------------------
-- ---------------------------------------------------------------------------------------
SELECT intern.nimm__TLKommentarSTS( 'prj', E'Ausschlielich im Schema "`Projekte"'' wird der Projektbezug fr alle weiteren Schemas hergestellt.
Die Definition des Begriffes "`Projekt"'' hngt selbstverstndlich von der Anwendung ab. 
\\\\
\\\\
In der vorliegenden Datenbank kann mittels des Projektes "`DBDokumentation"'' die Dokumentation der Datenbank aus den Kommentaren der verschiedenen Datenbankobjekte erzeugt werden.\\\\
Dazu sind in der Kommandozeile (Eingabeaufforderung engl. Shell) die folgenden Befehle einzugeben:
\\begin{enumerate}
  \\item \\texttt{psql -U micha vf -P tuples_only -P format=unaligned -P footer -c ``SELECT replace( makefile, ''-U micha vf'', ''-U '' || current_user || '' '' || current_database() ) FROM prj.projekte WHERE prjname = ''DBDokumentation'';`` -o makefile}\\\\Anstelle des Benutzers \\texttt{micha} im shell-Befehl \\texttt{psql -U micha vf ...} und des Datenbanknamens \\texttt{vf} ist der eigene Benutzername bzw. Datenbankname anzugeben
  \\item \\texttt{make}
\\end{enumerate}
Das genannte Verfahren kann fr smtliche Projekte, denen ein \\texttt{makefile} zugeordnet ist, angewendet werden. Mgliche Varianten zum Erzeugen unterschiedlicher Dokumente knnen dem \\texttt{makefile} des entsprechenden Projektes entnommen werden.
\\\\
\\\\

\\noindent\\textbf{Benennen der Tabellen}

\\begin{description}
  \\item[\\texttt{prj.p_*}] Projektbezug herstellen
  \\item[\\texttt{prj.pp_*}] projektbezogene Personenzuordnung
  \\item[\\texttt{prj.pl_*}] projektbezogene Logbuchfunktionalitt
  \\item[\\texttt{prj.pplu_*}] projektbezogene Logbuchfunktionalitt und Personenzuordnung
\\end{description}');
CREATE SCHEMA prj;
--
-- Layout:
-- -------
--
--
-- dok.doku <--------------- prj.p_dokstrkt
--			 ---
--			| --
-- prj.projekte <------- |
--			 |
-- str.strkt <-----------
--
--
-- prj.projekte <-------
--			|
--			 ---
-- prj.personen <----------- prj.pp_prtprotokoll
--			 ---
--			| --
-- prt.protokoll <------ |
--			 |
-- spr.uebvar  <---------
--
--
-- prj.projekte <----------- prj.p_prtstrstrkt
--			 ---
--			| --
-- prt.protokoll  <----- |
--			 |
-- str.strkt <-----------
--
--
-- prj.projekte <----------- prj.p_prtverbindung
--			 ---
--			|
-- prt.protokoll <------
--
--
-- prj.projekte <-----------
--			 --- prj.p_psabk
--			| --
-- ps.abk <------------- |
--			 |
-- spr.uebvar <----------
--
--
-- prj.projekte <-----------
--		       ----- prj.pl_psgefabk
--		      | ----
-- ps.abk <----------- | ---
--		       ||
-- ps.gefszenario <---- |
--		        |
-- spr.uebvar <---------
--
--
-- prj.projekte <-----------
--		       ----- prj.pl_psgefanm
--		      | ----
-- ps.anmerkung <----- | ---
--		       ||
-- ps.gefszenario <---- |
--		        |
-- spr.uebvar <---------
--
--
-- dok.doku <---------------
--		       ----- prj.pl_dokausgabe
--		      |  ---
-- prj.projekte <-----  |
--		        |
-- spr.uebvar <---------
--
--
-- prj.projekte <----------- prj.pl_prtpsgefszenario
--			 ---
--			| --
-- ps.gefszenario <----- |
--			 |
-- prt.protokoll <-------
--
--
-- prj.projekte <----------- prj.pl_psgefstrkt
--			 ---
--			| --
-- ps.gefszenario <----- |
--			 |
-- str.strkt <-----------
--
--
-- dok.doku <-----------
--			|
--			 ---
-- prj.personen <----------- prj.ppl_dokdoku
--			 ---
--			|
-- prj.projekte <------- 
--
--
-- prj.projekte <-------
--			|
--			 ---
-- prj.personen <----------- prj.pp_psgefszenario
--			 ---
--			| --
-- ps.gefszenario <----- |
--			 |
-- spr.uebvar <----------
--
--
-- prj.projekte <-------
--			|
--			 ---
-- prj.personen <----------- prj.pp_strstrkt
--			 ---
--			| --
-- str.strkt <---------- |
--			 |
-- spr.uebvar <----------
--
--
-- prt.protokoll <------
--			|
--			 ---
-- prj.personen <----------- prj.pl_prtdokdoku
--			 ---
--			| --
-- prj.projekte <------- |
--			 |
-- spr.uebvar <----------
--
--
-- prj.projekte <----------- prj.p_strverbindung
--			 ---
--			|
-- str.strkt <---------- 
--
--
--
-- noch nicht implementierte Aspekte:
-- ==================================
--
--  - Seriennummer (Kenzeichnung als Individuum / Konfigurationsmanagement)
--
--
CREATE TABLE prj.personen (
	LIKE intern.alle INCLUDING DEFAULTS,
	intern_firma_id INT DEFAULT 0 NOT NULL,
	name_n VARCHAR,
	name_v VARCHAR
) 
WITHOUT OIDS;
INSERT INTO prj.personen VALUES( 0 );

CREATE TABLE prj.projekte (
	LIKE intern.alle INCLUDING DEFAULTS,
	makefile VARCHAR,
	prjbeschr VARCHAR,
	prjname VARCHAR
) 
WITHOUT OIDS;
INSERT INTO prj.projekte VALUES( 0 );

CREATE TABLE prj.p_dokstrkt (
	LIKE intern.alle INCLUDING DEFAULTS,
	dok_doku_id INT DEFAULT 0 NOT NULL,
	prj_projekte_id INT DEFAULT 0 NOT NULL,
	str_strkt_id INT DEFAULT 0 NOT NULL
) 
WITHOUT OIDS;
INSERT INTO prj.p_dokstrkt VALUES( 0 );

CREATE TABLE prj.pp_prtprotokoll (
	LIKE intern.alle INCLUDING DEFAULTS,
	datuhrz TIMESTAMP DEFAULT CAST( timeofday() AS timestamp ) NOT NULL,
	duanfrage TIMESTAMP,	-- ist bei prj_personen_id = 0 NULL
	erledigt BOOLEAN DEFAULT false NOT NULL,
	intern BOOLEAN DEFAULT true NOT NULL,
	prj_personen_id INT DEFAULT 0 NOT NULL,
	prj_projekte_id INT DEFAULT 0 NOT NULL,
	prt_protokoll_id INT DEFAULT 0 NOT NULL,
	spr_uebvar_id INT DEFAULT 0 NOT NULL,
	teilnehmer BOOLEAN,	-- mu drei Zustnde annehmen knnen; NULL, true, false
	termin TIMESTAMP	-- ist bei prj_personen_id = 0 NULL
) 
WITHOUT OIDS;
INSERT INTO prj.pp_prtprotokoll VALUES( 0 );

CREATE TABLE prj.p_prtstrstrkt (
	LIKE intern.alle INCLUDING DEFAULTS,
	prj_projekte_id INT DEFAULT 0 NOT NULL,
	prt_protokoll_id INT DEFAULT 0 NOT NULL,
	str_strkt_id INT DEFAULT 0 NOT NULL
) 
WITHOUT OIDS;
INSERT INTO prj.p_prtstrstrkt VALUES( 0 );

CREATE TABLE prj.p_prtverbindung (
	LIKE intern.alle INCLUDING DEFAULTS,
	prj_projekte_id INT DEFAULT 0 NOT NULL,
	prt_protokoll_id_nachf INT DEFAULT 0 NOT NULL,
	prt_protokoll_id_vorg INT DEFAULT 0 NOT NULL
) 
WITHOUT OIDS;
INSERT INTO prj.p_prtverbindung VALUES( 0 );

CREATE TABLE prj.p_psabk (
	LIKE intern.alle INCLUDING DEFAULTS,
	prj_projekte_id INT DEFAULT 0 NOT NULL,
	ps_abk_id INT DEFAULT 0 NOT NULL,
	spr_uebvar_id INT DEFAULT 0 NOT NULL,
	spr_uebvar_id_l INT DEFAULT 0 NOT NULL,
	spr_uebvar_id_zus INT DEFAULT 0 NOT NULL
) 
WITHOUT OIDS;
INSERT INTO prj.p_psabk VALUES( 0 );

CREATE TABLE prj.pl_psgefabk (
	LIKE intern.allewlog INCLUDING DEFAULTS,
	prj_projekte_id INT DEFAULT 0 NOT NULL,
	ps_abk_id INT DEFAULT 0 NOT NULL,
	ps_gefszenario_id INT DEFAULT 0 NOT NULL,
	spr_uebvar_id_zus INT DEFAULT 0 NOT NULL
) 
WITHOUT OIDS;
INSERT INTO prj.pl_psgefabk VALUES( 0 );

CREATE TABLE prj.pl_psgefanm (
	LIKE intern.allewlog INCLUDING DEFAULTS,
	prj_projekte_id INT DEFAULT 0 NOT NULL,
	ps_anmerkung_id INT DEFAULT 0 NOT NULL,
	ps_gefszenario_id INT DEFAULT 0 NOT NULL,
	spr_uebvar_id INT DEFAULT 0 NOT NULL
) 
WITHOUT OIDS;
INSERT INTO prj.pl_psgefanm VALUES( 0 );

CREATE TABLE prj.pl_dokausgabe (
	LIKE intern.allewlog INCLUDING DEFAULTS,
	datum DATE DEFAULT '1900-01-01' NOT NULL,
	dok_doku_id INT DEFAULT 0 NOT NULL,
	istfrei BOOLEAN DEFAULT false NOT NULL,
	nr VARCHAR DEFAULT '???' NOT NULL,
	prj_projekte_id INT DEFAULT 0 NOT NULL,
	spr_uebvar_id INT DEFAULT 0 NOT NULL,
	stand VARCHAR DEFAULT '???' NOT NULL
) 
WITHOUT OIDS;
INSERT INTO prj.pl_dokausgabe VALUES( 0 );

CREATE TABLE prj.pl_prtpsgefszenario (
	LIKE intern.allewlog INCLUDING DEFAULTS,
	prj_projekte_id INT DEFAULT 0 NOT NULL,
	prt_protokoll_id INT DEFAULT 0 NOT NULL,
	ps_gefszenario_id INT DEFAULT 0 NOT NULL
) 
WITHOUT OIDS;
INSERT INTO prj.pl_prtpsgefszenario VALUES( 0 );

CREATE TABLE prj.pl_psgefstrkt (
	LIKE intern.allewlog INCLUDING DEFAULTS,
	prj_projekte_id INT DEFAULT 0 NOT NULL,
	ps_gefszenario_id INT DEFAULT 0 NOT NULL,
	str_strkt_id INT DEFAULT 0 NOT NULL
) 
WITHOUT OIDS;
INSERT INTO prj.pl_psgefstrkt VALUES( 0 );

CREATE TABLE prj.ppl_dokdoku (
	LIKE intern.allewlog INCLUDING DEFAULTS,
	dok_doku_id INT DEFAULT 0 NOT NULL,
	prj_personen_id INT DEFAULT 0 NOT NULL,	-- Ansprechpartner (ggf. verantwortlich(e) Person(en))
	prj_projekte_id INT DEFAULT 0 NOT NULL
) 
WITHOUT OIDS;
INSERT INTO prj.ppl_dokdoku VALUES( 0 );

CREATE TABLE prj.pp_psgefszenario (
	LIKE intern.alle INCLUDING DEFAULTS,
	prj_personen_id INT DEFAULT 0 NOT NULL,
	prj_projekte_id INT DEFAULT 0 NOT NULL,
	ps_gefszenario_id INT DEFAULT 0 NOT NULL,
	spr_uebvar_id INT DEFAULT 0 NOT NULL,
	spr_uebvar_id_reprgefszen INT DEFAULT 0 NOT NULL,
	spr_uebvar_id_ursp INT DEFAULT 0 NOT NULL
) 
WITHOUT OIDS;
INSERT INTO prj.pp_psgefszenario VALUES( 0 );

CREATE TABLE prj.pp_strstrkt (
	LIKE intern.alle INCLUDING DEFAULTS,
	prj_personen_id INT DEFAULT 0 NOT NULL,
	prj_projekte_id INT DEFAULT 0 NOT NULL,
	str_strkt_id INT DEFAULT 0 NOT NULL,
	fbereignis VARCHAR,
	spr_uebvar_id INT DEFAULT 0 NOT NULL,
	spr_uebvar_id_zus INT DEFAULT 0 NOT NULL
) 
WITHOUT OIDS;
INSERT INTO prj.pp_strstrkt VALUES( 0 );

CREATE TABLE prj.pl_prtdokdoku (
	LIKE intern.allewlog INCLUDING DEFAULTS,
	dok_doku_id INT DEFAULT 0 NOT NULL,
	prj_projekte_id INT DEFAULT 0 NOT NULL,
	prt_protokoll_id INT DEFAULT 0 NOT NULL
) 
WITHOUT OIDS;
INSERT INTO prj.pl_prtdokdoku VALUES( 0 );

CREATE TABLE prj.p_strverbindung (
	LIKE intern.alle INCLUDING DEFAULTS,
	fbtor VARCHAR,
	prj_projekte_id INT DEFAULT 0 NOT NULL,
	str_strkt_id_nachf INT DEFAULT 0 NOT NULL,
	str_strkt_id_vorg INT DEFAULT 0 NOT NULL
) 
WITHOUT OIDS;
INSERT INTO prj.p_strverbindung VALUES( 0 );



-- ---------------------------------------------------------------------------------------
-- prt - Protokoll	------------------------------------------------------------------
-- ---------------------------------------------------------------------------------------
CREATE SCHEMA prt;
SELECT intern.nimm__TLKommentarSTS( 'prt', E'Im Schema "`Protokoll"'' werden neben Protokolleintrgen (PE) auch Sicherheitsanforderungen (SF) und Terminplaneintrge (TP) gespeichert.
\\\\
Mittels der Tabelle \\texttt{prt.verbindung} knnen Verbindungn zwischen den PE, SF, TP hergestellt werden (sind auch aspektbergreifend [PE - SF - TE] sinnvoll).');
--
-- Layout:
-- -------
--
--
-- dok.doku	<---------------------------------------------- prt.dokdoku
--							    ---
--							   |
-- spr.uebvar <--- prt.typ <-------- prt.protokoll *1) <---
--
--
--
--
-- noch nicht implementierte Aspekte:
-- ==================================
--
-- - Ablage von Binrdaten (pdf, tiff, jpeg, ...) und Zuordung zum Protokolleintrag
--
-- - explizite Kennzeichnung einer Sicherheitsfunktion / sicherheitsrelevanten Funktion / ...
--
--

CREATE TABLE prt.protokoll (
	LIKE intern.alle INCLUDING DEFAULTS,
	prt_typ_id INT DEFAULT 0 NOT NULL
) 
WITHOUT OIDS;
INSERT INTO prt.protokoll VALUES( 0 );

CREATE TABLE prt.typ (
	LIKE intern.alle INCLUDING DEFAULTS,
	aspekt VARCHAR,
	spr_uebvar_id INT DEFAULT 0 NOT NULL
) 
WITHOUT OIDS;
INSERT INTO prt.typ VALUES( 0 );


-- ---------------------------------------------------------------------------------------
-- ps - Produktsicherheit	----------------------------------------------------------
-- ---------------------------------------------------------------------------------------
CREATE SCHEMA ps;
SELECT intern.nimm__TLKommentarSTS( 'ps', E'Das Schema "`Produktsicherheit"'' dient der Verwaltung smtlicher Aspekte zur Produktsicherheit.
\\\\
\\\\
Die Zuordnung von technischen Systemen / Komponenten bzw. Strukturpunkten erfolgt
\\\\
\\textbf{explizit}
\\begin{itemize}
  \\item \\texttt{str.strkt --- kmp.strkt --- kmp.komp --- ps.gefkomp --- ps.gefszenario}
  \\item \\texttt{str.strkt --- ps.gefstrkt --- ps.gefszenario}
\\end{itemize}

\\noindent \\textbf{implizit ber \\texttt{prt}}
\\begin{itemize}
  \\item \\texttt{str.strkt --- kmp.strkt --- kmp.komp --- prt.komp --- prt.protokoll --- ps.gefprot --- ps.gefszenario}
  \\item \\texttt{str.strkt --- prt.strkt --- prt.protokoll --- ps.gefprot --- ps.gefszenario}
\\end{itemize}

\\noindent \\textbf{implizit ber \\texttt{prt.dokausgabe}}
\\begin{itemize}
  \\item \\texttt{str.strkt --- kmp.strkt --- kmp.komp --- dok.komp --- dok.doku --- dok.ausgabe --- prt.dokausgabe --- prt.protokoll --- ps.gefprot --- ps.gefszenario}
  \\item \\texttt{str.strkt --- dok.strkt --- dok.doku --- dok.ausgabe --- prt.dokausgabe --- prt.protokoll --- ps.gefprot --- ps.gefszenario}
\\end{itemize}
');
--
--
-- Layout:
-- -------
--
--
-- ps.abk
--
--
-- ps.annmerkung
--
--
-- ps.gefszenario
--
--
--
--
-- noch nicht implementierte Aspekte:
-- ==================================
--
--	- >ps.erzeuge_systKomp(...)<
--		bezogen auf die aktuelle Gefahren-Id die beteiligten Komponenten ermitteln
--	  	(siehe Darstellung der Komp- / Strkt.-Zuordnung im Kommentar zu >ps<)
--
--
-- 	- >ps.erzeuge_risikostufe(...)<
--		aus >ps.abk.typ = 'RH' und 'RA'< die Risikostufe nach EN 50126 ermitteln
--
--
--	- "Meldung sicherheitsrelevanter Ereignisse"
--
--
CREATE TABLE ps.abk (
	LIKE intern.alle INCLUDING DEFAULTS,
	typ VARCHAR
) WITHOUT OIDS;
INSERT INTO ps.abk VALUES( 0 );

CREATE TABLE ps.anmerkung (
	LIKE intern.alle INCLUDING DEFAULTS
) WITHOUT OIDS;
INSERT INTO ps.anmerkung VALUES( 0 );

CREATE TABLE ps.gefszenario (
	LIKE intern.alle INCLUDING DEFAULTS
) WITHOUT OIDS;
INSERT INTO ps.gefszenario VALUES( 0 );


-- ---------------------------------------------------------------------------------------
-- spr - Sprache	------------------------------------------------------------------
-- ---------------------------------------------------------------------------------------
CREATE SCHEMA spr;
SELECT intern.nimm__TLKommentarSTS( 'spr', E'Das Schema \\texttt{Sprache} dient der sprachenabhngigen Verwaltung von Wortgruppen. Jeder Wortgruppe \\texttt{spr.wgruppe.id}< knnen mehrere unterschiedliche Sprachen \\texttt{spr.sprachen.id} mittels unterschiedlicher bersetzungsvarianten \\texttt{spr.uebvar.id} zugeordnet werden. Die Tabelle \\texttt{spr.uebersetzung} dient der Zuordnung der Sprachen / bersetzungsvarianten zur Wortgruppe.
\\\\
Innerhalb einer bersetzungsvariante \\texttt{spr.uebersetzung.spr_uebvar_id} tritt jede Sprache maximal einmal auf.
\\\\
\\\\
Die Tabelle \\texttt{spr.pos} dient der Bildung der Wortgruppen.
');
--
--
-- Layout:
-- -------
--
-- spr.uebvar	<-------
--			|
--			 ---
-- spr.sprachen	<----------- spr.uebersetzung
--			 ---
--			|
--		<-------
-- spr.wgruppe  <-------
--			|
--			 ---
-- intern.abczk	<----------- spr.pos
--			 ---
--			|
-- intern.restzk  <-----
--
CREATE TABLE spr.pos (
	LIKE intern.alle INCLUDING DEFAULTS,
	intern_abczk_id INT DEFAULT 0 NOT NULL,
	intern_restzk_id INT DEFAULT 0 NOT NULL,
	spr_wgruppe_id INT DEFAULT 0 NOT NULL
) WITHOUT OIDS;
INSERT INTO spr.pos VALUES( 0 );
ALTER TABLE spr.pos ALTER COLUMN notizen DROP DEFAULT;
ALTER TABLE spr.pos ALTER COLUMN notizen DROP NOT NULL;

CREATE TABLE spr.sprachen (
	LIKE intern.alle INCLUDING DEFAULTS,
	sprache VARCHAR DEFAULT '-'::VARCHAR NOT NULL,
	sprache_k VARCHAR DEFAULT '-'::VARCHAR NOT NULL
) WITHOUT OIDS;
INSERT INTO spr.sprachen VALUES( 0 );

CREATE TABLE spr.uebvar (
	LIKE intern.alle INCLUDING DEFAULTS
) WITHOUT OIDS;
INSERT INTO spr.uebvar VALUES( 0 );

CREATE TABLE spr.uebersetzung (
	LIKE intern.alle INCLUDING DEFAULTS,
	spr_sprachen_id INT DEFAULT 0 NOT NULL,
	spr_uebvar_id INT DEFAULT 0 NOT NULL,
	spr_wgruppe_id INT DEFAULT 0 NOT NULL
) WITHOUT OIDS;
INSERT INTO spr.uebersetzung VALUES( 0 );

CREATE TABLE spr.wgruppe (
	LIKE intern.alle INCLUDING DEFAULTS
) WITHOUT OIDS;
INSERT INTO spr.wgruppe VALUES( 0 );


-- ---------------------------------------------------------------------------------------
-- str - Strukturen	------------------------------------------------------------------
-- ---------------------------------------------------------------------------------------
CREATE SCHEMA str;
SELECT intern.nimm__TLKommentarSTS( 'str', 'Das Schema "`Strukturen"'' dient der Verwaltung smtlicher Strukturen (z.B. Fahrzeugstruktur, Gefahrennetz, Fehlerbaumstrukturen)');
--
-- Layout:
-- -------
--
--
-- str.name <----------- str.strkt
--
CREATE TABLE str.name (
	LIKE intern.alle INCLUDING DEFAULTS,
	name VARCHAR,
	name_k VARCHAR
) 
WITHOUT OIDS;
INSERT INTO str.name VALUES( 0 );

CREATE TABLE str.strkt (
	LIKE intern.alle INCLUDING DEFAULTS,
	nr VARCHAR,
	str_name_id INT DEFAULT 0 NOT NULL
) 
WITHOUT OIDS;
INSERT INTO str.strkt VALUES( 0 );


-- ---------------------------------------------------------------------------------------
-- tl - Tex/Latex	------------------------------------------------------------------
-- ---------------------------------------------------------------------------------------
CREATE SCHEMA tl;
SELECT intern.nimm__TLKommentarSTS( 'tl', E'Das Schema "`Tex/Latex"'' dient der Verwaltung der verwendeten {\\TeX}/\\LaTeX{} - Befehle, {\\TeX}/\\LaTeX{} - Wrter und sonstigen in {\\TeX}/\\LaTeX{} - Dateien auftretenden Zeichenketten.');
--
-- Layout:
-- -------
--
-- tl.befehl	 <------------------------
--			         ---------
--				|  ------- tl.pos
-- tl.datei	 <--------------  |  -----
--				  | |  ---
-- intern.abczk	 <--- tl.wort <---  | |
--				    | |
-- intern.abczk	 <------------------  |
--				      |
-- intern.restzk <--------------------
--
CREATE TABLE tl.befehl (
	LIKE intern.alle INCLUDING DEFAULTS,
	befname VARCHAR,
	abczk VARCHAR DEFAULT '' NOT NULL
) 
WITHOUT OIDS;
INSERT INTO tl.befehl VALUES( 0 );

CREATE TABLE tl.datei (
	LIKE intern.alle INCLUDING DEFAULTS,
	dname VARCHAR
) WITHOUT OIDS;
INSERT INTO tl.datei VALUES( 0 );

CREATE TABLE tl.pos (
	LIKE intern.alle INCLUDING DEFAULTS,
	intern_abczk_id INT DEFAULT 0 NOT NULL,
	intern_restzk_id INT DEFAULT 0 NOT NULL,
	pos INT,
	tl_befehl_id INT DEFAULT 0 NOT NULL,
	tl_datei_id INT DEFAULT 0 NOT NULL,
	tl_wort_id INT DEFAULT 0 NOT NULL
) WITHOUT OIDS;
INSERT INTO tl.pos VALUES( 0 );
ALTER TABLE tl.pos ALTER COLUMN notizen DROP DEFAULT;
ALTER TABLE tl.pos ALTER COLUMN notizen DROP NOT NULL;

CREATE TABLE tl.wort (
	LIKE intern.alle INCLUDING DEFAULTS,
	intern_abczk_id INT DEFAULT 0 NOT NULL,
	worte VARCHAR
) WITHOUT OIDS;
INSERT INTO tl.wort VALUES( 0 );


-- ---------------------------------------------------------------------------------------
--
-- 2.2) Tabellenkommentare
--
-- ---------------------------------------------------------------------------------------

-- ---------------------------------------------------------------------------------------
-- dok - Dokumente	------------------------------------------------------------------
-- ---------------------------------------------------------------------------------------
SELECT intern.nimm__TLKommentarSTS( 'dok.doku', 'Tabelle zur Verwaltung der Basisinformationen der Dokumente. Die Dokumente werden anhand des Typs und der projektbergreifenden Dokumentbezeichnung unterschieden.');

SELECT intern.nimm__TLKommentarSTS( 'dok.typ', E'Tabelle zur Verwaltung der Typen der Dokumente.');


-- ---------------------------------------------------------------------------------------
-- intern - Intern	------------------------------------------------------------------
-- ---------------------------------------------------------------------------------------
SELECT intern.nimm__TLKommentarSTS( 'intern.abczk', 'Tabelle die alle Zeichenketten aufnimmt, welche ausschliesslich aus Buchstaben bestehen. Gross-/Kleinschreibung wird unterschieden.');

SELECT intern.nimm__TLKommentarSTS( 'intern.allewlog', E'Tabelle, welche die Grundstruktur fr alle weiteren Tabellen mit Logbuchfunktion (Darstellen der nderungshistorie) bildet. Neben den Informationen der Tabelle \\texttt{intern.alle} wird die Uhrzeit des Eintrages, der Name des Benutzers, die Datenquelle (bei automatische eingelesenen Daten) der Zustand, ob ein automatisch eingelesener Datensatz geprft wurde und der Status, ob der Eintrag gelscht wurde, gehalten.');

SELECT intern.nimm__TLKommentarSTS( 'intern.alle', E'Tabelle, welche die Grundstruktur fr alle weiteren Tabellen bildet. Neben der Primaerschluesselspalte wird die Spalte zur Wiederverwendung freigegebener \\texttt{id} und eine Spalte zur Aufnahme interner Notizen zur Verfgung gestellt.');

SELECT intern.nimm__TLKommentarSTS( 'intern.firma', 'Tabelle zur Verwaltung der in den Projekten referenzierten Firmen.');

SELECT intern.nimm__TLKommentarSTS( 'intern.restzk', 'Tabelle die alle Zeichenketten aufnimmt, welche nicht aus Buchstaben bestehen.');


-- ---------------------------------------------------------------------------------------
-- prj - Projekte	------------------------------------------------------------------
-- ---------------------------------------------------------------------------------------
SELECT intern.nimm__TLKommentarSTS( 'prj.personen', 'Tabelle zur Verwaltung der in den Projekten eingebundenen Personen.');

SELECT intern.nimm__TLKommentarSTS( 'prj.projekte', 'Tabelle zur Verwaltung der projektspezifischen Informationen');

SELECT intern.nimm__TLKommentarSTS( 'prj.p_dokstrkt', 'Diese Tabelle dient der projektabhngigen Zuordnung der Strukturpunkte zu den Dokumenten.');

SELECT intern.nimm__TLKommentarSTS( 'prj.pp_prtprotokoll', E'Diese Tabelle dient der projektabhngigen Zuordnung der Personen zu den Protokolleintrgen / Sicherheitsanforderungen / Terminplaneintrgen. Weiterhin knnen verschiedene Eigenschaften projektabhngig umbenannt werden. Innerhalb dieser Tabelle werden drei Aspekte abgebildet: Protokolleintrag einem Projekt zuordnen, projektspezifisch modifizieren und Randbedingungen setzen; dem Protokolleintrag die beteiligten Personen zuordnen und den Protokolleintrag als Frage / Aufgabe formulieren.');

SELECT intern.nimm__TLKommentarSTS( 'prj.p_prtstrstrkt', 'Diese Tabelle dient der projektabhngigen Zuordnung der Strukturpunkte zu den Protokolleintrgen / Sicherheitsanforderungen / Terminplaneintrgen.');

SELECT intern.nimm__TLKommentarSTS( 'prj.p_prtverbindung', 'Diese Tabelle dient der projektabhngigen gegenseitigen Zuordnung der Protokolleintrge / Sicherheitsanforderungen / Terminplaneintrge.');

SELECT intern.nimm__TLKommentarSTS( 'prj.p_psabk', 'Diese Tabelle dient der projektabhngigen Zuordnung der Bezeichnungen der Abkrzungen.');

SELECT intern.nimm__TLKommentarSTS( 'prj.pl_dokausgabe', E'Tabelle zur Verwaltung der Dokumentnummer, des Dokumenttitels und der Ausgaben (Revisionsstnde) des aktuellen Dokumentes. Diese Tabelle enthlt alle im Projekt verwendeten Dokumente. Mittels Logbuchfunktion kann der Wechsel der Revisionsstnde verfolgt werden.');

SELECT intern.nimm__TLKommentarSTS( 'prj.pl_psgefabk', E'Mittels dieser Tabelle wird die projektabhngige Logbuchfunktion fr die Abkrzungen bereitgestellt, die dem aktuellen Gefahrenszenario zugeordnet sind.');

SELECT intern.nimm__TLKommentarSTS( 'prj.pl_psgefanm', E'Mittels dieser Tabelle wird die projektabhngige Logbuchfunktion fr die Anmerkungen bereitgestellt, die dem aktuellen Gefahrenszenario zugeordnet sind.');

SELECT intern.nimm__TLKommentarSTS( 'prj.pl_prtdokdoku', E'Mittels dieser Tabelle wird die projektabhngige Logbuchfunktion fr die Dokumente bereitgestellt, die dem aktuellen Gefahrenszenario zugeordnet sind.');

SELECT intern.nimm__TLKommentarSTS( 'prj.pl_prtpsgefszenario', E'Mittels dieser Tabelle wird die projektabhngige Logbuchfunktion fr die Protokolleintrge bereitgestellt, die dem aktuellen Gefahrenszenario zugeordnet werden.');

SELECT intern.nimm__TLKommentarSTS( 'prj.pl_psgefstrkt', E'Mittels dieser Tabelle wird die projektabhngige Logbuchfunktion fr die Strukturpunkte bereitgestellt, die dem aktuellen Gefahrenszenario zugeordnet werden.');

SELECT intern.nimm__TLKommentarSTS( 'prj.ppl_dokdoku', 'Diese Tabelle dient der projektabhngigen Zuordnung der Ansprechpartner (ggf. verantwortlichen Personen) zu den Dokumenten. Mittels Logbuchfunktion kann der Wechsel der Ansprechpartner verfolgt werden.');

SELECT intern.nimm__TLKommentarSTS( 'prj.pp_psgefszenario', 'Diese Tabelle dient der projektabhngigen Zuordnung der Beschreibung des Gefahrenszenarios einschlielich Zuordnung einer Person.');

SELECT intern.nimm__TLKommentarSTS( 'prj.pp_strstrkt', 'Diese Tabelle dient der projektabhngigen Zuordnung der Personen zu den Strukturpunkten. Weiterhin knnen verschiedene Eigenschaften projektabhngig umbenannt werden.');

SELECT intern.nimm__TLKommentarSTS( 'prj.p_strverbindung', 'Diese Tabelle dient der projektabhngigen gegenseitigen Zuordnung der Strukturpunkte.');



-- ---------------------------------------------------------------------------------------
-- prt - Protokoll	------------------------------------------------------------------
-- ---------------------------------------------------------------------------------------
SELECT intern.nimm__TLKommentarSTS( 'prt.protokoll', 'Tabelle zur Verwaltung der Id''s der PE, SF, TP.');

SELECT intern.nimm__TLKommentarSTS( 'prt.typ', E'Tabelle zur Verwaltung der Typen der PE, SF, TP (Aspekte).');



-- ---------------------------------------------------------------------------------------
-- ps - Produktsicherheit	----------------------------------------------------------
-- ---------------------------------------------------------------------------------------
SELECT intern.nimm__TLKommentarSTS( 'ps.abk', E'In dieser Tabelle werden alle im Schema \\texttt{ps} verwendeten Abkrzungen gehalten. Sie werden anhand ihres Typs (\\texttt{ps.abk.typ}) klassifiziert.' );

SELECT intern.nimm__TLKommentarSTS( 'ps.anmerkung', E'In dieser Tabelle werden alle im Schema \\texttt{ps} verwendeten Anmerkungen gehalten.' );

SELECT intern.nimm__TLKommentarSTS( 'ps.gefszenario', E'In dieser Tabelle wird die Identifikationsnummer des Gefahrenszenarios abgelegt. In der Spalte \\texttt{ps.gefszenario.notizen} wird der Sinn des Szenarios notiert. Diese Tabelle stellt die zentrale Verbindung aller Sicherheitsaspekte dar. ');


-- ---------------------------------------------------------------------------------------
-- spr - Sprache	------------------------------------------------------------------
-- ---------------------------------------------------------------------------------------
SELECT intern.nimm__TLKommentarSTS( 'spr.pos', E'Tabelle, die die Position des Wortes in der Wortgruppe aufnimmt (die Wortgruppe bildet). Die Reihenfolge der Worte wird mittels \\texttt{spr.pos.id} definiert.');

SELECT intern.nimm__TLKommentarSTS( 'spr.sprachen', 'Tabelle zur Verwaltung der unterschiedlichen Sprachen.');

SELECT intern.nimm__TLKommentarSTS( 'spr.uebvar', 'Mittels dieser Tabelle werden die mglichen bersetzungsvarianten bereitgestellt. Sie knnen von weiteren Tabellen verwendet werden.');

SELECT intern.nimm__TLKommentarSTS( 'spr.uebersetzung', 'Tabelle, die die Verbindung zwischen Sprache, bersetzungsvariante und Wortgruppe herstellt. Innerhalb einer bersetzungsvariante darf eine Sprache maximal einmal zugeordnet sein.');

SELECT intern.nimm__TLKommentarSTS( 'spr.wgruppe', 'Tabelle zur Verwaltung der unterschiedlichen Wortgruppen.');


-- ---------------------------------------------------------------------------------------
-- str - Strukturen	------------------------------------------------------------------
-- ---------------------------------------------------------------------------------------
SELECT intern.nimm__TLKommentarSTS( 'str.name', 'Tabelle zur Verwaltung der Bezeichnung der unterschiedlichen verwendeten Strukturen.');

SELECT intern.nimm__TLKommentarSTS( 'str.strkt', 'Tabelle zur Verwaltung der Strukturpunkte einschlielich Klassifizierung im Sinne eines Fehlerbaumereignisses (Basis, Haus, ...).');


-- ---------------------------------------------------------------------------------------
-- tl - Tex/Latex	------------------------------------------------------------------
-- ---------------------------------------------------------------------------------------
SELECT intern.nimm__TLKommentarSTS( 'tl.befehl', E'Tabelle zum Verwalten der Bezeichnungen der verwendeten {\\TeX}/\\LaTeX{} - Befehle.');

SELECT intern.nimm__TLKommentarSTS( 'tl.datei', E'Tabelle zum Verwalten der unterschiedlichen {\\TeX}/\\LaTeX{} - Dateien.');

SELECT intern.nimm__TLKommentarSTS( 'tl.pos', 'Tabelle zum Verwalten der Position der unterschiedelichen Zeichenketten, welche in einer TL-Datei auftreten.');

SELECT intern.nimm__TLKommentarSTS( 'tl.wort', E'Tabelle, die smtliche verwendeten Wrter aller natrlichen Sprachen einschlielich {\\TeX}/\\LaTeX{} - spezifischer Befehle aufnimmt. Als Beispiel knnen Trennhilfen (Rum\-mel), spezielle Buchstaben einer Sprache ("A = ) oder sonstige in ein Wort eingebettete Befehle, welche zur korrekten Darstellung des Wortes in {\\TeX}/\\LaTeX{} erforderlich sind, aufgenommen werden.');


-- ---------------------------------------------------------------------------------------
--
-- 2.3) Spaltenkommentare
--
-- ---------------------------------------------------------------------------------------

-- ---------------------------------------------------------------------------------------
-- dok - Dokumente	------------------------------------------------------------------
-- ---------------------------------------------------------------------------------------
SELECT intern.nimm__TLKommentarSTS( 'dok.doku.aspekt', E'Klassifizierung des Dokumentes anhand der mglichen Aspekte unter denen es den Protokolleintrgen, Sicherheitsanforderungen, Terminplaneintrgen, ... zugeordnet wird.  Die mglichen Aspekte sind \\texttt{dok.nimm__doku()} zu entnehmen.');
--SELECT intern.nimm__TLKommentarSTS( 'dok.doku.intern_firma_id', 'Identifikationsnummer der Firma, welche Eigentmer des Dokumentes ist.');
SELECT intern.nimm__TLKommentarSTS( 'dok.doku.dok_typ_id', E'Identifikationsnummer zur Klassifizierung des Dokumentes.');
SELECT intern.nimm__TLKommentarSTS( 'dok.doku.spr_uebvar_id_kb', 'Identifikationsnummer der bersetzungsvariante, welche die projektbergreifende Dokumentbezeichnung (Zweckes, Zieles, ...) darstellt.');

SELECT intern.nimm__TLKommentarSTS( 'dok.typ.spr_uebvar_id', 'Identifikationsnummer der bersetzungsvariante zur Darstellung des aktuellen Typs.');


-- ---------------------------------------------------------------------------------------
-- intern - Intern	------------------------------------------------------------------
-- ---------------------------------------------------------------------------------------
SELECT intern.nimm__TLKommentarSTS( 'intern.abczk.abczk', 'Es sind die Zeichenketten einzugeben.');

SELECT intern.nimm__TLKommentarSTS( 'intern.alle.id', 'Primrschlsselspalte: Diese Spalte steht in allen Tabellen jedes Schemas an erster Stelle. In vielen Fllen wird auf sie mittels Fremdschlssel referenziert.');
SELECT intern.nimm__TLKommentarSTS( 'intern.alle.idfrei', E'Hilfsspalte zur Id-Verwaltung: Diese Spalte folgt unmittelbar \\texttt{id}. Sie wird mit dem aktuellen Wert in \\texttt{id} versehen, wenn die aktuelle Zeile als gelscht angesehen werden soll und die zugeordnete \\texttt{id} fr neue Eintrge zur Verfgung steht, sonst wird \\texttt{0} eingetragen.');
SELECT intern.nimm__TLKommentarSTS( 'intern.alle.notizen', E'Interne Notizen / Anmerkungen: Diese Spalte folgt unmittelbar \\texttt{idfrei}. Sie dient der Aufnahme interner Notizen, die nicht in offiziellen Auswertungen Verwendung finden. Sie kann von allen Nutzern verwendet werden, die Werte in die Datenbank eingeben oder verndern.');

SELECT intern.nimm__TLKommentarSTS( 'intern.allewlog.logdatuhrz', E'Es werden Datum und Uhrzeit des aktuellen Eintrages aufgenommen (als \\texttt{DEFAULT}). Es wird die SQL-Funktion \\texttt{timeofday()} verwendet welche sicherstellt, da auch innerhalb einer Transaktion die aktuelle Zeit eingetragen wird.');
SELECT intern.nimm__TLKommentarSTS( 'intern.allewlog.logdqok', E'Es ist \\texttt{true} anzugeben, wenn automatisch eingelesene Daten vom Spezialisten akzeptiert wurden.');
SELECT intern.nimm__TLKommentarSTS( 'intern.allewlog.logdquelle', 'Es ist die Datenquelle (bei automatisch eingelesenden Daten) des aktuellen Eintrags anzugeben.');
SELECT intern.nimm__TLKommentarSTS( 'intern.allewlog.logentfernt', E'Es ist \\texttt{true} anzugeben, wenn der aktuelle Eintrag gelscht werden soll, sonst \\texttt{false}.');
SELECT intern.nimm__TLKommentarSTS( 'intern.allewlog.logname', 'Es ist der Datenbankbenutzername anzugeben, welcher den aktuellen Eintrag im System hinzugefgt hat.');

SELECT intern.nimm__TLKommentarSTS( 'intern.firma.name', 'Es ist der vollstndige Name der Firma anzugeben.');
SELECT intern.nimm__TLKommentarSTS( 'intern.firma.name_k', 'Es ist die Kurzbezeichnung des Namens der Firma anzugeben.');

SELECT intern.nimm__TLKommentarSTS( 'intern.restzk.restzk', 'Es sind die Zeichenketten einzugeben.');


-- ---------------------------------------------------------------------------------------
-- prj - Projekte	------------------------------------------------------------------
-- ---------------------------------------------------------------------------------------
SELECT intern.nimm__TLKommentarSTS( 'prj.personen.notizen', 'Es sind Zusatzinformationen (z.B. Position, Aufgabe, ...) zur Person anzugeben.');
SELECT intern.nimm__TLKommentarSTS( 'prj.personen.intern_firma_id', 'Es ist die Identifikationsnummer der Firma anzugeben, in welcher die Person angestellt ist.');
SELECT intern.nimm__TLKommentarSTS( 'prj.personen.name_n', 'Es ist der Nachname der Person anzugeben.');
SELECT intern.nimm__TLKommentarSTS( 'prj.personen.name_v', 'Es ist der Vorname der Person anzugeben.');

SELECT intern.nimm__TLKommentarSTS( 'prj.projekte.makefile', E'Es ist der Quelltext des \\texttt{makefiles} anzugeben, welches der Erzeugung smtlicher projektspezifischer Dokumente dient.');
SELECT intern.nimm__TLKommentarSTS( 'prj.projekte.prjbeschr', 'Es ist die Projektbeschreibung anzugeben. Hier sollen Besonderheiten des Projetes erfat werden.');
SELECT intern.nimm__TLKommentarSTS( 'prj.projekte.prjname', 'Es ist die  Bezeichnung (der Name) des aktuellen Projektes anzugeben.');

SELECT intern.nimm__TLKommentarSTS( 'prj.p_dokstrkt.dok_doku_id', 'Identifikationsnummer des aktuellen Dokumentes.');
SELECT intern.nimm__TLKommentarSTS( 'prj.p_dokstrkt.prj_projekte_id', 'Identifikationsnummer des aktuellen Projektes.');
SELECT intern.nimm__TLKommentarSTS( 'prj.p_dokstrkt.str_strkt_id', 'Identifikationsnummer des Strukturpunktes, welcher dem aktuellen Dokument zugeordnet ist.');

SELECT intern.nimm__TLKommentarSTS( 'prj.pp_prtprotokoll.datuhrz', 'Datum / Uhrzeit des Entstehens des PE oder der SF. Fr TP: Datum / Uhrzeit des Meilensteines bzw. Startpunkt einer Aktivitt, welche ber einen Zeitraum reicht.');
SELECT intern.nimm__TLKommentarSTS( 'prj.pp_prtprotokoll.duanfrage', 'Datum / Uhrzeit der Bitte um Antwort auf bzw. Stellungnahme zum aktuellen PE / SF / TP.');
SELECT intern.nimm__TLKommentarSTS( 'prj.pp_prtprotokoll.erledigt', E'Wenn der aktuellen PE, SF, TP erledigt ist, wird \\texttt{true} angegeben.');
SELECT intern.nimm__TLKommentarSTS( 'prj.pp_prtprotokoll.intern', E'Wenn der aktuelle PE, SF, TP ausschlielich intern verwendet werden darf, ist \\texttt{true} anzugeben.');
SELECT intern.nimm__TLKommentarSTS( 'prj.pp_prtprotokoll.prj_personen_id', E'Identifikationsnummer der Person, welche mit dem aktuellen PE / SF / TP in direktem Zusammenhang steht. Wurde \\texttt{pp_prtprotokoll.teilnehmer = true} gesetzt, war die Person am / beim Entstehen des PE / SF / TP beteiligt.');
SELECT intern.nimm__TLKommentarSTS( 'prj.pp_prtprotokoll.prj_projekte_id', 'Identifikationsnummer des aktuellen Projektes.');
SELECT intern.nimm__TLKommentarSTS( 'prj.pp_prtprotokoll.prt_protokoll_id', 'Identifikationsnummer des aktuellen PE / SF / TP.');
SELECT intern.nimm__TLKommentarSTS( 'prj.pp_prtprotokoll.spr_uebvar_id', E'Identifikationsnummer der projektabhngig angepaten Spalte \\texttt{prt.protokoll.spr_uebvar_id}.');
SELECT intern.nimm__TLKommentarSTS( 'prj.pp_prtprotokoll.teilnehmer', E'Wird \\texttt{true} gesetzt, war die beteiligte Person am / beim Entstehen des PE / SF / TP beteiligt. Wird \\texttt{false} gesetzt, wurde der aktuellen Person eine Aufgabe gestellt.');
SELECT intern.nimm__TLKommentarSTS( 'prj.pp_prtprotokoll.termin', 'Sptester Zeitpunkt (Datum / Uhrzeit) der Erledigung des aktuellen PE, SF, TP. Fr TP: Endpunkt einer Aktivitt, welche ber einen Zeitraum reicht.');

SELECT intern.nimm__TLKommentarSTS( 'prj.p_prtstrstrkt.prj_projekte_id', 'Identifikationsnummer des aktuellen Projektes.');
SELECT intern.nimm__TLKommentarSTS( 'prj.p_prtstrstrkt.prt_protokoll_id', 'Es ist die Identifikationsnummer des PE, SF, TP anzugeben.');
SELECT intern.nimm__TLKommentarSTS( 'prj.p_prtstrstrkt.str_strkt_id', 'Identifikationsnummer des dem PE / SF / TP projektspezifisch zugeordneten Strukturpunktes.');

SELECT intern.nimm__TLKommentarSTS( 'prj.p_prtverbindung.prj_projekte_id', 'Identifikationsnummer des aktuellen Projektes.');
SELECT intern.nimm__TLKommentarSTS( 'prj.p_prtverbindung.prt_protokoll_id_nachf', E'Es ist die Identifikationsnummer des PE, SF, TP anzugeben, welcher dem \\texttt{prt_protokoll_id_vorg} folgt.');
SELECT intern.nimm__TLKommentarSTS( 'prj.p_prtverbindung.prt_protokoll_id_vorg', E'Es ist die Identifikationsnummer des PE, SF, TP anzugeben, welcher der Vorgnger von \\texttt{prt_protokoll_id_nachf} ist.');

SELECT intern.nimm__TLKommentarSTS( 'prj.p_psabk.prj_projekte_id', 'Identifikationsnummer des aktuellen Projektes.');
SELECT intern.nimm__TLKommentarSTS( 'prj.p_psabk.ps_abk_id', 'Identifikationsnummer der im Projekt gltigen Abkrzung.');
SELECT intern.nimm__TLKommentarSTS( 'prj.p_psabk.spr_uebvar_id', E'Identifikationsnummer der projektabhngig angepaten Spalte \\texttt{ps.abk.spr_uebvar_id}.');
SELECT intern.nimm__TLKommentarSTS( 'prj.p_psabk.spr_uebvar_id_l', E'Identifikationsnummer der projektabhngig angepaten Spalte \\texttt{ps.abk.spr_uebvar_id_l}.');
SELECT intern.nimm__TLKommentarSTS( 'prj.p_psabk.spr_uebvar_id_zus', E'Identifikationsnummer der projektabhngig angepaten Spalte \\texttt{ps.abk.spr_uebvar_id_zus}.');

SELECT intern.nimm__TLKommentarSTS( 'prj.pl_psgefabk.prj_projekte_id', 'Identifikationsnummer des aktuellen Projektes.');
SELECT intern.nimm__TLKommentarSTS( 'prj.pl_psgefabk.ps_gefszenario_id', 'Identifikationsnummer des Gefahrenszenarios, welchem die Abkrzung zugeordnet werden soll.');
SELECT intern.nimm__TLKommentarSTS( 'prj.pl_psgefabk.ps_abk_id', 'Identifikationsnummer der Abkrzung \\texttt{ps.abk.id}.');
SELECT intern.nimm__TLKommentarSTS( 'prj.pl_psgefabk.spr_uebvar_id_zus', E'Identifikationsnummer der bersetzungsvariante, die zustzliche Informationen (z.B. Darstellung der Hufigkeit bzw. Gefahrenstufe bezogen auf das reprsentative Gefahrenszenario) enthlt.');

SELECT intern.nimm__TLKommentarSTS( 'prj.pl_psgefanm.prj_projekte_id', 'Identifikationsnummer des aktuellen Projektes.');
SELECT intern.nimm__TLKommentarSTS( 'prj.pl_psgefanm.ps_anmerkung_id', 'Identifikationsnummer der Anmerkung welche dem Gefahrenszenario zugeordnet und deren Text gesetzt werden soll.');
SELECT intern.nimm__TLKommentarSTS( 'prj.pl_psgefanm.ps_gefszenario_id', 'Identifikationsnummer des Gefahrenszenarios, welchem die Anmerkung zugeordnet werden soll.');
SELECT intern.nimm__TLKommentarSTS( 'prj.pl_psgefanm.spr_uebvar_id', E'Identifikationsnummer der projektabhngig angepaten Anmerkung.');

SELECT intern.nimm__TLKommentarSTS( 'prj.pl_dokausgabe.datum', 'Datum der aktuellen Ausgabe des Dokumentes.');
SELECT intern.nimm__TLKommentarSTS( 'prj.pl_dokausgabe.dok_doku_id', 'Identifikationsnummer des aktuellen Dokumentes.');
SELECT intern.nimm__TLKommentarSTS( 'prj.pl_dokausgabe.istfrei', E'\\texttt{true} --- Das Dokument ist in der aktuellen Ausgabe freigegeben (nicht mehr im Entwurfsstand).');
SELECT intern.nimm__TLKommentarSTS( 'prj.pl_dokausgabe.nr', 'Identifikationsnummer (Dokumentennummer) des Dokumentes.');
SELECT intern.nimm__TLKommentarSTS( 'prj.pl_dokausgabe.prj_projekte_id', 'Identifikationsnummer des aktuellen Projektes.');
SELECT intern.nimm__TLKommentarSTS( 'prj.pl_dokausgabe.spr_uebvar_id', 'Identifikationsnummer der bersetzungsvariante, welche den Titel des Dokumentes (Dokumententitel) darstellt.');
SELECT intern.nimm__TLKommentarSTS( 'prj.pl_dokausgabe.stand', 'Revisionstand (Kennzeichen der Ausgabe) des aktellen Dokumentes. Wenn er NULL ist, existiert kein Revisionstand.');

SELECT intern.nimm__TLKommentarSTS( 'prj.pl_prtpsgefszenario.prj_projekte_id', 'Identifikationsnummer des aktuellen Projektes.');
SELECT intern.nimm__TLKommentarSTS( 'prj.pl_prtpsgefszenario.prt_protokoll_id', 'Es ist die Identifikationsnummer des Protokolleintrages anzugeben, welcher dem aktuellen Gefahrenszenario zugeordnet werden soll.');
SELECT intern.nimm__TLKommentarSTS( 'prj.pl_prtpsgefszenario.ps_gefszenario_id', 'Es ist die Identifikationsnummer des aktuellen Gefahrenszenarios anzugeben.');

SELECT intern.nimm__TLKommentarSTS( 'prj.pl_psgefstrkt.prj_projekte_id', 'Identifikationsnummer des aktuellen Projektes.');
SELECT intern.nimm__TLKommentarSTS( 'prj.pl_psgefstrkt.ps_gefszenario_id', 'Es ist die Identifikationsnummer des aktuellen Gefahrenszenarios anzugeben.');
SELECT intern.nimm__TLKommentarSTS( 'prj.pl_psgefstrkt.str_strkt_id', 'Es ist die Identifikationsnummer des Strukturpunktes anzugeben, welcher dem aktuellen Gefahrenszenario zugeordnet ist.');

SELECT intern.nimm__TLKommentarSTS( 'prj.ppl_dokdoku.dok_doku_id', 'Es ist die Datenbank-Identifikationsnummer des aktuellen  Dokumentes anzugeben.');
SELECT intern.nimm__TLKommentarSTS( 'prj.ppl_dokdoku.prj_personen_id', 'Es ist die Identifikationsnummer des Ansprechpartners (ggf. der fr das Dokument verantwortlichen Person) anzugeben.');
SELECT intern.nimm__TLKommentarSTS( 'prj.ppl_dokdoku.prj_projekte_id', 'Identifikationsnummer des aktuellen Projektes.');

SELECT intern.nimm__TLKommentarSTS( 'prj.pp_psgefszenario.prj_personen_id', 'Identifikationsnummer der im Projekt fr das Gefahrenszenario verantwortlichen Person.');
SELECT intern.nimm__TLKommentarSTS( 'prj.pp_psgefszenario.prj_projekte_id', 'Identifikationsnummer des aktuellen Projektes.');
SELECT intern.nimm__TLKommentarSTS( 'prj.pp_psgefszenario.ps_gefszenario_id', 'Identifikationsnummer des im Projekt gltigen Gefahrenszenarios.');
SELECT intern.nimm__TLKommentarSTS( 'prj.pp_psgefszenario.spr_uebvar_id', E'Identifikationsnummer der projektabhngig angepaten Spalte \\texttt{ps.gefszenario.spr_uebvar_id}.');
SELECT intern.nimm__TLKommentarSTS( 'prj.pp_psgefszenario.spr_uebvar_id_reprgefszen', E'Identifikationsnummer der projektabhngig angepaten Spalte \\texttt{ps.gefszenario.spr_uebvar_id_reprgefszen}.');
SELECT intern.nimm__TLKommentarSTS( 'prj.pp_psgefszenario.spr_uebvar_id_ursp', E'Identifikationsnummer der projektabhngig angepaten Spalte \\texttt{ps.gefszenario.spr_uebvar_id_ursp}.');

SELECT intern.nimm__TLKommentarSTS( 'prj.pp_strstrkt.prj_personen_id', 'Identifikationsnummer der im Projekt fr den Strukturpunkt verantwortlichen Person.');
SELECT intern.nimm__TLKommentarSTS( 'prj.pp_strstrkt.prj_projekte_id', 'Identifikationsnummer des aktuellen Projektes.');
SELECT intern.nimm__TLKommentarSTS( 'prj.pp_strstrkt.str_strkt_id', 'Identifikationsnummer des im Projekt gltigen Strukturpunktes.');
SELECT intern.nimm__TLKommentarSTS( 'prj.pp_strstrkt.fbereignis', E'Projektabhngig angepate Spalte \\texttt{str.strkt.fbereignis}.');
SELECT intern.nimm__TLKommentarSTS( 'prj.pp_strstrkt.spr_uebvar_id', E'Projektabhngig angepate Spalte \\texttt{str.strkt.spr_uebvar_id}.');
SELECT intern.nimm__TLKommentarSTS( 'prj.pp_strstrkt.spr_uebvar_id_zus', E'Dem einzelnen Strukturpunkt knnen projektabhngige Zusatzinformationen zugeordnet werden.');

SELECT intern.nimm__TLKommentarSTS( 'prj.pl_prtdokdoku.dok_doku_id', 'Es ist die Datenbank-Identifikationsnummer des aktuellen  Dokumentes anzugeben.');
SELECT intern.nimm__TLKommentarSTS( 'prj.pl_prtdokdoku.prj_projekte_id', 'Identifikationsnummer des aktuellen Projektes.');
SELECT intern.nimm__TLKommentarSTS( 'prj.pl_prtdokdoku.prt_protokoll_id', 'Es ist die Identifikationsnummer des PE, SF, TP anzugeben.');

SELECT intern.nimm__TLKommentarSTS( 'prj.p_strverbindung.fbtor', E'Projektabhngig angepate Spalte \\texttt{str.verbindung.fbtor}.');
SELECT intern.nimm__TLKommentarSTS( 'prj.p_strverbindung.prj_projekte_id', 'Identifikationsnummer des aktuellen Projektes.');
SELECT intern.nimm__TLKommentarSTS( 'prj.p_strverbindung.str_strkt_id_nachf', 'Identifikationsnummer des Strukturpunktes, welcher auf einen weiteren Strukturpunkt verweist (diesem folgt).');
SELECT intern.nimm__TLKommentarSTS( 'prj.p_strverbindung.str_strkt_id_vorg', 'Identifikationsnummer des Strukturpunktes, welcher von einem weiteren Strukturpunkt referenziert wird.');



-- ---------------------------------------------------------------------------------------
-- prt - Protokoll	------------------------------------------------------------------
-- ---------------------------------------------------------------------------------------
SELECT intern.nimm__TLKommentarSTS( 'prt.protokoll.prt_typ_id', E'Identifikationsnummer der Klassifizierung des PE, SF, TP.');

SELECT intern.nimm__TLKommentarSTS( 'prt.typ.aspekt', E'Klassifizierung des Typs (ist er ein PE, SF, TP). Die mglichen Werte sind \\texttt{prt.nimm__xxx()} zu entnehmen.');
SELECT intern.nimm__TLKommentarSTS( 'prt.typ.spr_uebvar_id', 'Identifikationsnummer der bersetzungsvariante zur Darstellung des aktuellen Typs.');



--
-- ---------------------------------------------------------------------------------------
-- ps - Produktsicherheit	----------------------------------------------------------
-- ---------------------------------------------------------------------------------------
--
SELECT intern.nimm__TLKommentarSTS( 'ps.abk.typ', E'Es ist der Typ der aktuellen Abkrzung anzugeben. Die gltigen Typen knnen \\texttt{ps.nimm__abk()} entnommen werden.');


-- ---------------------------------------------------------------------------------------
-- spr - Sprache	------------------------------------------------------------------
-- ---------------------------------------------------------------------------------------
SELECT intern.nimm__TLKommentarSTS( 'spr.pos.intern_abczk_id', 'Es ist die Identifikationsnummer des aktuell verwendeten Wortes anzugeben.');
SELECT intern.nimm__TLKommentarSTS( 'spr.pos.intern_restzk_id', 'Es ist die Identifikationsnummer der Zeichenkette anzugeben, welche keine Buchstaben enthlt.');
SELECT intern.nimm__TLKommentarSTS( 'spr.pos.spr_wgruppe_id', 'Es ist die Identifikationsnummer der Wortgruppe anzugeben, in der das aktuelle Wort enthalten ist.');

SELECT intern.nimm__TLKommentarSTS( 'spr.sprachen.sprache', 'Bezeichnung der Sprache, welche fr  bersetzungen verwendet wird.');
SELECT intern.nimm__TLKommentarSTS( 'spr.sprachen.sprache_k', 'Kurzbezeichnung der Sprache.');

SELECT intern.nimm__TLKommentarSTS( 'spr.uebersetzung.spr_sprachen_id', 'Es ist die Identifikationsnummer der aktuell verwendeten Sprache anzugeben.');
SELECT intern.nimm__TLKommentarSTS( 'spr.uebersetzung.spr_uebvar_id', 'Es ist die Identifikationsnummer der aktuell verwendeten bersetzungsvariante anzugeben.');
SELECT intern.nimm__TLKommentarSTS( 'spr.uebersetzung.spr_wgruppe_id', 'Es ist die Identifikationsnummer der aktuell verwendeten Wortgruppe anzugeben.');


-- ---------------------------------------------------------------------------------------
-- str - Strukturen	------------------------------------------------------------------
-- ---------------------------------------------------------------------------------------
SELECT intern.nimm__TLKommentarSTS( 'str.name.name', 'Strukturbezeichnung (Produktgruppenstruktur, Funktionsgruppenstruktur, ...).');
SELECT intern.nimm__TLKommentarSTS( 'str.name.name_k', 'Strukturbezeichnung (Kurzbezeichnung).');

SELECT intern.nimm__TLKommentarSTS( 'str.strkt.nr', 'Nummer (Position) des aktuellen Strukturpunktes in einer Struktur. Die Nummer kann aus Zeichen, Ziffern oder einer Zeichen-/Ziffernkombination bestehen.');
SELECT intern.nimm__TLKommentarSTS( 'str.strkt.str_name_id', 'Identifikationsnummer der Strukturbezeichnung, welcher der aktuelle Strukturpunkt zugeordnet ist.');


-- ---------------------------------------------------------------------------------------
-- tl - Tex/Latex	------------------------------------------------------------------
-- ---------------------------------------------------------------------------------------
SELECT intern.nimm__TLKommentarSTS( 'tl.befehl.befname', E'Name bzw. Bezeichnung des {\\TeX}/\\LaTeX{} Befehls.');
SELECT intern.nimm__TLKommentarSTS( 'tl.befehl.abczk', E'Es ist die Zeichenkette anzugeben, die beim generieren eines ASCII-Textes als Ersatz des TL-Befehlsnamens (siehe \\texttt{tl.befname}) verwendet werden soll. Diese Spalte ist insbesondere fr das Ersetzen von Zweizeichenbefehlen zu verwenden (z.B. \\texttt{tl.befname = "A} --- \\texttt{tl.abczk = }).');

SELECT intern.nimm__TLKommentarSTS( 'tl.datei.dname', 'Dateiname der TL-Datei.');

SELECT intern.nimm__TLKommentarSTS( 'tl.pos.intern_abczk_id', 'Es ist die Identifikationsnummer des Wortes (besteht ausschliesslich aus Buchstaben) anzugeben, welches in der aktuellen TL-Datei verwendet wird.');
SELECT intern.nimm__TLKommentarSTS( 'tl.pos.intern_restzk_id', 'Es ist die Identifikationsnummer der Zeichenkette (enthlt keine Buchstaben) anzugeben, die in der aktuellen TL-Datei verwendet wird.');
SELECT intern.nimm__TLKommentarSTS( 'tl.pos.pos', 'Es ist die Position des TL-Objektes in der TL-Datei anzugeben.');
SELECT intern.nimm__TLKommentarSTS( 'tl.pos.tl_befehl_id', 'Es ist die Identifikationsnummer des TL-Befehls anzugeben, welcher in der aktuellen TL-Datei verwendet wird.');
SELECT intern.nimm__TLKommentarSTS( 'tl.pos.tl_datei_id', 'Es ist die Identifikationsnummer der TL-Datei anzugeben, welche die aktuellen Zeichenketten aufnimmt.');
SELECT intern.nimm__TLKommentarSTS( 'tl.pos.tl_wort_id', 'Es ist die Identifikationsnummer des TL-Wortes anzugeben, welches in der aktuellen TL-Datei verwendet wird.');

SELECT intern.nimm__TLKommentarSTS( 'tl.wort.intern_abczk_id', E'Es ist die Identifikationsnummer zur Spezifikation des Wortes (ohne {\\TeX}/\\LaTeX{} - spezifische Befehle) der aktuellen Sprache anzugeben.');
SELECT intern.nimm__TLKommentarSTS( 'tl.wort.worte', E'Es sind die verwendeten Wrter aller natuerlichen Sprachen einschlielich {\\TeX}/\\LaTeX{} - spezifischer Befehle anzugeben. Sie drfen nicht mehrfach auftreten.');


-- ---------------------------------------------------------------------------------------
-- ---------------------------------------------------------------------------------------
--
-- 3) Schlssel definieren
--
-- ---------------------------------------------------------------------------------------
-- ---------------------------------------------------------------------------------------

-- ---------------------------------------------------------------------------------------
--
-- 3.1) Primrschlssel
--
-- ---------------------------------------------------------------------------------------

-- ---------------------------------------------------------------------------------------
-- dok - Dokumente	------------------------------------------------------------------
-- ---------------------------------------------------------------------------------------
ALTER TABLE dok.doku ADD CONSTRAINT pk__dok_doku_id PRIMARY KEY(id);
ALTER TABLE dok.typ ADD CONSTRAINT pk__dok_typ_id PRIMARY KEY(id);


-- ---------------------------------------------------------------------------------------
-- intern - Intern	------------------------------------------------------------------
-- ---------------------------------------------------------------------------------------
ALTER TABLE intern.abczk ADD CONSTRAINT pk__intern_abczk_id PRIMARY KEY(id);
ALTER TABLE intern.firma ADD CONSTRAINT pk__intern_firma_id PRIMARY KEY(id);
ALTER TABLE intern.restzk ADD CONSTRAINT pk__intern_restzk_id PRIMARY KEY(id);


-- ---------------------------------------------------------------------------------------
-- prj - Projekte	------------------------------------------------------------------
-- ---------------------------------------------------------------------------------------
ALTER TABLE prj.personen ADD CONSTRAINT pk__prj_personen_id PRIMARY KEY(id);
ALTER TABLE prj.projekte ADD CONSTRAINT pk__prj_projekte_id PRIMARY KEY(id);

ALTER TABLE prj.p_dokstrkt ADD CONSTRAINT pk__prj_p_dokstrkt_id PRIMARY KEY(id);
ALTER TABLE prj.pp_prtprotokoll ADD CONSTRAINT pk__prj_pp_protokoll_id PRIMARY KEY(id);
ALTER TABLE prj.p_prtstrstrkt ADD CONSTRAINT pk__prj_p_prtstrstrkt_id PRIMARY KEY(id);
ALTER TABLE prj.p_prtverbindung ADD CONSTRAINT pk__prj_p_prtverbindung_id PRIMARY KEY(id);
ALTER TABLE prj.p_psabk ADD CONSTRAINT pk__prj_p_psabk_id PRIMARY KEY(id);
ALTER TABLE prj.pl_psgefabk ADD CONSTRAINT pk__prj_pl_psgefabk_id PRIMARY KEY(id);
ALTER TABLE prj.pl_psgefanm ADD CONSTRAINT pk__prj_pl_psgefanm_id PRIMARY KEY(id);
ALTER TABLE prj.pl_dokausgabe ADD CONSTRAINT pk__prj_pl_dokausgabe_id PRIMARY KEY(id);
ALTER TABLE prj.pl_prtpsgefszenario ADD CONSTRAINT pk__prj_pl_prtpsgefszenario_id PRIMARY KEY(id);
ALTER TABLE prj.pl_psgefstrkt ADD CONSTRAINT pk__prj_pl_psgefstrkt_id PRIMARY KEY(id);
ALTER TABLE prj.ppl_dokdoku ADD CONSTRAINT pk__prj_ppl_dokdoku_id PRIMARY KEY(id);
ALTER TABLE prj.pp_psgefszenario ADD CONSTRAINT pk__prj_pp_psgefszenario_id PRIMARY KEY(id);
ALTER TABLE prj.pp_strstrkt ADD CONSTRAINT pk__prj_pp_strstrkt_id PRIMARY KEY(id);
ALTER TABLE prj.pl_prtdokdoku ADD CONSTRAINT pk__prj_pl_prtdokdoku_id PRIMARY KEY(id);
ALTER TABLE prj.p_strverbindung ADD CONSTRAINT pk__prj_p_strverbindung_id PRIMARY KEY(id);


-- ---------------------------------------------------------------------------------------
-- prt - Protokoll	------------------------------------------------------------------
-- ---------------------------------------------------------------------------------------
ALTER TABLE prt.protokoll ADD CONSTRAINT pk__prt_protokoll_id PRIMARY KEY(id);
ALTER TABLE prt.typ ADD CONSTRAINT pk__prt_typ_id PRIMARY KEY(id);


-- ---------------------------------------------------------------------------------------
-- ps - Produktsicherheit	----------------------------------------------------------
-- ---------------------------------------------------------------------------------------
ALTER TABLE ps.abk ADD CONSTRAINT pk__ps_abk_id PRIMARY KEY(id);
ALTER TABLE ps.anmerkung ADD CONSTRAINT pk__ps_anmerkung_id PRIMARY KEY(id);
ALTER TABLE ps.gefszenario ADD CONSTRAINT pk__ps_gefszenario_id PRIMARY KEY(id);


-- ---------------------------------------------------------------------------------------
-- spr - Sprache	------------------------------------------------------------------
-- ---------------------------------------------------------------------------------------
ALTER TABLE spr.pos ADD CONSTRAINT pk__spr_pos_id PRIMARY KEY(id);
ALTER TABLE spr.sprachen ADD CONSTRAINT pk__spr_sprachen_id PRIMARY KEY(id);
ALTER TABLE spr.uebvar ADD CONSTRAINT pk__spr_uebvar_id PRIMARY KEY(id);
ALTER TABLE spr.uebersetzung ADD CONSTRAINT pk__spr_uebersetzung_id PRIMARY KEY(id);
ALTER TABLE spr.wgruppe ADD CONSTRAINT pk__spr_wgruppe_id PRIMARY KEY(id);


-- ---------------------------------------------------------------------------------------
-- str - Strukturen	------------------------------------------------------------------
-- ---------------------------------------------------------------------------------------
ALTER TABLE str.name ADD CONSTRAINT pk__str_name_id PRIMARY KEY(id);
ALTER TABLE str.strkt ADD CONSTRAINT pk__str_strkt_id PRIMARY KEY(id);


-- ---------------------------------------------------------------------------------------
-- tl - Tex/Latex	------------------------------------------------------------------
-- ---------------------------------------------------------------------------------------
ALTER TABLE tl.befehl ADD CONSTRAINT pk__tl_befehl_id PRIMARY KEY(id);
ALTER TABLE tl.datei ADD CONSTRAINT pk__tl_datei_id PRIMARY KEY(id);
ALTER TABLE tl.pos ADD CONSTRAINT pk__tl_pos_id PRIMARY KEY(id);
ALTER TABLE tl.wort ADD CONSTRAINT pk__tl_wort_id PRIMARY KEY(id);


-- ---------------------------------------------------------------------------------------
--
-- 3.2) Fremdschlssel
--
-- ---------------------------------------------------------------------------------------

-- ---------------------------------------------------------------------------------------
-- dok - Dokumente	------------------------------------------------------------------
-- ---------------------------------------------------------------------------------------
--ALTER TABLE dok.doku ADD CONSTRAINT fk__dok_doku__intern_firma_id FOREIGN KEY ( intern_firma_id ) REFERENCES intern.firma ( id );
ALTER TABLE dok.doku ADD CONSTRAINT fk__dok_doku__dok_typ_id FOREIGN KEY ( dok_typ_id ) REFERENCES dok.typ ( id );
ALTER TABLE dok.doku ADD CONSTRAINT fk__dok_doku__spr_uebvar_id_kb FOREIGN KEY ( spr_uebvar_id_kb ) REFERENCES spr.uebvar ( id );

ALTER TABLE dok.typ ADD CONSTRAINT fk__dok_typ__spr_uebvar_id FOREIGN KEY ( spr_uebvar_id ) REFERENCES spr.uebvar ( id );



-- ---------------------------------------------------------------------------------------
-- prj - Projekte	------------------------------------------------------------------
-- ---------------------------------------------------------------------------------------
ALTER TABLE prj.personen ADD CONSTRAINT fk__prj_personen__intern_firma_id FOREIGN KEY ( intern_firma_id ) REFERENCES intern.firma ( id );

ALTER TABLE prj.p_dokstrkt ADD CONSTRAINT fk__prj_p_dokstrkt__dok_doku_id FOREIGN KEY ( dok_doku_id ) REFERENCES dok.doku ( id );
ALTER TABLE prj.p_dokstrkt ADD CONSTRAINT fk__prj_p_dokstrkt__prj_projekte_id FOREIGN KEY ( prj_projekte_id ) REFERENCES prj.projekte ( id );
ALTER TABLE prj.p_dokstrkt ADD CONSTRAINT fk__prj_p_dokstrkt__str_strkt_id FOREIGN KEY (str_strkt_id) REFERENCES str.strkt (id);

ALTER TABLE prj.pp_prtprotokoll ADD CONSTRAINT fk__prj_pp_protokoll__prj_personen_id FOREIGN KEY ( prj_personen_id ) REFERENCES prj.personen ( id );
ALTER TABLE prj.pp_prtprotokoll ADD CONSTRAINT fk__prj_pp_protokoll__prj_projekte_id FOREIGN KEY ( prj_projekte_id ) REFERENCES prj.projekte ( id );
ALTER TABLE prj.pp_prtprotokoll ADD CONSTRAINT fk__prj_pp_protokoll__prt_protokoll_id FOREIGN KEY ( prt_protokoll_id ) REFERENCES prt.protokoll ( id );
ALTER TABLE prj.pp_prtprotokoll ADD CONSTRAINT fk__prj_pp_protokoll__spr_uebvar_id FOREIGN KEY ( spr_uebvar_id ) REFERENCES spr.uebvar ( id );

ALTER TABLE prj.p_prtstrstrkt ADD CONSTRAINT fk__prj_p_prtstrstrkt__prj_projekte_id FOREIGN KEY ( prj_projekte_id ) REFERENCES prj.projekte ( id );
ALTER TABLE prj.p_prtstrstrkt ADD CONSTRAINT fk__prj_p_prtstrstrkt__prt_protokoll_id FOREIGN KEY ( prt_protokoll_id ) REFERENCES prt.protokoll ( id );
ALTER TABLE prj.p_prtstrstrkt ADD CONSTRAINT fk__prj_p_prtstrstrkt__str_strkt_id FOREIGN KEY (str_strkt_id) REFERENCES str.strkt (id);

ALTER TABLE prj.p_prtverbindung ADD CONSTRAINT fk__prj_p_prtverbindung__prj_projekte_id FOREIGN KEY ( prj_projekte_id ) REFERENCES prj.projekte ( id );
ALTER TABLE prj.p_prtverbindung ADD CONSTRAINT fk__prj_p_prtverbindung__prt_protokoll_id_nachf FOREIGN KEY ( prt_protokoll_id_nachf ) REFERENCES prt.protokoll ( id );
ALTER TABLE prj.p_prtverbindung ADD CONSTRAINT fk__prj_p_prtverbindung__prt_protokoll_id_vorg FOREIGN KEY ( prt_protokoll_id_vorg ) REFERENCES prt.protokoll ( id );

ALTER TABLE prj.p_psabk ADD CONSTRAINT fk__prj_p_psabk__prj_projekte_id FOREIGN KEY ( prj_projekte_id ) REFERENCES prj.projekte ( id );
ALTER TABLE prj.p_psabk ADD CONSTRAINT fk__prj_p_psabk__ps_abk_id FOREIGN KEY ( ps_abk_id ) REFERENCES ps.abk ( id );
ALTER TABLE prj.p_psabk ADD CONSTRAINT fk__prj_p_psabk__spr_uebvar_id FOREIGN KEY ( spr_uebvar_id ) REFERENCES spr.uebvar ( id );
ALTER TABLE prj.p_psabk ADD CONSTRAINT fk__prj_p_psabk__spr_uebvar_id_l FOREIGN KEY ( spr_uebvar_id_l ) REFERENCES spr.uebvar ( id );
ALTER TABLE prj.p_psabk ADD CONSTRAINT fk__prj_p_psabk__spr_uebvar_id_zus FOREIGN KEY ( spr_uebvar_id_zus ) REFERENCES spr.uebvar ( id );

ALTER TABLE prj.pl_psgefabk ADD CONSTRAINT fk__prj_pl_psgefabk__prj_projekte_id FOREIGN KEY ( prj_projekte_id ) REFERENCES prj.projekte ( id );
ALTER TABLE prj.pl_psgefabk ADD CONSTRAINT fk__prj_pl_psgefabk__ps_abk_id FOREIGN KEY ( ps_abk_id ) REFERENCES ps.abk ( id );
ALTER TABLE prj.pl_psgefabk ADD CONSTRAINT fk__prj_pl_psgefabk__ps_gefszenario_id FOREIGN KEY ( ps_gefszenario_id ) REFERENCES ps.gefszenario ( id );
ALTER TABLE prj.pl_psgefabk ADD CONSTRAINT fk__prj_pl_psgefabk__spr_uebvar_id_zus FOREIGN KEY ( spr_uebvar_id_zus ) REFERENCES spr.uebvar ( id );

ALTER TABLE prj.pl_psgefanm ADD CONSTRAINT fk__prj_pl_psgefanm__prj_projekte_id FOREIGN KEY ( prj_projekte_id ) REFERENCES prj.projekte ( id );
ALTER TABLE prj.pl_psgefanm ADD CONSTRAINT fk__prj_pl_psgefanm__ps_anmerkung_id FOREIGN KEY ( ps_anmerkung_id ) REFERENCES ps.anmerkung ( id );
ALTER TABLE prj.pl_psgefanm ADD CONSTRAINT fk__prj_pl_psgefanm__ps_gefszenario_id FOREIGN KEY ( ps_gefszenario_id ) REFERENCES ps.gefszenario ( id );
ALTER TABLE prj.pl_psgefanm ADD CONSTRAINT fk__prj_pl_psgefanm__spr_uebvar_id FOREIGN KEY ( spr_uebvar_id ) REFERENCES spr.uebvar ( id );

ALTER TABLE prj.pl_dokausgabe ADD CONSTRAINT fk__prj_pl_dokausgabe__dok_doku_id FOREIGN KEY ( dok_doku_id ) REFERENCES dok.doku ( id );
ALTER TABLE prj.pl_dokausgabe ADD CONSTRAINT fk__prj_pl_dokausgabe__prj_projekte_id FOREIGN KEY ( prj_projekte_id ) REFERENCES prj.projekte ( id );
ALTER TABLE prj.pl_dokausgabe ADD CONSTRAINT fk__prj_pl_dokausgabe__spr_uebvar_id FOREIGN KEY ( spr_uebvar_id ) REFERENCES spr.uebvar ( id );

ALTER TABLE prj.pl_prtpsgefszenario ADD CONSTRAINT fk__prj_pl_prtpsgefszenario__prj_projekte_id FOREIGN KEY ( prj_projekte_id ) REFERENCES prj.projekte ( id );
ALTER TABLE prj.pl_prtpsgefszenario ADD CONSTRAINT fk__prj_pl_prtpsgefszenario__prt_protokoll_id FOREIGN KEY ( prt_protokoll_id ) REFERENCES prt.protokoll ( id );
ALTER TABLE prj.pl_prtpsgefszenario ADD CONSTRAINT fk__prj_pl_prtpsgefszenario__ps_gefszenario_id FOREIGN KEY ( ps_gefszenario_id ) REFERENCES ps.gefszenario ( id );

ALTER TABLE prj.pl_psgefstrkt ADD CONSTRAINT fk__prj_pl_psgefstrkt__prj_projekte_id FOREIGN KEY ( prj_projekte_id ) REFERENCES prj.projekte ( id );
ALTER TABLE prj.pl_psgefstrkt ADD CONSTRAINT fk__prj_pl_psgefstrkt__ps_gefszenario_id FOREIGN KEY ( ps_gefszenario_id ) REFERENCES ps.gefszenario ( id );
ALTER TABLE prj.pl_psgefstrkt ADD CONSTRAINT fk__prj_pl_psgefstrkt__str_strkt_id FOREIGN KEY ( str_strkt_id ) REFERENCES str.strkt ( id );

ALTER TABLE prj.ppl_dokdoku ADD CONSTRAINT fk__prj_ppl_dokdoku__dok_doku_id FOREIGN KEY ( dok_doku_id ) REFERENCES dok.doku ( id );
ALTER TABLE prj.ppl_dokdoku ADD CONSTRAINT fk__prj_ppl_dokdoku__prj_personen_id FOREIGN KEY ( prj_personen_id ) REFERENCES prj.personen ( id );
ALTER TABLE prj.ppl_dokdoku ADD CONSTRAINT fk__prj_ppl_dokdoku__prj_projekte_id FOREIGN KEY ( prj_projekte_id ) REFERENCES prj.projekte ( id );

ALTER TABLE prj.pp_psgefszenario ADD CONSTRAINT fk__prj_pp_psgefszenario__prj_personen_id FOREIGN KEY ( prj_personen_id ) REFERENCES prj.personen ( id );
ALTER TABLE prj.pp_psgefszenario ADD CONSTRAINT fk__prj_pp_psgefszenario__prj_projekte_id FOREIGN KEY ( prj_projekte_id ) REFERENCES prj.projekte ( id );
ALTER TABLE prj.pp_psgefszenario ADD CONSTRAINT fk__prj_pp_psgefszenario__ps_gefszenario_id FOREIGN KEY ( ps_gefszenario_id ) REFERENCES ps.gefszenario ( id );
ALTER TABLE prj.pp_psgefszenario ADD CONSTRAINT fk__prj_pp_psgefszenario__spr_uebvar_id FOREIGN KEY ( spr_uebvar_id ) REFERENCES spr.uebvar ( id );
ALTER TABLE prj.pp_psgefszenario ADD CONSTRAINT fk__prj_pp_psgefszenario__spr_uebvar_id_reprgefszen FOREIGN KEY ( spr_uebvar_id_reprgefszen ) REFERENCES spr.uebvar ( id );
ALTER TABLE prj.pp_psgefszenario ADD CONSTRAINT fk__prj_pp_psgefszenario__spr_uebvar_id_ursp FOREIGN KEY ( spr_uebvar_id_ursp ) REFERENCES spr.uebvar ( id );

ALTER TABLE prj.pp_strstrkt ADD CONSTRAINT fk__prj_pp_strstrkt__prj_personen_id FOREIGN KEY ( prj_personen_id ) REFERENCES prj.personen ( id );
ALTER TABLE prj.pp_strstrkt ADD CONSTRAINT fk__prj_pp_strstrkt__prj_projekte_id FOREIGN KEY ( prj_projekte_id ) REFERENCES prj.projekte ( id );
ALTER TABLE prj.pp_strstrkt ADD CONSTRAINT fk__prj_pp_strstrkt__str_strkt_id FOREIGN KEY (str_strkt_id) REFERENCES str.strkt (id);
ALTER TABLE prj.pp_strstrkt ADD CONSTRAINT fk__prj_pp_strstrkt__spr_uebvar_id FOREIGN KEY ( spr_uebvar_id ) REFERENCES spr.uebvar ( id );
ALTER TABLE prj.pp_strstrkt ADD CONSTRAINT fk__prj_pp_strstrkt__spr_uebvar_id_zus FOREIGN KEY ( spr_uebvar_id_zus ) REFERENCES spr.uebvar ( id );

ALTER TABLE prj.pl_prtdokdoku ADD CONSTRAINT fk__prj_pl_prtdokdoku__dok_doku_id FOREIGN KEY ( dok_doku_id ) REFERENCES dok.doku ( id );
ALTER TABLE prj.pl_prtdokdoku ADD CONSTRAINT fk__prj_pl_prtdokdoku__prj_projekte_id FOREIGN KEY ( prj_projekte_id ) REFERENCES prj.projekte ( id );
ALTER TABLE prj.pl_prtdokdoku ADD CONSTRAINT fk__prj_pl_prtdokdoku__prt_protokoll_id FOREIGN KEY ( prt_protokoll_id ) REFERENCES prt.protokoll ( id );

ALTER TABLE prj.p_strverbindung ADD CONSTRAINT fk__prj_p_strverbindung__prj_projekte_id FOREIGN KEY ( prj_projekte_id ) REFERENCES prj.projekte ( id );
ALTER TABLE prj.p_strverbindung ADD CONSTRAINT fk__prj_p_strverbindung__str_strkt_id_nachf FOREIGN KEY (str_strkt_id_nachf) REFERENCES str.strkt (id);
ALTER TABLE prj.p_strverbindung ADD CONSTRAINT fk__prj_p_strverbindung__str_strkt_id_vorg FOREIGN KEY (str_strkt_id_vorg) REFERENCES str.strkt (id);



-- ---------------------------------------------------------------------------------------
-- prt - Protokoll	------------------------------------------------------------------
-- ---------------------------------------------------------------------------------------

ALTER TABLE prt.protokoll ADD CONSTRAINT fk__prt_protokoll__prt_typ_id FOREIGN KEY ( prt_typ_id ) REFERENCES prt.typ ( id );

ALTER TABLE prt.typ ADD CONSTRAINT fk__prt_typ__spr_uebvar_id FOREIGN KEY ( spr_uebvar_id ) REFERENCES spr.uebvar ( id );


-- ---------------------------------------------------------------------------------------
-- spr - Sprache	------------------------------------------------------------------
-- ---------------------------------------------------------------------------------------
ALTER TABLE spr.pos ADD CONSTRAINT fk__spr_pos_intern_abczk_id FOREIGN KEY (intern_abczk_id) REFERENCES intern.abczk (id);
ALTER TABLE spr.pos ADD CONSTRAINT fk__spr_pos_intern_restzk_id FOREIGN KEY (intern_restzk_id) REFERENCES intern.restzk (id);
ALTER TABLE spr.pos ADD CONSTRAINT fk__spr_pos_spr_wgruppe_id FOREIGN KEY (spr_wgruppe_id) REFERENCES spr.wgruppe (id);

ALTER TABLE spr.uebersetzung ADD CONSTRAINT fk__spr_uebersetzung_spr_sprachen_id FOREIGN KEY (spr_sprachen_id) REFERENCES spr.sprachen (id);
ALTER TABLE spr.uebersetzung ADD CONSTRAINT fk__spr_uebersetzung_spr_uebvar_id FOREIGN KEY (spr_uebvar_id) REFERENCES spr.uebvar (id);
ALTER TABLE spr.uebersetzung ADD CONSTRAINT fk__spr_uebersetzung_spr_wgruppe_id FOREIGN KEY (spr_wgruppe_id) REFERENCES spr.wgruppe (id);


-- ---------------------------------------------------------------------------------------
-- str - Strukturen	------------------------------------------------------------------
-- ---------------------------------------------------------------------------------------
ALTER TABLE str.strkt ADD CONSTRAINT fk__str_strkt__str_name_id FOREIGN KEY (str_name_id) REFERENCES str.name (id);


-- ---------------------------------------------------------------------------------------
-- tl - Tex/Latex	------------------------------------------------------------------
-- ---------------------------------------------------------------------------------------
ALTER TABLE tl.wort ADD CONSTRAINT fk__tl_wort__intern_abczk_id FOREIGN KEY (intern_abczk_id) REFERENCES intern.abczk (id);

ALTER TABLE tl.pos ADD CONSTRAINT fk__tl_pos__intern_restzk_id FOREIGN KEY (intern_restzk_id) REFERENCES intern.restzk (id);
ALTER TABLE tl.pos ADD CONSTRAINT fk__tl_pos__intern_abczk_id FOREIGN KEY (intern_abczk_id) REFERENCES intern.abczk (id);
ALTER TABLE tl.pos ADD CONSTRAINT fk__tl_pos__tl_datei_id FOREIGN KEY (tl_datei_id) REFERENCES tl.datei (id);
ALTER TABLE tl.pos ADD CONSTRAINT fk__tl_pos__tl_befehl_id FOREIGN KEY (tl_befehl_id) REFERENCES tl.befehl (id);
ALTER TABLE tl.pos ADD CONSTRAINT fk__tl_pos__tl_wort_id FOREIGN KEY (tl_wort_id) REFERENCES tl.wort (id);


-- ---------------------------------------------------------------------------------------
--
-- 3.3) Unique Constraints
-- 
-- ---------------------------------------------------------------------------------------

-- ---------------------------------------------------------------------------------------
-- dok - Dokumente	------------------------------------------------------------------
-- ---------------------------------------------------------------------------------------
--ALTER TABLE dok.doku ADD CONSTRAINT uc__dok_doku UNIQUE( idfrei, intern_firma_id, spr_uebvar_id_kb );
ALTER TABLE dok.doku ADD CONSTRAINT uc__dok_doku UNIQUE( idfrei, dok_typ_id, spr_uebvar_id_kb );


-- ---------------------------------------------------------------------------------------
-- intern - Intern	------------------------------------------------------------------
-- ---------------------------------------------------------------------------------------
ALTER TABLE intern.abczk ADD CONSTRAINT uc__intern_abczk UNIQUE(idfrei, abczk);
ALTER TABLE intern.firma ADD CONSTRAINT uc__intern_firma UNIQUE(idfrei, name, name_k);
ALTER TABLE intern.restzk ADD CONSTRAINT uc__intern_restzk UNIQUE(idfrei, restzk);


-- ---------------------------------------------------------------------------------------
-- prj - Projekte	------------------------------------------------------------------
-- ---------------------------------------------------------------------------------------
ALTER TABLE prj.personen ADD CONSTRAINT uc__prj_personen UNIQUE(idfrei, name_n, name_v, intern_firma_id);

ALTER TABLE prj.projekte ADD CONSTRAINT uc__prj_projekte UNIQUE(idfrei, prjname);

ALTER TABLE prj.p_dokstrkt ADD CONSTRAINT uc__prj_p_dokstrkt UNIQUE( idfrei, dok_doku_id, prj_projekte_id, str_strkt_id );

ALTER TABLE prj.pp_prtprotokoll ADD CONSTRAINT uc__prj_pp_protokoll UNIQUE(idfrei, prj_projekte_id, prt_protokoll_id, teilnehmer, prj_personen_id );

ALTER TABLE prj.p_prtstrstrkt ADD CONSTRAINT uc__prj_p_prtstrstrkt UNIQUE(idfrei, prj_projekte_id, prt_protokoll_id, str_strkt_id );

ALTER TABLE prj.p_prtverbindung ADD CONSTRAINT uc__prj_p_prtverbindung UNIQUE(idfrei, prj_projekte_id, prt_protokoll_id_nachf, prt_protokoll_id_vorg );

ALTER TABLE prj.p_psabk ADD CONSTRAINT uc__prj_p_psabk UNIQUE(idfrei, prj_projekte_id, ps_abk_id );

ALTER TABLE prj.pl_dokausgabe ADD CONSTRAINT uc__prj_pl_dokausgabe UNIQUE(idfrei, logentfernt, logdatuhrz, dok_doku_id, prj_projekte_id );

ALTER TABLE prj.pl_psgefabk ADD CONSTRAINT uc__prj_pl_psgefabk UNIQUE(idfrei, prj_projekte_id, ps_abk_id, ps_gefszenario_id, logentfernt, logdatuhrz );

ALTER TABLE prj.pl_psgefanm ADD CONSTRAINT uc__prj_pl_psgefanm UNIQUE(idfrei, prj_projekte_id, ps_anmerkung_id, ps_gefszenario_id, logentfernt, logdatuhrz );

ALTER TABLE prj.pl_prtpsgefszenario ADD CONSTRAINT uc__prj_pl_prtpsgefszenario UNIQUE(idfrei, prj_projekte_id, prt_protokoll_id, ps_gefszenario_id, logentfernt, logdatuhrz );

ALTER TABLE prj.pl_psgefstrkt ADD CONSTRAINT uc__prj_pl_psgefstrkt UNIQUE(idfrei, prj_projekte_id, ps_gefszenario_id, str_strkt_id, logentfernt, logdatuhrz );

ALTER TABLE prj.ppl_dokdoku ADD CONSTRAINT uc__prj_ppl_dokdoku UNIQUE(idfrei, logentfernt, logdatuhrz, dok_doku_id, prj_personen_id, prj_projekte_id );

ALTER TABLE prj.pp_psgefszenario ADD CONSTRAINT uc__prj_pp_psgefszenario UNIQUE(idfrei, prj_projekte_id, ps_gefszenario_id );

ALTER TABLE prj.pp_strstrkt ADD CONSTRAINT uc__prj_pp_strstrkt UNIQUE(idfrei, prj_personen_id, prj_projekte_id, str_strkt_id );

ALTER TABLE prj.pl_prtdokdoku ADD CONSTRAINT uc__prj_pl_prtdokdoku UNIQUE(idfrei, logentfernt, logdatuhrz, dok_doku_id, prj_projekte_id, prt_protokoll_id );

ALTER TABLE prj.p_strverbindung ADD CONSTRAINT uc__prj_p_strverbindung UNIQUE(idfrei, prj_projekte_id, str_strkt_id_nachf, str_strkt_id_vorg );



-- ---------------------------------------------------------------------------------------
-- prt - Protokoll	------------------------------------------------------------------
-- ---------------------------------------------------------------------------------------
ALTER TABLE prt.typ ADD CONSTRAINT uc__prt_typ UNIQUE(idfrei, aspekt, spr_uebvar_id);



-- ---------------------------------------------------------------------------------------
-- ps - Produktsicherheit	----------------------------------------------------------
-- ---------------------------------------------------------------------------------------
ALTER TABLE ps.abk ADD CONSTRAINT uc__ps_abk UNIQUE( idfrei, typ );



-- ---------------------------------------------------------------------------------------
-- spr - Sprache	------------------------------------------------------------------
-- ---------------------------------------------------------------------------------------
ALTER TABLE spr.sprachen ADD CONSTRAINT uc__spr_sprachen UNIQUE(idfrei, sprache_k);
ALTER TABLE spr.uebersetzung ADD CONSTRAINT uc__spr_uebersetzung UNIQUE(idfrei, spr_sprachen_id, spr_uebvar_id);


-- ---------------------------------------------------------------------------------------
-- str - Strukturen	------------------------------------------------------------------
-- ---------------------------------------------------------------------------------------
ALTER TABLE str.name ADD CONSTRAINT uc__str_name UNIQUE( idfrei, name, name_k );
ALTER TABLE str.strkt ADD CONSTRAINT uc__str_str_strkt UNIQUE( idfrei, nr, str_name_id );


-- ---------------------------------------------------------------------------------------
-- tl - Tex/Latex	------------------------------------------------------------------
-- ---------------------------------------------------------------------------------------
ALTER TABLE tl.befehl ADD CONSTRAINT uc__tl_befehl UNIQUE(idfrei, befname, abczk);
ALTER TABLE tl.datei ADD CONSTRAINT uc__tl_datei UNIQUE(idfrei, dname);
ALTER TABLE tl.pos ADD CONSTRAINT uc__tl_pos UNIQUE(idfrei, pos, tl_datei_id);
ALTER TABLE tl.wort ADD CONSTRAINT uc__tl_wort UNIQUE(idfrei, intern_abczk_id, worte);


-- ---------------------------------------------------------------------------------------
--
-- 3.4) Check Constraints
-- 
-- ---------------------------------------------------------------------------------------

-- ---------------------------------------------------------------------------------------
-- dok - Dokumente	------------------------------------------------------------------
-- ---------------------------------------------------------------------------------------
ALTER TABLE dok.doku ADD CONSTRAINT cc__dok_doku CHECK( 
	-- Die Zulssigen Aspekte absichern
	( aspekt = 'BEWEIS' OR aspekt = 'QUELLE' ) 
);
SELECT intern.nimm__TLKommentar( 'CONSTRAINT cc__dok_doku ON dok.doku', E'Es darf ausschlielich BEWEIS oder QUELLE angegeben werden.' );


-- ---------------------------------------------------------------------------------------
-- intern - Intern	------------------------------------------------------------------
-- ---------------------------------------------------------------------------------------
ALTER TABLE intern.alle ADD CONSTRAINT cc__intern_alle CHECK( id = 0 AND idfrei = 0 );
SELECT intern.nimm__TLKommentar( 'CONSTRAINT cc__intern_alle ON intern.alle', E'In die Tabelle \\texttt{intern.alle} sollen keine Werte eingefgt werden.' );

ALTER TABLE intern.allewlog ADD CONSTRAINT cc__intern_allewlog CHECK( id = 0 AND idfrei = 0 AND logdatuhrz IS NOT NULL AND logname IS NOT NULL AND logdquelle IS NULL AND logdqok IS NULL AND logentfernt = false );
SELECT intern.nimm__TLKommentar( 'CONSTRAINT cc__intern_allewlog ON intern.allewlog', E'In die Tabelle \\texttt{intern.allewlog} sollen keine Werte eingefgt werden.' );


-- ---------------------------------------------------------------------------------------
-- prj - Projekte	------------------------------------------------------------------
-- ---------------------------------------------------------------------------------------
ALTER TABLE prj.p_strverbindung ADD CONSTRAINT cc__prj_p_strverbindung CHECK( 
	-- Alle Fremdschluessel mssen Null sein, wenn >id< gleich Null ist
	( str_strkt_id_nachf = 0 AND str_strkt_id_vorg = 0 ) 
	-- Wenn >id< grer 0 ist, muss >str_strkt_id_vorg< grer Null sein !
	OR ( id > 0 AND str_strkt_id_vorg > 0 ) 
);
SELECT intern.nimm__TLKommentar( 'CONSTRAINT cc__prj_p_strverbindung ON prj.p_strverbindung', E'Wenn \\texttt{id} Null ist, mssen \\texttt{str_strkt_id_vorg} und \\texttt{str_strkt_id_nachf} Null sein. Sonst mu \\texttt{str_strkt_id_vorg} immer grer Null sein.' );

ALTER TABLE prj.pp_prtprotokoll ADD CONSTRAINT cc__prj_pp_protokoll CHECK( 
	--
	-- Nulleintrag
	--
	( id = 0 AND idfrei = 0 AND prj_personen_id = 0	AND prj_projekte_id = 0	AND prt_protokoll_id = 0 AND spr_uebvar_id = 0 )
	--
	-- gelschter Eintrag
	--
	OR ( id > 0 AND idfrei > 0 )
	--
	-- Protokolleintrag projektspezifisch modifizieren und Randbedingungen setzen
	--
	OR ( id > 0 AND idfrei = 0 AND  prj_personen_id = 0 AND  prj_projekte_id > 0 AND  prt_protokoll_id > 0 AND  teilnehmer = NULL )
	--
	-- dem Protokolleintrag Personen zuordnen
	--
	OR ( id > 0 AND idfrei = 0 AND  prj_personen_id > 0 AND  prj_projekte_id > 0 AND  prt_protokoll_id > 0 AND  spr_uebvar_id = 0 AND  teilnehmer != NULL )
);
SELECT intern.nimm__TLKommentar( 'CONSTRAINT cc__prj_pp_protokoll ON prj.pp_prtprotokoll', E'Dieser CHECK Constraint deckt mehrere Flle ab:
\\\\
\\\\
\\textbf{Nulleintrag}\\\\
Wenn \\texttt{id = 0}, dann mu \\texttt{idfrei = 0}, \\texttt{prj_personen_id = 0}, \\texttt{prj_projekte_id = 0}, \\texttt{prt_protokoll_id = 0}, \\texttt{spr_uebvar_id = 0} sein.
\\\\
\\\\
\\textbf{Protokolleintrag einem Projekt zuordnen, projektspezifisch modifizieren und Randbedingungen setzen}\\\\
Wenn der Protokolleintrag einem Projekt zugeordnet oder umformuliert wird, ''Intern''/''Erledigt'' gesetzt wird oder das Datum des Erstellens des Protokolleintrages spezifiziert wird, dann mu ein Protokolleintrag (\\texttt{prt_protokoll_id > 0}) und ein Projekt (\\texttt{prj_projekte_id > 0}) zugeordnet sein. Weiterhin darf keine Person  (\\texttt{prj\_personen\_id = 0}) zugeordnet sein.
\\\\
Wenn der Protokolleintrag eine Frage / Aufgabe ist, dann mu zustzlich ein Termin (\\texttt{termin NOT NULL}) und das Datum des bersendens der Aufgabe \\texttt{duanfrage NOT NULL} angegeben sein.\\\\
\\\\
\\\\
\\textbf{dem Protokolleintrag die beteiligten Personen bzw. Ansprechpartner zuordnen}\\\\
Wenn dem Protokolleintrag die beteiligten Personen zugeordnet werden, dann mu ein Protokolleintrag (\\texttt{prt_protokoll_id > 0}) und ein Projekt (\\texttt{prj_projekte_id > 0}) ausgewhlt sein. Weiterhin mu eine Person (\\texttt{prj\_personen\_id > 0}) als beteiligte Person (\\texttt{teilnehmer = true}) bzw- Ansprechpartner (\\texttt{teilnehmer = false}) gekennzeichnet und \\texttt{spr_uebvar_id = 0} sein.
'  );


-- ---------------------------------------------------------------------------------------
-- prt - Protokoll	------------------------------------------------------------------
-- ---------------------------------------------------------------------------------------
ALTER TABLE prt.typ ADD CONSTRAINT cc__prt_typ CHECK( 
	-- Die Zulssigen Aspekte absichern
	( aspekt IS NULL OR aspekt = 'PE' OR aspekt = 'SF' OR aspekt = 'TP' ) 
);
SELECT intern.nimm__TLKommentar( 'CONSTRAINT cc__prt_typ ON prt.typ', E'Es darf ausschlielich NULL, PE, SF, TP angegeben werden.' );


-- ---------------------------------------------------------------------------------------
-- spr - Sprache	------------------------------------------------------------------
-- ---------------------------------------------------------------------------------------
ALTER TABLE spr.pos ADD CONSTRAINT cc__spr_pos CHECK( 
	-- Alle Fremdschluessel duerfen Null sein
	( intern_abczk_id = 0 AND intern_restzk_id = 0 AND spr_wgruppe_id = 0 ) 
	-- Wenn >intern_abczk_id< oder >intern_restzk_id< grer 0 ist, muss der andere Null
	-- sein; >spr_wgruppe_id< mu immer grer Null sein !
	OR ( intern_abczk_id > 0 AND intern_restzk_id = 0 AND spr_wgruppe_id > 0 ) 
	OR ( intern_abczk_id = 0 AND intern_restzk_id > 0 AND spr_wgruppe_id > 0 ) 
);
SELECT intern.nimm__TLKommentar( 'CONSTRAINT cc__spr_pos ON spr.pos', 'Wenn \\texttt{intern_abczk_id} grer Null ist, mu \\texttt{intern_restzk_id} Null sein (und umgekehrt). Sind \\texttt{intern_abczk_id} oder \\texttt{intern_restzk_id} grer Null, mu \\texttt{spr_wgruppe_id} immer grer Null sein.' );


-- ---------------------------------------------------------------------------------------
-- tl - Tex/Latex	------------------------------------------------------------------
-- ---------------------------------------------------------------------------------------
ALTER TABLE tl.pos ADD CONSTRAINT cc__tl_pos CHECK( 
	-- Alle Fremdschluessel duerfen Null sein
	( intern_abczk_id = 0 AND intern_restzk_id = 0 AND tl_befehl_id = 0 AND tl_wort_id = 0 ) 
	-- Wenn ein Fremdschluessel > 0 ist, muessen die anderen Null sein
	OR ( intern_abczk_id > 0 AND intern_restzk_id = 0 AND tl_befehl_id = 0 AND tl_wort_id = 0 ) 
	OR ( intern_abczk_id = 0 AND intern_restzk_id > 0 AND tl_befehl_id = 0 AND tl_wort_id = 0 ) 
	OR ( intern_abczk_id = 0 AND intern_restzk_id = 0 AND tl_befehl_id > 0 AND tl_wort_id = 0 ) 
	OR ( intern_abczk_id = 0 AND intern_restzk_id = 0 AND tl_befehl_id = 0 AND tl_wort_id > 0 ) 
);
SELECT intern.nimm__TLKommentar( 'CONSTRAINT cc__tl_pos ON tl.pos', 'Alle Fremdschlssel duerfen Null sein. Wenn ein jedoch Fremdschlssel grer Null ist, mssen die anderen Null sein.' );
