--
--
--
--    filename:	dbstruktur-funktionen.sql
--
--    version:	1.3
--
--    Definition des Datenbankmodells 'Virtuelles Fahrzeug' - vf
--    > Funktionen <
--
--
--
-- ----------------------------------------------------------------------------------------
--
--
--    Copyright (C) 2007-2011  Michael Bellair
--
--    This program is free software: you can redistribute it and/or modify
--    it under the terms of the GNU General Public License as published by
--    the Free Software Foundation, either version 3 of the License, or
--    (at your option) any later version.
--
--    This program is distributed in the hope that it will be useful,
--    but WITHOUT ANY WARRANTY; without even the implied warranty of
--    MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
--    GNU General Public License for more details.
--
--    You should have received a copy of the GNU General Public License
--    along with this program.  If not, see <http://www.gnu.org/licenses/>.
--
--    Michael Bellair
--    Sportplatzstrasse 11
--    01259 Dresden
--
--    E-Mail:	bellair@freenet.de
--    homepage:	http://vf.michaelbellair.de/index.html
--
--
-- ----------------------------------------------------------------------------------------
--





createlang -U postgres plpgsql vf




-- ---------------------------------------------------------------------------------------
-- ---------------------------------------------------------------------------------------
-- ---------------------------------------------------------------------------------------
--			------------------------------------------------------------------
-- dok - Dokumente	------------------------------------------------------------------
--			------------------------------------------------------------------
-- ---------------------------------------------------------------------------------------
-- ---------------------------------------------------------------------------------------
-- ---------------------------------------------------------------------------------------

-- ---------------------------------------------------------------------------------------
-- ---------------------------------------------------------------------------------------
--					--------------------------------------------------
-- 	dok.nimm__doku(...)		--------------------------------------------------
--					--------------------------------------------------
-- ---------------------------------------------------------------------------------------
-- ---------------------------------------------------------------------------------------
CREATE OR REPLACE FUNCTION dok.nimm__doku( IN liste_werte varchar[], OUT dokuid varchar ) AS
$$
DECLARE
--------------------------------------------------------------------------------
-- Konstanten
--------------------------------------------------------------------------------


--------------------------------------------------------------------------------
-- lokale Variablen
--------------------------------------------------------------------------------
--
-- temporre Ganzzahlvariable(n)
--
tmpInteger integer;



BEGIN



--
-- 1.)	Liste >liste_werte< auf Plausibilitt prfen
--		- spr_uebvar_id_kb
--		- dok_typ_id
--		- aspekt
--		- notizen
--
EXECUTE intern.pruefe__array( liste_werte, 2, 4, 'dok.nimm__doku(...)', 'liste_werte' );

EXECUTE intern.pruefe__dt( 'gz', liste_werte[1], '1', NULL
				, 'dok.nimm__doku(...)'
				, 'liste_werte[1]' );

EXECUTE intern.pruefe__dt( 'gz', liste_werte[2], '1', NULL
				, 'dok.nimm__doku(...)'
				, 'liste_werte[2]' );

IF(
	NOT( tmpInteger < 3 )
  ) 
THEN
	IF(
		( tabwerte[3] NOT IN( 'BEWEIS', 'QUELLE' ) )
	  ) 
	THEN

		RAISE EXCEPTION 'dok.nimm__doku(...)	Zur Klassifizierung der Dokumente  >tabwerte[3] = %', tabwerte[3] || '< drfen nur die Werte >BEWEIS< und >QUELLE< bergeben werden. Das Einlesen wird abgebrochen !';
	
	END IF;
	
END IF;



--
-- 2.)	Dokumentenreferenz in >dok.doku< einlesen (Reihenfolge siehe Kommentar)
--
tmpInteger := array_upper( liste_werte, 1 );
EXECUTE
	'SELECT intern.nimm__zeile( ''dok.doku''
			, ARRAY[ ''spr_uebvar_id_kb''
				, ''dok_doku_id'''
				|| CASE WHEN( NOT( tmpInteger < 3 ) )
					THEN ', ''aspekt''' ELSE '' END
				|| CASE WHEN( NOT( tmpInteger < 4 ) )
					THEN ', ''notizen''' ELSE '' END
				|| ']
			, ARRAY[''' 	|| liste_werte[1] || '''
				, '''	|| liste_werte[2] || ''''
				|| CASE WHEN( NOT( tmpInteger < 3 ) )
					THEN ', ''' || liste_werte[3] || '''' ELSE '' END
				|| CASE WHEN( NOT( tmpInteger < 4 ) )
					THEN ', ''' || liste_werte[4] || '''' ELSE '' END
				|| '])'
INTO dokuid;


END
$$LANGUAGE 'plpgsql'  VOLATILE;
SELECT intern.nimm__TLKommentarFunktion( 'dok.nimm__doku( IN liste_werte varchar[], OUT dokuid varchar )',
ARRAY[
E'Liste der Werte, welche in \\texttt{dok.doku} eingelesen werden sollen (Hinweise siehe Funktionsbeschreibung --- Werteliste einlesen). Sie werden in der folgenden Reihenfolge in die Spalten
\\begin{enumerate}
  \\item \\texttt{spr_uebvar_id_kb}
  \\item \\texttt{dok_typ_id}
  \\item \\texttt{aspekt}
  \\item \\texttt{notizen}
\\end{enumerate}
eingetragen. Es mssen mindestens die ersten zwei Werte bergeben werden.\\\\Fr \\texttt{aspekt} darf nur \\texttt{BEWEIS} zur Kennzeichnung von Dokumenen, die beweisen, da eine Sicherheitsanforderung umgesetzt wurde bzw. \\texttt{QUELLE} zur Kennzeichnung von Dokumenten, die auf den Ursprung einer Sicherheitsanforderung verweisen.'
, E'Es wird die Datenbank-Identifikationsnummer der eingelesenen Dokumentenreferenz (\\texttt{dok.doku.id}) zurckgegeben.'
],
E'Mittels dieser Funktion werden die im System zu referenzierenden Dokumente in \\texttt{dok.doku} eingelesen.
\\\\
\\\\
Werteliste einlesen:\\\\
Dem Funktionsparameter \\texttt{liste_werte} ist eine Werteliste (\\texttt{ARRAY}) zu bergeben (die maximale Anzahl und die Reihenfolge der Werte ist fest vorgegeben --- siehe oben). Soll nur eine Teilmenge der Werte bergeben werden, dann sind alle Werte von links nach rechts zu spezifizieren (nichtbentigte Werte am Ende der Liste drfen weggelassen werden).\\\\[2ex]
\\textbf{ACHTUNG\\\\Die Beispiele mssen aktualisiert werden !}'
, ARRAY[
E'-- Fehlermeldung. Der Parameter \\texttt{liste_werte} darf nicht \\texttt{NULL} sein.\\\\SELECT * FROM dok.nimm__doku( NULL );'
, E'-- Fehlermeldung. Es sind mindestens zwei Werte zu bergeben.\\\\SELECT * FROM dok.nimm__doku( ARRAY[''08-15''] );'
, E'-- Fehlermeldung. Die Werte mssen grer \\texttt{0} bzw. drfen nicht leer sein.\\\\SELECT * FROM dok.nimm__doku( ARRAY['''', ''1''] );\\\\SELECT * FROM dok.nimm__doku( ARRAY[''08-15'', ''0''] );'
, E'-- Dokumentenreferenz einlesen\\\\SELECT dok_doku_id, doknr, intern_firma_id_eigentuemer, spr_uebvar_id__doktitel, spr_uebvar_id__kurzbeschr, dok_doku_notizen FROM dok.zeige__doku;\\\\SELECT * FROM dok.nimm__doku( ARRAY[''08-15'', ''1''] );\\\\SELECT * FROM dok.nimm__doku( ARRAY[''08-15'', ''1'', spr.nimm__wgruppe( ''Dokumententitel'', ''1'', ''0'' )] );\\\\SELECT * FROM dok.nimm__doku( ARRAY[''08-15'', ''1'', spr.nimm__wgruppe( ''Dokumententitel'', ''1'', ''0'' ), spr.nimm__wgruppe( ''Dokumentenkurzbeschreibung'', ''1'', ''0'' )] );\\\\SELECT * FROM dok.nimm__doku( ARRAY[''08-15'', ''1'', spr.nimm__wgruppe( ''Dokumententitel'', ''1'', ''0'' ), spr.nimm__wgruppe( ''Dokumentenkurzbeschreibung'', ''1'', ''0'' ), ''Zusatzinformationen''] );\\\\SELECT dok_doku_id, doknr, intern_firma_id__eigentuemer, spr_uebvar_id__doktitel, spr_uebvar_id__kurzbeschr, dok_doku_notizen FROM dok.zeige__doku;'
]
);
--
-- Fehlermeldungen
-- ...............
--
--	-- Fehlermeldung. Der Parameter \\texttt{liste_werte} darf nicht \\texttt{NULL} sein.
--SELECT * FROM dok.nimm__doku( NULL );
--
--	-- Fehlermeldung. Es sind mindestens zwei Werte zu bergeben.
--SELECT * FROM dok.nimm__doku( ARRAY['08-15'] );
--
--	-- Fehlermeldung. Die Werte mssen grer \\texttt{0} bzw. drfen nicht leer sein.
--SELECT * FROM dok.nimm__doku( ARRAY['', '1'] );
--SELECT * FROM dok.nimm__doku( ARRAY['08-15', '0'] );
--
--
--
-- Standardverhalten:
-- ..................
--
--	-- Dokumentenreferenz einlesen
--SELECT dok_doku_id, doknr, intern_firma_id__eigentuemer, spr_uebvar_id__doktitel, spr_uebvar_id__kurzbeschr, dok_doku_notizen FROM dok.zeige__doku;
--SELECT * FROM dok.nimm__doku( ARRAY['08-15', '1'] );

--SELECT * FROM dok.nimm__doku( ARRAY['08-15', '1', spr.nimm__wgruppe( 'Dokumententitel', '1', '0' )] );
--SELECT * FROM dok.nimm__doku( ARRAY['08-15', '1', spr.nimm__wgruppe( 'Dokumententitel', '1', '0' ), spr.nimm__wgruppe( 'Dokumentenkurzbeschreibung', '1', '0' )] );
--SELECT * FROM dok.nimm__doku( ARRAY['08-15', '1', spr.nimm__wgruppe( 'Dokumententitel', '1', '0' ), spr.nimm__wgruppe( 'Dokumentenkurzbeschreibung', '1', '0' ), 'Zusatzinformationen'] );
--SELECT dok_doku_id, doknr, intern_firma_id__eigentuemer, spr_uebvar_id__doktitel, spr_uebvar_id__kurzbeschr, dok_doku_notizen FROM dok.zeige__doku;
--




-- ---------------------------------------------------------------------------------------
-- ---------------------------------------------------------------------------------------
-- ---------------------------------------------------------------------------------------
--				----------------------------------------------------------
-- intern - Interne Funktionen	----------------------------------------------------------
--				----------------------------------------------------------
-- ---------------------------------------------------------------------------------------
-- ---------------------------------------------------------------------------------------
-- ---------------------------------------------------------------------------------------

-- ---------------------------------------------------------------------------------------
-- ---------------------------------------------------------------------------------------
--					--------------------------------------------------
--	intern.gib__ERE_ABCZK()		--------------------------------------------------
--					--------------------------------------------------
-- ---------------------------------------------------------------------------------------
-- ---------------------------------------------------------------------------------------
CREATE OR REPLACE FUNCTION intern.gib__ERE_ABCZK( OUT ere_abczk varchar ) AS
$$

BEGIN

--
-- 1)	ERE zur Beschreibung einer Zeichenkette welche ausschlielich aus Buchstaben 
--	besteht (AbcZK)
--
ere_abczk := intern.gib__ERE_Buchstabe( true ) 
		|| replace( intern.gib__ERE_Buchstabe( false ), '(?e)^', '' )
		|| '*';

END
$$LANGUAGE 'plpgsql' VOLATILE;
SELECT intern.nimm__TLKommentarFunktion( 'intern.gib__ERE_ABCZK( OUT ere_abczk varchar )', 
ARRAY[
'Ist der erweiterte regulaere Ausdruck zur Beschreibung einer AbcZK.'
],
E'Ziel der Funktion ist das Definieren und Zurckgeben eines erweiterten regulren Ausdruckes (ERE), welcher das Textmuster eine Zeichenkette beschreibt, die ausschlielich aus Buchstaben besteht - (AbcZK)- (siehe \\texttt{intern.gib__ERE_Buchstabe(...)}).'
, ARRAY[
E'-- ERE zurckgeben\\\\SELECT * FROM intern.gib__ERE_ABCZK();'
, E'-- \\texttt{hallo} zurckgeben\\\\SELECT substring( ''hallo'' from intern.gib__ERE_ABCZK() );'
, E'-- \\texttt{hal} zurckgeben\\\\SELECT substring( ''hal2lo'' from intern.gib__ERE_ABCZK() );'
]
);
--
-- Standardverhalten:
-- ..................
--
--	-- ERE zurckgeben
--SELECT * FROM intern.gib__ERE_ABCZK();
--
--	-- \\texttt{hallo} zurckgeben
--SELECT substring( 'hallo' from intern.gib__ERE_ABCZK() );
--
--	-- \\texttt{hal} zurckgeben
--SELECT substring( 'hal2lo' from intern.gib__ERE_ABCZK() );
--


-- ---------------------------------------------------------------------------------------
-- ---------------------------------------------------------------------------------------
--					--------------------------------------------------
-- 	intern.gib__ERE_Buchstabe(...)	--------------------------------------------------
--					--------------------------------------------------
-- ---------------------------------------------------------------------------------------
-- ---------------------------------------------------------------------------------------
CREATE OR REPLACE FUNCTION intern.gib__ERE_Buchstabe( istAnfang boolean, OUT ere_buchstabe varchar ) AS
$$

BEGIN

--
-- ERE zur Beschreibung eines Buchstaben
--
ere_buchstabe := '(?e)^[a-zA-Z';


IF(
    istAnfang
  )
THEN
	--
	-- Anfangsbuchstabe
	--
	ere_buchstabe := ere_buchstabe || ']';
ELSE
	--
	-- Folgebuchstabe
	--
	ere_buchstabe := ere_buchstabe || ']';
END IF;

END
$$LANGUAGE 'plpgsql' VOLATILE;
SELECT intern.nimm__TLKommentarFunktion( 'intern.gib__ERE_Buchstabe( istAnfang boolean, OUT ere_buchstabe varchar )', 
ARRAY[
'Der erweiterte regulre Ausdruck eines Anfangsbuchstaben soll zurckgegeben werden'
, E'Soll der erweiterte regulre Ausdruck zur Beschreibung eines Anfangsbuchstaben zurckgegeben werden, ist \\texttt{istAnfang = true} zu setzen. Soll der erweiterte regulre Ausdruck zur Beschreibung eines Folgebuchstaben zurckgegeben werden, ist \\texttt{istAnfang = false} zu setzen.'
],
E'Ziel der Funktion ist das Definieren und Zurueckgeben eines erweiterten regulren Ausdruckes (ERE), welcher das Textmuster eines Anfangsbuchstaben oder Folgebuchstabens beschreibt. Die folgenden Buchstaben werden vom ERE erfat:
\\begin{itemize}
  \\item A-Z
  \\item a-z
  \\item 
  \\item 
  \\item  (nur Folgebuchstabe)
\\end{itemize}'
, ARRAY[
E'-- ERE fr Anfangsbuchstaben zurckgeben\\\\SELECT * FROM intern.gib__ERE_Buchstabe( true );'
, E'-- ERE fr die Buchstaben im Wort zurckgeben\\\\SELECT * FROM intern.gib__ERE_Buchstabe( false );'
, E'-- \\texttt{h} zurckgeben\\\\SELECT substring( ''h'' from intern.gib__ERE_Buchstabe( true ) );'
, E'-- Leerzeichenkette zurckgeben\\\\SELECT substring( '''' from intern.gib__ERE_Buchstabe( true ) );'
, E'-- \\texttt{} zurckgeben\\\\SELECT substring( '''' from intern.gib__ERE_Buchstabe( false ) );'
]
);
--
-- Standardverhalten:
-- ..................
--
--	-- ERE fr Anfangsbuchstaben zurckgeben
--SELECT * FROM intern.gib__ERE_Buchstabe( true );
--
--	-- ERE fr die Buchstaben im Wort zurckgeben
--SELECT * FROM intern.gib__ERE_Buchstabe( false );
--
--	-- \\texttt{h} zurckgeben
--SELECT substring( 'h' from intern.gib__ERE_Buchstabe( true ) );
--
--	-- Leerzeichenkette zurckgeben
--SELECT substring( '' from intern.gib__ERE_Buchstabe( true ) );
--
--	-- \\texttt{} zurckgeben
--SELECT substring( '' from intern.gib__ERE_Buchstabe( false ) );
--


-- ---------------------------------------------------------------------------------------
-- ---------------------------------------------------------------------------------------
--					--------------------------------------------------
--	intern.gib__ERE_RestZK()	--------------------------------------------------
--					--------------------------------------------------
-- ---------------------------------------------------------------------------------------
-- ---------------------------------------------------------------------------------------
CREATE OR REPLACE FUNCTION intern.gib__ERE_RestZK( OUT ere_restzk varchar ) AS
$$

BEGIN

--
-- 1)	ERE zur Beschreibung aller Zeichen, welche keine Buchstaben sind, einschl. Zeilenumbruch
--
ere_restzk :=  E'(?e)^[\]\[\\0-9\n[:space:]!"$%&/()=?`''{}@*+~#<>|,;.:_^|-]+';

END
$$LANGUAGE 'plpgsql' VOLATILE;
SELECT intern.nimm__TLKommentarFunktion( 'intern.gib__ERE_RestZK( OUT ere_restzk varchar )', 
ARRAY[
E'Ist der erweiterte regulre Ausdruck zur Beschreibung der Zeichenketten, die keine Buchstaben enthalten (in \\texttt{intern.restzk} gltig sind).'
],
'Ziel der Funktion ist das Definieren und Zurckgeben eines erweiterten regulren Ausdruckes (ERE), welcher das Textmuster der Zeichenkette beschreibt, die ber die Tastatur eingebbar ist, aber nicht aus Buchstaben besteht.'
, ARRAY[
E'-- ERE zurckgeben\\\\SELECT * FROM intern.gib__ERE_RestZK();'
]
);

--
-- Standardverhalten:
-- ..................
--
--	-- ERE zurckgeben
--SELECT * FROM intern.gib__ERE_RestZK();
--
--	-- die gesamte Zeichenkette bis \\texttt{} zurckgeben
--SELECT '>' || substring( E'		   1234567890 ^!"$%&/{([)]=}?\\` @*+~ '' ><|;,:._- #nderung' from intern.gib__ERE_RestZK() ) || '<';
--


-- ---------------------------------------------------------------------------------------
-- ---------------------------------------------------------------------------------------
--						------------------------------------------
-- 	intern.gib__Liste_abczkrestzk(...)	------------------------------------------
--						------------------------------------------
-- ---------------------------------------------------------------------------------------
-- ---------------------------------------------------------------------------------------
CREATE OR REPLACE FUNCTION intern.gib__Liste_abczkrestzk( wortgruppe varchar, OUT zk varchar, OUT istabczk boolean ) RETURNS SETOF RECORD AS
$$
DECLARE
--------------------------------------------------------------------------------
-- Konstanten
--------------------------------------------------------------------------------

--------------------------------------------------------------------------------
-- lokale Variablen
--------------------------------------------------------------------------------
--
-- Laufvariable
--
lauf integer;



BEGIN


--
-- 1.)	Plausibilitt
--	- Die Wortgruppe ist anzugeben !
--
EXECUTE intern.pruefe__dt( 'zk', wortgruppe, NULL, NULL
				, 'intern.gib__Liste_abczkrestzk(...)'
				, 'wortgruppe' );


--
-- 2.) Wortgruppe zerlegen
--
lauf := 1;
WHILE lauf <= length( wortgruppe )
LOOP

	--
	-- >abcZk< liegt vor
	--
	zk := substring( substr( wortgruppe, lauf ) from intern.gib__ERE_ABCZK() );
	istabczk := true;

	--
	-- >restzk liegt vor<
	--
	IF(
		zk IS NULL
	)
	THEN

		zk := substring( substr( wortgruppe, lauf ) from intern.gib__ERE_RestZK() );
		istabczk := false;

	END IF;

	--
	-- Zeichenketten zurckgeben
	--
	RETURN NEXT;

	--
	-- Startpunkt fr die nchste Zk setzen
	--
	lauf := lauf + length( zk );

END LOOP;

END
$$LANGUAGE 'plpgsql' VOLATILE;
SELECT intern.nimm__TLKommentarFunktion( 'intern.gib__Liste_abczkrestzk( wortgruppe varchar, OUT zk varchar, OUT istabczk boolean )', 
ARRAY[
E'Wortgruppe, welche in \\texttt{abczk} bzw. \\texttt{restzk} zerlegt werden soll'
, E'Zeichenkette aus der \\texttt{wortgruppe}, welche eine \\texttt{abczk} oder \\texttt{restzk} ist'
, E'Wenn \\texttt{istabczk = true} dann ist die in \\texttt{zk} vorliegende Zeichenkette eine \\texttt{abczk} sonst ist sie eine \\texttt{restzk}'
],
E'Ziel der Funktion ist das Zerlegen der Wortgruppe \\texttt{wortgruppe} in \\texttt{abczk} bzw. \\texttt{restzk}  mittels Erweiterter Regulaerer Ausdruecke (ERE).\\\\
\\\\
Die Vorschrift zum Erkennen einer

\\begin{itemize}
  \\item \\texttt{abczk} kann \\texttt{intern.gib__ERE_ABCZK()} bzw.
  \\item \\texttt{restzk} kann \\texttt{intern.gib__ERE_RestZK()}
\\end{itemize}

\\noindent entnommen werden.'
, ARRAY[
E'-- Fehlermeldung. Die Wortgruppe ist anzugeben.\\\\SELECT * FROM intern.gib__Liste_abczkrestzk( NULL );\\\\SELECT * FROM intern.gib__Liste_abczkrestzk( '''' );'
, E'-- Es werden die Bestandteile der Wortgruppe zurckgegeben\\\\SELECT ''>'' || zk || ''<'' AS zk, istabczk FROM intern.gib__Liste_abczkrestzk( ''Das ist ein Array - This is an Array - 1984E'' );'
]
);
--
-- Fehlermeldungen
-- ...............
--
--	-- Fehlermeldung. Die Wortgruppe ist anzugeben.
--SELECT * FROM intern.gib__Liste_abczkrestzk( NULL );
--SELECT * FROM intern.gib__Liste_abczkrestzk( '' );
--
--
--
-- Standardverhalten:
-- ..................
--
--	-- Es werden die Bestandteile der Wortgruppe zurckgegeben
--SELECT '>' || zk || '<' AS zk, istabczk FROM intern.gib__Liste_abczkrestzk( 'Das ist ein Array - This is an Array - 1984E' );
--


-- ---------------------------------------------------------------------------------------
-- ---------------------------------------------------------------------------------------
--							----------------------------------
-- 	intern.gib__Liste_Tabellenpositionen(...)	----------------------------------
--							----------------------------------
-- ---------------------------------------------------------------------------------------
-- ---------------------------------------------------------------------------------------
CREATE OR REPLACE FUNCTION intern.gib__Liste_Tabellenpositionen( IN schName varchar, OUT tabName varchar, OUT ebene varchar ) RETURNS SETOF RECORD AS
$$
DECLARE
--------------------------------------------------------------------------------
-- Konstanten
--------------------------------------------------------------------------------

--------------------------------------------------------------------------------
-- lokale Variablen
--------------------------------------------------------------------------------
--
-- Hilfslisten zur Ausgabe der Tabellenpositionen nach jedem Durchlauf
--
hListeAktPos integer[];		-- Position der Tabelle(n) in >listeZielTab< / >listeStartTab<
hListeAktTabName varchar[];	-- Name der Tabelle
hListeAktEbene varchar[];	-- Ebene der Tabelle
--
-- die Liste der Tabellen wird zum ersten mal durchlaufen
--
istErsterLauf boolean;
--
-- Laufvariablen
--
lauf_1 integer;
lauf_2 integer;
--
-- Liste der Zieltabellen
--
listeZielTab varchar[];
--
-- Liste der Starttabellen
--
listeStartTab varchar[];
--
-- lfd. Nummer der aktuellen Ebene
--
lfdNrEbene integer;
--
-- FOR-LOOP-Schleifenvariable
--
zeile RECORD;
--
-- Anzahl der Zeilen in den Listen
--
zAnz integer;



BEGIN


--
-- 1.)	Plausibilitt
--	- Der Schemaname ist anzugeben
--
EXECUTE intern.pruefe__dt( 'zk', schName, NULL, NULL
				, 'intern.gib__Liste_Tabellenpositionen(...)'
				, 'schName' );



--
-- 2.)	Alle in der DB enthaltenen Tabellennamen einschlielich Verbindungen ermitteln
--	und in >listeZielTab< bzw. >listeStartTab< einlesen
--
FOR
	zeile
IN
	SELECT DISTINCT
		pg_tables.schemaname || '.' || pg_tables.tablename AS tabziel
		, CASE WHEN( 
			verb.spstart IS NOT NULL
		  AND
			intern.gib__stsname( 'sch', verb.spstart ) = schName
		 ) THEN 
			intern.gib__stsname( 'schtab', verb.spstart )
		ELSE '' 
		END AS tabstart

	FROM 
		pg_tables LEFT OUTER JOIN intern.zeige__fremdschluessel verb ON (
			intern.gib__stsname( 'schtab', verb.spziel )
							= ( pg_tables.schemaname
								 || '.' || pg_tables.tablename )
		 )
	WHERE
		lower( pg_tables.schemaname ) NOT LIKE ( '%pg_%' ) 
	AND
		lower( pg_tables.schemaname ) NOT LIKE ( '%information_schema%' )
	AND
		pg_tables.schemaname || '.' || pg_tables.tablename LIKE( schName || '.%' )
	ORDER BY
		tabziel
		, tabstart
LOOP

	--
	-- Werte bernehmen
	--
	IF( array_dims( listeZielTab ) IS NULL ) 
	THEN
		listeZielTab[1] := zeile.tabziel;
		listeStartTab[1] := zeile.tabstart;
	ELSE
		listeZielTab := array_append( listeZielTab, CAST( zeile.tabziel AS varchar ) );
		listeStartTab := array_append( listeStartTab, CAST( zeile.tabstart AS varchar ) );
	END IF;

END LOOP;



--
-- 3.)	Tabellenpositionen ermitteln (Algorithmus siehe unten)
--	(offensichtlich gibt es keine Funktion zum Entfernen eines Elementes aus einem ARRAY, 
--	somit wird die Schleife verlassen, wenn kein Tabellenname mehr enthalten ist)
--
hListeAktPos[1] := 0;
hListeAktTabName[1] := '';
hListeAktEbene[1] := '';
istErsterLauf := true;
lauf_1 := 1;
lfdNrEbene := 1;
zAnz := array_upper( listeZielTab, 1 );
WHILE (
	NOT( '' = ALL ( listeZielTab ) )
	AND ( zAnz > 0 )
 ) 
LOOP

	--
	-- Der im Folgenden beschriebene Algorithmus ist nur dann anwendbar, wenn Ziel- und
	-- Starttabellen benannt sind.
	--
	-- Im ersten Durchlauf werden alle in >listeZielTab< enthaltenen Tabellen der Ebene 1
	-- zugeordnet, welche nicht in >listeStartTab< enthalten sind (diese Tabellen werden
	-- von keiner weiteren Tabelle referenziert - sind eigentlich keine Zieltabellen)
	-- Alle in  >listeZielTab< enthaltenen Tabellen, welche in >listeStartTab< enthalten
	-- sind, werden entfernt, da sie im folgenden Algorithmus bearbeitet werden.
	--
	IF(
		( istErsterLauf )
		AND ( listeStartTab[lauf_1] = '' )
	  )
	THEN

		--
		-- Auf die aktuelle Zieltab wurde nicht referenziert
		--  ->	Tabellennamen bernehmen und Ebene zuordnen, wenn nicht bereits 
		--	geschehen
		--
		IF(
			NOT( listeZielTab[lauf_1] = ANY ( listeStartTab ) )
			AND NOT( listeZielTab[lauf_1] = ANY ( hListeAktTabName ) )
		  )
		THEN

			hListeAktTabName := array_append( hListeAktTabName, 
								listeZielTab[lauf_1] );
			hListeAktEbene := array_append( hListeAktEbene,
							   CAST( lfdNrEbene AS varchar ) );

		END IF;

		--
		-- aktuelle Zieltab aus der Liste entfernen
		--
		listeZielTab[lauf_1] := '';



	--
	-- Modell 1
	-- ........
	--
	-- C <- G <--- F <--- B
	--          |      |
	--           - A    - D
	--          |
	--           - E
	--
	--
	-- Modell 2
	-- ........
	--
	-- B <--- E <--- F
	--     |      |
	-- G <-       |
	--     |      |
	--      - A <--- C
	--     |
	-- D <-
	--
	--
	--
	-- Algorithmus
	-- -----------
	--
	-- >z< ... Zieltabelle
	-- >s< ... Starttabelle
	--
	-- >istz = x<, wenn der Wert der Spalte >z< nicht in Spalte >s< zu finden ist
	--			(Tabelle ist eine Zieltabelle und referenziert nicht auf eine
	--			 weitere Tabelle)
	-- >ists = x<, wenn der Wert der Spalte >s< nicht in Spalte >z< zu finden ist
	--			(Tabelle ist eine Starttabelle und wird nicht referenziert)
	--
	-- nach jedem Durchlauf alle Zeilen mit >istz = x< entfernen.
	--
	-- Ebenen entsprechend >istz< / >ists< festlegen (siehe unten)
	--
	--
	-- Modell 1
	-- ........
	--
	--	z	istz	s	ists
	-- -----------------------------------
	--	C	x	G	-	C: >istz = x< E-Nr.: 1
	--	G	-	F	-	
	--	G	-	A	x	
	--	G	-	E	x	
	--	F	-	B	x	
	--	F	-	D	x	
	-- -----------------------------------
	--	G	x	F	-	G: >istz = x< E-Nr.: 2
	--	G	x	A	x	G: >istz = x< E-Nr.: 2, A: >ists = x< E-Nr.: 3
	--	G	x	E	x	G: >istz = x< E-Nr.: 2, E: >ists = x< E-Nr.: 3
	-- -----------------------------------
	--	F	x	B	x	F: >istz = x< E-Nr.: 3, B: >ists = x< E-Nr.: 4
	--	F	x	D	x	F: >istz = x< E-Nr.: 3, D: >ists = x< E-Nr.: 4
	--
	--
	-- Modell 2
	-- ........
	--
	--	z	istz	s	ists
	-- -----------------------------------
	--	B	x	E	-	B: >istz = x< E-Nr.: 1
	--	E	-	F	x
	--	G	x	E	-	G: >istz = x< E-Nr.: 1
	--	A	-	F	x
	--	A	-	C	x
	--	D	x	A	-	D: >istz = x< E-Nr.: 1
	-- -----------------------------------
	--	E	x	F	x	E: >istz = x< E-Nr.: 2, F: >ists = x< E-Nr.: 3
	--	A	x	F	x	A: >istz = x< E-Nr.: 2, F: >ists = x< E-Nr.: 3
	--	A	x	C	x	A: >istz = x< E-Nr.: 2, C: >ists = x< E-Nr.: 3
	--
	--
	--
	-- Zeilen mit leeren Zieltabellen werden nicht bearbeitet
	--
	ELSIF(
		NOT( istErsterLauf )
		AND ( listeZielTab[lauf_1] != '' )
	  )
	THEN

		--
		-- Tabelle ist eine Zieltabelle und referenziert selbst auf keine weitere 
		-- Tabelle
		--  -> Tabellenname und Ebene zuordnen, wenn nicht bereits geschehen
		--  -> Zeile zum lschen markieren
		--
		IF(
			NOT( listeZielTab[lauf_1] = ANY ( listeStartTab ) )
		  )
		THEN

			--
			-- Tabellenname und Ebene bernehmen
			--
			IF(
				NOT( listeZielTab[lauf_1] = ANY ( hListeAktTabName ) )
			 ) 
			THEN

				hListeAktTabName := array_append( hListeAktTabName, 
									listeZielTab[lauf_1] );
				hListeAktEbene := array_append( hListeAktEbene,
								CAST( lfdNrEbene AS varchar ) );

			END IF;

			--
			-- Position bernehmen
			--
			hListeAktPos := array_append( hListeAktPos, lauf_1 );

			--
			-- Tabelle ist eine Starttabelle und wird nicht referenziert
			--  ->	Tabellenname und nchste Ebene zuordnen, wenn nicht bereits
			--	geschehen
			--
			IF(
				NOT( listeStartTab[lauf_1] = ANY ( listeZielTab ) )
				AND NOT( listeStartTab[lauf_1] = ANY ( hListeAktTabName ) )
			  )
			THEN

				hListeAktTabName := array_append( hListeAktTabName, 
									listeStartTab[lauf_1] );
				hListeAktEbene := array_append( hListeAktEbene,
							   CAST( lfdNrEbene + 1 AS varchar ) );

			END IF;
		END IF;

	END IF;


	--
	-- Es wurde das Ende der Liste erreicht
	--
	IF(
		lauf_1 = zAnz
	  )
	THEN

		--
		-- Die Liste der Tabellenpositionen durchlaufen und
		-- Elemente aus >listeZielTab< / >listeStartTab< lschen
		--
		lauf_2 := 2;
		FOR lauf_2 IN 2..array_upper ( hListeAktPos, 1 ) 
		LOOP

			listeZielTab[hListeAktPos[lauf_2]] := '';
			listeStartTab[hListeAktPos[lauf_2]] := '';

		END LOOP;

		--
		-- Die Liste der Tabellenposition leeren
		--
		hListeAktPos := NULL;
		hListeAktPos[1] := 0;

		--
		-- Laufvariable neu starten
		--
		lauf_1 := 1;

		--
		-- Mit Beenden des zweiten Durchlaufes die lfd. Nr. der Ebene erhhen
		--
		IF(
			NOT( istErsterLauf )
		  )
		THEN
			lfdNrEbene := lfdNrEbene + 1;
		END IF;

		--
		-- Der erste Durchlauf ist beendet 
		--
		istErsterLauf := false;
		
	ELSE

		--
		-- Laufvariable hochzhlen
		--
		lauf_1 := lauf_1 + 1;

	END IF;

END LOOP;



--
-- Alle Tabellennamen einschlielich Ebene zurckgeben
--
lauf_1 := 2;
FOR lauf_1 IN 2..array_upper ( hListeAktTabName, 1 ) 
LOOP

	tabName := hListeAktTabName[lauf_1];
	ebene := hListeAktEbene[lauf_1];
	RETURN NEXT;

END LOOP;

END
$$LANGUAGE 'plpgsql' VOLATILE;
SELECT intern.nimm__TLKommentarFunktion( 'intern.gib__Liste_Tabellenpositionen( IN schName varchar, OUT tabName varchar, OUT ebene varchar )', 
ARRAY[
'Name des Schemas dessen Tabellenpositionen (Ebenen innerhalb der Tabellenhierarchie) ermittelt werden.'
, 'Tabellenname des Schemas'
, 'Position (Ebene) der Tabelle im Schema'
],
E'Ziel der Funktion ist das Ermitteln der Positionen (Ebenen) smtlicher Tabellen im Baum der Tabellenverbindungen (Fremdschlssel) des Schemas \\texttt{schName}.'
, ARRAY[
E'-- Fehlermeldung. Der Parameter \\texttt{schName} darf nicht \\texttt{NULL} oder Leer sein.\\\\SELECT * FROM intern.gib__Liste_Tabellenpositionen( '''' );'
, E'-- Tabellenpositionen ermitteln\\\\SELECT * FROM intern.gib__Liste_Tabellenpositionen( ''dok'' );\\\\SELECT * FROM intern.gib__Liste_Tabellenpositionen( ''intern'' );\\\\SELECT * FROM intern.gib__Liste_Tabellenpositionen( ''kmp'' );\\\\SELECT * FROM intern.gib__Liste_Tabellenpositionen( ''prj'' );\\\\SELECT * FROM intern.gib__Liste_Tabellenpositionen( ''prt'' );\\\\SELECT * FROM intern.gib__Liste_Tabellenpositionen( ''ps'' );\\\\SELECT * FROM intern.gib__Liste_Tabellenpositionen( ''spr'' );\\\\SELECT * FROM intern.gib__Liste_Tabellenpositionen( ''str'' );\\\\SELECT * FROM intern.gib__Liste_Tabellenpositionen( ''tl'' );'
]
);
--
-- Fehlermeldungen
-- ...............
--
--	-- Fehlermeldung. Der Parameter \\texttt{schName} darf nicht \\texttt{NULL} oder Leer sein.
--SELECT * FROM intern.gib__Liste_Tabellenpositionen( '' );
--
--
--
-- Standardverhalten:
-- ..................
--
--	-- Tabellenpositionen ermitteln
--SELECT * FROM intern.gib__Liste_Tabellenpositionen( 'dok' );
--SELECT * FROM intern.gib__Liste_Tabellenpositionen( 'intern' );
--SELECT * FROM intern.gib__Liste_Tabellenpositionen( 'kmp' );
--SELECT * FROM intern.gib__Liste_Tabellenpositionen( 'prj' );
--SELECT * FROM intern.gib__Liste_Tabellenpositionen( 'prt' );
--SELECT * FROM intern.gib__Liste_Tabellenpositionen( 'ps' );
--SELECT * FROM intern.gib__Liste_Tabellenpositionen( 'spr' );
--SELECT * FROM intern.gib__Liste_Tabellenpositionen( 'str' );
--SELECT * FROM intern.gib__Liste_Tabellenpositionen( 'tl' );
--


-- ---------------------------------------------------------------------------------------
-- ---------------------------------------------------------------------------------------
--					--------------------------------------------------
--	intern.gib__naechsteid(...)	--------------------------------------------------
--					--------------------------------------------------
-- ---------------------------------------------------------------------------------------
-- ---------------------------------------------------------------------------------------
CREATE OR REPLACE FUNCTION intern.gib__naechsteid( tabName varchar, OUT tabNameId varchar ) AS
$$

BEGIN

--
-- 1.)	Plausibilitt
--	- Es mu ein Tabellenname bergeben werden
--
EXECUTE intern.pruefe__dt( 'zk', tabName, NULL, NULL
				, 'intern.gib__naechsteid(...)'
				, 'tabName' );


--
-- 2.)	Wiederverwendbare >id< suchen
--
EXECUTE 
	'SELECT id FROM ' || tabName || ' WHERE idfrei > 0 ORDER BY idfrei ASC LIMIT 1'
INTO tabNameId;


--
-- 3.)	Es wurde keine wiederverwendbare >id< gefunden, deshalb nchste >id< berechnen
--
IF(
	tabNameId IS NULL
  ) 
THEN
	EXECUTE 
		'SELECT max( id ) + 1 FROM ' || tabName
	INTO tabNameId;
END IF;


END
$$LANGUAGE 'plpgsql' VOLATILE;
SELECT intern.nimm__TLKommentarFunktion( 'intern.gib__naechsteid( tabName varchar, OUT tabNameId varchar )', 
ARRAY[
E'Name der Tabelle (ggf. einschliesslich Schemaname), aus der die nchste verfgbare Identifikationsnummer \\texttt{id} ermittelt werden soll. (darf nicht leer sein).'
, E'Nchste freie \\texttt{id}'
],
E'Ziel der Funktion ist das Ermitteln der nchsten verfgbaren \\texttt{id} der bergebenen Tabelle \\texttt{tabName}. Es wird der kleinste mgliche Wert gesucht.'
, ARRAY[
E'-- Fehlermeldung. Der Parameter \\texttt{tabName} darf nicht \\texttt{NULL} sein.\\\\SELECT intern.gib__naechsteid( NULL );'
, E'-- Eine wiederverwendbare \\texttt{id} wurde nicht gefunden\\\\SELECT max(id) FROM intern.abczk;\\\\SELECT intern.gib__naechsteid( ''intern.abczk'' );'
, E'-- Eine wiederverwendbare \\texttt{id} wurde gefunden\\\\SELECT intern.nimm__zeile( ''intern.abczk'', ARRAY[''abczk''], ARRAY[''KeinRichtigesWort''] );\\\\SELECT intern.nimm__zeile( ''intern.abczk'', ARRAY[''abczk''], ARRAY[''KeinRichtigesWortZwei''] );\\\\SELECT * FROM intern.abczk ORDER BY id DESC LIMIT 5;\\\\SELECT intern.loesche__zeile( ''intern.abczk'', ''abczk = ''''KeinRichtigesWort'''''' );\\\\SELECT * FROM intern.abczk ORDER BY id DESC LIMIT 5;\\\\SELECT intern.gib__naechsteid( ''intern.abczk'' );'
]
);
--
-- Fehlermeldungen
-- ...............
--
--	-- Fehlermeldung. Der Parameter \\texttt{tabName} darf nicht \\texttt{NULL} sein.
--SELECT intern.gib__naechsteid( NULL );
--
--
--
-- Standardverhalten:
-- ..................
--
--	-- Eine wiederverwendbare \\texttt{id} wurde nicht gefunden
--SELECT max(id) FROM intern.abczk;
--SELECT intern.gib__naechsteid( 'intern.abczk' );
--
--	-- Eine wiederverwendbare \\texttt{id} wurde gefunden
--SELECT intern.nimm__zeile( 'intern.abczk', ARRAY['abczk'], ARRAY['KeinRichtigesWort'] );
--SELECT intern.nimm__zeile( 'intern.abczk', ARRAY['abczk'], ARRAY['KeinRichtigesWortZwei'] );
--SELECT * FROM intern.abczk ORDER BY id DESC LIMIT 5;
--SELECT intern.loesche__zeile( 'intern.abczk', 'abczk = ''KeinRichtigesWort''' );
--SELECT * FROM intern.abczk ORDER BY id DESC LIMIT 5;
--SELECT intern.gib__naechsteid( 'intern.abczk' );
--


-- ---------------------------------------------------------------------------------------
-- ---------------------------------------------------------------------------------------
--					--------------------------------------------------
--	intern.gib__sqlSELECT( ... )	--------------------------------------------------
--					--------------------------------------------------
-- ---------------------------------------------------------------------------------------
-- ---------------------------------------------------------------------------------------
CREATE OR REPLACE FUNCTION intern.gib__sqlSELECT( sel varchar, sel_from varchar[], sel_where varchar, OUT sqlSELECT varchar ) AS
$$
DECLARE
--------------------------------------------------------------------------------
-- Konstanten
--------------------------------------------------------------------------------

--------------------------------------------------------------------------------
-- lokale Variablen
--------------------------------------------------------------------------------
--
-- Laufvariable
--
lauf integer;
--
-- temp. Zk
--
tmpVarChar varchar := '';



BEGIN


--
-- 1.)	Die SELECT-Parameterliste ist anzugeben !
-- 	Die FROM-Parameterliste ist anzugeben !
EXECUTE intern.pruefe__dt( 'zk', sel, NULL, NULL
				, 'intern.gib__sqlSELECT(...)'
				, 'sel' );
EXECUTE intern.pruefe__array( sel_from, 1, NULL, 'intern.gib__sqlSELECT(...)', 'sel_from' );



--
-- 2.)	Die SELECT-Anweisung erzeugen
--
sqlSELECT:= 'SELECT ';

--
-- 2.1)	SELECT-Parameterliste
--
sqlSELECT:= sqlSELECT || sel;

--
-- 2.2)	FROM und WHERE
--
sqlSELECT:= sqlSELECT || ' FROM  ';

FOR lauf IN 1..array_upper ( sel_from, 1 ) 
LOOP
	-- Plausibilitt
	EXECUTE intern.pruefe__dt( 'zk', sel_from[lauf], NULL, NULL
					, 'intern.gib__sqlSELECT(...)'
					, 'sel_from[' || lauf || ']' );
	
	-- FROM
	sqlSELECT:= sqlSELECT || sel_from[lauf];

	-- WHERE
	tmpVarChar := tmpVarChar || sel_from[lauf] || '.idfrei = 0 ';

	IF(
    		lauf < array_upper ( sel_from, 1 )
	  ) 
	THEN
		-- FROM
		sqlSELECT:= sqlSELECT || ', ';

		-- WHERE
		tmpVarChar:= tmpVarChar || ' AND ';
	END IF;

END LOOP;

sqlSELECT:= sqlSELECT || ' WHERE ' || tmpVarChar || sel_where;

END
$$LANGUAGE 'plpgsql' VOLATILE;
SELECT intern.nimm__TLKommentarFunktion( 'intern.gib__sqlSELECT( sel varchar, sel_from varchar[], sel_where varchar, OUT sqlSELECT varchar )', 
ARRAY[
E'Es ist die Liste der Parameter anzugeben, welche das Ergebnis der \\texttt{SELECT} - Abfrage sind. Diese Variable darf nicht leer sein.'
, E'Es ist die Liste (\\texttt{ARRAY}) der Tabellen anzugeben, welche mittels \\texttt{SELECT} - Abfrage ausgewertet werden sollen. Diese Variable darf nicht leer sein.'
, E'Es ist eine \\texttt{WHERE} - Bedingung anzugeben (ggf. einschlielich Semikolon). Diese Variable darf leer sein.'
, E'Es wird die \\texttt{SELECT} - Anweisung zurueckgegeben.'
],
E'Ziel der Funktion ist das Erzeugen einer \\texttt{SELECT} - Anweisung, welche innerhalb einer \\texttt{PL/pgSQL} - Funktion verwendet werden kann. Sie bercksichtigt das Konzept zur Wiederverwendung gelschter \\texttt{id}.
Das abschliessende Semikolon ist explizit anzugeben.'
, ARRAY[
E'-- Fehlermeldung. Der Parameter \\texttt{sel} darf nicht leer oder \\texttt{NULL} sein.\\\\SELECT intern.gib__sqlSELECT( '''', ''{}'', '''' );'
, E'-- Fehlermeldung. Der Parameter \\texttt{sel_from} darf nicht leer oder \\texttt{NULL} sein.\\\\SELECT intern.gib__sqlSELECT( ''hsk'', NULL, '''' );'
, E'-- Fehlermeldung. Kein Element der Liste \\texttt{sel_from} darf leer sein\\\\SELECT intern.gib__sqlSELECT( ''hsk'', ARRAY[''''], '''' );'
, E'-- SQL-Abfrage erzeugen\\\\SELECT intern.gib__sqlSELECT( ''id, idfrei, notizen'', ''{intern.alle}'', '''' );\\\\SELECT intern.gib__sqlSELECT( ''id, idfrei, notizen'', ''{tt.muell, tt.test}'', '' AND tt.muell.id = tt.test.tt_muell_id'' );'
]
);
--
-- Fehlermeldungen
-- ...............
--
--	-- Fehlermeldung. Der Parameter \\texttt{sel} darf nicht leer oder \\texttt{NULL} sein.
--SELECT intern.gib__sqlSELECT( '', '{}', '' );
--
--	-- Fehlermeldung. Der Parameter \\texttt{sel_from} darf nicht leer oder \\texttt{NULL} sein.
--SELECT intern.gib__sqlSELECT( 'hsk', NULL, '' );
--
--	-- Fehlermeldung. Kein Element der Liste \\texttt{sel_from} darf leer sein
--SELECT intern.gib__sqlSELECT( 'hsk', ARRAY[''], '' );
--
--
--
-- Standardverhalten:
-- ..................
--
--	-- SQL-Abfrage erzeugen
--SELECT intern.gib__sqlSELECT( 'id, idfrei, notizen', '{intern.alle}', '' );
--SELECT intern.gib__sqlSELECT( 'id, idfrei, notizen', '{tt.muell, tt.test}', ' AND tt.muell.id = tt.test.tt_muell_id' );
--


-- ---------------------------------------------------------------------------------------
-- ---------------------------------------------------------------------------------------
--					--------------------------------------------------
-- 	intern.gib__stsname(...)	--------------------------------------------------
--					--------------------------------------------------
-- ---------------------------------------------------------------------------------------
-- ---------------------------------------------------------------------------------------
CREATE OR REPLACE FUNCTION intern.gib__stsname( IN befehl varchar, IN vollstname varchar, OUT name varchar ) AS
$$
BEGIN



--
-- 0.) Leerzeichenkette zuordnen
--
name := '';



--
-- 1.)	Plausibilitt
--	- Es mu ein vollstndiger Spaltenname spezifiziert werden.
--	- Es mu ein Befehl angegeben werden.
--
EXECUTE intern.pruefe__dt( 'zk', vollstname, NULL, NULL
				, 'intern.gib__stsname(...)'
				, 'vollstname' );
EXECUTE intern.pruefe__dt( 'zk', befehl, NULL, NULL
				, 'intern.gib__stsname(...)'
				, 'befehl' );



--
-- 2.) Syntax ist falsch
--
IF(
	( substring( vollstname from '(?e)^([a-zA-Z0-9_]+[.][a-zA-Z0-9_]+[.][a-zA-Z0-9_]+)' )  IS NULL )
	OR ( NOT( length( vollstname ) = length( substring( vollstname from '(?e)^([a-zA-Z0-9_]+[.][a-zA-Z0-9_]+[.][a-zA-Z0-9_]+)' ) ) ) )
  )
THEN
	RAISE EXCEPTION 'intern.gib__stsname(...)	Der vollstndige Spaltenname >%', vollstname || '< ist in der Syntax >schema.tabelle.spalte< anzugeben, wobei fr den Schema-, Tabellen- und Spaltenname ausschlielich die Buchstaben >a-z< bzw. >A-Z<, die Ziffern >0-9< und der Unterstrich zu verwenden sind. Das Extrahieren wird abgebrochen !';
END IF;



--
-- 3.) Namen dem >befehl< entsprechend zurckgeben
--
IF(
	befehl = 'sch'
  ) 
THEN

	--
	-- Schemaname
	--
	name := split_part( vollstname, '.', 1 );

ELSIF (
	befehl = 'tab'
  ) 
THEN

	--
	-- Tabellenname
	--
	name := split_part( vollstname, '.', 2 );

ELSIF (
	befehl = 'sp'
  ) 
THEN

	--
	-- Spaltenname
	--
	name := split_part( vollstname, '.', 3 );

ELSIF (
	befehl = 'schtab'
  ) 
THEN

	--
	-- Schemaname und Tabellenname
	--
	name := substring( vollstname from '(?e)^([a-zA-Z0-9_]+[.][a-zA-Z0-9_]+)[.]' );

ELSIF (
	befehl = 'tabsp'
  ) 
THEN

	--
	-- Tabellenname und Spaltenname
	--
	name := substring( vollstname from position( '.' in vollstname ) + 1 );

ELSE

	--
	-- Fehlermeldung. Es drfen nur die Befehle ... verwendet werden
	--
	RAISE EXCEPTION 'intern.gib__stsname(...)	Der bergebene Befehl  >befehl = %', befehl || '< ist nicht zulssig. Es drfen nur die Befehle >sch<, >tab<, >sp<, >schtab<, >tabsp<,  verwendet werden. Das Extrahieren wird abgebrochen !';

END IF;


END
$$LANGUAGE 'plpgsql'  VOLATILE;
SELECT intern.nimm__TLKommentarFunktion( 'intern.gib__stsname( IN befehl varchar, IN vollstname varchar, OUT name varchar )', 
ARRAY[
E'In Form eines fest vorgegebenen Befehls ist anzugeben, welcher Teil des vollstndigen Spaltennamens zurckzugeben ist:
\\begin{description}
  \\item[sch] Schemaname
  \\item[tab] Tabellenname
  \\item[sp] Spaltenname
  \\item[schtab] Schemaname und Tabellenname
  \\item[tabsp] Tabellenname und Spaltenname
\\end{description}
Die Gltigkeit der bergebenen Befehle wird nicht berprft. Es darf nicht \\texttt{NULL} bzw. keine Leerzeichenkette angegeben werden.'
, E'Es ist der vollstndige Spaltenname anzugeben. Es wird geprft, ob die Syntax eingehalten wurde.'
, E'Es wird der Name zurckgebene, welcher in \\texttt{befehl} spezifiziert wurde.'
],
E'Ziel der Funktion ist das Extrahieren des Schema,- Tabellen- oder Spaltennamens aus dem vollstndigen Spaltennamen. Der vollstndige Spaltenname besteht aus dem Schemanamen, dem Tabellennamen und dem Spaltennamen welche mittels Punkt getrennt sind und aus Buchstaben \\texttt{a-z} bzw. \\texttt{A-Z}, Ziffern \\texttt{0-9} bzw. Unterstrich bestehen.\\\\
Im Fehlerfall wird eine Leerzeichenkette zurckgegeben.'
, ARRAY[
E'-- Fehlermeldung. Es ist ein vollstndiger Spaltenname anzugeben\\\\SELECT * FROM intern.gib__stsname( ''sp'', NULL );\\\\SELECT * FROM intern.gib__stsname( ''sp'', '''' );'
, E'-- Fehlermeldung. Es ist Befehl anzugeben\\\\SELECT * FROM intern.gib__stsname( NULL, ''intern.alle.notizen'' );\\\\SELECT * FROM intern.gib__stsname( '''', ''intern.alle.notizen'' );'
, E'-- Fehlermeldung. Der vollstndige Spaltenname ist in der Syntax \\texttt{schema.tabelle.spalte} anzugeben\\\\SELECT * FROM intern.gib__stsname( ''sch'', ''i.a'' );\\\\SELECT * FROM intern.gib__stsname( ''sch'', ''.a.n'' );\\\\SELECT * FROM intern.gib__stsname( ''sch'', ''i..n'' );\\\\SELECT * FROM intern.gib__stsname( ''sch'', ''i.a.'' );\\\\SELECT * FROM intern.gib__stsname( ''sch'', ''..'' );\\\\SELECT * FROM intern.gib__stsname( ''sch'', ''i.a.n'' );\\\\SELECT * FROM intern.gib__stsname( ''sch'', ''i.a2.n'' );\\\\SELECT * FROM intern.gib__stsname( ''sch'', ''i.a.n,'' );\\\\SELECT * FROM intern.gib__stsname( ''sch'', ''i.a.n.falsch'' );'
, E'-- Fehlermeldung. Der bergebene \\texttt{befehl} ist falsch\\\\SELECT * FROM intern.gib__stsname( ''unbekannterBefehl'', ''intern.alle.notizen'' );'
, E'-- Schema, Tabelle, Spalte, ... zurckgeben\\\\SELECT * FROM intern.gib__stsname( ''sch'', ''intern.alle.notizen'' );\\\\SELECT * FROM intern.gib__stsname( ''tab'', ''intern.alle.notizen'' );\\\\SELECT * FROM intern.gib__stsname( ''sp'', ''intern.alle.notizen'' );\\\\SELECT * FROM intern.gib__stsname( ''schtab'', ''intern.alle.notizen'' );\\\\SELECT * FROM intern.gib__stsname( ''tabsp'', ''intern.alle.notizen'' );\\\\SELECT * FROM intern.gib__stsname( ''tabsp'', ''int2ern.al_le.notizen85'' );'
]
);
--
-- Fehlermeldungen
-- ...............
--
--	-- Fehlermeldung. Es ist ein vollstndiger Spaltenname anzugeben
--SELECT * FROM intern.gib__stsname( 'sp', NULL );
--SELECT * FROM intern.gib__stsname( 'sp', '' );
--
--	-- Fehlermeldung. Es ist Befehl anzugeben
--SELECT * FROM intern.gib__stsname( NULL, 'intern.alle.notizen' );
--SELECT * FROM intern.gib__stsname( '', 'intern.alle.notizen' );
--
--	-- Fehlermeldung. Der vollstndige Spaltenname ist in der Syntax \\texttt{schema.tabelle.spalte} anzugeben
--SELECT * FROM intern.gib__stsname( 'sch', 'i.a' );
--SELECT * FROM intern.gib__stsname( 'sch', '.a.n' );
--SELECT * FROM intern.gib__stsname( 'sch', 'i..n' );
--SELECT * FROM intern.gib__stsname( 'sch', 'i.a.' );
--SELECT * FROM intern.gib__stsname( 'sch', '..' );
--SELECT * FROM intern.gib__stsname( 'sch', 'i.a.n' );
--SELECT * FROM intern.gib__stsname( 'sch', 'i.a2.n' );
--SELECT * FROM intern.gib__stsname( 'sch', 'i.a.n,' );
--SELECT * FROM intern.gib__stsname( 'sch', 'i.a.n.falsch' );
--
--	-- Fehlermeldung. Der bergebene \\texttt{befehl} ist falsch
--SELECT * FROM intern.gib__stsname( 'unbekannterBefehl', 'intern.alle.notizen' );
--
-- 
-- Standardverhalten:
-- ..................
--
--	-- Schema, Tabelle, Spalte, ... zurckgeben
--SELECT * FROM intern.gib__stsname( 'sch', 'intern.alle.notizen' );
--SELECT * FROM intern.gib__stsname( 'tab', 'intern.alle.notizen' );
--SELECT * FROM intern.gib__stsname( 'sp', 'intern.alle.notizen' );
--SELECT * FROM intern.gib__stsname( 'schtab', 'intern.alle.notizen' );
--SELECT * FROM intern.gib__stsname( 'tabsp', 'intern.alle.notizen' );
--SELECT * FROM intern.gib__stsname( 'tabsp', 'int2ern.al_le.notizen85' );
--


-- ---------------------------------------------------------------------------------------
-- ---------------------------------------------------------------------------------------
--				----------------------------------------------------------
--	intern.gib__ZU()	----------------------------------------------------------
--				----------------------------------------------------------
-- ---------------------------------------------------------------------------------------
-- ---------------------------------------------------------------------------------------
CREATE OR REPLACE FUNCTION intern.gib__ZU( OUT zu char ) AS
$$
DECLARE
--------------------------------------------------------------------------------
-- Konstanten
--------------------------------------------------------------------------------

--------------------------------------------------------------------------------
-- lokale Variablen
--------------------------------------------------------------------------------

BEGIN

--
-- 1.)	Das im System zugelassene Ersatzzeichen fr den Zeilenumbruch ist das ASCII Zeichen mit 
--	dem Wert (Dezimal) 1
--
zu := chr(1);

END
$$LANGUAGE 'plpgsql' VOLATILE;
SELECT intern.nimm__TLKommentarFunktion( 'intern.gib__ZU( OUT zu char )', 
ARRAY[
'Das Ersatzzeichen fr den Zeilenumbruch'
],
E'Ziel der Funktion ist das Zurckgeben des im System zugelassenen Ersatzzeichens fr den Zeilenumbruch.\\\\
Alle Texte, welche ein Zeilenumbruchzeichen enthalten, sollen mit dem hier zurckgegebenen Zeichen erstellt (gespeichert werden). Das Bearbeiten der Datenbankdumps oder der Texte, welche aus der Datenbank ausgelesen werden, wird vereinfacht.'
, ARRAY[
E'-- Es wird das Ersatzzeichen fr den Zeilenumbruch zurckgegeben\\\\SELECT * FROM intern.gib__ZU();'
]
);
--
-- Standardverhalten:
-- ..................
--
--	-- Es wird das Ersatzzeichen fr den Zeilenumbruch zurckgegeben
--SELECT * FROM intern.gib__ZU();
--


-- ---------------------------------------------------------------------------------------
-- ---------------------------------------------------------------------------------------
--					--------------------------------------------------
--	intern.ist__abczk( ... )	--------------------------------------------------
--					--------------------------------------------------
-- ---------------------------------------------------------------------------------------
-- ---------------------------------------------------------------------------------------
CREATE OR REPLACE FUNCTION intern.ist__abczk( abczk varchar, OUT istAbczk boolean ) AS
$$
DECLARE
--------------------------------------------------------------------------------
-- Konstanten
--------------------------------------------------------------------------------

--------------------------------------------------------------------------------
-- lokale Variablen
--------------------------------------------------------------------------------


BEGIN

--
-- 	Die Entscheidung, ob eine Zeichenkette, welche ausschlielich aus Buchstaben besteht
--	(AbcZK) vorliegt, wird mittels regulrer Ausdrcke (regular expressions - RE) 
--	getroffen.
--
IF(
	length( abczk ) = length( substring( abczk from intern.gib__ERE_ABCZK() ) )
  ) 
THEN
	--
	-- >abczk< ist eine AbcZK
	--
	istAbczk := true;
ELSE
	--
	-- >abczk< ist keine AbcZK
	--
	istAbczk := false;
END IF;

END
$$LANGUAGE 'plpgsql' VOLATILE;
SELECT intern.nimm__TLKommentarFunktion( 'intern.ist__abczk( abczk varchar, OUT istAbczk boolean )', 
ARRAY[
'Es ist die zu testende Zeichenkette anzugeben.'
, E'Wenn eine AbcZK vorliegt wird \\texttt{true} zurckgegeben, sonst \\texttt{false}.'
],
E'Ziel der Funktion ist das Prfen, ob die bergebene Zeichenkette \\texttt{abczk} als Zeichenkette interpretiert werden kann, welche ausschlielich aus Buchstaben besteht (AbcZK). Die gltigen Buchstaben knnen \\texttt{intern.gib__ERE_ABCZK()} entnommen werden.'
, ARRAY[
E'-- Es wird \\texttt{false} zurckgegeben\\\\SELECT * FROM intern.ist__abczk( '''' );\\\\SELECT * FROM intern.ist__abczk( ''ein-/auslesen'' );\\\\SELECT * FROM intern.ist__abczk( '''' );\\\\SELECT * FROM intern.ist__abczk( ''beginnt'' );'
, E'-- Es wird \\texttt{true} zurckgegeben\\\\SELECT * FROM intern.ist__abczk( ''I'' );\\\\SELECT * FROM intern.ist__abczk( ''da'' );'
]
);
--
-- Standardverhalten:
-- ..................
--
--	-- Es wird \\texttt{false} zurckgegeben
--SELECT * FROM intern.ist__abczk( '' );
--SELECT * FROM intern.ist__abczk( 'ein-/auslesen' );
--SELECT * FROM intern.ist__abczk( '' );
--SELECT * FROM intern.ist__abczk( 'beginnt' );
--
--	-- Es wird \\texttt{true} zurckgegeben
--SELECT * FROM intern.ist__abczk( 'I' );
--SELECT * FROM intern.ist__abczk( 'da' );
--


-- ---------------------------------------------------------------------------------------
-- ---------------------------------------------------------------------------------------
--					--------------------------------------------------
--	intern.loesche__zeile(...)	--------------------------------------------------
--					--------------------------------------------------
-- ---------------------------------------------------------------------------------------
-- ---------------------------------------------------------------------------------------
CREATE OR REPLACE FUNCTION intern.loesche__zeile( IN tabName varchar, IN sql_where varchar, IN beachteRI varchar ) RETURNS void AS
$$
DECLARE
--------------------------------------------------------------------------------
-- Konstanten
--------------------------------------------------------------------------------

--------------------------------------------------------------------------------
-- lokale Variablen
--------------------------------------------------------------------------------
--
-- Hilfsvariablen
--
tmpBeachteRI boolean;
tmpVarchar_1 varchar;
tmpVarchar_2 varchar;
--
-- Hilfsvariable fr den UPDATE-Befehl
--
sql_where_intern varchar := CASE WHEN ( ( sql_where = '' ) OR ( sql_where IS NULL ) ) 
				THEN CAST( '' AS text )
				ELSE ' AND ' || sql_where 
				END;
updateSET varchar := '';
updateWHERE varchar := '';
updateZeilen integer;
--
-- FOR-LOOP-Schleifenvariable
--
zeile RECORD;


BEGIN



--
-- 1.)	Plausibilitt
--	- Es mu ein Tabellenname bergeben werden
--
EXECUTE intern.pruefe__dt( 'zk', tabName, NULL, NULL
				, 'intern.loesche__zeile(...)'
				, 'tabName' );
--
--	- Es mu ein Boolescher Wert bergeben werden
--
EXECUTE intern.pruefe__dt( 'bw', beachteRI, NULL, NULL
				, 'intern.loesche__zeile(...)'
				, 'beachteRI' );

tmpBeachteRI := CAST( beachteRI AS Boolean );


--
-- 2)	Liste der zu setzenden Spalten zusammenstellen
--
FOR zeile IN

	SELECT 
		pg_attribute.attname
	FROM 
		pg_namespace, pg_class, pg_attribute
	WHERE 
		pg_class.relnamespace = pg_namespace.oid
	AND
		pg_attribute.attrelid = pg_class.oid
	AND
		NOT( pg_attribute.attisdropped )	-- gelschte Spalten nicht anzeigen
	AND
		NOT( pg_class.relname LIKE( 'sql_%' )	-- Systemtabellen beginnen mit >sql_<
		OR pg_class.relname LIKE( 'pg_%' ) )	-- oder >pg_<
	AND
		pg_class.relkind = 'r'			-- normale Tabelle
	AND
		pg_attribute.attnum > 0			-- < 1 -> Systemspalten
	AND
		pg_namespace.nspname || '.' || pg_class.relname = tabName
	ORDER BY 
		pg_namespace.nspname
		, pg_class.relname
		, pg_attribute.attnum

LOOP

	--
	-- Die Spalten >idfrei< oder >id< berspringen
	--
	IF(
		( zeile.attname = 'id' )
		OR ( zeile.attname = 'idfrei' )
	  ) 
	THEN
		CONTINUE;
	END IF;

	--
	-- Die UPDATE-SET-Zk zusammenstellen
	--
	updateSET := updateSET || ', ' || zeile.attname || ' = DEFAULT';

END LOOP;



--
-- 3)	Die bergebene Tabelle wurde im System nicht gefunden, oder hat keine Spalten ...
--
IF(
	length( updateSET ) = 0
  ) 
THEN
	RAISE EXCEPTION 'intern.loesche__zeile(...)	Die uebergebene Tabelle >%', tabName || '< konnte nicht im System gefunden werden bzw. enthaelt nicht mindestens die Spalten >id<, >idfrei< und >notizen<. Das Loeschen der Zeile wird nicht durchgefuehrt !';
END IF;



--
-- 4) referentielle Integritt sicherstellen
--
tmpVarchar_2 := '';
FOR zeile IN

	SELECT 
		spziel
		, rtrim( substring( spstart from '(?e)^.*[.]' ), '.' ) AS tabstart
		, spstart
	FROM 
		intern.zeige__fremdschluessel
	WHERE
		rtrim( substring( spziel from '(?e)^.*[.]' ), '.' ) = tabName

LOOP

	--
	-- Suche nach mindestens einer Zeile, welche von der Zeile abhngt, die gelscht
	-- werden soll und deren id > 0 
	--
	EXECUTE 
		intern.gib__sqlSELECT( zeile.tabstart || '.id'
					, ARRAY[ tabName, zeile.tabstart]
					, ' AND ' || zeile.spziel || ' = ' || zeile.spstart 
						|| sql_where_intern 
						|| ' AND ' || zeile.tabstart || '.id > 0'
						|| ' LIMIT 1' )
	INTO tmpVarchar_1;

	--
	-- Es wurde eine Zeile gefunden -> Dateinamen fr die Fehlermeldung bernehmen
	--
 	IF(
 		tmpVarchar_1 IS NOT NULL
 	  )
 	THEN
		tmpVarchar_2 := tmpVarchar_2 || ', ' || zeile.tabstart;
	END IF;

END LOOP;


--
-- Wenn mindestens eine Zeile gefunden wurde, welche von der zu lschenden Zeile abhngt
-- und referentielle Integritt beachtet werden soll, dann eine Fehlermeldung generiereren 
-- und die Routine abbrechen

IF(
	( tmpVarchar_2 != '' ) AND tmpBeachteRI
)
THEN

	RAISE EXCEPTION 'intern.loesche__zeile(...)	Die in der uebergebenen Tabelle >%', tabName || '< enthaltene(n) Zeile(n) zur Bedingung >' || ltrim( sql_where_intern, ' AND ' ) || '< werden von der (den) Tabelle(n) >' || ltrim( tmpVarchar_2, ', ' ) || '< verwendet. Das Loeschen der Zeile wird nicht durchgefuehrt (referentielle Integritaet wird sichergestellt) !';

END IF;



--
-- 5)	UPDATE-Bedingung zusammenstellen
--
IF(
	sql_where_intern != ''
  ) 
THEN
	updateWHERE := 'WHERE ' || ltrim( sql_where_intern, ' AND ' );
END IF;



--
-- 6)	Zeile(n) lschen
--
EXECUTE 'UPDATE ' || tabName || ' SET idfrei = id' || updateSET || ' ' || updateWHERE;



--
-- 7)	Die Zeile(n) konnte(n) nicht gelscht werden ...
--
GET DIAGNOSTICS updateZeilen = ROW_COUNT;
IF(
	updateZeilen = 0
  )
THEN
	RAISE EXCEPTION 'intern.loesche__zeile(...)	Die uebergebene Bedingung >%', updateWHERE || '< ist nicht gueltig. Das Loeschen der Zeile(n) wird nicht durchgefuehrt !';
END IF;

END
$$LANGUAGE 'plpgsql' VOLATILE;
SELECT intern.nimm__TLKommentarFunktion( 'intern.loesche__zeile( tabName varchar, sql_where varchar, IN beachteRI varchar )', 
ARRAY[
'Name einschliesslich Schemaname der Tabelle, aus der die Zeile gelscht werden soll (darf nicht leer sein)'
, 'SQL-Bedingung welche die zu lschende(n) Zeile(n) beschreibt (darf leer sein)'
, E'Es ist \\texttt{true} anzugeben, wenn die referentielle Integritt beachtet werden soll. Sonst ist \\texttt{false} anzugeben.'
],
E'Ziel der Funktion ist das Lschen von Zeilen (auer der Zeile mit \\texttt{id = 0} ) unter Bercksichtigung der Bedingungen, welche mittels \\texttt{sql_where} spezifiziert sind. Wenn \\texttt{sql_where} leer ist, werden alle Zeilen gelscht.\\\\
Es ist besonders zu beachten, da \\texttt{tabName} den Schemanamen enthalten muss !'
, ARRAY[
E'-- Fehlermeldung. Der Tabellenname ist anzugeben\\\\SELECT intern.loesche__zeile( NULL, '''' );'
, E'-- Fehlermeldung.  Die bergebene Tabelle ist nicht vorhanden\\\\SELECT intern.loesche__zeile( ''intern.abc'', '''' );'
, E'-- Fehlermeldung. Die Zeilen knnen nicht gelscht werden, da weitere Zeilen abhngen.\\\\SELECT intern.loesche__zeile( ''intern.abczk'', '''' );'
, E'-- Fehlermeldung. Die bergebe WHERE - Bedingung ist ungltig\\\\SELECT intern.loesche__zeile( ''intern.abczk'', ''intern.abczk.id = 99999999'' );'

, E'-- Tabelleninhalt anzeigen\\\\SELECT intern.nimm__zeile( ''tl.datei'', ARRAY[''dname''], ARRAY[''Dateiname-1'']);\\\\SELECT intern.nimm__zeile( ''tl.datei'', ARRAY[''dname''], ARRAY[''Dateiname-2'']);\\\\SELECT * FROM tl.datei WHERE id < 5;'
, E'-- Gesamten Inhalt der Tabelle lschen\\\\SELECT intern.loesche__zeile( ''tl.datei'', NULL );'
, E'-- Zeile mit der \\texttt{id = 1} lschen\\\\SELECT intern.loesche__zeile( ''tl.datei'', ''tl.datei.id = 1'' );'
, E'-- Tabelleninhalt anzeigen\\\\SELECT * FROM tl.datei WHERE id < 5;'
]
);
--
-- Fehlermeldungen
-- ...............
--
--	-- Fehlermeldung. Der Tabellenname ist anzugeben
--SELECT intern.loesche__zeile( NULL, '' );
--
--	-- Fehlermeldung.  Die bergebene Tabelle ist nicht vorhanden
--SELECT intern.loesche__zeile( 'intern.abc', '' );
--
--	-- Fehlermeldung. Die Zeilen knnen nicht gelscht werden, da weitere Zeilen abhngen.
--SELECT intern.loesche__zeile( 'intern.abczk', '' );
--
--	-- Fehlermeldung. Die bergebe WHERE - Bedingung ist ungltig
--SELECT intern.loesche__zeile( 'intern.abczk', 'intern.abczk.id = 99999999' );
--
--
--
-- Standardverhalten:
-- ..................
--
--	-- Tabelleninhalt anzeigen
--SELECT intern.nimm__zeile( 'tl.datei', ARRAY['dname'], ARRAY['Dateiname-1']);
--SELECT intern.nimm__zeile( 'tl.datei', ARRAY['dname'], ARRAY['Dateiname-2']);
--SELECT * FROM tl.datei WHERE id < 5;
--
--	-- Gesamten Inhalt der Tabelle lschen
--SELECT intern.loesche__zeile( 'tl.datei', NULL );
--
--	-- Zeile mit der \\texttt{id = 1} lschen
--SELECT intern.loesche__zeile( 'tl.datei', 'tl.datei.id = 1' );
--
--	-- Tabelleninhalt anzeigen
--SELECT * FROM tl.datei WHERE id < 5;
--


-- ---------------------------------------------------------------------------------------
-- ---------------------------------------------------------------------------------------
--					--------------------------------------------------
--	intern.nimm__TLKommentar(...)	--------------------------------------------------
--					--------------------------------------------------
-- ---------------------------------------------------------------------------------------
-- ---------------------------------------------------------------------------------------
CREATE OR REPLACE FUNCTION intern.nimm__TLKommentar( sqlDBObj varchar, kommentar varchar ) RETURNS void AS
$$
DECLARE
--------------------------------------------------------------------------------
-- Konstanten
--------------------------------------------------------------------------------

--------------------------------------------------------------------------------
-- lokale Variablen
--------------------------------------------------------------------------------


BEGIN


--
-- 1.)	Plausibilitt
--	- Es mu das DB-Objekt bergeben werden
--
EXECUTE intern.pruefe__dt( 'zk', sqlDBObj, NULL, NULL
				, 'intern.nimm__TLKommentar(...)'
				, 'sqlDBObj' );


--
-- 2.)	Kommentar setzen 
--	(Backslash als Escape-Sequenz angeben -> siehe Posgres-Doku  >Section 4.1.2.1<)
--
EXECUTE 'COMMENT ON ' 
		|| sqlDBObj 
		|| ' IS E''' 
		|| replace( replace( replace( kommentar, E'\n', intern.gib__ZU() ), E'\\', E'\\\\' ), '''', '''''' )
		|| '''';


END
$$LANGUAGE 'plpgsql' VOLATILE;
SELECT intern.nimm__TLKommentarFunktion( 'intern.nimm__TLKommentar( sqlDBObj varchar, kommentar varchar )', 
ARRAY[
'Es ist das Datenbankobjekt zu benennen (SQL) welchem der Kommentar hinzugefgt werden soll.'
, E'Der Kommentar (einschl. TL-Befehlen). ''$\\backslash$'' sind zu maskieren !'
],
E'Ziel der Funktion ist das Hinzufgen eines Kommentares zu einem Datenbankobjekt. Im Kommentar knnen TL-Befehle verwendet werden, da die Dokumentation zur Datenbank mittels {\\TeX}/\\LaTeX{} formatiert wird.\\\\
Zeilenumbrche werden mittels \\texttt{intern.gib__ZU()} ersetzt.'
, ARRAY[
E'-- Fehlermeldung. Der Parameter \\texttt{sqlDBObj} darf nicht leer oder \\texttt{NULL} sein.\\\\SELECT intern.nimm__TLKommentar( '''', '''' );\\\\SELECT intern.nimm__TLKommentar( NULL, '''' );'
, E'-- Kommantar gelscht\\\\SELECT intern.nimm__TLKommentar( ''DATABASE '' || current_database(), '''' );'
, E'-- Kommantar hinzugefgt\\\\SELECT intern.nimm__TLKommentar( ''DATABASE '' || current_database(), ''Neuer Kommentar'' );'
, E'-- prfen, ob Kommantar tatschlich hinzugefgt wurde\\\\SELECT shobj_description( ( SELECT oid FROM pg_database WHERE pg_database.datname = current_database() LIMIT 1 ), ''pg_database'');'
]
);
--
-- Fehlermeldungen
-- ...............
--
--	-- Fehlermeldung. Der Parameter \\texttt{sqlDBObj} darf nicht leer oder \\texttt{NULL} sein.
--SELECT intern.nimm__TLKommentar( '', '' );
--SELECT intern.nimm__TLKommentar( NULL, '' );
--
--
--
-- Standardverhalten:
-- ..................
--
--	-- Kommantar gelscht
--SELECT intern.nimm__TLKommentar( 'DATABASE ' || current_database(), '' );
--
--	-- Kommantar hinzugefgt
--SELECT intern.nimm__TLKommentar( 'DATABASE ' || current_database(), 'Neuer Kommentar' );
--
--	-- prfen, ob Kommantar tatschlich hinzugefgt wurde
--SELECT shobj_description( ( SELECT oid FROM pg_database WHERE pg_database.datname = current_database() LIMIT 1 ), 'pg_database');
--


-- ---------------------------------------------------------------------------------------
-- ---------------------------------------------------------------------------------------
--						------------------------------------------
--	intern.nimm__TLKommentarFunktion(...)	------------------------------------------
--						------------------------------------------
-- ---------------------------------------------------------------------------------------
-- ---------------------------------------------------------------------------------------
CREATE OR REPLACE FUNCTION intern.nimm__TLKommentarFunktion( fkt varchar, fktparam varchar[], beschr varchar, beispiel varchar[] ) RETURNS void AS
$$
DECLARE
--------------------------------------------------------------------------------
-- Konstanten
--------------------------------------------------------------------------------

--------------------------------------------------------------------------------
-- lokale Variablen
--------------------------------------------------------------------------------
--
-- Kommentar zusammenbauen
--
kommentar varchar;
--
-- Laufvariable
--
lauf integer;



BEGIN



--
-- 1.)	Plausibilitt
--	- Es mu der Funktionsname bergeben werden
-- 	- Es mu eine Beschreibung bergeben werden
--
EXECUTE intern.pruefe__dt( 'zk', fkt, NULL, NULL
				, 'intern.nimm__TLKommentarFunktion(...)'
				, 'fkt' );
EXECUTE intern.pruefe__dt( 'zk', beschr, NULL, NULL
				, 'intern.nimm__TLKommentarFunktion(...)'
				, 'beschr' );



--
-- 2.)	Kommentar der Funktionsparameter zusammenbauen ASCII-2 als Trennzeichen verwenden
--
IF(
	fktparam IS NULL
  )
THEN

	kommentar := '';

ELSE

	kommentar := '
Beschreibung der Funktionsparameter/Rckgabewert(e):
----------------------------------------------------
';

	FOR lauf IN 1..array_upper ( fktparam, 1 )
	LOOP
		kommentar := kommentar
				|| 'P'
				|| CAST( lauf AS text )
				|| '    '
				|| chr( 2 )
				|| fktparam[lauf]
				|| chr( 2 )
				|| chr( 10 );
	END LOOP;

END IF;



--
-- 3.)	Funktionsbeschreibung ergnzen
--
kommentar := kommentar 
		|| '
Beschreibung:
-------------
'
		|| chr( 3 )
		|| beschr
		|| chr( 10 );



--
-- 4.)	Kommentar der Funktionsparameter zusammenbauen ASCII-2 als Trennzeichen verwenden
--
IF(
	beispiel IS NULL
  )
THEN

	kommentar := kommentar || '';

ELSE

	kommentar := kommentar || chr( 3 ) || '
Beispiele:
----------
';

	FOR lauf IN 1..array_upper ( beispiel, 1 )
	LOOP
		kommentar := kommentar
				|| chr( 3 )
				|| beispiel[lauf]
				|| chr( 10 );
	END LOOP;

END IF;



--
-- 5.)	Beschreibung (Kommentar) setzen
--
EXECUTE intern.nimm__TLKommentar( 'FUNCTION '|| fkt, kommentar );


END
$$LANGUAGE 'plpgsql' VOLATILE;
SELECT intern.nimm__TLKommentarFunktion( 'intern.nimm__TLKommentarFunktion( fkt varchar, fktparam varchar[], beschr varchar, beispiel varchar[] )'
, ARRAY[
'Es ist der Name der Funktion anzugeben, der der Kommentar zugeordnet werden soll. Er darf nicht leer oder NULL sein.'
, E'In Form eines ARRAY sind in der Reihenfolge ihres Auftretens smtliche Beschreibungen der Funktionsparameter anzugeben. Es wird nicht zwischen Eingabeparametern \\texttt{IN} bzw. Rckgabeparametern \\texttt{OUT / INOUT} unterschieden. Sollte die Funktion ber keine Parameter verfgen, ist \\texttt{NULL} anzugeben.'
, E'Es ist die Beschreibung der Funktion einzugeben. Sie darf nicht leer oder \\texttt{NULL} sein.'
, E'Es knnen mehrere Beispiele zur Demonstration der Nutzung der Funktion angegeben werden. Sie drfen \\texttt{NULL} sein.'
],
E'Ziel der Funktion ist das Hinzufgen einer Beschreibung (eines  Kommentars) zu einer Funktion.
Hinweise zur Gltigkeit knnen \\texttt{intern.nimm__TLKommentar(...)} entnommen werden.' 
, ARRAY[
E'-- Fehlermeldung. Die Parameter \\texttt{fkt} und \\texttt{beschr} drfen nicht \\texttt{NULL} sein.\\\\SELECT intern.nimm__TLKommentarFunktion( NULL, NULL, '''', NULL );\\\\SELECT intern.nimm__TLKommentarFunktion( ''intern.nimm__TLKommentarFunktion'', NULL, '''', NULL );'
, E'-- Kommentar einlesen\\\\SELECT intern.nimm__TLKommentarFunktion( ''intern.nimm__TLKommentarFunktion( fkt varchar, fktparam varchar[], beschr varchar, beispiel varchar[] )'', NULL, ''Testbeschreibung'', NULL );\\\\$\\backslash$df+ intern.nimm__tlkommentarfunktion '
]
);
--
-- Fehlermeldungen
-- ...............
--
--	-- Fehlermeldung. Die Parameter \\texttt{fkt} und \\texttt{beschr} drfen nicht \\texttt{NULL} sein.
--SELECT intern.nimm__TLKommentarFunktion( NULL, NULL, '', NULL );
--SELECT intern.nimm__TLKommentarFunktion( 'intern.nimm__TLKommentarFunktion', NULL, '', NULL );
--
--
--
-- Standardverhalten:
-- ..................
--
--	-- Kommentar einlesen
--SELECT intern.nimm__TLKommentarFunktion( 'intern.nimm__TLKommentarFunktion( fkt varchar, fktparam varchar[], beschr varchar, beispiel varchar[] )', NULL, E'Testbeschreibung - \\texttt{fkt}', NULL );
--\df+ intern.nimm__tlkommentarfunktion 
--


-- ---------------------------------------------------------------------------------------
-- ---------------------------------------------------------------------------------------
--						------------------------------------------
--	intern.nimm__TLKommentarSicht(...)	------------------------------------------
--						------------------------------------------
-- ---------------------------------------------------------------------------------------
-- ---------------------------------------------------------------------------------------
CREATE OR REPLACE FUNCTION intern.nimm__TLKommentarSicht( sicht varchar, spNamen varchar[], spBeschr varchar[], beschr varchar ) RETURNS void AS
$$
DECLARE
--------------------------------------------------------------------------------
-- Konstanten
--------------------------------------------------------------------------------

--------------------------------------------------------------------------------
-- lokale Variablen
--------------------------------------------------------------------------------
--
-- Kommentar zusammenbauen
--
kommentar varchar;
--
-- Laufvariable
--
lauf integer;



BEGIN



--
-- 1.)	Plausibilitt
--	- Es mu der Name der Sicht bergeben werden
-- 	- Es mu mindestens eine Spalte beschrieben werden
--	- Es mu eine Funktionsbeschreibung bergeben werden
--
EXECUTE intern.pruefe__dt( 'zk', sicht, NULL, NULL
				, 'intern.nimm__TLKommentarSicht(...)'
				, 'sicht' );
EXECUTE intern.pruefe__array( spNamen, 1, NULL
				, 'intern.nimm__TLKommentarSicht(...)'
				, 'spNamen' );
EXECUTE intern.pruefe__array( spBeschr, 1, NULL
				, 'intern.nimm__TLKommentarSicht(...)'
				, 'spBeschr' );
EXECUTE intern.pruefe__dt( 'zk', beschr, NULL, NULL
				, 'intern.nimm__TLKommentarSicht(...)'
				, 'beschr' );


--
-- 1.)	
--
--IF(
--	( length( sicht ) = 0 )
--	OR ( sicht IS NULL )
--  ) 
--THEN
--	RAISE EXCEPTION 'intern.nimm__TLKommentarSicht(...)	Es ist der Name der Sicht anzugeben, welcher der Kommentar zugeordnet werden soll. Der Kommentar wurde nicht zugeordnet !';
--END IF;



--
-- 2.)	
--
--IF(
--	( spNamen IS NULL )
--	OR ( spBeschr IS NULL )
--  ) 
--THEN
--	RAISE EXCEPTION 'intern.nimm__TLKommentarSicht(...)	Es muss mindestens eine Spalte beschrieben werden. Der Kommentar wurde nicht zugeordnet !';
--END IF;



--
-- 3.)	Die Anzahl der Spaltennamen mu mit der Anzahl der Beschreibungen bereinstimmen
--
IF(
	array_upper( spNamen, 1 ) != array_upper( spBeschr, 1 )
  ) 
THEN
	RAISE EXCEPTION 'intern.nimm__TLKommentarSicht(...)	Die Anzahl der Spaltennamen muss mit der Anzahl der Beschreibungen uebereinstimmen. Der Kommentar wurde nicht zugeordnet !';
END IF;



--
-- 4.)	Es mu eine Beschreibung bergeben werden
--
--IF(
--	( length( beschr ) = 0 )
--	OR ( beschr IS NULL )
--  ) 
--THEN
--	RAISE EXCEPTION 'intern.nimm__TLKommentarSicht(...)	Es ist eine Beschreibung der Sicht anzugeben. Der Kommentar wurde nicht zugeordnet !';
--END IF;



--
-- 5.)	Kommentar der Spalten zusammenbauen ASCII-2 als Trennzeichen verwenden
--
kommentar := '
Beschreibung der Spalten:
-------------------------
';

FOR lauf IN 1..array_upper ( spNamen, 1 )
LOOP
	kommentar := kommentar
			|| chr( 2 )
			|| spNamen[lauf] || chr( 2 ) || '	' || spBeschr[lauf]
			|| chr( 10 );
END LOOP;
kommentar := kommentar || chr( 2 );


--
-- 6.)	Funktionsbeschreibung ergnzen
--
kommentar := kommentar 
		|| '
Beschreibung der Sicht:
-----------------------
'
		|| chr( 3 )
		|| beschr
		|| chr( 10 );



--
-- 7.)	Beschreibung (Kommentar) setzen
--
EXECUTE intern.nimm__TLKommentar( 'VIEW '|| sicht, kommentar );

END
$$LANGUAGE 'plpgsql' VOLATILE;
SELECT intern.nimm__TLKommentarFunktion( 'intern.nimm__TLKommentarSicht( sicht varchar, spNamen varchar[], spBeschr varchar[], beschr varchar )', 
ARRAY[
'Es ist der vollstndige Name der Sicht anzugeben. Er darf nicht leer oder NULL sein.'
, E'In Form eines \\texttt{ARRAY} sind in der Reihenfolge ihres Auftretens smtliche Namen der Spalten anzugeben, welche von der Sicht bereitgestellt werden. Es mu mindestens eine Spalte beschrieben werden.'
, E'In Form eines \\texttt{ARRAY} sind in der Reihenfolge ihres Auftretens smtliche Beschreibungen der Spalten anzugeben, welche von der Sicht bereitgestellt werden. Es mu mindestens eine Spalte beschrieben werden.'
, E'Es ist die Sicht zu beschreiben. Es mu eine Beschreibung angegeben werden.'
],
E'Ziel der Funktion ist das Hinzufgen einer Beschreibung (eines  Kommentars) zu einer Sicht. Hinweise zur Gltigkeit knnen \\texttt{intern.nimm__TLKommentar(...)} entnommen werden.'
, ARRAY[
E'-- Fehlermeldung. Der Name der Sicht fehlt\\\\SELECT intern.nimm__TLKommentarSicht( NULL, NULL, NULL, '''' );'
, E'-- Fehlermeldung. Der Kommentar fehlt\\\\SELECT intern.nimm__TLKommentarSicht( ''intern.zeige__fremdschluessel'', ARRAY[''spName''], ARRAY[''spBeschreibung''], '''' );'
, E'-- Fehlermeldung. Es ist mindestens eine Spalte zu beschreiben\\\\SELECT intern.nimm__TLKommentarSicht( ''intern.zeige__fremdschluessel'', NULL, ARRAY[''spBeschreibung''], ''Kommentar'' );\\\\SELECT intern.nimm__TLKommentarSicht( ''intern.zeige__fremdschluessel'', ARRAY[''spName''], NULL, ''Kommentar'' );'
, E'-- Fehlermeldung. Die Anzahl der Spaltennamen mu mit der Anzahl der Spaltenbeschreibungen bereinstimmen\\\\SELECT intern.nimm__TLKommentarSicht( ''intern.zeige__fremdschluessel'', ARRAY[''spName1'', ''spName2''], ARRAY[''spBeschreibung''], ''Kommentar'' );'
, E'-- Sicht kommentieren, Ergebnis berprfen\\\\SELECT intern.nimm__TLKommentarSicht( ''intern.zeige__fremdschluessel'', ARRAY[''SpName''], ARRAY[''SpBeschreibung''], ''Beschreibung'' );\\\\$\\backslash$dv+ intern.zeige__fremdschluessel'
]
);
--
-- Fehlermeldungen
-- ...............
--
--	-- Fehlermeldung. Der Name der Sicht fehlt
--SELECT intern.nimm__TLKommentarSicht( NULL, NULL, NULL, '' );
--
--	-- Fehlermeldung. Der Kommentar fehlt
--SELECT intern.nimm__TLKommentarSicht( 'intern.zeige__fremdschluessel', ARRAY['spName'], ARRAY['spBeschreibung'], '' );
--
--	-- Fehlermeldung. Es ist mindestens eine Spalte zu beschreiben
--SELECT intern.nimm__TLKommentarSicht( 'intern.zeige__fremdschluessel', NULL, ARRAY['spBeschreibung'], 'Kommentar' );
--SELECT intern.nimm__TLKommentarSicht( 'intern.zeige__fremdschluessel', ARRAY['spName'], NULL, 'Kommentar' );
--
--	-- Fehlermeldung. Die Anzahl der Spaltennamen mu mit der Anzahl der Spaltenbeschreibungen bereinstimmen
--SELECT intern.nimm__TLKommentarSicht( 'intern.zeige__fremdschluessel', ARRAY['spName1', 'spName2'], ARRAY['spBeschreibung'], 'Kommentar' );
--
--
--
-- Standardverhalten:
-- ..................
--
--	-- Sicht kommentieren, Ergebnis berprfen
--SELECT intern.nimm__TLKommentarSicht( 'intern.zeige__fremdschluessel', ARRAY['SpName'], ARRAY['SpBeschreibung'], 'Beschreibung' );
--\dv+ intern.zeige__fremdschluessel
--


-- ---------------------------------------------------------------------------------------
-- ---------------------------------------------------------------------------------------
--						------------------------------------------
--	intern.nimm__TLKommentarSTS(...)	------------------------------------------
--						------------------------------------------
-- ---------------------------------------------------------------------------------------
-- ---------------------------------------------------------------------------------------
CREATE OR REPLACE FUNCTION intern.nimm__TLKommentarSTS( sts varchar, kommentar varchar ) RETURNS void AS
$$
DECLARE


BEGIN


--
-- 1.)	Plausibilitt
--	- Es mu ein Schemaname oder eine Tabelle oder eine Spalte bergeben werden
-- 	- 
--
EXECUTE intern.pruefe__dt( 'zk', sts, NULL, NULL
				, 'intern.nimm__TLKommentarSTS(...)'
				, 'sts' );


--
-- 2.)	Kommentar setzen
--
IF(
	length( split_part( sts, '.', 3 ) ) > 0
  ) 
THEN
	--
	-- Spalte
	--
	EXECUTE intern.nimm__TLKommentar( 'COLUMN '|| sts, kommentar );
	RETURN;

ELSIF (
	length( split_part( sts, '.', 2 ) ) > 0
  ) 
THEN
	--
	-- Tabelle
	--
	EXECUTE intern.nimm__TLKommentar( 'TABLE '|| sts, kommentar );
	RETURN;

ELSE
	--
	-- Schema
	--
	EXECUTE intern.nimm__TLKommentar( 'SCHEMA '|| sts, kommentar );

END IF;


END
$$LANGUAGE 'plpgsql' VOLATILE;
SELECT intern.nimm__TLKommentarFunktion( 'intern.nimm__TLKommentarSTS( sts varchar, kommentar varchar )', 
ARRAY[
'Es ist der vollstndige Schemaname, Tabelnname oder Spaltenname anzugeben.'
, 'Es ist der Kommentar anzugeben'
],
E'Ziel der Funktion ist das Hinzufgen eines Kommentares zu einem Schema, einer Tabelle oder einer Spalte. Es ist der vollstndige Name anzugeben (Bsp.: \\texttt{schema.tabelle.spalte}). Anhand der Anzahl der Datenbankobjekte wird entschieden, ob ein Schema, eine Tabelle oder eine Spalte vorliegt.\\\\
Hinweise zur Gltigkeit knnen \\texttt{intern.nimm__TLKommentar(...)} entnommen werden.'
, ARRAY[
E'-- Fehlermeldung. Der Parameter \\texttt{sts} darf nicht \\texttt{NULL} sein.\\\\SELECT intern.nimm__TLKommentarSTS( '''', '''' );\\\\SELECT intern.nimm__TLKommentarSTS( NULL, '''' );'
, E'-- Kommantar gelscht\\\\SELECT intern.nimm__TLKommentarSTS( ''intern.alle.id'', '''' );'
, E'-- Kommantar hinzugefgt\\\\SELECT intern.nimm__TLKommentarSTS( ''intern.alle.id'', ''Neuer Kommentar'' );\\\\ $\\backslash$d+ intern.alle'
]
);
--
-- Fehlermeldungen
-- ...............
--
--	-- Fehlermeldung. Der Parameter \\texttt{sts} darf nicht \\texttt{NULL} sein.
--SELECT intern.nimm__TLKommentarSTS( '', '' );
--SELECT intern.nimm__TLKommentarSTS( NULL, '' );
--
--
--
-- Standardverhalten:
-- ..................
--
--	-- Kommantar gelscht
--SELECT intern.nimm__TLKommentarSTS( 'intern.alle.id', '' );
--
--	-- Kommantar hinzugefgt
--SELECT intern.nimm__TLKommentarSTS( 'intern.alle.id', 'Neuer Kommentar' );
--\d+ intern.alle
--


-- ---------------------------------------------------------------------------------------
-- ---------------------------------------------------------------------------------------
--				----------------------------------------------------------
--	intern.nimm__zeile(...)	----------------------------------------------------------
--				----------------------------------------------------------
-- ---------------------------------------------------------------------------------------
-- ---------------------------------------------------------------------------------------
CREATE OR REPLACE FUNCTION intern.nimm__zeile( tabName varchar, liste_spName varchar[], liste_werte varchar[], OUT tabNameId varchar ) AS
$$
DECLARE
--------------------------------------------------------------------------------
-- Konstanten
--------------------------------------------------------------------------------

--------------------------------------------------------------------------------
-- lokale Variablen
--------------------------------------------------------------------------------
--
-- Hilfsvariable fr den INSERT-Befehl
--
insertSpalten varchar:= '';
insertWerte varchar:= '';
--
-- Hilfsvariable fr den SELECT-Befehl
--
selectWHERE varchar:= '';
--
-- Hilfsvariable fr den UPDATE-Befehl
--
updateSET varchar:= '';
--
-- Hilfsvariablen fr den Fall, da die Spalte >id< in >liste_spName< benannt wurde
--
hatId boolean:=false;
wertId varchar;
--
-- Laufvariable
--
lauf integer;


BEGIN


--
-- 1.)	Plausibilitt
--	- Es mu ein Tabellenname bergeben werden
--	- >liste_spName< mu mindestens ein Element haben
--	- >liste_werte< mu mindestens ein Element haben
--
EXECUTE intern.pruefe__dt( 'zk', tabName, NULL, NULL
				, 'intern.nimm__zeile(...)'
				, 'tabName' );
EXECUTE intern.pruefe__array( liste_spName, 1, NULL, 'intern.nimm__zeile(...)', 'liste_spName' );
EXECUTE intern.pruefe__array( liste_werte, 1, NULL, 'intern.nimm__zeile(...)', 'liste_werte' );


--
-- 2.)	Plausibilitt
--	- Die Anzahl der Spaltennamen mu mit der Anzahl der Werte bereinstimmen !
--
IF(
	( array_dims( liste_spName ) != array_dims( liste_werte ) )
  ) 
THEN
	RAISE EXCEPTION 'intern.nimm__zeile(...)	Die Anzahl der Spaltennamen muss mit der Anzahl der Werte uebereinstimmen. Das Einlesen der Werte wird abgebrochen !';
END IF;



--
-- 3.)	Die Teilzeichenketten fr SELECT, UPDATE, INSERT zusammenstellen
--
FOR lauf IN 1..array_upper ( liste_spName, 1 )
LOOP
	--
	-- Plausibilitt
	--	- Spaltennamen und Werte drfen nicht leer sein
	--
	EXECUTE intern.pruefe__dt( 'zk', liste_spName[lauf], NULL, NULL
					, 'intern.nimm__zeile(...)'
					, 'liste_spName[' || lauf || ']' );
	EXECUTE intern.pruefe__dt( 'zk', liste_werte[lauf], NULL, NULL
					, 'intern.nimm__zeile(...)'
					, 'liste_werte[' || lauf || ']' );

	--
	-- Wenn die Spalte >idfrei< verndert werden soll, wird eine Fehlermeldung
	-- ausgegeben
	--
	IF(
		lower( liste_spName[lauf] ) = 'idfrei'
	  ) 
	THEN
		RAISE EXCEPTION 'intern.nimm__zeile(...)	Die Spalte >idfrei< darf nicht direkt veraendert werden. Das Einlesen der Werte wird abgebrochen !';
		CONTINUE;
	END IF;

	--
	-- Wenn die Spalte >id< explizit benannt wurde, wird dieser Zustand vermerkt
	--
	IF(
		lower( liste_spName[lauf] ) = 'id'
	  ) 
	THEN
		hatId := true;
		wertId := liste_werte[lauf];
	END IF;

	--
	-- Die Bedingung der SELECT-Abfrage zusammenstellen
	--
	selectWHERE:= selectWHERE || ' AND ' || liste_spName[lauf] || ' = ' || quote_literal( liste_werte[lauf] );

	--
	-- UPDATE / INSERT
	--
	IF(
		lower( liste_spName[lauf] ) != 'id'
	  ) 
	THEN

		--
		-- Die Variablen-/Werteliste der UPDATE-Abfrage zusammenstellen
		--
		updateSET := updateSET || ', ' || liste_spName[lauf] || ' = ' || quote_literal( liste_werte[lauf] );

		--
		-- Die Variablen- und Werteliste der INSERT-Abfrage zusammenstellen
		--
		insertSpalten := insertSpalten || ', ' || liste_spName[lauf];
		insertWerte := insertWerte || ', ' || quote_literal( liste_werte[lauf] );
	END IF;

END LOOP;



--
-- 4.)	SELECT
--	Suche nach einer Zeile in der DB, welche bereits die bergebenen Werte enthlt
--	(Dopplungen vermeiden) ---> gefundene >id< zurckgeben, Funktion verlassen
--
EXECUTE 
	intern.gib__sqlSELECT(	'id', 
				ARRAY[tabName], 
				selectWHERE || ' LIMIT 1' )
INTO tabNameId;

--
-- Es wurde eine Zeile gefunden -> Funktion verlassen
--
IF(
	tabNameId IS NOT NULL
  )
THEN
	RETURN;
END IF;



--
-- 5.)	UPDATE
--
-- 5.1)	Sollte >id< in der Parameterliste bergeben worden sein, ist zu prfen, ob sie bereits
--	in der DB vorhanden ist (unabhngig von >idfrei<)
--
IF(
	hatId
  ) 
THEN

 	EXECUTE 
 		'SELECT id FROM ' || tabName || ' WHERE id = ' || wertId || ' LIMIT 1'
 	INTO tabNameId;

--
-- 5.2)	Wurde >id< nicht in der Parameterliste bergeben ist zu prfen, ob eine 
--	wiederverwendbare >id< vorhanden ist
--
ELSE

 	EXECUTE 
 		'SELECT id FROM ' || tabName || ' WHERE idfrei > 0 ORDER BY idfrei ASC LIMIT 1'
 	INTO tabNameId;

END IF;

--
-- 5.3)	In der Datenbank konnte eine >id< gefunden werden, welche die bergebenen Werte 
--	aufnehmen kann --> DB aktualisieren und Funktion verlassen
--
IF(
	tabNameId IS NOT NULL
  )
THEN

	--
	-- alle bisher eingetragenen Werte lschen -> dazu >id< bergeben (referentielle
	-- Integritt nicht beachten !)
	--
	IF(
		hatId
	  ) 
	THEN
		EXECUTE intern.loesche__zeile( tabName, tabName || '.id = ' || tabNameId, 'false' );
	END IF;

	--
	-- UPDATE ausfhren
	--
	EXECUTE 
		'UPDATE '
		|| tabName 
		|| ' SET idfrei = 0' || updateSET
		|| ' WHERE id = ' || tabNameId;
	RETURN;

END IF;



--
-- 6.)	INSERT
--
-- 6.1)	Sollte >id< in der Parameterliste bergeben worden sein, ist diese zu verwenden
--
IF(
	hatId
  ) 
THEN

--	tabNameId := CAST( wertId AS integer);
	tabNameId := wertId;

--
-- 6.2)	Wurde >id< nicht in der Parameterliste bergeben, ist die nchste >id< zu ermitteln
--
ELSE
	EXECUTE 
		'SELECT max( id ) + 1 FROM ' || tabName
	INTO tabNameId;
END IF;

--
-- 6.3)	Zeile in DB einfgen
--
	EXECUTE 
		'INSERT INTO ' 
		|| tabName 
		|| '( id' || insertSpalten || ' ) ' 
		|| ' VALUES( ' || tabNameId || insertWerte || ' )';


END
$$LANGUAGE 'plpgsql' VOLATILE;
SELECT intern.nimm__TLKommentarFunktion( 'intern.nimm__zeile( tabName varchar, liste_spName varchar[], liste_wert varchar[], OUT tabNameId varchar )', 
ARRAY[
E'Name der Tabelle (ggf. einschliesslich Schemaname), in die die Werte \\texttt{liste_werte[]} eingelesen werden sollen (darf nicht leer sein).'
, E'Liste der Spalten, welche die Werte aufnehmen sollen. Es mu mindestens ein Spaltenname bergeben werden. Es drfen keine Leerzeichenketten bergeben werden.'
, E'Liste der Werte, welche eingefgt werden sollen. Es mu mindestens ein Wert bergeben werden. Es drfen keine Leerzeichenketten bergeben werden. Weiterhin mu dieselbe Anzahl Werte bergeben werden, wie Spalten benannt sind.'
, E'\\texttt{id} der Zeile, welche die bergebenen Werte aufgenommen hat'
],
E'Ziel der Funktion ist das Einlesen von Werten. Der Spaltenliste \\texttt{liste_spName[]} darf jede in der Tabelle \\texttt{tabName} vorhandene Spalte bergeben werden. Die Spalte \\texttt{idfrei} darf nicht pbergeben werden, da sie ausschlielich vom System gesetzt wird.\\\\
Die bergebenen Werte \\texttt{liste_werte[]} werden in der DB gesucht und die \\texttt{id} der Zeile zurckgegeben, welche die Werte bereits enthlt. Sollte keine Zeile gefunden werden, wird die nchste verfgbare \\texttt{id} ermittelt und die Werte eingelesen.\\\\
\\\\
Sollte \\texttt{liste_spName[]} die Spalte \\texttt{id} explizit benannt sein, so wird unabhngig vom Wert der Spalte \\texttt{idfrei} die bergebene \\texttt{id} gesucht, der gesamte Inhalt gelscht und die neuen Werte eingetragen. Wurde \\texttt{id} nicht gefunden, wird eine Zeile mit der uebergebenen \\texttt{id} hinzugefgt.'
, ARRAY[
E'-- Fehlermeldung. Der Parameter \\texttt{tabName} darf nicht \\texttt{NULL} oder leer sein.\\\\SELECT intern.nimm__zeile( NULL, ARRAY[''''], ARRAY[''''] );'
, E'-- Fehlermeldung. Die Parameter \\texttt{liste_spName} und \\texttt{liste_werte} mssen mindestens ein Element enthalten.\\\\SELECT intern.nimm__zeile( ''intern.abczk'', NULL, NULL );\\\\SELECT intern.nimm__zeile( ''intern.abczk'', ARRAY[''abczk''], NULL );'
, E'-- Fehlermeldung. Die Parameter \\texttt{liste_spName} und \\texttt{liste_werte} drfen keine Leerzeichenketten enthalten.\\\\SELECT intern.nimm__zeile( ''intern.abczk'', ARRAY[''''], ARRAY[''''] );\\\\SELECT intern.nimm__zeile( ''intern.abczk'', ARRAY[''abczk''], ARRAY[''''] );'
, E'-- Fehlermeldung. Der Parameter \\texttt{liste_wert} mu dieselbe Anzahl Elemente enthalten, wie der Parameter \\texttt{liste_spName}.\\\\SELECT intern.nimm__zeile( ''intern.abczk'', ''{notizen, abczk}'', ''{zeichenkette fr notizen}'' );'
, E'-- Fehlermeldung. Die Spalte \\texttt{idfrei} darf nicht explizit gesetzt werden\\\\SELECT intern.nimm__zeile( ''intern.abczk'', ARRAY[''idfrei''], ARRAY[''0''] );'
, E'-- Der Wert war bereits in der Datenbank enthalten\\\\SELECT intern.nimm__zeile( ''intern.abczk'', ARRAY[''abczk''], ARRAY[''KeinRichtigesWort''] );\\\\SELECT * FROM intern.abczk ORDER BY id DESC LIMIT 5;\\\\SELECT intern.nimm__zeile( ''intern.abczk'', ARRAY[''abczk''], ARRAY[''KeinRichtigesWort''] );\\\\SELECT * FROM intern.abczk ORDER BY id DESC LIMIT 5;'
, E'-- Wiederverwendung einer gelschten \\texttt{id}\\\\SELECT intern.nimm__zeile( ''intern.abczk'', ARRAY[''abczk''], ARRAY[''KeinRichtigesWort''] );\\\\SELECT intern.nimm__zeile( ''intern.abczk'', ARRAY[''abczk''], ARRAY[''KeinRichtigesWortZwei''] );\\\\SELECT * FROM intern.abczk ORDER BY id DESC LIMIT 5;\\\\SELECT intern.loesche__zeile( ''intern.abczk'', ''abczk = ''''KeinRichtigesWort'''''' );\\\\SELECT * FROM intern.abczk ORDER BY id DESC LIMIT 5;\\\\SELECT intern.nimm__zeile( ''intern.abczk'', ARRAY[''abczk''], ARRAY[''KeinRichtigesWortEins''] );\\\\SELECT * FROM intern.abczk ORDER BY id DESC LIMIT 5;'
, E'-- berschreiben einer Zeile mit vorgegebener \\texttt{id}\\\\SELECT intern.nimm__zeile( ''intern.abczk'', ARRAY[''abczk''], ARRAY[''KeinRichtigesWort''] );\\\\SELECT intern.nimm__zeile( ''intern.abczk'', ARRAY[''abczk''], ARRAY[''KeinRichtigesWortZwei''] );\\\\SELECT * FROM intern.abczk ORDER BY id DESC LIMIT 5;\\\\SELECT intern.nimm__zeile( ''intern.abczk'', ARRAY[''id'', ''abczk''], ARRAY[''2399'', ''KeinRichtigesWortEins''] );\\\\SELECT * FROM intern.abczk ORDER BY id DESC LIMIT 5;'
, E'-- Einfgen einer Zeile mit vorgegebener \\texttt{id}\\\\SELECT * FROM intern.abczk ORDER BY id DESC LIMIT 5;\\\\SELECT intern.nimm__zeile( ''intern.abczk'', ARRAY[''id'', ''abczk''], ARRAY[''999999'', ''NichtVorhandeneId''] );\\\\SELECT * FROM intern.abczk ORDER BY id DESC LIMIT 5;'
]
);
--
-- Fehlermeldungen
-- ...............
--
--	-- Fehlermeldung. Der Parameter \\texttt{tabName} darf nicht \\texttt{NULL} oder leer sein.
--SELECT intern.nimm__zeile( NULL, ARRAY[''], ARRAY[''] );
--
--	-- Fehlermeldung. Die Parameter \\texttt{liste_spName} und \\texttt{liste_werte} mssen mindestens ein Element enthalten.
--SELECT intern.nimm__zeile( 'intern.abczk', NULL, NULL );
--SELECT intern.nimm__zeile( 'intern.abczk', ARRAY['abczk'], NULL );
--
--	-- Fehlermeldung. Die Parameter \\texttt{liste_spName} und \\texttt{liste_werte} drfen keine Leerzeichenketten enthalten.
--SELECT intern.nimm__zeile( 'intern.abczk', ARRAY[''], ARRAY[''] );
--SELECT intern.nimm__zeile( 'intern.abczk', ARRAY['abczk'], ARRAY[''] );
--
--	-- Fehlermeldung. Der Parameter \\texttt{liste_wert} mu dieselbe Anzahl Elemente enthalten, wie der Parameter \\texttt{liste_spName}.
--SELECT intern.nimm__zeile( 'intern.abczk', '{notizen, abczk}', '{zeichenkette fr notizen}' );
--
--	-- Fehlermeldung. Die Spalte \\texttt{idfrei} darf nicht explizit gesetzt werden
--SELECT intern.nimm__zeile( 'intern.abczk', ARRAY['idfrei'], ARRAY['0'] );
--
--
--
-- Standardverhalten:
-- ..................
--
--	-- Der Wert war bereits in der Datenbank enthalten
--SELECT intern.nimm__zeile( 'intern.abczk', ARRAY['abczk'], ARRAY['KeinRichtigesWort'] );
--SELECT * FROM intern.abczk ORDER BY id DESC LIMIT 5;
--SELECT intern.nimm__zeile( 'intern.abczk', ARRAY['abczk'], ARRAY['KeinRichtigesWort'] );
--SELECT * FROM intern.abczk ORDER BY id DESC LIMIT 5;
--
--	-- Wiederverwendung einer gelschten \\texttt{id}
--SELECT intern.nimm__zeile( 'intern.abczk', ARRAY['abczk'], ARRAY['KeinRichtigesWort'] );
--SELECT intern.nimm__zeile( 'intern.abczk', ARRAY['abczk'], ARRAY['KeinRichtigesWortZwei'] );
--SELECT * FROM intern.abczk ORDER BY id DESC LIMIT 5;
--SELECT intern.loesche__zeile( 'intern.abczk', 'abczk = ''KeinRichtigesWort''' );
--SELECT * FROM intern.abczk ORDER BY id DESC LIMIT 5;
--SELECT intern.nimm__zeile( 'intern.abczk', ARRAY['abczk'], ARRAY['KeinRichtigesWortEins'] );
--SELECT * FROM intern.abczk ORDER BY id DESC LIMIT 5;
--
--	-- berschreiben einer Zeile mit vorgegebener \\texttt{id}
--SELECT intern.nimm__zeile( 'intern.abczk', ARRAY['abczk'], ARRAY['KeinRichtigesWort'] );
--SELECT intern.nimm__zeile( 'intern.abczk', ARRAY['abczk'], ARRAY['KeinRichtigesWortZwei'] );
--SELECT * FROM intern.abczk ORDER BY id DESC LIMIT 5;
--SELECT intern.nimm__zeile( 'intern.abczk', ARRAY['id', 'abczk'], ARRAY['2399', 'KeinRichtigesWortEins'] );
--SELECT * FROM intern.abczk ORDER BY id DESC LIMIT 5;
--
--	-- Einfgen einer Zeile mit vorgegebener \\texttt{id}
--SELECT * FROM intern.abczk ORDER BY id DESC LIMIT 5;
--SELECT intern.nimm__zeile( 'intern.abczk', ARRAY['id', 'abczk'], ARRAY['999999', 'NichtVorhandeneId'] );
--SELECT * FROM intern.abczk ORDER BY id DESC LIMIT 5;
--


-- ---------------------------------------------------------------------------------------
-- ---------------------------------------------------------------------------------------
--					--------------------------------------------------
-- 	intern.pruefe__array(...)	--------------------------------------------------
--					--------------------------------------------------
-- ---------------------------------------------------------------------------------------
-- ---------------------------------------------------------------------------------------
CREATE OR REPLACE FUNCTION intern.pruefe__array( IN liste varchar[], IN minel integer, IN maxel integer, IN fktname varchar, IN paramname varchar ) RETURNS void AS
$$
DECLARE

BEGIN

--
-- 1.)	Plausibilittsprfung
--
IF(
	( liste IS NULL )
  ) 
THEN

	--
	-- Fehlermeldung.
	-- >minel< ist nicht kleiner >1< oder >NULL<, deshalb darf >liste< nicht >NULL< sein
	--
	IF(
		( minel IS NOT NULL )
		AND ( minel > 0 )
	  ) 
	THEN
		RAISE EXCEPTION '%', CASE WHEN( ( fktname IS NULL ) OR ( fktname = '' ) ) THEN 'intern.pruefe__array(...)' ELSE fktname END
				|| '	Die bergebene Liste >'
				|| CASE WHEN( ( paramname IS NULL ) OR ( paramname = '' ) ) THEN 'liste' ELSE paramname END
				|| '< darf nicht >NULL< sein. Das Programm wird abgebrochen !';
	END IF;

ELSE

	--
	-- Fehlermeldung.
	-- >minel< ist kleiner >1< oder >NULL<, deshalb mu >liste = NULL< sein
	--
	IF(
		( minel IS NULL )
		OR ( minel < 1 )
	  ) 
	THEN
		RAISE EXCEPTION '%', CASE WHEN( ( fktname IS NULL ) OR ( fktname = '' ) ) THEN 'intern.pruefe__array(...)' ELSE fktname END
				|| '	Die bergebene Liste >'
				|| CASE WHEN( ( paramname IS NULL ) OR ( paramname = '' ) ) THEN 'liste' ELSE paramname END
				|| ' = ( '
				|| array_to_string( liste, ', ')
				||' )< mu >NULL< sein. Das Programm wird abgebrochen !';
	END IF;

	--
	-- Fehlermeldung.
	-- Die Anzahl der Listenelemente ist kleiner als >minel<
	-- Die Anzahl der Listenelemente ist grer als  >maxel<
	--
	IF(
		( array_upper( liste, 1 ) < minel )
		OR (
			( maxel IS NOT NULL )
			AND ( array_upper( liste, 1 ) > maxel )
		)
	  ) 
	THEN
		RAISE EXCEPTION '%', CASE WHEN( ( fktname IS NULL ) OR ( fktname = '' ) ) THEN 'intern.pruefe__array(...)' ELSE fktname END
				|| '	Die bergebene Liste >'
				|| CASE WHEN( ( paramname IS NULL ) OR ( paramname = '' ) ) THEN 'liste' ELSE paramname END
				|| ' = ( '
				|| array_to_string( liste, ', ')
				||' )< mu mindestens >minel = '
				|| minel
				|| '< und maximal >maxel = '
				|| CASE WHEN( ( maxel IS NULL ) OR ( maxel = 0 ) ) THEN 'unbegrenzt' ELSE CAST( maxel AS text ) END
				|| '< Elemente enthalten. Das Programm wird abgebrochen !';
	END IF;

	--
	-- Fehlermeldung.
	-- Keines der Listenelemente darf leer sein
	--
	IF(
		NOT( '' != ALL ( liste ) )
	  ) 
	THEN
		RAISE EXCEPTION '%', CASE WHEN( ( fktname IS NULL ) OR ( fktname = '' ) ) THEN 'intern.pruefe__array(...)' ELSE fktname END
				|| '	Kein Elemente der bergebene Liste >'
				|| CASE WHEN( ( paramname IS NULL ) OR ( paramname = '' ) ) THEN 'liste' ELSE paramname END
				|| ' = ( '
				|| array_to_string( liste, ', ')
				||' )< darf leer sein. Das Programm wird abgebrochen !';
	END IF;

END IF;

END
$$LANGUAGE 'plpgsql'  VOLATILE;
SELECT intern.nimm__TLKommentarFunktion( 'intern.pruefe__array( IN liste varchar[], IN minel integer, IN maxel integer, IN fktname varchar, IN paramname varchar )', 
ARRAY[
'Es ist die Liste anzugeben, deren Plausibilit geprft werden soll.'
, E'Es ist die Anzahl der Listenelemente anzugeben, welche mindestens bergeben werden sollen. Wenn kleiner \\texttt{1} oder \\texttt{NULL} bergeben wird, mu die Liste \\texttt{NULL} sein.'
, E'Es ist die Anzahl der Listenelemente anzugeben, welche maximal bergeben werden sollen. Wenn kleiner \\texttt{1} oder \\texttt{NULL} bergeben wird, darf die Liste eine beliebige Anzahl Elemente besitzen. Andernfalls darf die Anzahl der Elemente den bergebenen Wert nicht berschreiten.'
, E'Es ist der Name der Funktion anzugeben, welche die Prfroutine aufruft. Der Funktionsname wird in der Fehlermeldung verwendet. Sollte er leer oder \\texttt{NULL} sein, wird \\texttt{intern.pruefe__array(...)} verwendet.'
, E'Es ist der Name des Parameters anzugeben, welcher die zu prfende Liste \\texttt{liste} beinhaltet. Der Parametername wird in der Fehlermeldung verwendet. Sollte er leer oder \\texttt{NULL} sein, wird \\texttt{liste} verwendet.'
],
E'Ziel der Funktion ist die Plausibilittsprfung der mittels des Parameters \\texttt{liste} bergebenen Liste (\\texttt{ARRAY}) anhand der Randbedingungen \\texttt{minel} und \\texttt{maxel}.
Wenn die Liste nicht \\texttt{NULL} sein darf, darf keines der Listenelemente leer sein.
Sollte die Plausibilittsprfung negativ ausfallen, wird eine Fehlermeldung ausgegeben.'
, ARRAY[
E'Fehlermeldung mit Standardfunktions- und Parameternamen ausgeben, wenn \\texttt{liste} nicht \\texttt{NULL} sein darf.\\\\SELECT * FROM intern.pruefe__array( NULL, 1, 1, NULL, NULL );\\\\SELECT * FROM intern.pruefe__array( NULL, 1, 1, '''', '''' );'
, E'Fehlermeldung mit bergebenen Funktions- und Parameternamen ausgeben, wenn \\texttt{liste} nicht \\texttt{NULL} sein darf.\\\\SELECT * FROM intern.pruefe__array( NULL, 1, 1, ''fktname(...)'', ''listenName'' );'
, E'Fehlermeldung mit Standardfunktions- und Parameternamen ausgeben, wenn \\texttt{liste NULL} sein mu.\\\\SELECT * FROM intern.pruefe__array( ARRAY[ ''eins'', ''zwei'' ], NULL, 1, NULL, NULL );\\\\SELECT * FROM intern.pruefe__array( ARRAY[ ''eins'', ''zwei'' ], 0, 1, '''', '''' );\\\\SELECT * FROM intern.pruefe__array( ARRAY[ ''eins'', ''zwei'' ], -5, 1, NULL, NULL );'
, E'Fehlermeldung mit bergebenen Funktions- und Parameternamen ausgeben, wenn \\texttt{liste NULL} sein mu.\\\\SELECT * FROM intern.pruefe__array( ARRAY[ ''eins'', ''zwei'' ], NULL, 1, ''fktname(...)'', ''listenName'' );'
, E'Fehlermeldung ausgeben, wenn \\texttt{liste} mindesten \\texttt{2} Elemente enthalten mu.\\\\SELECT * FROM intern.pruefe__array( ARRAY[ ''eins'' ], 2, 0, NULL, NULL );\\\\SELECT * FROM intern.pruefe__array( ARRAY[ ''eins'' ], 2, NULL, ''fktname(...)'', ''listenName'' );'
, E'Fehlermeldung ausgeben, wenn \\texttt{liste} maximal \\texttt{1} Element enthalten darf.\\\\SELECT * FROM intern.pruefe__array( ARRAY[ ''eins'', ''zwei'' ], 1, 1, '''', '''' );\\\\SELECT * FROM intern.pruefe__array( ARRAY[ ''eins'', ''zwei'' ], 1, 1, ''fktname(...)'', ''listenName'' );'
, E'Fehlermeldung ausgeben, wenn \\texttt{liste} maximal \\texttt{1} Element enthalten darf.\\\\SELECT * FROM intern.pruefe__array( ARRAY[ ''eins'', '''', ''drei'' ], 1, 3, NULL, NULL );\\\\SELECT * FROM intern.pruefe__array( ARRAY[ ''eins'', '''', ''drei'' ], 1, 3, '''', '''' );\\\\SELECT * FROM intern.pruefe__array( ARRAY[ ''eins'', '''', ''drei'' ], 1, 3, ''fktname(...)'', ''listenName'' );'
, E'keine Fehlermeldung ausgeben, weil \\texttt{liste NULL} sein darf.\\\\SELECT * FROM intern.pruefe__array( NULL, NULL, 1, ''fktname(...)'', ''listenName'' );\\\\SELECT * FROM intern.pruefe__array( NULL, 0, 1, ''fktname(...)'', ''listenName'' );\\\\SELECT * FROM intern.pruefe__array( NULL, -5, 1, ''fktname(...)'', ''listenName'' );'
, E'keine Fehlermeldung ausgeben, weil \\texttt{liste} minimal \\texttt{1} und maximal \\texttt{2} Element enthalten darf.\\\\SELECT * FROM intern.pruefe__array( ARRAY[ ''eins'', ''zwei'' ], 1, 2, ''fktname(...)'', ''listenName'' );'
]
);
--
-- Standardverhalten:
-- ..................
--
--	Fehlermeldung mit Standardfunktions- und Parameternamen ausgeben, wenn \\texttt{liste} nicht \\texttt{NULL} sein darf.
--SELECT * FROM intern.pruefe__array( NULL, 1, 1, NULL, NULL );
--SELECT * FROM intern.pruefe__array( NULL, 1, 1, '', '' );
--
--	Fehlermeldung mit bergebenen Funktions- und Parameternamen ausgeben, wenn \\texttt{liste} nicht \\texttt{NULL} sein darf.
--SELECT * FROM intern.pruefe__array( NULL, 1, 1, 'fktname(...)', 'listenName' );
--
--	Fehlermeldung mit Standardfunktions- und Parameternamen ausgeben, wenn \\texttt{liste NULL} sein mu.
--SELECT * FROM intern.pruefe__array( ARRAY[ 'eins', 'zwei' ], NULL, 1, NULL, NULL );
--SELECT * FROM intern.pruefe__array( ARRAY[ 'eins', 'zwei' ], 0, 1, '', '' );
--SELECT * FROM intern.pruefe__array( ARRAY[ 'eins', 'zwei' ], -5, 1, NULL, NULL );
--
--	Fehlermeldung mit bergebenen Funktions- und Parameternamen ausgeben, wenn \\texttt{liste NULL} sein mu.
--SELECT * FROM intern.pruefe__array( ARRAY[ 'eins', 'zwei' ], NULL, 1, 'fktname(...)', 'listenName' );
--
--	Fehlermeldung ausgeben, wenn \\texttt{liste} mindesten \\texttt{2} Elemente enthalten mu.
--SELECT * FROM intern.pruefe__array( ARRAY[ 'eins' ], 2, 0, NULL, NULL );
--SELECT * FROM intern.pruefe__array( ARRAY[ 'eins' ], 2, NULL, 'fktname(...)', 'listenName' );
--
--	Fehlermeldung ausgeben, wenn \\texttt{liste} maximal \\texttt{1} Element enthalten darf.
--SELECT * FROM intern.pruefe__array( ARRAY[ 'eins', 'zwei' ], 1, 1, '', '' );
--SELECT * FROM intern.pruefe__array( ARRAY[ 'eins', 'zwei' ], 1, 1, 'fktname(...)', 'listenName' );
--
--	Fehlermeldung ausgeben, wenn \\texttt{liste} maximal \\texttt{1} Element enthalten darf.
--SELECT * FROM intern.pruefe__array( ARRAY[ 'eins', '', 'drei' ], 1, 3, NULL, NULL );
--SELECT * FROM intern.pruefe__array( ARRAY[ 'eins', '', 'drei' ], 1, 3, '', '' );
--SELECT * FROM intern.pruefe__array( ARRAY[ 'eins', '', 'drei' ], 1, 3, 'fktname(...)', 'listenName' );
--
--	keine Fehlermeldung ausgeben, weil \\texttt{liste NULL} sein darf.
--SELECT * FROM intern.pruefe__array( NULL, NULL, 1, 'fktname(...)', 'listenName' );
--SELECT * FROM intern.pruefe__array( NULL, 0, 1, 'fktname(...)', 'listenName' );
--SELECT * FROM intern.pruefe__array( NULL, -5, 1, 'fktname(...)', 'listenName' );
--
--	keine Fehlermeldung ausgeben, weil \\texttt{liste} minimal \\texttt{1} und maximal \\texttt{2} Element enthalten darf.
--SELECT * FROM intern.pruefe__array( ARRAY[ 'eins', 'zwei' ], 1, 2, 'fktname(...)', 'listenName' );


-- ---------------------------------------------------------------------------------------
-- ---------------------------------------------------------------------------------------
--				----------------------------------------------------------
-- 	intern.pruefe__dt(...)	----------------------------------------------------------
--				----------------------------------------------------------
-- ---------------------------------------------------------------------------------------
-- ---------------------------------------------------------------------------------------
CREATE OR REPLACE FUNCTION intern.pruefe__dt( IN dt varchar, IN wert varchar, IN ug varchar, IN og varchar, IN fktname varchar, IN paramname varchar ) RETURNS void AS
$$
DECLARE



BEGIN



--
-- 1.)	Keiner der Werte darf leer oder >NULL< sein
--
IF(
	( wert IS NULL )
	OR ( wert = '' )
  ) 
THEN
	--
	-- Fehlermeldung
	--
	RAISE EXCEPTION '%', CASE WHEN( ( fktname IS NULL ) OR ( fktname = '' ) ) THEN 'intern.pruefe__dt(...)' ELSE fktname END
			|| '	Der bergebene Wert >'
			|| CASE WHEN( ( paramname IS NULL ) OR ( paramname = '' ) ) THEN 'wert' ELSE paramname END
			|| '< darf nicht leer oder >NULL< sein. Das Programm wird abgebrochen !';
END IF;



--
-- 2.)	Plausibilittsprfung der Datentypen durchfhren
--
-- 2.1)	Boolescher Wert
--
IF(
	( dt = 'bw' )
  ) 
THEN
	--
	-- Fehlermeldung. Kein boolescher Wert
	-- siehe Postgres-Doku >8.6. Boolean Type<
	--
	IF ( 
		NOT( ( lower( wert ) = 't' )
			OR ( lower( wert ) = 'true' )
			OR ( lower( wert ) = 'y' )
			OR ( lower( wert ) = 'yes' )
			OR ( lower( wert ) = '1' )
			OR ( lower( wert ) = 'f' )
			OR ( lower( wert ) = 'false' )
			OR ( lower( wert ) = 'n' )
			OR ( lower( wert ) = 'no' )
			OR ( lower( wert ) = '0' ) )
	  ) 
	THEN
		RAISE EXCEPTION '%', CASE WHEN( ( fktname IS NULL ) OR ( fktname = '' ) ) THEN 'intern.pruefe__dt(...)' ELSE fktname END
			|| '	Die bergebene Zeichenkette >'
			|| CASE WHEN( ( paramname IS NULL ) OR ( paramname = '' ) ) THEN 'wert' ELSE paramname END
			|| ' =  '
			|| wert
			|| '< kann nicht als boolescher Wert interpretiert werden. Das Programm wird abgebrochen !';
	END IF;


-- -----------------------------------------------------------------------------
-- 2.2) Datum~/~Uhrzeit
-- -----------------------------------------------------------------------------
ELSIF (
	( dt = 'du' )
  ) 
THEN
	IF ( 
		( ( ug IS NOT NULL ) AND ( ug != '' ) 
			AND ( CAST( wert AS timestamp ) < CAST( ug AS timestamp ) ) )
		OR( ( og IS NOT NULL ) AND ( og != '' ) 
			AND ( CAST( og AS timestamp ) < CAST( wert AS timestamp ) ) )
	  ) 
	THEN
		RAISE EXCEPTION '%', CASE WHEN( ( fktname IS NULL ) OR ( fktname = '' ) ) THEN 'intern.pruefe__dt(...)' ELSE fktname END
			|| '	Der bergebene Datum/Uhrzeit-Wert mu im Bereich >ug( '
			|| CASE WHEN( ( ug IS NULL ) OR ( ug = '' ) ) THEN 'siehe Definition PostgreSQL' ELSE ug END
			|| ' ) <= '
			|| CASE WHEN( ( paramname IS NULL ) OR ( paramname = '' ) ) THEN 'wert' ELSE paramname END
			|| '( '
			|| wert
			|| ' ) <= og( '
			|| CASE WHEN( ( og IS NULL ) OR ( og = '' ) ) THEN 'siehe Definition PostgreSQL' ELSE og END
			|| ' )< liegen. Das Programm wird abgebrochen !';
	END IF;


-- -----------------------------------------------------------------------------
-- 2.3) Ganzzahl	--------------------------------------------------------
-- -----------------------------------------------------------------------------
ELSIF (
	( dt = 'gz' )
  ) 
THEN
	IF ( 
		( ( ug IS NOT NULL ) AND ( ug != '' ) 
			AND ( CAST( wert AS integer ) < CAST( ug AS integer ) ) )
		OR( ( og IS NOT NULL ) AND ( og != '' ) 
			AND ( CAST( og AS integer ) < CAST( wert AS integer ) ) )
	  ) 
	THEN
		RAISE EXCEPTION '%', CASE WHEN( ( fktname IS NULL ) OR ( fktname = '' ) ) THEN 'intern.pruefe__dt(...)' ELSE fktname END
			|| '	Die bergebene Ganzzahl (integer) mu im Bereich >ug( '
			|| CASE WHEN( ( ug IS NULL ) OR ( ug = '' ) ) THEN 'siehe Definition PostgreSQL' ELSE ug END
			|| ' ) <= '
			|| CASE WHEN( ( paramname IS NULL ) OR ( paramname = '' ) ) THEN 'wert' ELSE paramname END
			|| '( '
			|| wert
			|| ' ) <= og( '
			|| CASE WHEN( ( og IS NULL ) OR ( og = '' ) ) THEN 'siehe Definition PostgreSQL' ELSE og END
			|| ' )< liegen. Das Programm wird abgebrochen !';
	END IF;


-- -----------------------------------------------------------------------------
-- 2.4) Zeichenkette
-- -----------------------------------------------------------------------------
ELSIF (
	( dt = 'zk' )
  ) 
THEN
	IF ( 
		length( wert ) > CAST( og AS integer )
	  ) 
	THEN
		RAISE EXCEPTION '%', CASE WHEN( ( fktname IS NULL ) OR ( fktname = '' ) ) THEN 'intern.pruefe__dt(...)' ELSE fktname END
			|| '	Die bergebene Zeichenkette >'
			|| CASE WHEN( ( paramname IS NULL ) OR ( paramname = '' ) ) THEN 'wert' ELSE paramname END
			|| ' = '
			|| wert
			|| '< darf nicht mehr als >og = '
			|| og
			|| '< Zeichen enthalten. Das Programm wird abgebrochen !';
	END IF;


-- -----------------------------------------------------------------------------
-- Fehlermeldung. Der bergebene Datentyp ist unbekannt.
-- -----------------------------------------------------------------------------
ELSE

	RAISE EXCEPTION '%', 'intern.pruefe__dt(...)	Der bergebene Datentyp >dt'
				|| CASE WHEN( ( dt IS NULL ) OR ( dt = '' ) ) THEN '< darf nicht leer oder >NULL< sein.' ELSE ' = ' || dt || '< ist nicht definiert.' END
			|| ' Das Programm wird abgebrochen !';

END IF;

END
$$LANGUAGE 'plpgsql'  VOLATILE;
SELECT intern.nimm__TLKommentarFunktion( 'intern.pruefe__dt( IN dt varchar, IN wert varchar, IN ug varchar, IN og varchar, IN fktname varchar, IN paramname varchar )', 
ARRAY[
'Es ist einer der mglichen Datentypen (siehe Funktionsbeschreibung --- Gltige Datentypen~/~Wertebereich) anzugeben'
, E'Es ist der Wert anzugeben, dessen Plausibilit geprft werden soll. Er darf nicht \\texttt{NULL} oder leer sein.'
, E'Es ist die untere Grenze des Wertes anzugeben (weitere Hinweise siehe Funktionsbeschreibung --- Gltige Datentypen~/~Wertebereich). Wird \\texttt{NULL} oder eine Leerzeichenkette angegeben, gilt die in PostgreSQL implementierte untere Grenze.'
, E'Es ist die obere Grenze des Wertes anzugeben. Wird \\texttt{NULL} oder eine Leerzeichenkette angegeben, gilt die in PostgreSQL implementierte obere Grenze.'
, E'Es ist der Name der Funktion anzugeben, welche die Prfroutine aufruft. Der Funktionsname wird in der Fehlermeldung verwendet. Sollte er leer oder \\texttt{NULL} sein, wird \\texttt{intern.pruefe__dt(...)} verwendet.'
, E'Es ist der Name des Parameters anzugeben, welcher den zu prfenden Wert \\texttt{wert} beinhaltet. Der Parametername wird in der Fehlermeldung verwendet. Sollte er leer oder \\texttt{NULL} sein, wird \\texttt{wert} verwendet.'
],
E'Ziel der Funktion ist die Plausibilittsprfung elementarer Datentypen. Die Datentypen und der Wertebereich werden als Zeichenketten bergeben. Sollte die Plausibilittsprfung negativ ausfallen, wird eine Fehlermeldung ausgegeben.
\\\\
Der im PostgreSQL implementierte Wertebereich der Datentypen kann der Postgres-Dokumentation entnommen werden. Er wird von PostgreSQL automatisch und somit innerhalb dieser Rputine nicht explizit berprft.
\\\\
\\\\
Gltige Datentypen~/~Wertebereich\\\\
Es werden die folgenden Datentypen geprft:
\\begin{description}
  \\item[bw] Boolescher Wert. Die untere~/~obere Grenze wird nicht berprft.
  \\item[du] Datum~/~Uhrzeit. Die untere~/~obere Grenze wird berprft.
  \\item[gz] Ganzzahl (integer). Die untere~/~obere Grenze wird berprft.
  \\item[zk] Zeichenkette. Die untere Grenze wird nicht berprft. Die obere Grenze wird berprft.
\\end{description}'
, ARRAY[
E'Fehlermeldung. Der bergebene Datentyp darf nicht \\texttt{NULL} oder leer sein\\\\SELECT * FROM intern.pruefe__dt( NULL, ''1'', NULL, NULL, NULL, NULL );'
, E'Fehlermeldung. Der bergebene Datentyp ist unbekannt\\\\SELECT * FROM intern.pruefe__dt( ''unbekannt'', ''1'', NULL, NULL, ''fktname(...)'', ''wertName'' );'
, E'Fehlermeldung: Es ist kein \\texttt{boolean}\\\\SELECT * FROM intern.pruefe__dt( ''bw'', ''keinBool'', ''ignoriert'', ''ignoriert'', NULL, NULL );\\\\SELECT * FROM intern.pruefe__dt( ''bw'', ''keinBool'', ''ignoriert'', ''ignoriert'', ''fktname(...)'', ''wertName'' );'
, E'Fehlermeldung. Der bergebene Wert darf nicht \\texttt{NULL} oder leer sein\\\\SELECT * FROM intern.pruefe__dt( NULL, NULL, NULL, NULL, NULL, NULL );\\\\SELECT * FROM intern.pruefe__dt( NULL, '''', NULL, NULL, ''fktname(...)'', ''wertName'' );'
, E'Fehlermeldung. Das Datum befindet sich auerhalb der zulssigen Grenzen\\\\SELECT * FROM intern.pruefe__dt( ''du'', ''2007-04-16'', ''2007-04-17'', NULL, ''fktname(...)'', ''datUhrz'' );\\\\SELECT * FROM intern.pruefe__dt( ''du'', ''2007-04-18'', NULL, ''2007-04-17'', ''fktname(...)'', ''datUhrz'' );\\\\SELECT * FROM intern.pruefe__dt( ''du'', ''2007-04-19'', ''2007-04-17'', ''2007-04-18'', ''fktname(...)'', ''datUhrz'' );'
, E'Fehlermeldung. Die Ganzzahl (integer) befindet sich auerhalb der zulssigen Grenzen\\\\SELECT * FROM intern.pruefe__dt( ''gz'', ''-2'', ''-1'', NULL, ''fktname(...)'', ''gz_int'' );\\\\SELECT * FROM intern.pruefe__dt( ''gz'', ''2'', NULL, ''1'', ''fktname(...)'', ''gz_int'' );\\\\SELECT * FROM intern.pruefe__dt( ''gz'', ''-5'', ''-1'', ''1'', ''fktname(...)'', ''gz_int'' );'
, E'Fehlermeldung. Die bergebene Zeichenkette ist zu lang\\\\SELECT * FROM intern.pruefe__dt( ''zk'', ''1234567890'', NULL, ''9'', NULL, NULL );\\\\SELECT * FROM intern.pruefe__dt( ''zk'', ''1234567890'', NULL, ''9'', ''fktname(...)'', ''zkWert'' );'
, E'keine Fehlermeldung\\\\SELECT * FROM intern.pruefe__dt( ''bw'', ''TRUE'', NULL, NULL, ''fktname(...)'', ''wertName'' );\\\\SELECT * FROM intern.pruefe__dt( ''bw'', ''T'', NULL, NULL, ''fktname(...)'', ''wertName'' );\\\\SELECT * FROM intern.pruefe__dt( ''bw'', ''Y'', NULL, NULL, ''fktname(...)'', ''wertName'' );\\\\SELECT * FROM intern.pruefe__dt( ''bw'', ''YES'', NULL, NULL, ''fktname(...)'', ''wertName'' );\\\\SELECT * FROM intern.pruefe__dt( ''bw'', ''1'', NULL, NULL, ''fktname(...)'', ''wertName'' );\\\\SELECT * FROM intern.pruefe__dt( ''bw'', ''FALSE'', NULL, NULL, ''fktname(...)'', ''wertName'' );\\\\SELECT * FROM intern.pruefe__dt( ''bw'', ''F'', NULL, NULL, ''fktname(...)'', ''wertName'' );\\\\SELECT * FROM intern.pruefe__dt( ''bw'', ''N'', NULL, NULL, ''fktname(...)'', ''wertName'' );\\\\SELECT * FROM intern.pruefe__dt( ''bw'', ''NO'', NULL, NULL, ''fktname(...)'', ''wertName'' );\\\\SELECT * FROM intern.pruefe__dt( ''bw'', ''0'', NULL, NULL, ''fktname(...)'', ''wertName'' );\\\\SELECT * FROM intern.pruefe__dt( ''du'', ''2007-04-18'', NULL, NULL, ''fktname(...)'', ''wertName'' );\\\\SELECT * FROM intern.pruefe__dt( ''du'', ''2007-04-18'', ''2007-04-17'', ''2007-04-19'', ''fktname(...)'', ''wertName'' );\\\\SELECT * FROM intern.pruefe__dt( ''gz'', ''2123456'', NULL, NULL, ''fktname(...)'', ''wertName'' );\\\\SELECT * FROM intern.pruefe__dt( ''gz'', ''0'', ''-1'', ''1'', ''fktname(...)'', ''wertName'' );\\\\SELECT * FROM intern.pruefe__dt( ''zk'', ''123456789'', ''ignoriert'', ''9'', ''fktname(...)'', ''wertName'' );'
]
);
--
-- Fehlermeldungen
-- ...............
--
--	Fehlermeldung. Der bergebene Datentyp darf nicht \\texttt{NULL} oder leer sein
--SELECT * FROM intern.pruefe__dt( NULL, '1', NULL, NULL, NULL, NULL );
--
--	Fehlermeldung. Der bergebene Datentyp ist unbekannt
--SELECT * FROM intern.pruefe__dt( 'unbekannt', '1', NULL, NULL, 'fktname(...)', 'wertName' );
--
--	Fehlermeldung: Es ist kein \\texttt{boolean}
--SELECT * FROM intern.pruefe__dt( 'bw', 'keinBool', 'ignoriert', 'ignoriert', NULL, NULL );
--SELECT * FROM intern.pruefe__dt( 'bw', 'keinBool', 'ignoriert', 'ignoriert', 'fktname(...)', 'wertName' );
--
--
--
-- Standardverhalten:
-- ..................
--
--	Fehlermeldung. Der bergebene Wert darf nicht \\texttt{NULL} oder leer sein
--SELECT * FROM intern.pruefe__dt( NULL, NULL, NULL, NULL, NULL, NULL );
--SELECT * FROM intern.pruefe__dt( NULL, '', NULL, NULL, 'fktname(...)', 'wertName' );
--
--	Fehlermeldung. Das Datum befindet sich auerhalb der zulssigen Grenzen
--SELECT * FROM intern.pruefe__dt( 'du', '2007-04-16', '2007-04-17', NULL, 'fktname(...)', 'datUhrz' );
--SELECT * FROM intern.pruefe__dt( 'du', '2007-04-18', NULL, '2007-04-17', 'fktname(...)', 'datUhrz' );
--SELECT * FROM intern.pruefe__dt( 'du', '2007-04-19', '2007-04-17', '2007-04-18', 'fktname(...)', 'datUhrz' );
--
--	Fehlermeldung. Die Ganzzahl (integer) befindet sich auerhalb der zulssigen Grenzen
--SELECT * FROM intern.pruefe__dt( 'gz', '-2', '-1', NULL, 'fktname(...)', 'gz_int' );
--SELECT * FROM intern.pruefe__dt( 'gz', '2', NULL, '1', 'fktname(...)', 'gz_int' );
--SELECT * FROM intern.pruefe__dt( 'gz', '-5', '-1', '1', 'fktname(...)', 'gz_int' );
--
--	Fehlermeldung. Die bergebene Zeichenkette ist zu lang
--SELECT * FROM intern.pruefe__dt( 'zk', '1234567890', NULL, '9', NULL, NULL );
--SELECT * FROM intern.pruefe__dt( 'zk', '1234567890', NULL, '9', 'fktname(...)', 'zkWert' );
--
--	keine Fehlermeldung
--SELECT * FROM intern.pruefe__dt( 'bw', 'TRUE', NULL, NULL, 'fktname(...)', 'wertName' );
--SELECT * FROM intern.pruefe__dt( 'bw', 'T', NULL, NULL, 'fktname(...)', 'wertName' );
--SELECT * FROM intern.pruefe__dt( 'bw', 'Y', NULL, NULL, 'fktname(...)', 'wertName' );
--SELECT * FROM intern.pruefe__dt( 'bw', 'YES', NULL, NULL, 'fktname(...)', 'wertName' );
--SELECT * FROM intern.pruefe__dt( 'bw', '1', NULL, NULL, 'fktname(...)', 'wertName' );
--SELECT * FROM intern.pruefe__dt( 'bw', 'FALSE', NULL, NULL, 'fktname(...)', 'wertName' );
--SELECT * FROM intern.pruefe__dt( 'bw', 'F', NULL, NULL, 'fktname(...)', 'wertName' );
--SELECT * FROM intern.pruefe__dt( 'bw', 'N', NULL, NULL, 'fktname(...)', 'wertName' );
--SELECT * FROM intern.pruefe__dt( 'bw', 'NO', NULL, NULL, 'fktname(...)', 'wertName' );
--SELECT * FROM intern.pruefe__dt( 'bw', '0', NULL, NULL, 'fktname(...)', 'wertName' );
--SELECT * FROM intern.pruefe__dt( 'du', '2007-04-18', NULL, NULL, 'fktname(...)', 'wertName' );
--SELECT * FROM intern.pruefe__dt( 'du', '2007-04-18', '2007-04-17', '2007-04-19', 'fktname(...)', 'wertName' );
--SELECT * FROM intern.pruefe__dt( 'gz', '2123456', NULL, NULL, 'fktname(...)', 'wertName' );
--SELECT * FROM intern.pruefe__dt( 'gz', '0', '-1', '1', 'fktname(...)', 'wertName' );
--SELECT * FROM intern.pruefe__dt( 'zk', '123456789', 'ignoriert', '9', 'fktname(...)', 'wertName' );
--


-- ---------------------------------------------------------------------------------------
-- ---------------------------------------------------------------------------------------
--				----------------------------------------------------------
--	intern.verbindezk()	----------------------------------------------------------
--				----------------------------------------------------------
-- ---------------------------------------------------------------------------------------
-- ---------------------------------------------------------------------------------------
CREATE OR REPLACE FUNCTION intern.verbindezk( zk varchar, zkadd varchar, OUT zkges varchar ) AS
$$

BEGIN

--
-- 1.)	Zeichenketten verbinden
--
zkges := zk || zkadd;

END
$$LANGUAGE 'plpgsql' VOLATILE;
SELECT intern.nimm__TLKommentarFunktion( 'intern.verbindezk( zk varchar, zkadd varchar, OUT zkges varchar )', 
ARRAY[
'Erste Zeichenkette.'
, 'Zweite Zeichenkette.'
, 'Erste + Zweite Zeichenkette.'
],
e'Ziel der Funktion ist das Verbinden beider Zeichenketten. Diese Funktion wird in der Aggregatfunktion \\texttt{intern.erzeuge__zk(...)} verwendet.'
, ARRAY[
'intern.verbindezk( ''Anfang '', ''- Ende'' );'
]
);
--
-- Standardverhalten:
-- ..................
--
--SELECT intern.verbindezk( 'Anfang ', '- Ende' );
--



-- ---------------------------------------------------------------------------------------
-- ---------------------------------------------------------------------------------------
-- ---------------------------------------------------------------------------------------
--			------------------------------------------------------------------
-- prj - Projekte	------------------------------------------------------------------
--			------------------------------------------------------------------
-- ---------------------------------------------------------------------------------------
-- ---------------------------------------------------------------------------------------
-- ---------------------------------------------------------------------------------------

-- ---------------------------------------------------------------------------------------
-- ---------------------------------------------------------------------------------------
--				----------------------------------------------------------
-- 	prj.nimm__tabwerte(...)	----------------------------------------------------------
--				----------------------------------------------------------
-- ---------------------------------------------------------------------------------------
-- ---------------------------------------------------------------------------------------
CREATE OR REPLACE FUNCTION prj.nimm__tabwerte( IN tabname varchar, IN tabwerte varchar[], OUT tabid varchar ) AS
$$
DECLARE
--------------------------------------------------------------------------------
-- Konstanten
--------------------------------------------------------------------------------


--------------------------------------------------------------------------------
-- lokale Variablen
--------------------------------------------------------------------------------
--
-- temporre Ganzzahlvariable(n)
--
tmpInteger integer;
--
-- Grenzen
--
uGoG integer[];
--
-- Liste der Spaltennamen
--
spNamen varchar[];
--
-- Tabellenwerte mssen vernderbar sein
--
tabwerteIntern varchar[];


BEGIN

--
-- 0. Tabellenwerte bernehmen
--
tabwerteIntern := tabwerte;


--
-- 1.)	Tabname einlesen / prfen
--
tmpInteger := array_upper( tabwerte, 1 );
IF(
	tabname='p_dokstrkt'
  )
THEN

	--
	-- Plausibilittsprfung ab tabwerte[3]
	--
	EXECUTE intern.pruefe__dt( 'gz', tabwerte[3], '1', NULL
					, 'prj.nimm__tabwerte(...)'
					, tabname || '.tabwerte[3]' );

	--
	-- Werte zuweisen
	--
	uGoG := ARRAY[ '3', '4' ];
	spNamen := ARRAY[
			'prj_projekte_id'
			, 'dok_doku_id'
			, 'dok_strkt_id'
			, 'notizen'
			];




ELSIF(
	tabname='p_prtstrstrkt'
  )
THEN

	--
	-- Plausibilittsprfung ab tabwerte[3]
	--
	IF(
		NOT( tmpInteger < 3 )
	  ) 
	THEN
		EXECUTE intern.pruefe__dt( 'gz', tabwerte[3], '1', NULL
					, 'prj.nimm__tabwerte(...)'
					, tabname || '.tabwerte[3]' );
	END IF;

	--
	-- Werte zuweisen
	--
	uGoG := ARRAY[ '3', '4' ];
	spNamen := ARRAY[
			'prj_projekte_id'
			, 'prt_protokoll_id'
			, 'str_strkt_id'
			, 'notizen'
			];


ELSIF(
	tabname='p_prtverbindung'
  )
THEN

	--
	-- Plausibilittsprfung ab tabwerte[3]
	--
	IF(
		NOT( tmpInteger < 3 )
	  ) 
	THEN
		EXECUTE intern.pruefe__dt( 'gz', tabwerte[3], '1', NULL
					, 'prj.nimm__tabwerte(...)'
					, tabname || '.tabwerte[3]' );
	END IF;

	--
	-- Werte zuweisen
	--
	uGoG := ARRAY[ '3', '4' ];
	spNamen := ARRAY[
			'prj_projekte_id'
			, 'prt_protokoll_id_nachf'
			, 'prt_protokoll_id_vorg'
			, 'notizen'
			];


ELSIF(
	tabname='personen'
  )
THEN

	--
	-- Werte zuweisen
	--
	uGoG := ARRAY[ '3', '4' ];
	spNamen := ARRAY[
			'intern_firma_id'
			, 'name_n'
			, 'name_v'
			, 'notizen'
			];


ELSIF(
	tabname='pl_dokausgabe'
  )
THEN

	--
	-- Plausibilittsprfung ab tabwerte[3]
	--
	IF(
		NOT( tmpInteger < 3 )
	  ) 
	THEN
		EXECUTE intern.pruefe__dt( 'bw', tabwerte[3], NULL, NULL
					, 'prj.nimm__tabwerte(...)'
					, tabname || '.tabwerte[3]' );
	END IF;

	--
	-- Plausibilittsprfung ab tabwerte[5]
	--
	IF(
		NOT( tmpInteger < 5 )
	  ) 
	THEN
		EXECUTE intern.pruefe__dt( 'gz', tabwerte[5], '1', NULL
					, 'prj.nimm__tabwerte(...)'
					, tabname || '.tabwerte[5]' );
	END IF;

	--
	-- Plausibilittsprfung ab tabwerte[7]
	--
	IF(
		NOT( tmpInteger < 7 )
	  ) 
	THEN
		EXECUTE intern.pruefe__dt( 'du', tabwerte[7], NULL, NULL
					, 'prj.nimm__tabwerte(...)'
					, tabname || '.tabwerte[7]' );
	END IF;

	--
	-- Plausibilittsprfung ab tabwerte[8]
	--
	IF(
		NOT( tmpInteger < 8 )
	  ) 
	THEN
		EXECUTE intern.pruefe__dt( 'bw', tabwerte[8], NULL, NULL
					, 'prj.nimm__tabwerte(...)'
					, tabname || '.tabwerte[8]' );
	END IF;

	--
	-- Werte zuweisen
	--
	uGoG := ARRAY[ '2', '13' ];
	spNamen := ARRAY[
			'prj_projekte_id'
			, 'dok_doku_id'
			, 'logentfernt'
			, 'nr'
			, 'spr_uebvar_id'
			, 'stand'
			, 'datum'
			, 'istfrei'
			, 'notizen'
			, 'logdatuhrz'
			, 'logdquelle'
			, 'logname'
			, 'logdqok'
			];


ELSIF(
	tabname='pl_prtpsgefszenario'
  )
THEN

	--
	-- Plausibilittsprfung ab tabwerte[3]
	--
	IF(
		NOT( tmpInteger < 3 )
	  ) 
	THEN
		EXECUTE intern.pruefe__dt( 'gz', tabwerte[3], '1', NULL
					, 'prj.nimm__tabwerte(...)'
					, tabname || '.tabwerte[3]' );
	END IF;

	--
	-- Werte zuweisen
	--
	uGoG := ARRAY[ '3', '9' ];
	spNamen := ARRAY[
			'prj_projekte_id'
			, 'ps_gefszenario_id'
			, 'prt_protokoll_id'
			, 'notizen'
			, 'logentfernt'
			, 'logdatuhrz'
			, 'logdquelle'
			, 'logname'
			, 'logdqok'
			];


ELSIF(
	tabname='pl_psgefstrkt'
  )
THEN

	--
	-- Plausibilittsprfung ab tabwerte[3]
	--
	IF(
		NOT( tmpInteger < 3 )
	  ) 
	THEN
		EXECUTE intern.pruefe__dt( 'gz', tabwerte[3], '1', NULL
					, 'prj.nimm__tabwerte(...)'
					, tabname || '.tabwerte[3]' );
	END IF;

	--
	-- Werte zuweisen
	--
	uGoG := ARRAY[ '3', '9' ];
	spNamen := ARRAY[
			'prj_projekte_id'
			, 'ps_gefszenario_id'
			, 'str_strkt_id'
			, 'notizen'
			, 'logentfernt'
			, 'logdatuhrz'
			, 'logdquelle'
			, 'logname'
			, 'logdqok'
			];


ELSIF(
	tabname='pl_psgefabk'
  )
THEN

	--
	-- Plausibilittsprfung ab tabwerte[3]
	--
	IF(
		NOT( tmpInteger < 3 )
	  ) 
	THEN
		EXECUTE intern.pruefe__dt( 'bw', tabwerte[3], NULL, NULL
					, 'prj.nimm__tabwerte(...)'
					, tabname || '.tabwerte[3]' );
	END IF;

	--
	-- Plausibilittsprfung tabwerte[4]
	--
	IF(
		NOT( tmpInteger < 4 )
	  ) 
	THEN
		EXECUTE intern.pruefe__dt( 'gz', tabwerte[4], '0', NULL
						, 'prj.nimm__tabwerte(...)'
						, tabname || '.tabwerte[4]' );
	END IF;
	--
	-- Plausibilittsprfung tabwerte[5]
	--
	IF(
		NOT( tmpInteger < 5 )
	  ) 
	THEN
		EXECUTE intern.pruefe__dt( 'gz', tabwerte[5], '0', NULL
						, 'prj.nimm__tabwerte(...)'
						, tabname || '.tabwerte[5]' );
	END IF;


	--
	-- Werte zuweisen
	--
	uGoG := ARRAY[ '4', '10' ];
	spNamen := ARRAY[
			'prj_projekte_id'
			, 'ps_gefszenario_id'
			, 'logentfernt'
			, 'ps_abk_id'
			, 'spr_uebvar_id_zus'
			, 'notizen'
			, 'logdatuhrz'
			, 'logdquelle'
			, 'logname'
			, 'logdqok'
			];


ELSIF(
	tabname='pl_psgefanm'
  )
THEN

	--
	-- Plausibilittsprfung ab tabwerte[3]
	--
	IF(
		NOT( tmpInteger < 3 )
	  ) 
	THEN
		EXECUTE intern.pruefe__dt( 'bw', tabwerte[3], NULL, NULL
					, 'prj.nimm__tabwerte(...)'
					, tabname || '.tabwerte[3]' );
	END IF;

	--
	-- Plausibilittsprfung ab tabwerte[4]
	--
	IF(
		NOT( tmpInteger < 4 )
	  ) 
	THEN
		EXECUTE intern.pruefe__dt( 'gz', tabwerte[4], '0', NULL
					, 'prj.nimm__tabwerte(...)'
					, tabname || '.tabwerte[4]' );
	END IF;

	--
	-- Plausibilittsprfung ab tabwerte[5]
	--
	IF(
		NOT( tmpInteger < 5 )
	  ) 
	THEN
		EXECUTE intern.pruefe__dt( 'gz', tabwerte[5], '0', NULL
					, 'prj.nimm__tabwerte(...)'
					, tabname || '.tabwerte[5]' );
	END IF;

	--
	-- Werte zuweisen
	--
	uGoG := ARRAY[ '5', '10' ];
	spNamen := ARRAY[
			'prj_projekte_id'
			, 'ps_gefszenario_id'
			, 'logentfernt'
			, 'ps_anmerkung_id'
			, 'spr_uebvar_id'
			, 'notizen'
			, 'logdatuhrz'
			, 'logdquelle'
			, 'logname'
			, 'logdqok'
			];


ELSIF(
	tabname='ppl_dokdoku'
  )
THEN

	--
	-- Plausibilittsprfung ab tabwerte[3]
	--
	IF(
		NOT( tmpInteger < 3 )
	  ) 
	THEN
		EXECUTE intern.pruefe__dt( 'gz', tabwerte[3], '1', NULL
					, 'prj.nimm__tabwerte(...)'
					, tabname || '.tabwerte[3]' );
	END IF;

	--
	-- Plausibilittsprfung ab tabwerte[4]
	--
	IF(
		NOT( tmpInteger < 4 )
	  ) 
	THEN
		EXECUTE intern.pruefe__dt( 'bw', tabwerte[4], NULL, NULL
					, 'prj.nimm__tabwerte(...)'
					, tabname || '.tabwerte[4]' );
	END IF;

	--
	-- Werte zuweisen
	--
	uGoG := ARRAY[ '3', '9' ];
	spNamen := ARRAY[
			'prj_projekte_id'
			, 'dok_doku_id'
			, 'prj_personen_id'
			, 'logentfernt'
			, 'notizen'
			, 'logdatuhrz'
			, 'logdquelle'
			, 'logname'
			, 'logdqok'
			];


--
-- 1.1.) Protokolleintrag einem Projekt zuordnen bzw. projektspezifisch modifizieren
--
--	vorbergehend deaktiviert !
--
--ELSIF(
--	tabname='pp_prtprotokoll'
--  )
--THEN
--
--	--
--	-- Plausibilittsprfung ab tabwerte[3]
--	--
--	IF(
--		NOT( tmpInteger < 3 )
--	  ) 
--	THEN
--		EXECUTE intern.pruefe__dt( 'gz', tabwerte[3], '0', NULL
--					, 'prj.nimm__tabwerte(...)'
--					, tabname || '.tabwerte[3]' );
--	END IF;
--
--	IF(
--		NOT( tmpInteger < 4 )
--	  ) 
--	THEN
--		EXECUTE intern.pruefe__dt( 'du', tabwerte[4], NULL, NULL
--					, 'prj.nimm__tabwerte(...)'
--					, tabname || '.tabwerte[4]' );
--	END IF;
--
--	IF(
--		NOT( tmpInteger < 5 )
--	  ) 
--	THEN
--		EXECUTE intern.pruefe__dt( 'bw', tabwerte[5], NULL, NULL
--					, 'prj.nimm__tabwerte(...)'
--					, tabname || '.tabwerte[5]' );
--	END IF;
--
--	IF(
--		NOT( tmpInteger < 6 )
--	  ) 
--	THEN
--		EXECUTE intern.pruefe__dt( 'bw', tabwerte[6], NULL, NULL
--					, 'prj.nimm__tabwerte(...)'
--					, tabname || '.tabwerte[6]' );
--	END IF;
--
--	--
--	-- Werte zuweisen
--	--
--	uGoG := ARRAY[ '3', '7' ];
--	spNamen := ARRAY[
--			'prj_projekte_id'
--			, 'prt_protokoll_id'
-- 			, 'spr_uebvar_id'
--			, 'datuhrz'
--			, 'intern'
--			, 'erledigt'
--			, 'notizen'
--			];
--
--
---- 1.2.) dem Protokolleintrag die beteiligten Personen zuordnen
---- 1.3.) der Protokolleintrag ist eine Frage / Aufgabe
--ELSIF(
--	tabname='pp_prtprotokoll_pers'
--  )
--THEN
--
--	--
--	-- Plausibilittsprfung ab tabwerte[3]
--	--
--	IF(
--		NOT( tmpInteger < 3 )
--	  ) 
--	THEN
--		EXECUTE intern.pruefe__dt( 'bw', tabwerte[3], NULL, NULL
--					, 'prj.nimm__tabwerte(...)'
--					, tabname || '.tabwerte[3]' );
--	END IF;
--
--	IF(
--		NOT( tmpInteger < 4 )
--	  ) 
--	THEN
--		EXECUTE intern.pruefe__dt( 'gz', tabwerte[4], '1', NULL
--					, 'prj.nimm__tabwerte(...)'
--					, tabname || '.tabwerte[4]' );
--	END IF;
--
--	IF(
--		NOT( tmpInteger < 5 )
--	  ) 
--	THEN
--		EXECUTE intern.pruefe__dt( 'du', tabwerte[5], NULL, NULL
--					, 'prj.nimm__tabwerte(...)'
--					, tabname || '.tabwerte[5]' );
--	END IF;
--
--	IF(
--		NOT( tmpInteger < 6 )
--	  ) 
--	THEN
--		EXECUTE intern.pruefe__dt( 'du', tabwerte[6], NULL, NULL
--					, 'prj.nimm__tabwerte(...)'
--					, tabname || '.tabwerte[6]' );
--	END IF;
--
--	--
--	-- Teilnehmer / Frage behandeln
--	--
--	IF(
--		( tmpInteger > 4 )
--		AND ( CAST( tabwerte[3] AS boolean ) = true )
--	  ) 
--	THEN
--		RAISE EXCEPTION 'prj.nimm__tabwerte(...)	Wenn >tabwerte[3] = true< ist, darf >tabwerte[5]< und >tabwerte[6]< nicht angegeben werden. Das Einlesen wird abgebrochen !';
--	END IF;
--
--	IF(
--		( tmpInteger > 3 )
--		AND ( tmpInteger < 5 )
--		AND ( CAST( tabwerte[3] AS boolean ) = false )
--	  ) 
--	THEN
--		RAISE EXCEPTION 'prj.nimm__tabwerte(...)	Wenn >tabwerte[3] = false< ist, mu >tabwerte[5]< angegeben werden. Das Einlesen wird abgebrochen !';
--	END IF;
--
--
--	--
--	-- Werte zuweisen
--	--
--	uGoG := ARRAY[ '4', '7' ];
--	spNamen := ARRAY[
--			'prj_projekte_id'
--			, 'prt_protokoll_id'
--			, 'teilnehmer'
--			, 'prj_personen_id'
--			, 'termin'
--			, 'duanfrage'
--			, 'notizen'
--			];
--
--
ELSIF(
	tabname='pp_psgefszenario'
  )
THEN

	--
	-- Plausibilittsprfung ab tabwerte[3]
	--
	EXECUTE intern.pruefe__dt( 'gz', tabwerte[3], '0', NULL
					, 'prj.nimm__tabwerte(...)'
					, tabname || '.tabwerte[3]' );

	IF(
		NOT( tmpInteger < 4 )
	  ) 
	THEN
		EXECUTE intern.pruefe__dt( 'gz', tabwerte[4], '0', NULL
					, 'prj.nimm__tabwerte(...)'
					, tabname || '.tabwerte[4]' );
	END IF;

	IF(
		NOT( tmpInteger < 5 )
	  ) 
	THEN
		EXECUTE intern.pruefe__dt( 'gz', tabwerte[5], '0', NULL
					, 'prj.nimm__tabwerte(...)'
					, tabname || '.tabwerte[5]' );
	END IF;

	IF(
		NOT( tmpInteger < 6 )
	  ) 
	THEN
		EXECUTE intern.pruefe__dt( 'gz', tabwerte[6], '0', NULL
					, 'prj.nimm__tabwerte(...)'
					, tabname || '.tabwerte[6]' );
	END IF;

	--
	-- Werte zuweisen
	--
	uGoG := ARRAY[ '3', '7' ];
	spNamen := ARRAY[
			'prj_projekte_id'
			, 'ps_gefszenario_id'
			, 'prj_personen_id'
			, 'spr_uebvar_id'
			, 'spr_uebvar_id_reprgefszen'
			, 'spr_uebvar_id_ursp'
			, 'notizen'
			];


ELSIF(
	tabname='pp_strstrkt'
  )
THEN

	--
	-- Plausibilittsprfung ab tabwerte[3]
	--
	EXECUTE intern.pruefe__dt( 'gz', tabwerte[3], '1', NULL
					, 'prj.nimm__tabwerte(...)'
					, tabname || '.tabwerte[3]' );

	IF(
		NOT( tmpInteger < 4 )
	  ) 
	THEN
		EXECUTE intern.pruefe__dt( 'gz', tabwerte[4], '0', NULL
						, 'prj.nimm__tabwerte(...)'
						, tabname || '.tabwerte[4]' );
	END IF;

	IF(
		NOT( tmpInteger < 5 )
	  ) 
	THEN
		EXECUTE intern.pruefe__dt( 'gz', tabwerte[5], '0', NULL
						, 'prj.nimm__tabwerte(...)'
						, tabname || '.tabwerte[5]' );
	END IF;

	IF(
		NOT( tmpInteger < 6 )
	  ) 
	THEN
		EXECUTE str.pruefe__fbwerte( 'FB-Ereignis', tabwerte[6]
						, 'prj.nimm__tabwerte(...)'
						, 'tabwerte[6]' );
	END IF;

	--
	-- Werte zuweisen
	--
	uGoG := ARRAY[ '3', '7' ];
	spNamen := ARRAY[
			'prj_projekte_id'
			, 'str_strkt_id'
			, 'prj_personen_id'
			, 'spr_uebvar_id'
			, 'spr_uebvar_id_zus'
			, 'fbereignis'
			, 'notizen'
			];


ELSIF(
	tabname='pl_prtdokdoku'
  )
THEN

	--
	-- Plausibilittsprfung ab tabwerte[3]
	--
	IF(
		NOT( tmpInteger < 3 )
	  ) 
	THEN
		EXECUTE intern.pruefe__dt( 'gz', tabwerte[3], '1', NULL
					, 'prj.nimm__tabwerte(...)'
					, tabname || '.tabwerte[3]' );
	END IF;

	--
	-- Plausibilittsprfung ab tabwerte[4]
	--
	IF(
		NOT( tmpInteger < 4 )
	  ) 
	THEN
		EXECUTE intern.pruefe__dt( 'bw', tabwerte[6], NULL, NULL
					, 'prj.nimm__tabwerte(...)'
					, tabname || '.tabwerte[6]' );
	END IF;

	--
	-- Werte zuweisen
	--
	uGoG := ARRAY[ '3', '9' ];
	spNamen := ARRAY[
			'prj_projekte_id'
			, 'dok_doku_id'
			, 'prt_protokoll_id'
			, 'logentfernt'
			, 'notizen'
			, 'logdatuhrz'
			, 'logdquelle'
			, 'logname'
			, 'logdqok'
			];


ELSIF(
	tabname='projekte'
  )
THEN
	--
	-- Werte zuweisen
	--
	uGoG := ARRAY[ '2', '4' ];
	spNamen := ARRAY[
			'prjname'
			, 'prjbeschr'
			, 'makefile'
			, 'notizen'
			];


ELSIF(
	tabname='p_psabk'
  )
THEN

	--
	-- Plausibilittsprfung ab tabwerte[3]
	--
	IF(
		NOT( tmpInteger < 3 )
	  ) 
	THEN
		EXECUTE intern.pruefe__dt( 'gz', tabwerte[3], '1', NULL
					, 'prj.nimm__tabwerte(...)'
					, tabname || '.tabwerte[3]' );
	END IF;


	IF(
		NOT( tmpInteger < 4 )
	  ) 
	THEN
		EXECUTE intern.pruefe__dt( 'gz', tabwerte[4], '1', NULL
					, 'prj.nimm__tabwerte(...)'
					, tabname || '.tabwerte[4]' );
	END IF;


	IF(
		NOT( tmpInteger < 5 )
	  ) 
	THEN
		EXECUTE intern.pruefe__dt( 'gz', tabwerte[5], '1', NULL
					, 'prj.nimm__tabwerte(...)'
					, tabname || '.tabwerte[5]' );
	END IF;

	--
	-- Werte zuweisen
	--
	uGoG := ARRAY[ '2', '6' ];
	spNamen := ARRAY[
			'prj_projekte_id'
			, 'ps_abk_id'
			, 'spr_uebvar_id'
			, 'spr_uebvar_id_l'
			, 'spr_uebvar_id_zus'
			, 'notizen'
			];


ELSIF(
	tabname='p_strverbindung'
  )
THEN

	IF(
		NOT( tmpInteger < 3 )
	  ) 
	THEN
		EXECUTE intern.pruefe__dt( 'gz', tabwerte[3], '1', NULL
					, 'prj.nimm__tabwerte(...)'
					, tabname || '.tabwerte[3]' );
	END IF;

	IF(
		NOT( tmpInteger < 4 )
	  ) 
	THEN
		EXECUTE str.pruefe__fbwerte( 'FB-Tor', tabwerte[4]
						, 'prj.nimm__tabwerte(...)'
						, 'tabwerte[4]' );
	END IF;

	--
	-- Werte zuweisen
	--
	uGoG := ARRAY[ '3', '5' ];
	spNamen := ARRAY[
			'prj_projekte_id'
			, 'str_strkt_id_vorg'
			, 'str_strkt_id_nachf'
			, 'fbtor'
			, 'notizen'
			];


ELSE

	--
	-- Fehlermeldung. Es drfen nur die im Schema >prj< verfgbaren Tabellennamen verwendet 
	-- werden
	--
	RAISE EXCEPTION 'prj.nimm__tabwerte(...)	Der bergebene Tabellenname  >tabname = %', 
		CASE WHEN( tabname IS NULL ) THEN 'NULL' ELSE tabname END
		 || '< ist nicht zulssig. Es drfen nur die im Schema >prj< enthaltenen Tabellennamen verwendet werden. Das Einlesen wird abgebrochen !';

END IF;



--
-- 2.1)	Plausibilittsprfungen fr alle Tabellen
--	- Listengre
--
EXECUTE intern.pruefe__array( tabwerte, uGoG[1], uGoG[2]
				, 'prj.nimm__tabwerte(...)'
				, tabname || '.tabwerte' );

--
-- 2.2)	Plausibilittsprfungen fr alle Tabellen auer >prj.projekte<
--	- tabwerte[1]
--	- tabwerte[2] (auer >prj.personen<)
--
IF(
	tabname != 'projekte'
  )
THEN

	--
	-- >tabwerte[1]< mu mindestens  >0< sein.
	--
	EXECUTE intern.pruefe__dt( 'gz', tabwerte[1], '0', NULL
					, 'prj.nimm__tabwerte(...)'
					, tabname || '.tabwerte[1]' );

	IF(
		tabname != 'personen'
	  )
	THEN

		--
		-- >tabwerte[2]< mu mindestens  >1< sein.
		--
		EXECUTE intern.pruefe__dt( 'gz', tabwerte[2], '1', NULL
						, 'prj.nimm__tabwerte(...)'
						, tabname || '.tabwerte[2]' );

	END IF;

END IF;


--
-- 2.3)	Bei allen Tabellen mit Logbuchfunktion, das Wiederverwenden von Zeilen mittels
--	expliziten Setzen von >logdatuhrz< deaktivieren
--
--	Bei der bergabe von Werten, die unterhalb >logdatuhrz< liegen, wird >logdatuhrz<
--	automatisch ergnzt
--
--	ACHTUNG ! hier wird das vernderbare Array >tabwerteIntern< gesetzt
--

-- pl_prtdokdoku < 6
-- pl_prtpsgefszenario < 6
-- pl_psgefstrkt < 6
-- ppl_dokdoku < 6

-- pl_psgefabk < 7
-- pl_psgefanm < 7

-- pl_dokausgabe < 10


IF(
	( ( tabname= 'pl_prtpsgefszenario' OR tabname='pl_psgefstrkt' OR tabname='ppl_dokdoku' OR tabname='pl_prtdokdoku' ) AND ( tmpInteger < 6 ) )
	OR ( ( tabname='pl_psgefabk' OR tabname='pl_psgefanm' ) AND ( tmpInteger < 7 ) )
	OR ( ( tabname='pl_dokausgabe' ) AND ( tmpInteger < 10) )
  ) 
THEN
	--
	-- Spaltennamen und Wert ergnzen / >tmpInteger< hochzhlen
	--
	tmpInteger := tmpInteger + 1;
	spNamen[tmpInteger] := 'logdatuhrz';
	tabwerteIntern := tabwerteIntern || CAST( timeofday() AS varchar );
END IF;


--
-- 3.)	Tabname einlesen
--		- >spNamen[1]< immer vorhanden
--		- >spNamen[2]< immer vorhanden
--		- >spNamen[3 ... 11]< ggf. vorhanden
--
--		- ab hier statt >tabwerte< das vernderbare Array >tabwerteIntern< verwenden
--
EXECUTE
	'SELECT intern.nimm__zeile( ''prj.' 
				|| CASE WHEN( tabname = 'pp_prtprotokoll_pers' ) 
					THEN 'pp_prtprotokoll' ELSE tabname END
				|| ''', ARRAY[ ''' || spNamen[1] || '''
				, ''' || spNamen[2] || ''''
				|| CASE WHEN( NOT( tmpInteger < 3 ) )
					THEN ', ''' || spNamen[3] || '''' ELSE '' END
				|| CASE WHEN( NOT( tmpInteger < 4 ) )
					THEN ', ''' || spNamen[4] ||  '''' ELSE '' END
				|| CASE WHEN( NOT( tmpInteger < 5 ) )
					THEN ', ''' || spNamen[5] ||  '''' ELSE '' END
				|| CASE WHEN( NOT( tmpInteger < 6 ) )
					THEN ', ''' || spNamen[6] ||  '''' ELSE '' END
				|| CASE WHEN( NOT( tmpInteger < 7 ) )
					THEN ', ''' || spNamen[7] ||  '''' ELSE '' END
				|| CASE WHEN( NOT( tmpInteger < 8 ) )
					THEN ', ''' || spNamen[8] ||  '''' ELSE '' END
				|| CASE WHEN( NOT( tmpInteger < 9 ) )
					THEN ', ''' || spNamen[9] ||  '''' ELSE '' END
				|| CASE WHEN( NOT( tmpInteger < 10 ) )
					THEN ', ''' || spNamen[10] ||  '''' ELSE '' END
				|| CASE WHEN( NOT( tmpInteger < 11 ) )
					THEN ', ''' || spNamen[11] ||  '''' ELSE '' END
				|| ']
			, ARRAY[''' 	|| tabwerteIntern[1] || '''
				, '''	|| tabwerteIntern[2] || ''''
				|| CASE WHEN( NOT( tmpInteger < 3 ) )
					THEN ', ''' || tabwerteIntern[3] || '''' ELSE '' END
				|| CASE WHEN( NOT( tmpInteger < 4 ) )
					THEN ', ''' || tabwerteIntern[4] || '''' ELSE '' END
				|| CASE WHEN( NOT( tmpInteger < 5 ) )
					THEN ', ''' || tabwerteIntern[5] || '''' ELSE '' END
				|| CASE WHEN( NOT( tmpInteger < 6 ) )
					THEN ', ''' || tabwerteIntern[6] || '''' ELSE '' END
				|| CASE WHEN( NOT( tmpInteger < 7 ) )
					THEN ', ''' || tabwerteIntern[7] || '''' ELSE '' END
				|| CASE WHEN( NOT( tmpInteger < 8 ) )
					THEN ', ''' || tabwerteIntern[8] || '''' ELSE '' END
				|| CASE WHEN( NOT( tmpInteger < 9 ) )
					THEN ', ''' || tabwerteIntern[9] || '''' ELSE '' END
				|| CASE WHEN( NOT( tmpInteger < 10 ) )
					THEN ', ''' || tabwerteIntern[10] || '''' ELSE '' END
				|| CASE WHEN( NOT( tmpInteger < 11 ) )
					THEN ', ''' || tabwerteIntern[11] || '''' ELSE '' END
				|| '])'
INTO tabid;


END
$$LANGUAGE 'plpgsql'  VOLATILE;
SELECT intern.nimm__TLKommentarFunktion( 'prj.nimm__tabwerte( IN tabname varchar, IN tabwerte varchar[], OUT tabid varchar )',
ARRAY[
E'Name der Tabelle (ohne Schemanamen) des Schemas \\texttt{prj}, welche die Werte bernehmen soll  (Details siehe Funktionsbeschreibung --- Werteliste einlesen).'
, E'Liste der Werte, welche in die aktuelle Tabelle eingelesen werden sollen (Details siehe Funktionsbeschreibung --- Werteliste einlesen).'
, E'Es wird die Identifikationsnummer des aktuell eingelesenen Wertes \\texttt{prj.*.id} zurckgegeben.'
],
E'Mittels dieser Funktion werden in die Tabellen des Schemas \\texttt{prj} die Werte eingelesen.
\\\\
\\\\
Werteliste einlesen:\\\\
Dem Funktionsparameter \\texttt{tabwerte} ist eine Werteliste (\\texttt{ARRAY}) zu bergeben (die maximale Anzahl und die Reihenfolge der Werte ist fest vorgegeben --- siehe oben). Soll nur eine Teilmenge der Werte bergeben werden, dann sind alle Werte von links nach rechts zu spezifizieren (nichtbentigte Werte am Ende der Liste drfen weggelassen werden).
\\\\
\\\\
\\noindent \\textbf{personen}

\\begin{enumerate}
  \\item \\texttt{intern_firma_id}
  \\item \\texttt{name_n}
  \\item \\texttt{name_v}
  \\item \\texttt{notizen}
\\end{enumerate}
Es mssen mindestens die ersten drei Werte bergeben werden. Der erste Wert mu grer \\texttt{0} sein.
\\\\
\\\\
\\noindent \\textbf{projekte}

\\begin{enumerate}
  \\item \\texttt{prjname}
  \\item \\texttt{prjbeschr}
  \\item \\texttt{makefile}
  \\item \\texttt{notizen}
\\end{enumerate}
Es mssen mindestens die ersten beiden Werte bergeben werden.
\\\\
\\\\
\\textbf{p_dokstrkt, p_prtstrstrkt, p_prtverbindung, \\\\p_psabk, p_strverbindung}

\\begin{enumerate}
  \\item \\texttt{prj_projekte_id}
  \\item \\texttt{dok_doku_id, prt_protokoll_id, prt_protokoll_id_nachf, \\\\ps_abk_id, str_strkt_id_vorg}
  \\item \\texttt{dok_strkt_id, str_strkt_id, prt_protokoll_id_vorg, \\\\spr_uebvar_id, str_strkt_id_nachf}
  \\item \\texttt{notizen, notizen, notizen, \\\\spr_uebvar_id_l, fbtor}
  \\item \\texttt{---, ---, ---, \\\\spr_uebvar_id_zus, notizen}
  \\item \\texttt{---, ---, ---, \\\\notizen, ---}
\\end{enumerate}
Es mssen mindestens die ersten drei Werte bergeben werden. \\texttt{prj_projekte_id} darf \\texttt{0} sein, die anderen beiden Werte mssen grer \\texttt{0} sein.
\\\\
\\\\
\\noindent \\textbf{pl_dokausgabe, pl_prtdokdoku, pl_prtpsgefszenario, \\\\pl_psgefabk, pl_psgefanm, pl_psgefstrkt}

\\begin{enumerate}
  \\item \\texttt{prj_projekte_id}
  \\item \\texttt{dok_doku_id, dok_doku_id, ps_gefszenario_id, \\\\ps_gefszenario_id, ps_gefszenario_id, ps_gefszenario_id}
  \\item \\texttt{logentfernt, prt_protokoll_id, prt_protokoll_id, \\\\logentfernt, logentfernt, str_strkt_id}
  \\item \\texttt{nr, logentfernt, notizen, \\\\ps_abk_id, ps_anmerkung_id, notizen}
  \\item \\texttt{spr_uebvar_id, notizen, logentfernt, \\\\spr_uebvar_id_zus, spr_uebvar_id, logentfernt}
  \\item \\texttt{stand, logdatuhrz, logdatuhrz, \\\\notizen, notizen, logdatuhrz}
  \\item \\texttt{datum, logdquelle, logdquelle, \\\\logdatuhrz, logdatuhrz, logdquelle}
  \\item \\texttt{istfrei, logname, logname, \\\\logdquelle, logdquelle, logname}
  \\item \\texttt{notizen, logdqok, logdqok, \\\\logname, logname, logdqok}
  \\item \\texttt{logdatuhrz, ---, ---, \\\\logdqok, logdqok, ---}
  \\item \\texttt{logdquelle, ---, ---, \\\\---, ---, ---}
  \\item \\texttt{logname, ---, ---, \\\\---, ---, ---}
  \\item \\texttt{logdqok, ---, ---, \\\\---, ---, ---}
\\end{enumerate}
Es mssen mindestens die ersten beiden Werte bergeben werden. \\texttt{prj_projekte_id} darf \\texttt{0} sein, der andere Wert mu grer \\texttt{0} sein.
Bei diesen Tabellen (Tabellen mit Logbuchfunktion) wird nicht nach bereits eingelesenen Eintrgen gesucht. Somit ist es mglich mehrfach dieselben Eintrge einzulesen. 
\\\\
\\\\
\\noindent \\textbf{pp_prtprotokoll, pp_prtprotokoll_pers (beide z.Zt. inaktiv), pp_psgefszenario, \\\\ pp_strstrkt, ppl_dokdoku}

\\begin{enumerate}
  \\item \\texttt{prj_projekte_id}
  \\item \\texttt{prt_protokoll_id, prt_protokoll_id, ps_gefszenario_id, \\\\ str_strkt_id, dok_doku_id}
  \\item \\texttt{spr_uebvar_id, teilnehmer, prj_personen_id, \\\\ prj_personen_id, prj_personen_id}
  \\item \\texttt{datuhrz, prj_personen_id, spr_uebvar_id, \\\\ spr_uebvar_id, logentfernt}
  \\item \\texttt{intern, termin, spr_uebvar_id_reprgefszen, \\\\ spr_uebvar_id_zus, notizen} Fr die Spalten \\texttt{spr_uebvar_id_fzg} und \\texttt{spr_uebvar_id} mu der Wert grer  \\texttt{0} sein.
  \\item \\texttt{erledigt, duanfrage, spr_uebvar_id_ursp, \\\\ fbereignis, logdatuhrz}
  \\item \\texttt{notizen, notizen, notizen, \\\\ notizen, logdquelle}
  \\item \\texttt{---, ---, ---, \\\\ ---, logname }
  \\item \\texttt{---, ---, ---, \\\\ ---, logdqok }
\\end{enumerate}
Bei den Tabellen \\texttt{ppl_dokdoku} mssen die ersten drei und bei den Tabellen \\texttt{pp_psgefszenario, pp_strstrkt} die ersten zwei Werte bergeben werden. \\texttt{prj_projekte_id} darf \\texttt{0} sein, die anderen Drei bzw. Zwei Werte mssen grer \\texttt{0} sein.
\\\\
Bei der Tabelle \\texttt{pl_prtdokdoku} mssen die ersten drei Werte bergeben werden.
\\\\
\\\\
Die Tabelle \\texttt{pp_prtprotokoll} deckt drei Aspekte ab:
\\begin{enumerate}
  \\item Protokolleintrag einem Projekt zuordnen, projektspezifisch modifizieren und Randbedingungen setzen (\\texttt{pp_prtprotokoll} whlen);
  \\item dem Protokolleintrag die beteiligten Personen zuordnen (\\texttt{pp_prtprotokoll_pers} whlen);
  \\item dem Protokolleintrag der eine Frage / Aufgabe ist, die relevanten Informationen zuordnen (\\texttt{pp_prtprotokoll_pers} whlen);
\\end{enumerate}
wobei ein Protokolleintrag ein Gefahrenprotokolleintrag, eine Sicherheitsberprfung oder ein Terminplaneintrag (je nach Sinnflligkeit) sein kann.
\\\\
Zur Unterscheidung der drei Aspekte werden die Spalten \\texttt{prj_personen_id} und \\texttt{teilnehmer} verwendet. Es gilt fr
\\begin{enumerate}
  \\item \\texttt{prj_personen_id = 0} und \\texttt{teilnehmer = NULL}
  \\item \\texttt{prj_personen_id > 0} und \\texttt{teilnehmer = true}
  \\item \\texttt{prj_personen_id > 0} und \\texttt{teilnehmer = false}
\\end{enumerate}
Die Spalten der Tabelle \\texttt{pp_prtprotokoll} werden zur Abbildung der drei Aspekte wie folgt verwendet:  \\\\
 \\texttt{notizen ........... 1} \\\\
 \\texttt{datuhrz ........... 1} \\\\
 \\texttt{duanfrage ............. 3} \\\\
 \\texttt{erledigt .......... 1} \\\\
 \\texttt{intern ............ 1} \\\\
 \\texttt{prj_personen_id ..... 2 3} \\\\
 \\texttt{prj_projekte_id ... 1 2 3} \\\\
 \\texttt{prt_protokoll_id .. 1 2 3} \\\\
 \\texttt{spr_uebvar_id ..... 1} \\\\
 \\texttt{teilnehmer .......... 2 3} \\\\
 \\texttt{termin ................ 3}
'
, ARRAY[
E'ACTUNG ! Die Beispiele sind nicht aktualisiert --- mu spter bereinit werden.'
, E'-- Fehlermeldung. Ungltige Tabelle !\\\\SELECT * FROM prj.nimm__tabwerte( NULL, NULL );'
, E'-- Fehlermeldung. Bei allen Tabellen mssen mindestens zwei Elemente bergeben werden\\\\SELECT * FROM prj.nimm__tabwerte( ''projekte'', ARRAY[''1''] );'
, E'-- Fehlermeldung. Die bergebenen Parameter mssen grer \\texttt{0} sein.\\\\SELECT * FROM prj.nimm__tabwerte( ''p_dokkomp'', ARRAY[''0'', ''1''] );\\\\SELECT * FROM prj.nimm__tabwerte( ''p_dokkomp'', ARRAY[''1'', ''0''] );\\\\SELECT * FROM prj.nimm__tabwerte( ''pl_psgefanm'', ARRAY[''1'', ''1'', ''0''] );\\\\SELECT * FROM prj.nimm__tabwerte( ''ppu_kmpkomp'', ARRAY[''1'', ''1'', ''1'', '''', ''0''] );\\\\SELECT * FROM prj.nimm__tabwerte( ''pp_prtprotokoll'', ARRAY[''1'', ''1'', ''1'', '''', '''', '''', '''', '''', '''', ''0''] );'
, E'-- Fehlermeldung. Es drfen nur die zulssigen Begriffe verwendet werden\\\\SELECT * FROM prj.nimm__tabwerte( ''pp_strstrkt'', ARRAY[''1'', ''22'', ''1'', ''99'', ''ttt''] );\\\\SELECT * FROM prj.nimm__tabwerte( ''p_strverbindung'', ARRAY[''1'', ''1'', ''ttt''] );'

, E'-- \\texttt{prj.projekte} einlesen\\\\SELECT * FROM prj.projekte;\\\\SELECT * FROM prj.nimm__tabwerte( ''projekte'', ARRAY[''testProj'', ''Testprojekt'', ''Inhalt des makefile'', ''Zusatzinformationen''] );\\\\SELECT * FROM prj.projekte;'
, E'-- \\texttt{dok.*} einlesen\\\\SELECT * FROM prj.pp_dokausgabe;\\\\SELECT * FROM prj.nimm__tabwerte( ''pp_dokausgabe'', ARRAY[prj.nimm__tabwerte( ''projekte'', ARRAY[''testProj'', ''Testprojekt''] ), dok.nimm__tabwerte( ''ausgabe'', ARRAY[ dok.nimm__doku( ARRAY[''08-15'', ''1''] ), ''01''] ), prj.nimm__tabwerte( ''personen'', ARRAY[''1'', ''Bellair'', ''Michael''] ), ''Zusatzinformationen''] );\\\\SELECT * FROM prj.pp_dokausgabe;\\\\SELECT * FROM prj.p_dokkomp;\\\\SELECT * FROM prj.nimm__tabwerte( ''p_dokkomp'', ARRAY[prj.nimm__tabwerte( ''projekte'', ARRAY[''testProj'', ''Testprojekt''] ), dok.nimm__tabwerte( ''komp'', ARRAY[dok.nimm__doku( ARRAY[''08-15'', ''1''] ), kmp.nimm__komp( ARRAY[''1'', ''47/11''] )] ), ''Zusatzinformationen''] );\\\\SELECT * FROM prj.p_dokkomp;\\\\SELECT * FROM prj.p_dokstrkt;\\\\SELECT * FROM prj.nimm__tabwerte( ''p_dokstrkt'', ARRAY[prj.nimm__tabwerte( ''projekte'', ARRAY[''testProj'', ''Testprojekt''] ), dok.nimm__tabwerte( ''strkt'', ARRAY[dok.nimm__doku( ARRAY[''08-15'', ''1''] ), str.nimm__strkt( ARRAY[''1'', ''-BAAA'', spr.nimm__wgruppe( ''Strukturpunkt'', ''1'', ''0'' )] )] ), ''Zusatzinformationen''] );\\\\SELECT * FROM prj.p_dokstrkt;'
, E'-- \\texttt{kmp.*} einlesen\\\\SELECT * FROM prj.ppu_kmpkomp;\\\\SELECT * FROM prj.nimm__tabwerte( ''ppu_kmpkomp'', ARRAY[prj.nimm__tabwerte( ''projekte'', ARRAY[''testProj'', ''Testprojekt''] ), kmp.nimm__komp( ARRAY[''1'', ''08-15''] ), prj.nimm__tabwerte( ''personen'', ARRAY[''1'', ''Bellair'', ''Michael''] ), ''kmp-id-fzg'', spr.nimm__wgruppe( ''Komponentenbezeichnung-Fahrezeughersteller'', ''1'', ''0'' ), ''Zusatzinformationen''] );\\\\SELECT * FROM prj.ppu_kmpkomp;\\\\SELECT * FROM prj.p_kmpstrkt;\\\\SELECT * FROM prj.nimm__tabwerte( ''p_kmpstrkt'', ARRAY[prj.nimm__tabwerte( ''projekte'', ARRAY[''testProj'', ''Testprojekt''] ), kmp.nimm__strkt( ARRAY[kmp.nimm__komp( ARRAY[''1'', ''08-15''] ), str.nimm__strkt( ARRAY[''1'', ''-BAAA'', spr.nimm__wgruppe( ''Strukturpunkt'', ''1'', ''0'' )] ), ''Zusatzinformationen''] ), ''Zusatzinformationen''] );\\\\SELECT * FROM prj.p_kmpstrkt;'
, E'-- \\texttt{prt.*} einlesen\\\\SELECT * FROM prj.p_prtdokausgabe;\\\\SELECT * FROM prj.nimm__tabwerte( ''p_prtdokausgabe'', ARRAY[prj.nimm__tabwerte( ''projekte'', ARRAY[''testProj'', ''Testprojekt''] ), prt.nimm__tabwerte( ''dokausgabe'', ARRAY[prt.nimm__protokolleintrag( ARRAY[spr.nimm__wgruppe( ''Aktueller Protokolleintrag.'', ''1'', ''0'' ), ''PE_OK''] ), dok.nimm__tabwerte( ''ausgabe'', ARRAY[ dok.nimm__doku( ARRAY[''08-15'', ''1''] ), ''01''] ), ''Zusatzinformationen''] ), ''Zusatzinformationen''] );\\\\SELECT * FROM prj.p_prtdokausgabe;\\\\SELECT * FROM prj.p_prtkomp;\\\\SELECT * FROM prj.nimm__tabwerte( ''p_prtkomp'', ARRAY[prj.nimm__tabwerte( ''projekte'', ARRAY[''testProj'', ''Testprojekt''] ), prt.nimm__tabwerte( ''komp'', ARRAY[prt.nimm__protokolleintrag( ARRAY[spr.nimm__wgruppe( ''Aktueller Protokolleintrag.'', ''1'', ''0'' ), ''PE_OK''] ), kmp.nimm__komp( ARRAY[''1'', ''47/11''] )] ), ''Zusatzinformationen''] );\\\\SELECT * FROM prj.p_prtkomp;\\\\SELECT * FROM prj.pp_prtprotokoll;\\\\SELECT * FROM prj.nimm__tabwerte( ''pp_prtprotokoll'', ARRAY[prj.nimm__tabwerte( ''projekte'', ARRAY[''testProj'', ''Testprojekt''] ), prt.nimm__protokolleintrag( ARRAY[spr.nimm__wgruppe( ''Aktueller Protokolleintrag.'', ''1'', ''0'' ), ''PE_OK''] ), prj.nimm__tabwerte( ''personen'', ARRAY[''1'', ''Bellair'', ''Michael''] ), ''true'', ''2007-06-08'', ''2007-06-20'', ''2007-07-07'', ''true'', ''true'', spr.nimm__wgruppe( ''Projektabhngiger, aktueller Protokolleintrag.'', ''1'', ''0'' ), ''Zusatzinformationen''] );\\\\SELECT * FROM prj.pp_prtprotokoll;\\\\SELECT * FROM prj.p_prtstrstrkt;\\\\SELECT * FROM prj.nimm__tabwerte( ''p_prtstrstrkt'', ARRAY[prj.nimm__tabwerte( ''projekte'', ARRAY[''testProj'', ''Testprojekt''] ), prt.nimm__tabwerte( ''strkt'', ARRAY[prt.nimm__protokolleintrag( ARRAY[spr.nimm__wgruppe( ''Aktueller Protokolleintrag.'', ''1'', ''0'' ), ''PE_OK''] ), str.nimm__strkt( ARRAY[''1'', ''-BAAA'', spr.nimm__wgruppe( ''Strukturpunkt'', ''1'', ''0'' )])]), ''Zusatzinformationen''] );\\\\SELECT * FROM prj.p_prtstrstrkt;\\\\SELECT * FROM prj.p_prtverbindung;\\\\SELECT * FROM prj.nimm__tabwerte( ''p_prtverbindung'', ARRAY[prj.nimm__tabwerte( ''projekte'', ARRAY[''testProj'', ''Testprojekt''] ), prt.nimm__tabwerte( ''verbindung'', ARRAY[prt.nimm__protokolleintrag( ARRAY[spr.nimm__wgruppe( ''Aktueller Protokolleintrag.'', ''1'', ''0'' ), ''PE_OK''] ), prt.nimm__protokolleintrag( ARRAY[spr.nimm__wgruppe( ''Zugeordneter Aktueller Protokolleintrag.'', ''1'', ''0'' ), ''PE_OK''] )]), ''Zusatzinformationen''] );\\\\SELECT * FROM prj.p_prtverbindung;'
, E'-- \\texttt{ps.*} einlesen\\\\SELECT * FROM prj.p_psabk;\\\\SELECT * FROM prj.nimm__tabwerte( ''p_psabk'', ARRAY[prj.nimm__tabwerte( ''projekte'', ARRAY[''testProj'', ''Testprojekt''] ), ps.nimm__abk( ARRAY[spr.nimm__wgruppe( ''abk'', ''1'', ''0'' ), spr.nimm__wgruppe( ''Abkrzung'', ''1'', ''0'' ), ''BP''] ), spr.nimm__wgruppe( ''projabk'', ''1'', ''0'' ), spr.nimm__wgruppe( ''projektabhngige Abkrzung'', ''1'', ''0'' ), ''Zusatzinformationen''] );\\\\SELECT * FROM prj.p_psabk;\\\\SELECT * FROM prj.pl_psgefabk;\\\\SELECT * FROM prj.nimm__tabwerte( ''pl_psgefabk'', ARRAY[prj.nimm__tabwerte( ''projekte'', ARRAY[''testProj'', ''Testprojekt''] ), ps.nimm__aspekte( ''gefabk'', ARRAY[ ps.nimm__gefszenario( ARRAY[spr.nimm__wgruppe( ''Gefahrenszenario'', ''1'', ''0'' ), spr.nimm__wgruppe( ''Ursprung des Gefahrenszenarios'', ''1'', ''0'' )] ), ps.nimm__abk( ARRAY[spr.nimm__wgruppe( ''abk'', ''1'', ''0'' ), spr.nimm__wgruppe( ''Abkrzung'', ''1'', ''0'' ), ''BP''] )] ), ''2007-06-06'', ''datenquelle'', ''micha'', ''true'', ''Zusatzinformationen''] );\\\\SELECT * FROM prj.pl_psgefabk;\\\\SELECT * FROM prj.pl_psgefanm;\\\\SELECT * FROM prj.nimm__tabwerte( ''pl_psgefanm'', ARRAY[prj.nimm__tabwerte( ''projekte'', ARRAY[''testProj'', ''Testprojekt''] ),  ps.nimm__aspekte( ''gefanm'', ARRAY[ps.nimm__gefszenario( ARRAY[spr.nimm__wgruppe( ''Gefahrenszenario'', ''1'', ''0'' ), spr.nimm__wgruppe( ''Ursprung des Gefahrenszenarios'', ''1'', ''0'' )] ), spr.nimm__wgruppe( ''Anmerkungen'', ''1'', ''0'' )] ), spr.nimm__wgruppe( ''projektspezifische Anmerkungen'', ''1'', ''0'' ), ''true'', ''2007-06-06'', ''datenquelle'', ''micha'', ''true'', ''Zusatzinformationen''] );\\\\SELECT * FROM prj.pl_psgefanm;\\\\SELECT * FROM prj.pl_psgefkomp;\\\\SELECT * FROM prj.nimm__tabwerte( ''pl_psgefkomp'', ARRAY[prj.nimm__tabwerte( ''projekte'', ARRAY[''testProj'', ''Testprojekt''] ), ps.nimm__aspekte( ''gefkomp'', ARRAY[ps.nimm__gefszenario( ARRAY[spr.nimm__wgruppe( ''Gefahrenszenario'', ''1'', ''0'' ), spr.nimm__wgruppe( ''Ursprung des Gefahrenszenarios'', ''1'', ''0'' )] ), kmp.nimm__komp( ARRAY[''1'',''08-15''] )] ), ''2007-06-06'', ''datenquelle'', ''micha'', ''true'', ''Zusatzinformationen''] );\\\\SELECT * FROM prj.pl_psgefkomp;\\\\SELECT * FROM prj.pl_psgefnetz;\\\\SELECT * FROM prj.nimm__tabwerte( ''pl_psgefnetz'', ARRAY[prj.nimm__tabwerte( ''projekte'', ARRAY[''testProj'', ''Testprojekt''] ),  ps.nimm__aspekte( ''gefnetz'', ARRAY[ps.nimm__gefszenario( ARRAY[spr.nimm__wgruppe( ''Gefahrenszenario'', ''1'', ''0'' ), spr.nimm__wgruppe( ''Ursprung des Gefahrenszenarios'', ''1'', ''0'' )]), str.nimm__strkt( ARRAY[''1'', ''-BAAA'', spr.nimm__wgruppe( ''Strukturpunkt'', ''1'', ''0'' )])] ), ''2007-06-06'', ''datenquelle'', ''micha'', ''true'', ''Zusatzinformationen''] );\\\\SELECT * FROM prj.pl_psgefnetz;\\\\SELECT * FROM prj.pl_prtpsgefszenario;\\\\SELECT * FROM prj.nimm__tabwerte( ''pl_prtpsgefszenario'', ARRAY[prj.nimm__tabwerte( ''projekte'', ARRAY[''testProj'', ''Testprojekt''] ), ps.nimm__aspekte( ''gefprot'', ARRAY[ps.nimm__gefszenario( ARRAY[spr.nimm__wgruppe( ''Gefahrenszenario'', ''1'', ''0'' ), spr.nimm__wgruppe( ''Ursprung des Gefahrenszenarios'', ''1'', ''0'' )]), prt.nimm__protokolleintrag( ARRAY[spr.nimm__wgruppe( ''Zugeordneter Aktueller Protokolleintrag.'', ''1'', ''0'' ), ''PE_OK''] )] ), ''true'', ''2007-06-06'', ''datenquelle'', ''micha'', ''true'', ''Zusatzinformationen''] );\\\\SELECT * FROM prj.pl_prtpsgefszenario;\\\\SELECT * FROM prj.pl_psgefstrkt;\\\\SELECT * FROM prj.nimm__tabwerte( ''pl_psgefstrkt'', ARRAY[prj.nimm__tabwerte( ''projekte'', ARRAY[''testProj'', ''Testprojekt''] ), ps.nimm__aspekte( ''gefstrkt'', ARRAY[ps.nimm__gefszenario( ARRAY[spr.nimm__wgruppe( ''Gefahrenszenario'', ''1'', ''0'' ), spr.nimm__wgruppe( ''Ursprung des Gefahrenszenarios'', ''1'', ''0'' )]), str.nimm__strkt( ARRAY[''1'', ''-BAAA'', spr.nimm__wgruppe( ''Strukturpunkt'', ''1'', ''0'' )])] ), ''true'', ''2007-06-06'', ''datenquelle'', ''micha'', ''true'', ''Zusatzinformationen''] );\\\\SELECT * FROM prj.pl_psgefstrkt;\\\\SELECT * FROM prj.pp_psgefszenario;\\\\SELECT * FROM prj.nimm__tabwerte( ''pp_psgefszenario'', ARRAY[prj.nimm__tabwerte( ''projekte'', ARRAY[''testProj'', ''Testprojekt''] ), ps.nimm__gefszenario( ARRAY[spr.nimm__wgruppe( ''Gefahrenszenario'', ''1'', ''0'' ), spr.nimm__wgruppe( ''Ursprung des Gefahrenszenarios'', ''1'', ''0'' )]), prj.nimm__tabwerte( ''personen'', ARRAY[''1'', ''Bellair'', ''Michael''] ), spr.nimm__wgruppe( ''projektspezifisch formuliertes Gefahrenszenario'', ''1'', ''0'' ), spr.nimm__wgruppe( ''projektspezifisch formulierter Ursprung des Gefahrenszenarios'', ''1'', ''0'' ), ''Zusatzinformationen''] );\\\\SELECT * FROM prj.pp_psgefszenario;'
, E'-- \\texttt{str.*} einlesen\\\\SELECT * FROM prj.pp_strstrkt;\\\\SELECT * FROM prj.nimm__tabwerte( ''pp_strstrkt'', ARRAY[prj.nimm__tabwerte( ''projekte'', ARRAY[''testProj'', ''Testprojekt''] ), str.nimm__strkt( ARRAY[''1'', ''-BAAA'', spr.nimm__wgruppe( ''Strukturpunkt'', ''1'', ''0'' )]), prj.nimm__tabwerte( ''personen'', ARRAY[''1'', ''Bellair'', ''Michael''] ), spr.nimm__wgruppe( ''Strukturpunkt bersetzt ?'', ''1'', ''0'' ), ''HAUS'', ''Zusatzinformationen''] );\\\\SELECT * FROM prj.pp_strstrkt;\\\\SELECT * FROM prj.p_strverbindung;\\\\SELECT * FROM prj.nimm__tabwerte( ''p_strverbindung'', ARRAY[prj.nimm__tabwerte( ''projekte'', ARRAY[''testProj'', ''Testprojekt''] ), str.nimm__verbindung( ARRAY[str.nimm__strkt( ARRAY[''1'', ''-BAAA1'', spr.nimm__wgruppe( ''Strukturpunkt-1'', ''1'', ''0'' )]), str.nimm__strkt( ARRAY[''1'', ''-BAAA2'', spr.nimm__wgruppe( ''Strukturpunkt-2'', ''1'', ''0'' )])] ), ''UND'', ''Zusatzinformationen''] );\\\\SELECT * FROM prj.p_strverbindung;'
]
);
--
-- Fehlermeldungen
-- ...............
--
--
--	-- Fehlermeldung. Ungltige Tabelle !
--SELECT * FROM prj.nimm__tabwerte( NULL, NULL );
--
--	-- Fehlermeldung. Bei allen Tabellen mssen mindestens zwei Elemente bergeben werden
--SELECT * FROM prj.nimm__tabwerte( 'projekte', ARRAY['1'] );
--
--	-- Fehlermeldung. Die bergebenen Parameter mssen grer \\texttt{0} sein.
--SELECT * FROM prj.nimm__tabwerte( 'p_dokkomp', ARRAY['0', '1'] );
--SELECT * FROM prj.nimm__tabwerte( 'p_dokkomp', ARRAY['1', '0'] );
--SELECT * FROM prj.nimm__tabwerte( 'pl_psgefanm', ARRAY['1', '1', '0'] );
--SELECT * FROM prj.nimm__tabwerte( 'pp_prtprotokoll', ARRAY['1', '1', '1', '', '', '', '', '', '', '0'] );
--
--	-- Fehlermeldung. Es drfen nur die zulssigen Begriffe verwendet werden
--SELECT * FROM prj.nimm__tabwerte( 'pp_strstrkt', ARRAY['1', '22', '1', '99', 'ttt'] );
--SELECT * FROM prj.nimm__tabwerte( 'p_strverbindung', ARRAY['1', '1', 'ttt'] );
--
--
--
--
-- Standardverhalten:
-- ..................
--
--	-- \\texttt{prj.personen} einlesen
--SELECT * FROM prj.personen;
--SELECT * FROM prj.nimm__tabwerte( 'personen', ARRAY['1', 'Bellair', 'Auguste', 'Zusatzinformationen'] );
--SELECT * FROM prj.personen;
--
--
--	-- \\texttt{prj.projekte} einlesen
--SELECT * FROM prj.projekte;
--SELECT * FROM prj.nimm__tabwerte( 'projekte', ARRAY['testProj', 'Testprojekt', 'Inhalt des makefile', 'Zusatzinformationen'] );
--SELECT * FROM prj.projekte;
--
--
--
--	-- \\texttt{dok.*} einlesen
--SELECT * FROM prj.pp_dokausgabe;
--SELECT * FROM prj.nimm__tabwerte( 'pp_dokausgabe', ARRAY[
--	prj.nimm__tabwerte( 'projekte', ARRAY['testProj', 'Testprojekt'] )
--	, dok.nimm__tabwerte( 'ausgabe', ARRAY[ dok.nimm__doku( ARRAY['08-15', '1'] ), '01'] )
--	, prj.nimm__tabwerte( 'personen', ARRAY['1', 'Bellair', 'Michael'] )
--	, 'Zusatzinformationen'] );
--SELECT * FROM prj.pp_dokausgabe;
--
--SELECT * FROM prj.p_dokkomp;
--SELECT * FROM prj.nimm__tabwerte( 'p_dokkomp', ARRAY[
--	prj.nimm__tabwerte( 'projekte', ARRAY['testProj', 'Testprojekt'] )
--	, dok.nimm__tabwerte( 'komp', ARRAY[dok.nimm__doku( ARRAY['08-15', '1'] )
--					, kmp.nimm__komp( ARRAY['1', '47/11'] )] )
--	, 'Zusatzinformationen'] );
--SELECT * FROM prj.p_dokkomp;
--
--SELECT * FROM prj.p_dokstrkt;
--SELECT * FROM prj.nimm__tabwerte( 'p_dokstrkt', ARRAY[
--	prj.nimm__tabwerte( 'projekte', ARRAY['testProj', 'Testprojekt'] )
--	, dok.nimm__tabwerte( 'strkt', ARRAY[dok.nimm__doku( ARRAY['08-15', '1'] )
--					, str.nimm__strkt( ARRAY['1', '-BAAA', spr.nimm__wgruppe( 'Strukturpunkt', '1', '0' )] )] )
--	, 'Zusatzinformationen'] );
--SELECT * FROM prj.p_dokstrkt;
--
--
--	-- \\texttt{prt.*} einlesen
--SELECT * FROM prj.p_prtdokausgabe;
--SELECT * FROM prj.nimm__tabwerte( 'p_prtdokausgabe', ARRAY[
--	prj.nimm__tabwerte( 'projekte', ARRAY['testProj', 'Testprojekt'] )
--	, prt.nimm__tabwerte( 'dokausgabe', ARRAY[prt.nimm__protokolleintrag( ARRAY[spr.nimm__wgruppe( 'Aktueller Protokolleintrag.', '1', '0' ), 'PE_OK'] ), dok.nimm__tabwerte( 'ausgabe', ARRAY[ dok.nimm__doku( ARRAY['08-15', '1'] ), '01'] ), 'Zusatzinformationen'] )
--	, 'Zusatzinformationen'] );
--SELECT * FROM prj.p_prtdokausgabe;
--
--SELECT * FROM prj.p_prtkomp;
--SELECT * FROM prj.nimm__tabwerte( 'p_prtkomp', ARRAY[
--	prj.nimm__tabwerte( 'projekte', ARRAY['testProj', 'Testprojekt'] )
--	, prt.nimm__tabwerte( 'komp', ARRAY[prt.nimm__protokolleintrag( ARRAY[spr.nimm__wgruppe( 'Aktueller Protokolleintrag.', '1', '0' ), 'PE_OK'] ), kmp.nimm__komp( ARRAY['1', '47/11'] )] )
--	, 'Zusatzinformationen'] );
--SELECT * FROM prj.p_prtkomp;
--
--SELECT * FROM prj.pp_prtprotokoll;
--SELECT * FROM prj.nimm__tabwerte( 'pp_prtprotokoll', ARRAY[
--	prj.nimm__tabwerte( 'projekte', ARRAY['testProj', 'Testprojekt'] )
--	, prt.nimm__protokolleintrag( ARRAY[spr.nimm__wgruppe( 'Aktueller Protokolleintrag.', '1', '0' ), 'PE_OK'] )
--	, prj.nimm__tabwerte( 'personen', ARRAY['1', 'Bellair', 'Michael'] )
--	, 'true'
--	, '2007-06-08'
--	, '2007-06-20'
--	, '2007-07-07'
--	, 'true'
--	, 'true'
--	, spr.nimm__wgruppe( 'Projektabhngiger, aktueller Protokolleintrag.', '1', '0' )
--	, 'Zusatzinformationen'] );
--SELECT * FROM prj.pp_prtprotokoll;
--
--SELECT * FROM prj.nimm__tabwerte( 'pp_prtprotokoll', ARRAY['2', '1'] );
--SELECT * FROM prj.nimm__tabwerte( 'pp_prtprotokoll', ARRAY['1', '1', '0', '2008-12-18', 'false', 'true', 'Interne Notizen'] );
--SELECT * FROM prj.nimm__tabwerte( 'pp_prtprotokoll_pers', ARRAY['1', '1', 'false', '1', '2008-12-18', '2008-12-18', 'Interne Notizen'] );
--
--SELECT * FROM prj.p_prtstrstrkt;
--SELECT * FROM prj.nimm__tabwerte( 'p_prtstrstrkt', ARRAY[
--	prj.nimm__tabwerte( 'projekte', ARRAY['testProj', 'Testprojekt'] )
--	, prt.nimm__tabwerte( 'strkt', ARRAY[prt.nimm__protokolleintrag( ARRAY[spr.nimm__wgruppe( 'Aktueller Protokolleintrag.', '1', '0' ), 'PE_OK'] ), str.nimm__strkt( ARRAY['1', '-BAAA', spr.nimm__wgruppe( 'Strukturpunkt', '1', '0' )])])
--	, 'Zusatzinformationen'] );
--SELECT * FROM prj.p_prtstrstrkt;
--
--SELECT * FROM prj.p_prtverbindung;
--SELECT * FROM prj.nimm__tabwerte( 'p_prtverbindung', ARRAY[
--	prj.nimm__tabwerte( 'projekte', ARRAY['testProj', 'Testprojekt'] )
--	, prt.nimm__tabwerte( 'verbindung', ARRAY[prt.nimm__protokolleintrag( ARRAY[spr.nimm__wgruppe( 'Aktueller Protokolleintrag.', '1', '0' ), 'PE_OK'] ), prt.nimm__protokolleintrag( ARRAY[spr.nimm__wgruppe( 'Zugeordneter Aktueller Protokolleintrag.', '1', '0' ), 'PE_OK'] )])
--	, 'Zusatzinformationen'] );
--SELECT * FROM prj.p_prtverbindung;
--
--
--	-- \\texttt{ps.*} einlesen
--SELECT * FROM prj.p_psabk;
--SELECT * FROM prj.nimm__tabwerte( 'p_psabk', ARRAY[
--	prj.nimm__tabwerte( 'projekte', ARRAY['testProj', 'Testprojekt'] )
--	, ps.nimm__abk( ARRAY[spr.nimm__wgruppe( 'abk', '1', '0' ), spr.nimm__wgruppe( 'Abkrzung', '1', '0' ), 'BP'] )
--	, spr.nimm__wgruppe( 'projabk', '1', '0' )
--	, spr.nimm__wgruppe( 'projektabhngige Abkrzung', '1', '0' )
--	, 'Zusatzinformationen'] );
--SELECT * FROM prj.p_psabk;
--
--SELECT * FROM prj.pl_psgefabk;
--SELECT * FROM prj.nimm__tabwerte( 'pl_psgefabk', ARRAY[
--	prj.nimm__tabwerte( 'projekte', ARRAY['testProj', 'Testprojekt'] )
--	, ps.nimm__aspekte( 'gefabk', ARRAY[ ps.nimm__gefszenario( ARRAY[spr.nimm__wgruppe( 'Gefahrenszenario', '1', '0' ), spr.nimm__wgruppe( 'Ursprung des Gefahrenszenarios', '1', '0' )] ), ps.nimm__abk( ARRAY[spr.nimm__wgruppe( 'abk', '1', '0' ), spr.nimm__wgruppe( 'Abkrzung', '1', '0' ), 'BP'] )] )
--	, 'true'
--	, '2007-06-06'
--	, 'datenquelle'
--	, 'micha'
--	, 'true'
--	, 'Zusatzinformationen'] );
--SELECT * FROM prj.pl_psgefabk;
--
--SELECT * FROM prj.pl_psgefanm;
--SELECT * FROM prj.nimm__tabwerte( 'pl_psgefanm', ARRAY[
--	prj.nimm__tabwerte( 'projekte', ARRAY['testProj', 'Testprojekt'] )
--	,  ps.nimm__aspekte( 'gefanm', ARRAY[ps.nimm__gefszenario( ARRAY[spr.nimm__wgruppe( 'Gefahrenszenario', '1', '0' ), spr.nimm__wgruppe( 'Ursprung des Gefahrenszenarios', '1', '0' )] ), spr.nimm__wgruppe( 'Anmerkungen', '1', '0' )] )
--	, spr.nimm__wgruppe( 'projektspezifische Anmerkungen', '1', '0' )
--	, 'true'
--	, '2007-06-06'
--	, 'datenquelle'
--	, 'micha'
--	, 'true'
--	, 'Zusatzinformationen'] );
--SELECT * FROM prj.pl_psgefanm;
--
--SELECT * FROM prj.pl_prtpsgefszenario;
--SELECT * FROM prj.nimm__tabwerte( 'pl_prtpsgefszenario', ARRAY[
--	prj.nimm__tabwerte( 'projekte', ARRAY['testProj', 'Testprojekt'] )
--	, ps.nimm__aspekte( 'gefprot', ARRAY[ps.nimm__gefszenario( ARRAY[spr.nimm__wgruppe( 'Gefahrenszenario', '1', '0' ), spr.nimm__wgruppe( 'Ursprung des Gefahrenszenarios', '1', '0' )]), prt.nimm__protokolleintrag( ARRAY[spr.nimm__wgruppe( 'Zugeordneter Aktueller Protokolleintrag.', '1', '0' ), 'PE_OK'] )] )
--	, 'true'
--	, '2007-06-06'
--	, 'datenquelle'
--	, 'micha'
--	, 'true'
--	, 'Zusatzinformationen'] );
--SELECT * FROM prj.pl_prtpsgefszenario;
--
--SELECT * FROM prj.pl_psgefstrkt;
--SELECT * FROM prj.nimm__tabwerte( 'pl_psgefstrkt', ARRAY[
--	prj.nimm__tabwerte( 'projekte', ARRAY['testProj', 'Testprojekt'] )
--	, ps.nimm__aspekte( 'gefstrkt', ARRAY[ps.nimm__gefszenario( ARRAY[spr.nimm__wgruppe( 'Gefahrenszenario', '1', '0' ), spr.nimm__wgruppe( 'Ursprung des Gefahrenszenarios', '1', '0' )]), str.nimm__strkt( ARRAY['1', '-BAAA', spr.nimm__wgruppe( 'Strukturpunkt', '1', '0' )])] )
--	, 'true'
--	, '2007-06-06'
--	, 'datenquelle'
--	, 'micha'
--	, 'true'
--	, 'Zusatzinformationen'] );
--SELECT * FROM prj.pl_psgefstrkt;
--
--SELECT * FROM prj.pp_psgefszenario;
--SELECT * FROM prj.nimm__tabwerte( 'pp_psgefszenario', ARRAY[
--	prj.nimm__tabwerte( 'projekte', ARRAY['testProj', 'Testprojekt'] )
--	, ps.nimm__gefszenario( ARRAY[spr.nimm__wgruppe( 'Gefahrenszenario', '1', '0' ), spr.nimm__wgruppe( 'Ursprung des Gefahrenszenarios', '1', '0' )])
--	, prj.nimm__tabwerte( 'personen', ARRAY['1', 'Bellair', 'Michael'] )
--	, spr.nimm__wgruppe( 'projektspezifisch formuliertes Gefahrenszenario', '1', '0' )
--	, spr.nimm__wgruppe( 'projektspezifisch formulierter Ursprung des Gefahrenszenarios', '1', '0' )
--	, 'Zusatzinformationen'] );
--SELECT * FROM prj.pp_psgefszenario;
--
--
--	-- \\texttt{str.*} einlesen
--SELECT * FROM prj.pp_strstrkt;
--SELECT * FROM prj.nimm__tabwerte( 'pp_strstrkt', ARRAY[
--	prj.nimm__tabwerte( 'projekte', ARRAY['testProj', 'Testprojekt'] )
--	, str.nimm__strkt( ARRAY['1', '-BAAA', spr.nimm__wgruppe( 'Strukturpunkt', '1', '0' )])
--	, prj.nimm__tabwerte( 'personen', ARRAY['1', 'Bellair', 'Michael'] )
--	, spr.nimm__wgruppe( 'Strukturpunkt bersetzt ?', '1', '0' )
--	, 'HAUS'
--	, 'Zusatzinformationen'] );
--SELECT * FROM prj.pp_strstrkt;
--
--SELECT * FROM prj.p_strverbindung;
--SELECT * FROM prj.nimm__tabwerte( 'p_strverbindung', ARRAY[
--	prj.nimm__tabwerte( 'projekte', ARRAY['testProj', 'Testprojekt'] )
--	, str.nimm__verbindung( ARRAY[str.nimm__strkt( ARRAY['1', '-BAAA1', spr.nimm__wgruppe( 'Strukturpunkt-1', '1', '0' )]), str.nimm__strkt( ARRAY['1', '-BAAA2', spr.nimm__wgruppe( 'Strukturpunkt-2', '1', '0' )])] )
--	, 'UND'
--	, 'Zusatzinformationen'] );
--SELECT * FROM prj.p_strverbindung;
--



-- ---------------------------------------------------------------------------------------
-- ---------------------------------------------------------------------------------------
-- ---------------------------------------------------------------------------------------
--			------------------------------------------------------------------
-- prt - Protokoll	------------------------------------------------------------------
--			------------------------------------------------------------------
-- ---------------------------------------------------------------------------------------
-- ---------------------------------------------------------------------------------------
-- ---------------------------------------------------------------------------------------

-- ---------------------------------------------------------------------------------------
-- ---------------------------------------------------------------------------------------
--						------------------------------------------
-- 	prt.nimm__protokolleintrag(...)		------------------------------------------
--						------------------------------------------
-- ---------------------------------------------------------------------------------------
-- ---------------------------------------------------------------------------------------
CREATE OR REPLACE FUNCTION prt.nimm__protokolleintrag( IN tabwerte varchar[], OUT protokollid varchar ) AS
$$
DECLARE
--------------------------------------------------------------------------------
-- Konstanten
--------------------------------------------------------------------------------


--------------------------------------------------------------------------------
-- lokale Variablen
--------------------------------------------------------------------------------
--
-- temporre Ganzzahlvariable(n)
--
tmpInteger integer;



BEGIN



--
-- 1.)	Liste >tabwerte< auf Plausibilitt prfen
--	>tabwerte[1]< mu die benannten Werte beinhalten
--
EXECUTE intern.pruefe__array( tabwerte, 1, 2, 'prt.nimm__protokolleintrag(...)', 'tabwerte' );
EXECUTE intern.pruefe__dt( 'gz', tabwerte[1], '1', NULL
				, 'prt.nimm__protokolleintrag(...)'
				, 'tabwerte[1]' );



--
-- 2.)	Protokolleintrag in >prt.protokoll< einlesen (Reihenfolge siehe Kommentar)
--	- typ
--	- notizen
--
tmpInteger := array_upper( tabwerte, 1 );
EXECUTE
	'SELECT intern.nimm__zeile( ''prt.protokoll''
			, ARRAY[ ''prt_typ_id'''
				|| CASE WHEN( NOT( tmpInteger < 2 ) )
					THEN ', ''notizen''' ELSE '' END
				|| ']
			, ARRAY[''' 	|| tabwerte[1] || ''''
				|| CASE WHEN( NOT( tmpInteger < 2 ) )
					THEN ', ''' || tabwerte[2] || '''' ELSE '' END
				|| '])'
INTO protokollid;

END
$$LANGUAGE 'plpgsql'  VOLATILE;
SELECT intern.nimm__TLKommentarFunktion( 'prt.nimm__protokolleintrag( IN tabwerte varchar[], OUT protokollid varchar )',
ARRAY[
E'Liste der Werte, welche in \\texttt{prt.protokoll} eingelesen werden sollen (Details siehe Funktionsbeschreibung --- Werteliste einlesen). Sie werden in der folgenden Reihenfolge in die Spalten
\\begin{enumerate}
  \\item \\texttt{prt_typ_id} - Identifikationsnummer des Typs des Protokolleintrages.
  \\item \\texttt{notizen}
\\end{enumerate}
Es mssen mindestens die ersten beiden Werte bergeben werden.'
, E'Es wird die Identifikationsnummer des eingelesenen Protokolleintrages zurckgegeben (\\texttt{prt.protokoll.id})'
]
, E'Ziel der Funktion ist das Einlesen eines Protokolleintrages, einer Sicherheitsanforderung, eines Terminplaneintrages.
\\\\
\\\\
Werteliste einlesen:\\\\
Dem Funktionsparameter \\texttt{tabwerte} ist eine Werteliste (\\texttt{ARRAY}) zu bergeben (die maximale Anzahl und die Reihenfolge der Werte ist fest vorgegeben --- siehe oben). Soll nur eine Teilmenge der Werte bergeben werden, dann sind alle Werte von links nach rechts zu spezifizieren (nichtbentigte Werte am Ende der Liste drfen weggelassen werden).'
, ARRAY[
E'-- Fehlermeldung. Die Mindestanzahl der Elemente mu stimmen.\\\\SELECT * FROM prt.nimm__protokolleintrag( ARRAY[''1''] );'
, E'-- Fehlermeldung. Der Parameter \\texttt{tabwerte[1]} mu grer \\texttt{0} sein.\\\\SELECT * FROM prt.nimm__protokolleintrag( ARRAY[''0'', ''1''] );'
, E'-- Fehlermeldung. Der Parameter \\texttt{tabwerte[2]} mu grer \\texttt{0} sein.\\\\SELECT * FROM prt.nimm__protokolleintrag( ARRAY[''1'', ''0''] );'
, E'-- Protokolleintrag einlesen\\\\SELECT prt_protokoll_id, prt_typ_id, prt_protokoll__spr_uebvar_id, prt_protokoll_notizen FROM prt.zeige__protokolleintrag;\\\\SELECT * FROM prt.nimm__typ( ARRAY[spr.nimm__wgruppe( ''Frage'', ''1'', ''0'' ), ''PE''] );\\\\SELECT * FROM prt.nimm__protokolleintrag( ARRAY[spr.nimm__wgruppe( ''Aktueller Protokolleintrag.'', ''1'', ''0'' ), ''1''] );\\\\SELECT * FROM prt.nimm__protokolleintrag( ARRAY[spr.nimm__wgruppe( ''Aktueller Protokolleintrag.'', ''1'', ''0'' ), ''1''] );\\\\SELECT * FROM prt.nimm__protokolleintrag( ARRAY[spr.nimm__wgruppe( ''Weiterer Protokolleintrag.'', ''1'', ''0'' ), ''1'', ''interne Notizen zum PE''] );\\\\SELECT prt_protokoll_id, prt_typ_id, prt_protokoll__spr_uebvar_id, prt_protokoll_notizen FROM prt.zeige__protokolleintrag;'
]
);
--
-- Fehlermeldungen
-- ...............
--
--	-- Fehlermeldung. Die Mindestanzahl der Elemente mu stimmen.
--SELECT * FROM prt.nimm__protokolleintrag( ARRAY['1'] );
--
--	-- Fehlermeldung. Der Parameter \\texttt{tabwerte[1]} mu grer \\texttt{0} sein.
--SELECT * FROM prt.nimm__protokolleintrag( ARRAY['0', '1'] );
--
--	-- Fehlermeldung. Der Parameter \\texttt{tabwerte[2]} mu grer \\texttt{0} sein.
--SELECT * FROM prt.nimm__protokolleintrag( ARRAY['1', '0'] );
--
--
-- 
-- Standardverhalten:
-- ..................
--
--	-- Protokolleintrag einlesen
--SELECT prt_protokoll_id, prt_typ_id, prt_protokoll__spr_uebvar_id, prt_protokoll_notizen FROM prt.zeige__protokolleintrag;
--SELECT * FROM prt.nimm__typ( ARRAY[spr.nimm__wgruppe( 'Frage', '1', '0' ), 'PE'] );
--SELECT * FROM prt.nimm__protokolleintrag( ARRAY[spr.nimm__wgruppe( 'Aktueller Protokolleintrag.', '1', '0' ), '1'] );
--SELECT * FROM prt.nimm__protokolleintrag( ARRAY[spr.nimm__wgruppe( 'Aktueller Protokolleintrag.', '1', '0' ), '1'] );
--SELECT * FROM prt.nimm__protokolleintrag( ARRAY[spr.nimm__wgruppe( 'Weiterer Protokolleintrag.', '1', '0' ), '1', 'interne Notizen zum PE'] );
--SELECT prt_protokoll_id, prt_typ_id, prt_protokoll__spr_uebvar_id, prt_protokoll_notizen FROM prt.zeige__protokolleintrag;
--


-- ---------------------------------------------------------------------------------------
-- ---------------------------------------------------------------------------------------
--				----------------------------------------------------------
-- 	prt.nimm__typ(...)	----------------------------------------------------------
--				----------------------------------------------------------
-- ---------------------------------------------------------------------------------------
-- ---------------------------------------------------------------------------------------
CREATE OR REPLACE FUNCTION prt.nimm__typ( IN tabwerte varchar[], OUT typid varchar ) AS
$$
DECLARE
--------------------------------------------------------------------------------
-- Konstanten
--------------------------------------------------------------------------------


--------------------------------------------------------------------------------
-- lokale Variablen
--------------------------------------------------------------------------------
--
-- temporre Ganzzahlvariable(n)
--
tmpInteger integer;



BEGIN



--
-- 1.)	Liste >tabwerte< auf Plausibilitt prfen
--	>tabwerte[1]< mu mindestens  >1< sein.
--	>tabwerte[2]< mu die benannten Werte beinhalten
--
EXECUTE intern.pruefe__array( tabwerte, 2, 3, 'prt.nimm__typ(...)', 'tabwerte' );
EXECUTE intern.pruefe__dt( 'gz', tabwerte[1], '1', NULL
				, 'prt.nimm__typ(...)'
				, 'tabwerte[1]' );
IF(
	( tabwerte[2] NOT IN( 'PE', 'SF', 'TP' ) )
  ) 
THEN

	RAISE EXCEPTION 'prt.nimm__typ(...)	Als Aspekte der Typen der Protokolleintrge >tabwerte[2] = %', tabwerte[2] || '< drfen nur die Werte >PE, SF, TP< (Protokolleintrag, Sicherheitsanforderung, Terminplan) bergeben werden. Das Einlesen wird abgebrochen !';

END IF;



--
-- 2.)	Typ in >prt.typ< einlesen (Reihenfolge siehe Kommentar)
--	- spr_uebvar_id
--	- aspekt
--	- notizen
--
tmpInteger := array_upper( tabwerte, 1 );
EXECUTE
	'SELECT intern.nimm__zeile( ''prt.typ''
			, ARRAY[ ''spr_uebvar_id''
				, ''aspekt'''
				|| CASE WHEN( NOT( tmpInteger < 3 ) )
					THEN ', ''notizen''' ELSE '' END
				|| ']
			, ARRAY[''' 	|| tabwerte[1] || '''
				, ''' || tabwerte[2] || ''''
				|| CASE WHEN( NOT( tmpInteger < 3 ) )
					THEN ', ''' || tabwerte[3] || '''' ELSE '' END
				|| '])'
INTO typid;

END
$$LANGUAGE 'plpgsql'  VOLATILE;
SELECT intern.nimm__TLKommentarFunktion( 'prt.nimm__typ( IN tabwerte varchar[], OUT typid varchar )',
ARRAY[
E'Liste der Werte, welche in \\texttt{prt.typ} eingelesen werden sollen (Details siehe Funktionsbeschreibung --- Werteliste einlesen). Sie werden in der folgenden Reihenfolge in die Spalten
\\begin{enumerate}
  \\item \\texttt{spr_uebvar_id} - Identifikationsnummer der Wortgruppe, welche den Typ des Protokolleintrages / der Sicherheitsanforderung / den Terminplaneintrag darstellt. Sie mu grer \\texttt{0} sein.
  \\item \\texttt{aspekt} (gltige Kurzbezeichnungen siehe Funktionsbeschreibung --- Aspekt - gltige Kurzbezeichnungen. Sie werden auf Plusibilitt geprft.), 
  \\item \\texttt{notizen}
\\end{enumerate}
Es mssen mindestens die ersten beiden Werte bergeben werden.'
, E'Es wird die Identifikationsnummer des eingelesenen Typs des Protokolleintrages / der Sicherheitsanforderung / den Terminplaneintrag zurckgegeben (\\texttt{prt.typ.id})'
]
, E'Ziel der Funktion ist das Einlesen eines Typs des Protokolleintrages, der Sicherheitsanforderung, des Terminplaneintrages.
\\\\
\\\\
\\textbf{Werteliste einlesen:}\\\\
Dem Funktionsparameter \\texttt{tabwerte} ist eine Werteliste (\\texttt{ARRAY}) zu bergeben (die maximale Anzahl und die Reihenfolge der Werte ist fest vorgegeben --- siehe oben). Soll nur eine Teilmenge der Werte bergeben werden, dann sind alle Werte von links nach rechts zu spezifizieren (nichtbentigte Werte am Ende der Liste drfen weggelassen werden).
\\\\
Es wird empfohlen, zum Einlesen des ersten Parameters die Funktion \\texttt{spr.nimm__wgruppe(...)} zu verwenden (Hinweise zum Umgang siehe dort).
\\\\
\\\\
\\textbf{Aspekt - gltige Kurzbezeichnungen:}\\\\
Zur Klassifizierung der Aspekte sind die folgenden Kurzbezeichnungen zu verwenden.
\\begin{description}
  \\item[PE] Protokolleintrag
  \\item[SF] Sicherheitsanforderung
  \\item[TP] Terminplaneintrag
\\end{description}'
, ARRAY[
E'-- Fehlermeldung. Die Mindestanzahl der Elemente mu stimmen.\\\\SELECT * FROM prt.nimm__typ( ARRAY[''1''] );'
, E'-- Fehlermeldung. Der Parameter \\texttt{tabwerte[1]} mu grer \\texttt{0} sein.\\\\SELECT * FROM prt.nimm__typ( ARRAY[''0'', ''PE''] );'
, E'-- Fehlermeldung. Der Parameter \\texttt{tabwerte[2]} mu gltige Werte enthalten.\\\\SELECT * FROM prt.nimm__typ( ARRAY[''1'', ''C''] );'
, E'-- Typ einlesen\\\\SELECT prt_typ_id, prt_typ_notizen, prt_typ_aspekt, prt_typ__spr_uebvar_id \\\\FROM prt.zeige__protokolleintrag;\\\\SELECT * FROM prt.nimm__typ( ARRAY[spr.nimm__wgruppe( ''Frage'', ''1'', ''0'' ), ''PE''] );\\\\SELECT * FROM prt.nimm__typ( ARRAY[spr.nimm__wgruppe( ''Technische Manahme'', ''1'', ''0'' ), ''SF''] );\\\\SELECT * FROM prt.nimm__typ( ARRAY[spr.nimm__wgruppe( ''Meilenstein'', ''1'', ''0'' ), ''TP'', ''interne Notizen zum TP''] );\\\\SELECT prt_typ_id, prt_typ_notizen, prt_typ_aspekt, prt_typ__spr_uebvar_id \\\\FROM prt.zeige__protokolleintrag;'
]
);
--
-- Fehlermeldungen
-- ...............
--
--	-- Fehlermeldung. Die Mindestanzahl der Elemente mu stimmen.
--SELECT * FROM prt.nimm__typ( ARRAY['1'] );
--
--	-- Fehlermeldung. Der Parameter \\texttt{tabwerte[1]} mu grer \\texttt{0} sein.
--SELECT * FROM prt.nimm__typ( ARRAY['0', 'PE'] );
--
--	-- Fehlermeldung. Der Parameter \\texttt{tabwerte[2]} mu gltige Werte enthalten.
--SELECT * FROM prt.nimm__typ( ARRAY['1', 'C'] );
--
--
-- 
-- Standardverhalten:
-- ..................
--
--	-- Typ einlesen
--SELECT prt_typ_id, prt_typ_notizen, prt_typ_aspekt, prt_typ__spr_uebvar_id FROM prt.zeige__protokolleintrag;
--SELECT * FROM prt.nimm__typ( ARRAY[spr.nimm__wgruppe( 'Frage', '1', '0' ), 'PE'] );
--SELECT * FROM prt.nimm__typ( ARRAY[spr.nimm__wgruppe( 'Technische Manahme', '1', '0' ), 'SF'] );
--SELECT * FROM prt.nimm__typ( ARRAY[spr.nimm__wgruppe( 'Meilenstein', '1', '0' ), 'TP', 'interne Notizen zum TP'] );
--SELECT prt_typ_id, prt_typ_notizen, prt_typ_aspekt, prt_typ__spr_uebvar_id FROM prt.zeige__protokolleintrag;
--



-- ---------------------------------------------------------------------------------------
-- ---------------------------------------------------------------------------------------
-- ---------------------------------------------------------------------------------------
--				----------------------------------------------------------
-- ps - Produktsicherheit	----------------------------------------------------------
--				----------------------------------------------------------
-- ---------------------------------------------------------------------------------------
-- ---------------------------------------------------------------------------------------
-- ---------------------------------------------------------------------------------------

-- ---------------------------------------------------------------------------------------
-- ---------------------------------------------------------------------------------------
--				----------------------------------------------------------
-- 	ps.nimm__abk(...)	----------------------------------------------------------
--				----------------------------------------------------------
-- ---------------------------------------------------------------------------------------
-- ---------------------------------------------------------------------------------------
CREATE OR REPLACE FUNCTION ps.nimm__abk( tabwerte varchar[], OUT abkid varchar ) AS
$$
DECLARE
--------------------------------------------------------------------------------
-- Konstanten
--------------------------------------------------------------------------------


--------------------------------------------------------------------------------
-- lokale Variablen
--------------------------------------------------------------------------------
--
-- temporre Ganzzahlvariable(n)
--
tmpInteger integer;



BEGIN



--
-- 1.)	Liste >tabwerte< auf Plausibilitt prfen
--	>tabwerte[1]< mu mindestens  >1< sein.
--	>tabwerte[2]< mu mindestens  >1< sein.
--
EXECUTE intern.pruefe__array( tabwerte, 2, 2
				, 'ps.nimm__abk(...)', 'tabwerte' );
EXECUTE intern.pruefe__dt( 'zk', tabwerte[1], NULL, NULL
				, 'ps.nimm__abk(...)'
				, 'tabwerte[1]' );
EXECUTE intern.pruefe__dt( 'zk', tabwerte[2], NULL, NULL
				, 'ps.nimm__abk(...)'
				, 'tabwerte[2]' );

IF(
	( tabwerte[1] NOT IN( 'GP', 'RG', 'RH', 'RR' ) )
  ) 
THEN

	RAISE EXCEPTION 'ps.nimm__abk(...)	Als Abkrzung >tabwerte[1] = %', tabwerte[4] || '< drfen nur die Werte >GP, RG, RH, RR< bergeben werden. Das Einlesen wird abgebrochen !';

END IF;



--
-- 2.)	Tabellenwerte in >ps.abk< einlesen
--
EXECUTE
	'SELECT intern.nimm__zeile( ''ps.abk''
			, ARRAY[ ''typ''
				, ''notizen'' ]
			, ARRAY[''' 	|| tabwerte[1] || '''
				, '''	|| tabwerte[2] || '''])'
INTO abkid;


END
$$LANGUAGE 'plpgsql'  VOLATILE;
SELECT intern.nimm__TLKommentarFunktion( 'ps.nimm__abk( tabwerte varchar[], OUT abkid varchar )', 
ARRAY[
E'Liste der Werte, welche in \\texttt{ps.abk} eingelesen werden sollen (Details siehe Funktionsbeschreibung --- Werteliste einlesen). Sie werden in der folgenden Reihenfolge in die Spalten
\\begin{enumerate}
  \\item \\texttt{typ} gltige Kurzbezeichnungen siehe Funktionsbeschreibung --- Typ - gltige Kurzbezeichnungen. 
  \\item \\texttt{notizen}
\\end{enumerate}
eingetragen. Es mssen beide Werte bergeben werden.'
, E'Es wird die Identifikationsnummer der Abkrzung \\texttt{ps.abk.id} zurckgegeben.'
]
, E'Ziel der Funktion ist das Einlesen der Abkrzungen, welche einem Gefahrenszenario zugeordnet werden knnen..
\\\\
\\\\
\\emph{Werteliste einlesen:}\\\\
Dem Funktionsparameter \\texttt{tabwerte} ist eine Werteliste (\\texttt{ARRAY}) zu bergeben (die maximale Anzahl und die Reihenfolge der Werte ist fest vorgegeben --- siehe oben). Soll nur eine Teilmenge der Werte bergeben werden, dann sind alle Werte von links nach rechts zu spezifizieren (nichtbentigte Werte am Ende der Liste drfen weggelassen werden).
\\\\
\\\\
\\emph{Typ - gltige Kurzbezeichnungen}:
\\begin{description}
  \\item[GP] gefhrdete Person (die dem Gefahrenszenario ausgesetzen Personen)
  \\item[RG] Gefahrenstufe --- Auswirkungen bei Eintreten des Gefahrenszenarios (zur Risikobewertung lt. EN 50126)
  \\item[RH] Hufigkeit des Auftretens des Gefahrenszenarios (zur Risikobewertung lt. EN 50126)
  \\item[RR] Risikostufe --- Bewertung des Risikos des Gefahrenszenarios (zur Risikobewertung lt. EN 50126)
\\end{description}'
, ARRAY[
E'-- Fehlermeldung. Die Mindestanzahl der Elemente mu stimmen.\\\\SELECT * FROM ps.nimm__abk( ARRAY[''1'', ''1''] );'
, E'-- Fehlermeldung. Der Parameter \\texttt{tabwerte[1]} bzw. \\texttt{tabwerte[2]} mu grer \\texttt{0} sein.\\\\SELECT * FROM ps.nimm__abk( ARRAY[''0'', ''1'', ''C'' ] );\\\\SELECT * FROM ps.nimm__abk( ARRAY[''1'', ''0'', ''C'' ] );'
, E'-- Fehlermeldung. Der Parameter \\texttt{tabwerte[3]} mu gltige Werte enthalten.\\\\SELECT * FROM ps.nimm__abk( ARRAY[''1'', ''1'', ''C'' ] );'
, E'-- Standardverhalten\\\\SELECT * FROM ps.abk;\\\\SELECT * FROM ps.nimm__abk( ARRAY[spr.nimm__wgruppe( ''abk'', ''1'', ''0'' ), spr.nimm__wgruppe( ''Abkrzung'', ''1'', ''0'' ), spr.nimm__wgruppe( ''Zusatzinfo'', ''1'', ''0'' ), ''GP''] );\\\\SELECT * FROM ps.nimm__abk( ARRAY[spr.nimm__wgruppe( ''abk-1'', ''1'', ''0'' ), spr.nimm__wgruppe( ''Abkrzung-1'', ''1'', ''0'' ), spr.nimm__wgruppe( ''Zusatzinfo'', ''1'', ''0'' ), ''GP'', ''Notizen''] );\\\\SELECT * FROM ps.abk;'
]
);
--
-- Fehlermeldungen
-- ...............
--
--	-- Fehlermeldung. Die Mindestanzahl der Elemente mu stimmen.
--SELECT * FROM ps.nimm__abk( ARRAY['1', '1'] );
--
--	-- Fehlermeldung. Der Parameter \\texttt{tabwerte[1]} bzw. \\texttt{tabwerte[2]} mu grer \\texttt{0} sein.
--SELECT * FROM ps.nimm__abk( ARRAY['0', '1', 'C' ] );
--SELECT * FROM ps.nimm__abk( ARRAY['1', '0', 'C' ] );
--
--	-- Fehlermeldung. Der Parameter \\texttt{tabwerte[3]} mu gltige Werte enthalten.
--SELECT * FROM ps.nimm__abk( ARRAY['1', '1', 'C' ] );
--
-- 
-- Standardverhalten
-- .................
--
--SELECT * FROM ps.abk;
--SELECT * FROM ps.nimm__abk( ARRAY[spr.nimm__wgruppe( 'abk', '1', '0' ), spr.nimm__wgruppe( 'Abkrzung', '1', '0' ), spr.nimm__wgruppe( 'Zusatzinfo', '1', '0' ), 'GP'] );
--SELECT * FROM ps.nimm__abk( ARRAY[spr.nimm__wgruppe( 'abk-1', '1', '0' ), spr.nimm__wgruppe( 'Abkrzung-1', '1', '0' ), spr.nimm__wgruppe( 'Zusatzinfo', '1', '0' ), 'GP', 'Notizen'] );
--SELECT * FROM ps.abk;
--




-- ---------------------------------------------------------------------------------------
-- ---------------------------------------------------------------------------------------
-- ---------------------------------------------------------------------------------------
--			------------------------------------------------------------------
-- spr - Sprache	------------------------------------------------------------------
--			------------------------------------------------------------------
-- ---------------------------------------------------------------------------------------
-- ---------------------------------------------------------------------------------------
-- ---------------------------------------------------------------------------------------

-- ---------------------------------------------------------------------------------------
-- ---------------------------------------------------------------------------------------
--					--------------------------------------------------
-- 	spr.nimm__wgruppe(...)		--------------------------------------------------
--					--------------------------------------------------
-- ---------------------------------------------------------------------------------------
-- ---------------------------------------------------------------------------------------
CREATE OR REPLACE FUNCTION spr.nimm__wgruppe( IN wortgruppe varchar, IN sprachenid varchar, INOUT spruebvarid varchar ) AS
$$
DECLARE
--------------------------------------------------------------------------------
-- Konstanten
--------------------------------------------------------------------------------
--
-- Modus 'bersetzen' liegt vor, wenn eine im System vorhandene Referenzwortgruppe angegeben
-- wurde
--
istUebersetzung CONSTANT boolean := NOT( ( spruebvarid = '0' ) OR ( spruebvarid IS NULL ) );


--------------------------------------------------------------------------------
-- lokale Variablen
--------------------------------------------------------------------------------
--
-- spr.wgruppe.id
--
sprWgruppeId varchar;
--
-- temporre Textvariable(n)
--
tmpVarchar_1 varchar;
--
-- Zeile der SELECT-Abfrage einlesen
--
zeile RECORD;



BEGIN



--
-- 1.)	Plausibilittsprfungen
--
EXECUTE intern.pruefe__dt( 'zk', wortgruppe, NULL, NULL
				, 'spr.nimm__wgruppe(...)'
				, 'wortgruppe' );
EXECUTE intern.pruefe__dt( 'gz', sprachenid, '0', NULL
				, 'spr.nimm__wgruppe(...)'
				, 'sprachenid' );
EXECUTE intern.pruefe__dt( 'gz', spruebvarid, '0', NULL
				, 'spr.nimm__wgruppe(...)'
				, 'spruebvarid' );



--
-- 2.1.)	Modus Einlesen:
--	Wenn >wortgruppe< und >sprachenid< gefunden wurde, dann >spr.uebvar.id< zurckgeben
--
IF(
	NOT( istUebersetzung )
  )
THEN

	EXECUTE
		'SELECT spr_uebvar_id FROM spr.zeige__wgruppe WHERE wgruppe = ''' 
			|| wortgruppe || '''
		AND
			spr_sprachen_id = '
			|| sprachenid 
	INTO spruebvarid;

	IF(
		spruebvarid IS NOT NULL
	  )
	THEN
		RETURN;
	END IF;


--
-- 2.2.)	Modus bersetzen:
--
-- 2.2.1.)	Wenn >spruebvarid< nicht im Abfrageergebnis enthalten ist, wird eine 
--		Fehlermeldung zurckgegeben
--
-- 2.2.2.)	Wenn in einer Zeile >wortgruppe< und >sprachenid< gefunden wurde, dann wird
--		 >spr.uebvar.id< zurckgeben und die Routine verlassen
--
-- 2.2.3.)	Wenn in einer Zeile nur >sprachenid< gefunden wurde, dann ist die 
--		bersetzungsvariante belegt und es wird eine Fehlermeldung zurckgegeben.
--
--  2.2.4.)	Unabhngig davon, ob in einer Zeile >wortgruppe< gefunden wurde oder nicht, wird
--		 >wortgruppe< und >sprachenid< bernommen und >spruebvarid< zugeordnet
--
ELSE

	EXECUTE
		'SELECT 
			spr_uebvar_id
			, max( CASE WHEN( ( spr_sprachen_id = '
					|| sprachenid
					|| ' ) AND ( wgruppe = '''
					|| wortgruppe
					|| ''' ) ) THEN 1 ELSE 0 END ) AS istvorh
			, max( CASE WHEN( spr_sprachen_id = '
					|| sprachenid
					|| ' ) THEN 1 ELSE 0 END ) AS istbelegt
		FROM 
			spr.zeige__wgruppe
		WHERE
			spr_uebvar_id = ' || spruebvarid ||
		'AND
			spr_uebvar_id > 0
		GROUP BY 
			spr_uebvar_id'
	INTO zeile;

	--
	-- 2.2.1.)
	--
	IF(
		zeile.spr_uebvar_id IS NULL
	  )
	THEN
		RAISE EXCEPTION 'spr.nimm__wgruppe(...)	Die bergebene bersetzungsvariante >spruebvarid = %', spruebvarid || '< ist nicht im System vorhanden. Das Einlesen wird abgebrochen !';
	END IF;
	
	--
	-- 2.2.2.)
	--
	IF(
		zeile.istvorh = 1
	  )
	THEN
		RETURN;
	END IF;
	
	--
	-- 2.2.3.)
	--
	IF(
		zeile.istbelegt = 1
	  )
	THEN
		RAISE EXCEPTION 'spr.nimm__wgruppe(...)	Der bergebenen bersetzungsvariante >spruebvarid = %', spruebvarid || '< ist bereits eine bersetzung in der gewnschten Sprache >sprachenid = ' || sprachenid || '< zugeordnet. Das Einlesen wird abgebrochen !';
	END IF;

	--
	--  2.2.4.)
	--
	-- wird in den folgenden Abschnitten bearbeitet.

END IF;



--
-- 3.)	Wortgruppe einlesen:
--		Nchste >spr.wgruppe.id< bereitstellen
--
EXECUTE

	'SELECT intern.nimm__zeile( ''spr.wgruppe''
					, ARRAY[''id'']
					, ARRAY[intern.gib__naechsteid( ''spr.wgruppe'' )] )'

INTO sprWgruppeId;


--
--		>spr.pos< / >intern.abczk< / >intern.restzk< ergnzen
--
FOR
	zeile
IN

	SELECT
		zk
		, istabczk
	FROM
		intern.gib__Liste_abczkrestzk( wortgruppe )

LOOP

	--
	-- nchste gltige >spr.pos.id< ermitteln, da sonst gleiche 
	-- Zeichenketten (z.B. Leerzeichen) verschluckt werden
	--
	EXECUTE

		'SELECT tabNameId FROM intern.gib__naechsteid( ''spr.pos'' )'

	INTO tmpVarchar_1;

	--
	-- Wortgruppe in >intern.abczk< oder >intern.restzk< einlesen und in
	-- >spr.pos< einlesen
	--
	EXECUTE
		'SELECT intern.nimm__zeile( ''spr.pos''
			, ARRAY[ ''id''
				, ''spr_wgruppe_id'''
				|| CASE WHEN( zeile.istabczk )
					THEN ', ''intern_abczk_id'''
					ELSE ', ''intern_restzk_id'''
					END
				|| ']
			, ARRAY[''' 	|| tmpVarchar_1 || '''
				, '''	|| sprWgruppeId || '''
				, CAST( ' || 'intern.nimm__zeile( '
					|| CASE WHEN( zeile.istabczk )
					   THEN '''intern.abczk'', ARRAY[ ''abczk'' ]'
					   ELSE '''intern.restzk'', ARRAY[ ''restzk'' ]'
					   END
					|| ', ARRAY[''' || zeile.zk || ''']) AS varchar )])';

END LOOP;



--
-- 4.)	bersetzungsvariante einlesen:
--		im Modus 'Einlesen' nchste >spr.uebvar.id< bereitstellen
--
IF(
	NOT( istUebersetzung )
  )
THEN

	EXECUTE

	'SELECT intern.nimm__zeile( ''spr.uebvar''
					, ARRAY[''id'']
					, ARRAY[intern.gib__naechsteid( ''spr.uebvar'' )] )'

	INTO spruebvarid;

END IF;

--
-- bersetzungsvariante in >spr.uebersetzung< einlesen
--	- spr_sprachen_id
--	- spr_uebvar_id
--	- spr_wgruppe_id
--
EXECUTE
	'SELECT intern.nimm__zeile( ''spr.uebersetzung''
			, ARRAY[ ''spr_sprachen_id''
				, ''spr_uebvar_id''
				, ''spr_wgruppe_id'']
			, ARRAY[''' 	|| sprachenid || '''
				, '''	|| spruebvarid || '''
				, '''	|| sprWgruppeId || '''])';

END
$$LANGUAGE 'plpgsql'  VOLATILE;
SELECT intern.nimm__TLKommentarFunktion( 'spr.nimm__wgruppe( IN wortgruppe varchar, IN sprachenid varchar, INOUT spruebvarid varchar )', 
ARRAY[
E'Es ist die einzulesende Wortgruppe anzugeben. Sie darf nicht leer oder \\texttt{NULL} sein.'
, E'Es ist die Identifikationsnummer \\texttt{spr.sprachen.id} der Sprache anzugeben, in der die Wortgruppe eingelesen werden soll. Der Wert mu angegeben werden und grer/gleich \\texttt{0} sein.'
, E'Es wird die  Identifikationsnummer (\\texttt{spr.uebvar.id}) der bersetzungsvariante zurckgegeben, welcher die aktuelle Wortgruppe einschliesslich Sprache zugeordnet wurde. Wird ein Wert grer \\texttt{0} bergeben, so soll die aktuelle Wortgruppe einschliesslich Sprache dieser bersetzungsvariante hinzugefgt werden (Modus "`bersetzen"''). Andernfalls liegt der Modus "`Einlesen"'' vor.'
],
E'Ziel der Funktion ist 
\\begin{itemize}
  \\item das Einlesen von Wortgruppen im Modus "`Einlesen"'' bzw.
  \\item das bersetzen einer im System vorhandenen Referenzwortgruppe \\texttt{spruebvarid} mittels aktueller Wortgruppe  \\texttt{wortgruppe} in der aktuellen Sprache \\texttt{spr.sprachen.id} im Modus "`bersetzen"''.
\\end{itemize}

\\noindent \\textbf{Modus "`Einlesen"''}
\\\\
Konnte die aktuelle Wortgruppe \\texttt{wortgruppe} zur gewnschten Sprache \\texttt{spr.sprachen.id} im System gefunden werden, wird  die erste passende bersetzungsvariante \\texttt{spr.uebvar.id} zurckgegeben. Andernfalls  wird sie mit der nchsten verfgbaren \\texttt{spr.uebvar.id} eingelesen.
\\\\
\\\\
\\textbf{Modus "`bersetzen"''}
\\\\
Im System werden bersetzungsvarianten mittels \\texttt{spr.uebvar.id} gebildet. Sie stellen den konstanten Bezug auf Wortgruppen verschiedener Sprachen, welche in einem gemeinsamen Kontext stehen, dar. Innerhalb einer bersetzungsvariante darf nur eine bersetzung je Sprache zugeordnet werden. Somit ist es mglich unter Angabe der Sprache und Identifikationsnummer der bersetzungsvariante die korrekte Wortgruppe zu ermitteln.
\\\\
Zum korrekten Verstndnis der Funktionalitt im Modus "`bersetzen"'' sind die folgenden Randbedingungen zu beachten:
\\begin{enumerate}
  \\item Wird die aktuelle Wortgruppe zur gewnschten Sprache innerhalb der vorgegebenen bersetzungsvariante gefunden, so wird die Identifikationsnummer der bersetzungsvariante zurckgegeben.
  \\item Wird innerhalb der vorgegebenen bersetzungsvariante keine bersetzung in der gewnschten Sprache gefunden, wird die aktuelle Wortgruppe zur gewnschten Sprache eingelesen.
  \\item Wird die  vorgegebenen bersetzungsvariante nicht gefunden, so wird eine Fehlermeldung ausgegeben und das Einlesen abgebrochen.
  \\item Wird innerhalb der vorgegebenen bersetzungsvariante eine bersetzung in der gewnschten Sprache gefunden (Sprache ist bereits belegt), so wird eine Fehlermeldung ausgegeben und das Einlesen abgebrochen.
\\end{enumerate}'
, ARRAY[
E'-- Fehlermeldung, die Wortgruppe ist anzugeben\\\\SELECT * FROM spr.nimm__wgruppe( NULL, ''1'', NULL );\\\\SELECT * FROM spr.nimm__wgruppe( '''', ''1'', NULL );'
, E'-- Fehlermeldung, die Identifikationsnummer der Sprache mu grer \\texttt{0} sein\\\\SELECT * FROM spr.nimm__wgruppe( ''Das ist ein Test .'', ''0'', NULL );'
, E'-- Fehlermeldung, die Identifikationsnummer der bersetzungsvariante mu grer/gleich \\texttt{0} sein\\\\SELECT * FROM spr.nimm__wgruppe( ''Das ist ein Test .'', ''1'', NULL );\\\\SELECT * FROM spr.nimm__wgruppe( ''das ist ein Array'', ''1'', ''-1'' );'
, E'-- Fehlermeldung, die Identifikationsnummer der bersetzungsvariante mu im System vorhanden sein\\\\SELECT * FROM spr.nimm__wgruppe( ''das ist ein Array'', ''1'', ''999999'' );'
, E'-- Fehlermeldung, die bersetzungsvariante ist bereits mit einer bersetzung in der gewnschten Sprache belegt\\\\SELECT * FROM spr.nimm__wgruppe( ''Das ist ein Array.'', ''1'', ''0'' );\\\\SELECT * FROM spr.nimm__wgruppe( ''This is an Array.'', ''2'', ''1'' );\\\\SELECT * FROM spr.zeige__wgruppe;\\\\SELECT * FROM spr.nimm__wgruppe( ''-----This is an Array.'', ''2'', ''1'' );'
, E'-- Modus "`Einlesen"'':\\\\-- Die aktuelle Wortgruppe konnte nicht im System gefunden werden. Sie wird neu angelegt.\\\\SELECT * FROM spr.zeige__wgruppe;\\\\SELECT * FROM spr.nimm__wgruppe( ''Das ist ein Array.'', ''1'', ''0'' );\\\\SELECT * FROM spr.zeige__wgruppe;'
, E'-- Modus "`Einlesen"'':\\\\-- Die aktuelle Wortgruppe konnte im System gefunden werden.\\\\SELECT * FROM spr.nimm__wgruppe( ''Das ist ein Array.'', ''1'', ''0'' );\\\\SELECT * FROM spr.zeige__wgruppe ORDER BY spr_uebvar_id DESC LIMIT 5;\\\\SELECT * FROM spr.nimm__wgruppe( ''Das ist ein Array.'', ''1'', ''0'' );\\\\SELECT * FROM spr.zeige__wgruppe ORDER BY spr_uebvar_id DESC LIMIT 5;'
, E'-- Modus "`bersetzen"'':\\\\-- Die aktuelle Wortgruppe konnte nicht im System gefunden werden. Die bersetzungsvariante wird neu angelegt.\\\\SELECT * FROM spr.nimm__wgruppe( ''Das ist ein Array.'', ''1'', ''0'' );\\\\SELECT * FROM spr.zeige__wgruppe;\\\\SELECT * FROM spr.nimm__wgruppe( ''This is an Array.'', ''2'', ''1'' );\\\\SELECT * FROM spr.zeige__wgruppe;'
, E'-- Modus "`bersetzen"'':\\\\-- Die aktuelle Wortgruppe konnte im System gefunden werden.\\\\SELECT * FROM spr.nimm__wgruppe( ''Das ist ein Array.'', ''1'', ''0'' );\\\\SELECT * FROM spr.nimm__wgruppe( ''This is an Array.'', ''2'', ''1'' );\\\\SELECT * FROM spr.zeige__wgruppe;\\\\SELECT * FROM spr.nimm__wgruppe( ''This is an Array.'', ''2'', ''1'' );\\\\SELECT * FROM spr.zeige__wgruppe;'
]
);
--
-- Fehlermeldungen
-- ...............
--
--	-- Fehlermeldung, die Wortgruppe ist anzugeben
--SELECT * FROM spr.nimm__wgruppe( NULL, '1', NULL );
--SELECT * FROM spr.nimm__wgruppe( '', '1', NULL );
--
--	-- Fehlermeldung, die Identifikationsnummer der Sprache mu grer \\texttt{0} sein
--SELECT * FROM spr.nimm__wgruppe( 'Das ist ein Test .', '0', NULL );
--
--	-- Fehlermeldung, die Identifikationsnummer der bersetzungsvariante mu grer/gleich \\texttt{0} sein
--SELECT * FROM spr.nimm__wgruppe( 'Das ist ein Test .', '1', NULL );
--SELECT * FROM spr.nimm__wgruppe( 'das ist ein Array', '1', '-1' );
--
--	-- Fehlermeldung, die Identifikationsnummer der bersetzungsvariante mu im System vorhanden sein
--SELECT * FROM spr.nimm__wgruppe( 'das ist ein Array', '1', '999999' );
--
--	-- Fehlermeldung, die bersetzungsvariante ist bereits mit einer bersetzung in der gewnschten Sprache belegt
--SELECT * FROM spr.nimm__wgruppe( 'Das ist ein Array.', '1', '0' );
--SELECT * FROM spr.nimm__wgruppe( 'This is an Array.', '2', '1' );
--SELECT * FROM spr.zeige__wgruppe;
--SELECT * FROM spr.nimm__wgruppe( '-----This is an Array.', '2', '1' );
--
--
-- 
-- Standardverhalten:
-- ..................
--
--	-- Modus "`Einlesen"'':
--	-- Die aktuelle Wortgruppe konnte nicht im System gefunden werden. Sie wird neu angelegt.
--SELECT * FROM spr.zeige__wgruppe;
--SELECT * FROM spr.nimm__wgruppe( 'Das ist ein Array.', '1', '0' );
--SELECT * FROM spr.zeige__wgruppe;
--
--	-- Modus "`Einlesen"'':
--	-- Die aktuelle Wortgruppe konnte im System gefunden werden.
--SELECT * FROM spr.nimm__wgruppe( 'Das ist ein Array.', '1', '0' );
--SELECT * FROM spr.zeige__wgruppe ORDER BY spr_uebvar_id DESC LIMIT 5;
--SELECT * FROM spr.nimm__wgruppe( 'Das ist ein Array.', '1', '0' );
--SELECT * FROM spr.zeige__wgruppe ORDER BY spr_uebvar_id DESC LIMIT 5;
--
--	-- Modus "`bersetzen"'':
--	-- Die aktuelle Wortgruppe konnte nicht im System gefunden werden. Die bersetzungsvariante wird neu angelegt.
--SELECT * FROM spr.nimm__wgruppe( 'Das ist ein Array.', '1', '0' );
--SELECT * FROM spr.zeige__wgruppe;
--SELECT * FROM spr.nimm__wgruppe( 'This is an Array.', '2', '1' );
--SELECT * FROM spr.zeige__wgruppe;
--
--	-- Modus "`bersetzen"'':
--	-- Die aktuelle Wortgruppe konnte im System gefunden werden.
--SELECT * FROM spr.nimm__wgruppe( 'Das ist ein Array.', '1', '0' );
--SELECT * FROM spr.nimm__wgruppe( 'This is an Array.', '2', '1' );
--SELECT * FROM spr.zeige__wgruppe;
--SELECT * FROM spr.nimm__wgruppe( 'This is an Array.', '2', '1' );
--SELECT * FROM spr.zeige__wgruppe;
--




-- ---------------------------------------------------------------------------------------
-- ---------------------------------------------------------------------------------------
-- ---------------------------------------------------------------------------------------
--			------------------------------------------------------------------
-- str - Strukturen	------------------------------------------------------------------
--			------------------------------------------------------------------
-- ---------------------------------------------------------------------------------------
-- ---------------------------------------------------------------------------------------
-- ---------------------------------------------------------------------------------------


-- ---------------------------------------------------------------------------------------
-- ---------------------------------------------------------------------------------------
--					--------------------------------------------------
-- 	str.pruefe__fbwerte(...)	--------------------------------------------------
--					--------------------------------------------------
-- ---------------------------------------------------------------------------------------
-- ---------------------------------------------------------------------------------------
CREATE OR REPLACE FUNCTION str.pruefe__fbwerte( IN aspekt varchar, IN wert varchar, IN fktname varchar, IN paramname varchar ) RETURNS void AS
$$


BEGIN


--
--	Plausibilittsprfungen
--
EXECUTE intern.pruefe__dt( 'zk', wert, NULL, NULL
				, 'str.pruefe__fbwerte(...)'
				, 'wert' );

IF(
	( aspekt = 'FB-Ereignis' )
  ) 
THEN

	--
	-- 1.)	Werte der Spalte >str.strkt.fbereignis< prfen
	--
	IF(
		( wert NOT IN( 'EBB', 'GE', 'NUE', 'AUE', 'HAUS', 'NULL', 'VWVA', 'VWNA' ) )
	  ) 
	THEN

		--
		-- Fehlermeldung
		--
		RAISE EXCEPTION '%', CASE WHEN( ( fktname IS NULL ) OR ( fktname = '' ) ) THEN 'str.pruefe__fbwerte(...)' ELSE fktname END
				|| '	Als Fehlerbaum-Ereignis >'
				|| CASE WHEN( ( paramname IS NULL ) OR ( paramname = '' ) ) THEN 'wert' ELSE paramname END
				|| ' = ' || wert || '< drfen nur die Werte >EBB, GE, NUE, AUE, HAUS, NULL, VWVA, VWNA< bergeben werden. Das Programm wird abgebrochen !';

	END IF;


ELSIF (
	( aspekt = 'FB-Tor' )
  ) 
THEN

	--
	-- 2.)	Werte der Spalte >str.verbindung.fbtor< prfen
	--
	IF(
		( wert NOT IN( 'UND', 'ODER', 'XODER', 'NICHT', 'BED', 'RED', 'ALLG' ) )
	  ) 
	THEN

		--
		-- Fehlermeldung
		--
		RAISE EXCEPTION '%', CASE WHEN( ( fktname IS NULL ) OR ( fktname = '' ) ) THEN 'str.pruefe__fbwerte(...)' ELSE fktname END
				|| '	Als Fehlerbaum-Tore (Verknpfungen) >'
				|| CASE WHEN( ( paramname IS NULL ) OR ( paramname = '' ) ) THEN 'wert' ELSE paramname END
				|| ' = ' || wert || '< drfen nur die Werte >UND, ODER, XODER, NICHT, BED, RED, ALLG< bergeben werden. Das Programm wird abgebrochen !';

	END IF;


ELSE

	--
	-- 3.) Fehlermeldung. Es drfen nur die gltigen Aspekte verwendet werden
	--
	RAISE EXCEPTION 'str.pruefe__fbwerte(...)	Der bergebene Fehlerbaumaspekt >aspekt = %', 
		CASE WHEN( aspekt IS NULL ) THEN 'NULL' ELSE aspekt END
		 || '< ist nicht zulssig. Es drfen nur die folgenden Aspekte >FB-Ereignis< und >FB-Tor<  verwendet werden. Das Programm wird abgebrochen !';

END IF;

END
$$LANGUAGE 'plpgsql'  VOLATILE;
SELECT intern.nimm__TLKommentarFunktion( 'str.pruefe__fbwerte( IN aspekt varchar, IN wert varchar, IN fktname varchar, IN paramname varchar )', 
ARRAY[
E'Sollen Fehlerbaum-Ereignisse geprft werden, ist \\texttt{FB-Ereignis} anzugeben. Sollen Fehlerbaum-Tore geprft werden, ist \\texttt{FB-Tor} anzugeben.'
, E'Es ist der Wert anzugeben, dessen Plausibilit geprft werden soll.'
, E'Es ist der Name der Funktion anzugeben, welche die Prfroutine aufruft. Der Funktionsname wird in der Fehlermeldung verwendet. Sollte er leer oder \\texttt{NULL} sein, wird \\texttt{str.pruefe__fbwerte(...)} verwendet.'
, E'Es ist der Name des Parameters anzugeben, welcher den zu prfenden Wert \\texttt{wert} beinhaltet. Der Parametername wird in der Fehlermeldung verwendet. Sollte er leer oder \\texttt{NULL} sein, wird \\texttt{wert} verwendet.'
],
E'Ziel der Funktion ist die Plausibilittsprfung gltiger Fehlerbaum-Ereignisse bzw. -Tore.
\\\\
\\\\
\\texttt{FB-Ereignis} - gltige Werte nach DIN IEC 61025:1993-12):
\\begin{description}
  \\item[EBB] Ereignis-Beschreibungs-Block
  \\item[GE] Grundereignis
  \\item[NUE] Nicht weiter untersuchtes Ereignis
  \\item[AUE] Anderweitig untersuchtes Ereignis
  \\item[HAUS] Haus
  \\item[NULL] Null-Ereignis
  \\item[VWVA] Verweisungs-Zeichen von auen
  \\item[VWNA] Verweisungs-Zeichen nach auen
\\end{description}

\\noindent \\texttt{FB-Tor} - gltige Werte nach DIN IEC 61025:1993-12):
\\begin{description}
  \\item[UND] UND-Verknpfung
  \\item[ODER] ODER-Verknpfung
  \\item[XODER] EXCLUSIV-ODER-Verknpfung
  \\item[NICHT] NICHT-Verknpfung
  \\item[BED] Bedingungs-Verknpfung
  \\item[RED] Redundante Struktur
  \\item[ALLG] Verknpfung (allgemein)
\\end{description}'
, ARRAY[
E'-- Fehlermeldung. Der bergebene Aspekt ist ungltig.\\\\SELECT * FROM str.pruefe__fbwerte( NULL, ''HAUS'', NULL, NULL );'
, E'-- Fehlermeldung. Der bergebene Wert darf Nicht \\texttt{NULL} oder leer sein, bzw. mu dem gltigen Wert entsprechen\\\\SELECT * FROM str.pruefe__fbwerte( ''FB-Ereignis'', NULL, NULL, NULL );\\\\SELECT * FROM str.pruefe__fbwerte( ''FB-Ereignis'', ''ungueltig'', NULL, NULL );\\\\SELECT * FROM str.pruefe__fbwerte( ''FB-Tor'', ''ungueltig'', ''fktname'', ''fktparam'' );'
, E'-- Die Werte sind gltig\\\\SELECT * FROM str.pruefe__fbwerte( ''FB-Ereignis'', ''HAUS'', NULL, NULL );\\\\SELECT * FROM str.pruefe__fbwerte( ''FB-Tor'', ''UND'', NULL, NULL );'
]
);
--
-- Fehlermeldungen
-- ...............
--
--	-- Fehlermeldung. Der bergebene Aspekt ist ungltig.
--SELECT * FROM str.pruefe__fbwerte( NULL, 'HAUS', NULL, NULL );
--
--
--
-- Standardverhalten:
-- ..................
--
--	-- Fehlermeldung. Der bergebene Wert darf Nicht \\texttt{NULL} oder leer sein, bzw. mu dem gltigen Wert entsprechen
--SELECT * FROM str.pruefe__fbwerte( 'FB-Ereignis', NULL, NULL, NULL );
--SELECT * FROM str.pruefe__fbwerte( 'FB-Ereignis', 'ungueltig', NULL, NULL );
--SELECT * FROM str.pruefe__fbwerte( 'FB-Tor', 'ungueltig', 'fktname', 'fktparam' );
--
--	-- Die Werte sind gltig
--SELECT * FROM str.pruefe__fbwerte( 'FB-Ereignis', 'HAUS', NULL, NULL );
--SELECT * FROM str.pruefe__fbwerte( 'FB-Tor', 'UND', NULL, NULL );
--




-- ---------------------------------------------------------------------------------------
-- ---------------------------------------------------------------------------------------
-- ---------------------------------------------------------------------------------------
--			------------------------------------------------------------------
-- tl - TEX/LATEX	------------------------------------------------------------------
--			------------------------------------------------------------------
-- ---------------------------------------------------------------------------------------
-- ---------------------------------------------------------------------------------------
-- ---------------------------------------------------------------------------------------

-- ---------------------------------------------------------------------------------------
-- ---------------------------------------------------------------------------------------
--				----------------------------------------------------------
-- 	tl.erzeuge__ABCZk(...)	----------------------------------------------------------
--				----------------------------------------------------------
-- ---------------------------------------------------------------------------------------
-- ---------------------------------------------------------------------------------------
CREATE OR REPLACE FUNCTION tl.erzeuge__ABCZk( tlwort varchar, OUT abcZk varchar ) AS
$$
DECLARE
--------------------------------------------------------------------------------
-- Konstanten
--------------------------------------------------------------------------------

--------------------------------------------------------------------------------
-- lokale Variablen
--------------------------------------------------------------------------------
--
-- Laufvariable
--
lauf integer;
--
-- Liste der TL-Zweizeichenbefehle, die im Wort gefunden wurden
--
listetlzzbefehl varchar[];
--
-- temporre Textvariable
--
tmpVarchar varchar;


BEGIN

--
-- 1.)	Plausibilitt
--	- Es mu ein TL-Wort bergeben werden
--
EXECUTE intern.pruefe__dt( 'zk', tlwort, NULL, NULL
				, 'tl.erzeuge__ABCZk(...)'
				, 'tlwort' );


--
-- 2)	TL-Zweizeichenbefehle, die im Wort gefunden wurden, bernehmen
--
listetlzzbefehl := tl.gib__Liste_TLZZBefehl( tlwort );


--
-- 3)	In >tlwort< wurden keine TL-Zweizeichenbefehle gefunden
--	-> Fehlermeldung ausgeben
--
IF(
    listetlzzbefehl IS NULL
  ) 
THEN
	RAISE EXCEPTION 'tl.erzeuge__ABCZk(...)	Aus der uebergebenen Zeichenkette >%', tlwort || '< konnten keine TL-Zweizeichenbefehle extrahiert werden. Das Erzeugen der ABCZk wird abgebrochen.';
END IF;


--
-- 4)	Liste der gefundenen TL-Zweizeichenbefehle durchlaufen
--
abcZk := tlwort;
FOR lauf IN array_lower ( listetlzzbefehl, 1 )..array_upper ( listetlzzbefehl, 1 ) LOOP

	--
	-- wenn mindestens ein TL-Zweizeichenbefehl nicht in der DB gefunden wurde, wird
	-- eine Fehlermeldung ausgegeben und die Analyse des Wortes abgebrochen 
	--
	EXECUTE 
		intern.gib__sqlSELECT( 'abczk',
					ARRAY['tl.befehl'], 
					' AND tl.befehl.befname = ' 
					|| quote_literal( listetlzzbefehl[lauf] )
					|| ' LIMIT 1' )
	INTO tmpVarchar;
 	IF(
 		tmpVarchar IS NULL
 	  )
 	THEN
		RAISE EXCEPTION 'tl.erzeuge__ABCZk(...)	Der im uebergebenen TL-Wort ( >%', tlwort || '< ) enthaltene TL-Zweizeichenbefehl >' || listetlzzbefehl[lauf] || '< konnte in >tl.befehl.befname< nicht gefunden werden. Der genannte TL-Zweizeichenbefehl ist manuell einlesen. Die Analyse wird abgebrochen.';
	END IF;

	--
	-- die ASCII-Darstellung von TL-Wort erzeugen
	--
	abcZk := replace( abcZk, listetlzzbefehl[lauf], tmpVarchar );

END LOOP;


--
-- 5)	Die entstandene Zeichenkette ist ungltig (vermutlich nur erzeugbar, wenn 
--	>tl.befehl.asciizk< eine ungltige Zeichenkette enthlt)
--
IF(
    NOT intern.ist__abczk( abczk )
  ) 
THEN
	RAISE EXCEPTION 'tl.erzeuge__ABCZk(...)	Die aus der uebergebenen Zeichenkette >%', tlwort || '< erzeugte Zeichenkette >' || abcZk || '< ist keine gueltige AbcZk.';
END IF;


END
$$LANGUAGE 'plpgsql' VOLATILE;
SELECT intern.nimm__TLKommentarFunktion( 'tl.erzeuge__ABCZk( tlwort varchar, OUT abcZk varchar )', 
ARRAY[
E'Es ist das Wort anzugeben, aus welchem die AbCZk extrahiert werden soll. ACHTUNG ! Das ''$\\backslash$'' ist doppelt anzugeben (zu maskieren). Bsp.: \\texttt{tl.erzeuge__ABCZk( ''"An\\-de\\-rung'' )}'
, E'Es wird die aus dem TL-Wort erzeugte AbCZk zurckgegeben.'
],
E'Ziel der Funktion ist das Erzeugen einer AbCZk \\texttt{abcZk} aus dem bergebenen TL-Wort \\texttt{tlwort}. Es werden alle TL-Zweizeichenbefehle in \\texttt{tlwort} mittels der in \\texttt{tl.befehl.abczk} zugeordneten AbCZk ersetzt.\\\\
Sollte \\texttt{tlwort} leer sein, oder beim Erzeugen ein Fehler auftreten bzw. \\texttt{abcZk} kein AbCZk darstellen, wird eine Fehlermeldung generiert.'
, ARRAY[
E'-- Fehlermeldung. Der Parameter \\texttt{tlwort} darf nicht leer oder \\texttt{NULL} sein.\\\\SELECT * FROM tl.erzeuge__ABCZk( '''' );'
, E'-- Fehlermeldung. Es konnten keine TL-Zweizeichenbefehle gefunden werden.\\\\SELECT * FROM tl.erzeuge__ABCZk( ''nderung'' );'
, E'-- \\texttt{nderung} zurckgeben\\\\SELECT intern.nimm__zeile( ''tl.befehl'', ARRAY[''abczk'', ''befname''], ARRAY['''', ''"A''] );\\\\SELECT intern.nimm__zeile( ''tl.befehl'', ARRAY[''befname''], ARRAY[E''\\-''] );\\\\SELECT * FROM tl.erzeuge__ABCZk( E''"An\\-de\\-rung'' );'
]
);
--
-- Fehlermeldungen
-- ...............
--
--	-- Fehlermeldung. Der Parameter \\texttt{tlwort} darf nicht leer oder \\texttt{NULL} sein.
--SELECT * FROM tl.erzeuge__ABCZk( '' );
--
--	-- Fehlermeldung. Es konnten keine TL-Zweizeichenbefehle gefunden werden.
--SELECT * FROM tl.erzeuge__ABCZk( 'nderung' );
--
--
--
-- Standardverhalten:
-- ..................
--
--	-- \\texttt{nderung} zurckgeben
--SELECT intern.nimm__zeile( 'tl.befehl', ARRAY['abczk', 'befname'], ARRAY['', '"A'] );
--SELECT intern.nimm__zeile( 'tl.befehl', ARRAY['befname'], ARRAY[E'\\-'] );
--SELECT * FROM tl.erzeuge__ABCZk( E'"An\\-de\\-rung' );
--


-- ---------------------------------------------------------------------------------------
-- ---------------------------------------------------------------------------------------
--				----------------------------------------------------------
-- 	tl.erzeuge__DBModell()	----------------------------------------------------------
--				----------------------------------------------------------
-- ---------------------------------------------------------------------------------------
-- ---------------------------------------------------------------------------------------
CREATE OR REPLACE FUNCTION tl.erzeuge__DBModell( OUT tldateiinhalt varchar ) AS
$$
DECLARE
--------------------------------------------------------------------------------
-- Konstanten
--------------------------------------------------------------------------------
--
-- Datenbankname (db[1]), Titel (db[2]), Version (db[3])
--
db varchar[] := ARRAY['vf', 'Virtuelles Fahrzeug', '1.3'];

--------------------------------------------------------------------------------
-- lokale Variablen
--------------------------------------------------------------------------------
--
-- temporre Ganzzahlvariablen
--
tmpInteger_1 integer;
tmpInteger_2 integer;
tmpInteger_3 integer;
tmpInteger_4 integer;
tmpInteger_5 integer;
tmpInteger_6 integer;
tmpInteger_7 integer;
--
-- temporre Textvariablen
--
tmpVarchar_1 varchar;
tmpVarchar_2 varchar;
tmpVarchar_3 varchar;
tmpVarchar_4 varchar;
tmpVarchar_5 varchar;
tmpVarchar_6 varchar;
tmpVarchar_7 varchar;
--
-- Liste temporrer Textvariablen
--
tmpVarcharListe_1 varchar[] := ARRAY[''];
tmpVarcharListe_2 varchar[] := ARRAY[''];
tmpVarcharListe_3 varchar[] := ARRAY[''];
--
-- FOR-LOOP-Schleifenvariablen
--
zeile_1 RECORD;
zeile_2 RECORD;




BEGIN

--------------------------------------------------------------------------------
--			--------------------------------------------------------
-- 1.)	Statischer Teil	--------------------------------------------------------
--			--------------------------------------------------------
--------------------------------------------------------------------------------
tldateiinhalt := E'% vf-dbdoku.tex
%
% Dokument erzeugen siehe ''makefile''
%
\\documentclass{gnufdlartikelA4}
%\\makeglossary
\\makeglossaries



% ---------------------------------------------------------------------------------------
% ---------------------------------------------------------------------------------------
% --								-------------------------
% --	glossary-Befehle (Stichwortverzeichnis) umdefinieren	-------------------------
% --								-------------------------
% ---------------------------------------------------------------------------------------
% ---------------------------------------------------------------------------------------
%
\\renewcommand{\\glossaryname}{Verzeichnis der Tabellenspalten und Begriffe}
\\renewcommand{\\entryname}{Tabellenspalte / Begriff}
\\renewcommand{\\descriptionname}{Beschreibung}



% ---------------------------------------------------------------------------------------
% ---------------------------------------------------------------------------------------
% --								-------------------------
% --	\\dbGlossary{spaltenname}{schema.tabelle}{beschreibung}	-------------------------
% --								-------------------------
% ---------------------------------------------------------------------------------------
% ---------------------------------------------------------------------------------------
%
\\newcommand{\\dbGlossary}[3]{%
  \\texttt{#1}%
  \\ifthenelse{\\equal{#2}{}}%
  {\\glossary{name=\\texttt{#1}, description={#3},sort=#1}}%
  {\\glossary{name=\\texttt{#2#1}, description={#3},sort=#2#1}}%
}



% ---------------------------------------------------------------------------------------
% ---------------------------------------------------------------------------------------
% --					-------------------------------------------------
% --	Tabellenhierarchie darstellen	-------------------------------------------------
% --					-------------------------------------------------
% ---------------------------------------------------------------------------------------
% ---------------------------------------------------------------------------------------
\\usepackage{lscape}
\\usepackage{tikz}
%
% 
%	Breite und Hhe aus >gnufdlartikelA4.cls<
%
%	Breite:					240mm ((\\textHoehe+6) : 3 = Ganzzahl)
%	Hhe:					160mm (\\textBreite - 8mm zum Vermeiden des 
%							Seitenumbruches)
%
%	Zeichenbereichbreite der Ebenen:	240mm : 3 = 80mm
%
%	max. Lnge der Spaltennamen
%	(11pt \\scriptsize, 30 Zeichen):		46mm
%
%	max. Lnge der Basisdatentypen
%	(11pt \\scriptsize, 8 Zeichen):		14mm
%
%	max. Lnge der Verweise
%	(11pt \\scriptsize, 3 Zeichen)
%
%	Linke obere Ecke (x,y)mm
%		Ebene 1:			(33, 157.5)
%		Ebene 2:			(113, 157.5)
%		Ebene 3:			(193, 157.5)
%
%
%	||	          33			  113			  193
%	||  15  |	(46+14)	| 5 ||  15  |	(46+14)	| 5 ||  15  |	(46+14)	| 5 ||
%	-
%	-
% 157.5	5 LEERZEILE
%	-
% 152.5	5 schema.tabellenname
%	-
% 147.5	5 Tabellenspalte / Datentyp
%	-
% ...	5 ...
%	-
%	5 Tabellenspalte / Datentyp
%	-
%	-
%	5 LEERZEILE
%	-
%	5 schema.tabellenname
%	-
%	5 Tabellenspalte / Datentyp
%	-
%	5 ...
%


% ---------------------------------------------------------------------------------------
% --				---------------------------------------------------------
% --	seiteTabHierarchie	---------------------------------------------------------
% --				---------------------------------------------------------
% ---------------------------------------------------------------------------------------
%
\\newenvironment{seiteTabHierarchie}[1]{%
  \\begin{landscape}
    \\subsection{Tabellenhierarchie der Ebenen #1}
    \\begin{tikzpicture}

      %
      % Alle Texte werden in Schreibmaschinenschrift dargestellt
      % Der Abstand zum linken und rechten Boxrand ist Null
      %
      \\tikzstyle{every node}=[font=\\ttfamily\\scriptsize, inner xsep=0mm]

      %
      % Rahmen um die Grafik zeichnen und somit die Maximalgre unabhngig von der Anzahl und 
      % Position der dargestellten Tabellen festlegen (Breite, Hhe verwenden)
      %
      \\draw (0,0) rectangle (240mm,160mm);
}{%
    \\end{tikzpicture}%
  \\end{landscape}
}


% ---------------------------------------------------------------------------------------
% --				---------------------------------------------------------
% --	Lngen / Zhler		---------------------------------------------------------
% --				---------------------------------------------------------
% ---------------------------------------------------------------------------------------
%
\\newcounter{cEins}



% ---------------------------------------------------------------------------------------
% --									-----------------
% --	\\zeichneTabelle{lfdNr Zielspalte}{Nodename Zielspalte}{x}{y}	-----------------
% --		{schema.tabelle}{spName, dTyp, Nodename}		-----------------
% --									-----------------
% ---------------------------------------------------------------------------------------
%
\\newcommand{\\zeichneTabelle}[6]{%

  %
  % Zhler  setzen
  %
  \\setcounter{cEins}{1}

  %
  % Tabellenname
  %
  % befindet sich 5mm unterhalb der bergebenen y-Koordinate
  %
  \\draw	(#3, #4 - 5mm ) node[minimum height=5mm,text width=42mm, inner xsep=2mm]{#5};

  %
  % Spalten
  %
  % Syntax des \\foreach - Befehls aus 
  % Kapitel 15 "Repeating Things: The Foreach Statement" S. 134 
  % des Dokumentes "TikZ and pgf --- Manual for Version 1.01"
  %
  \\foreach \\spName / \\dTyp / \\nodeName in {#6} {%

    %
    % Spalten zeichnen
    %
    % Nodename:
    %	schema-tabelle-spalte
    %
    \\ifthenelse{\\value{cEins} = 1}{%

      %
      % die erste Spalte ist stets >id< und ist Zielpunkt der Verbindung
      %
      \\draw %
      ( #3, #4 - 5mm * \\value{cEins} - 5mm ) %
      node[minimum height=5mm, minimum width=46mm, draw, fill=white]{\\spName}
      ( [xshift=30mm] #3, #4 - 5mm * \\value{cEins} - 5mm ) %
      node[minimum height=5mm, minimum width=14mm, draw, fill=white, name = \\nodeName]{\\dTyp};

      %
      % Verweis auf Zielspalte (id) setzen
      %
      \\ifthenelse{\\equal{#1}{}}{}{%

	\\zeichneVerbindung{#1}{#2}{}{z}
	
      }

    }{%

      %
      % die restlichen Spalten knnen Startpunkt einer Verbindung sein
      %
      \\draw %
      ( #3, #4 - 5mm * \\value{cEins} - 5mm ) %
      node[minimum height=5mm, minimum width=46mm, draw, fill=white, name = \\nodeName]{\\spName}
      ( [xshift=30mm] #3, #4 - 5mm * \\value{cEins} - 5mm ) %
      node[minimum height=5mm, minimum width=14mm, draw, fill=white]{\\dTyp};

    }

    %
    % den Wert des Zhlers um Eins erhhen
    %
    \\stepcounter{cEins}
  }
}


% ---------------------------------------------------------------------------------------
% --									-----------------
% --	\\zeichneVerbindung{lfdNr Zielspalte}{Nodename Zielspalte}	-----------------
% --				{Nodename Startspalte}{istVerweis}	-----------------
% --									-----------------
% --	istVerweis: leer ... Verbindung zeichnen			-----------------
% --	istVerweis: z    ... Verweis auf Zielspalte			-----------------
% --	istVerweis: s    ... Verweis aus Startspalte			-----------------
% --									-----------------
% ---------------------------------------------------------------------------------------
%
\\newcommand{\\zeichneVerbindung}[4]{%

  %
  % Farbe (Hintergrundfllung)
  % siehe "11.1 Nodes and Their Shapes" aus "TikZ and pgf --- Manual for Version 1.01"
  %
  % Pfeilspitzen
  % siehe "24.5 Predefined Arrow Tip Kinds" aus "TikZ and pgf --- Manual for Version 1.01"
  %
  % Linienstrken
  % siehe "10.2.1 Graphic Parameters: Line Width, Line Cap, and Line Join" aus 
  %			"TikZ and pgf --- Manual for Version 1.01"
  %
  % Koordinaten
  % siehe "8.1 Coordinates and Coordinate Options"
  % siehe "8.3 Polar Coordinates"
  % siehe "8.5.1 Named Anchor Coordinates"
  %			aus "TikZ and pgf --- Manual for Version 1.01"
  %

  %
  % Verbindung zeichnen
  %
  \\ifthenelse{\\equal{#4}{}}{%

    \\draw[latex-] (#2.east) -- ++(2ex, 0mm) -- ([xshift=-4ex]#3.west) -- (#3.west);

  }{%

    %
    % Verweis in Zielspalte
    %
    \\ifthenelse{\\equal{#4}{z}}{%

      \\draw[latex-] (#2.east) --  ++(2ex, 0mm) -- ++(0mm, 2mm) node[yshift = 1ex, fill=white]{#1};

    }{%

      \\draw[-latex] ([yshift=-0.75ex]#3.west) --  ++(-2ex, 0mm);
      \\draw ([yshift=-0.75ex]#3.west) node[xshift = -2ex, yshift = 1.5ex, fill=white, inner sep=0pt]{#1};

    }

  }

}



% ----------------------------------------------------------------------------------------
% ----------------------------------------------------------------------------------------
%				----------------------------------------------------------
%  Deckblatt und Copyleft	----------------------------------------------------------
%  Zusammenfassung		----------------------------------------------------------
%  Inhaltsverzeichnis		----------------------------------------------------------
%				----------------------------------------------------------
% ----------------------------------------------------------------------------------------
% ----------------------------------------------------------------------------------------
\\begin{document}

%
% Titel, Autor, Ausgabe
%
\\newcommand{\\dbmodellvf}[1]{Datenbankmodell #1"`'
|| db[2]
|| E'"''}
\\TitelAutorAusgabe{\\dbmodellvf{\\\\}\\\\Version '
|| db[3]
|| '}{Michael Bellair}{Ausgabedatum: ' 
|| to_char( current_date, 'YYYY-MM-DD')
|| E'}

%
% Zusammenfassung
%
\\Zusammenfassung{%
Das {\\dbmodellvf{}} wird beschrieben.}

%
% Inhaltsverzeichnis
%
\\Inhaltsverzeichnis



% ----------------------------------------------------------------------------------------
% ----------------------------------------------------------------------------------------
%		--------------------------------------------------------------------------
%  Einleitung	--------------------------------------------------------------------------
%		--------------------------------------------------------------------------
% ----------------------------------------------------------------------------------------
% ----------------------------------------------------------------------------------------
\\cleardoublepage
\\section{Einleitung}

Es wird die Struktur des Datenbankmodells vorgestellt.
Jedem Datenbankschema ist ein Abschnitt zugeordnet. 
Ziel und Zweck des Schemas werden beschrieben.';





--------------------------------------------------------------------------------
--									--------
-- 2.)	Dynamischer Teil - Kommentar zur Datenbank 'vf' auslesen	--------
--									--------
--------------------------------------------------------------------------------
tldateiinhalt := tldateiinhalt || E'


% ----------------------------------------------------------------------------------------
% ----------------------------------------------------------------------------------------
%			------------------------------------------------------------------
%  Das Datenbankmodell	------------------------------------------------------------------
%			------------------------------------------------------------------
% ----------------------------------------------------------------------------------------
% ----------------------------------------------------------------------------------------
\\cleardoublepage
\\section{Das Datenbankmodell}
';
EXECUTE 
	'SELECT 
		shobj_description(
			( SELECT oid FROM pg_database 
			  WHERE pg_database.datname = current_database() LIMIT 1 )
			,''pg_database'')'

INTO tmpVarchar_1;
tldateiinhalt := tldateiinhalt || tmpVarchar_1;



--------------------------------------------------------------------------------
--							------------------------
-- 3.)	Dynamischer Teil - Darstellung der Schemas	------------------------
--							------------------------
--------------------------------------------------------------------------------
FOR zeile_1 IN

	SELECT
		pg_namespace.nspname
		, pg_description.description
	FROM
		pg_description
		, pg_namespace
	WHERE
		pg_description.objoid = pg_namespace.oid
	AND
		NOT ( pg_namespace.nspname LIKE( 'pg_%' )
		OR pg_namespace.nspname LIKE( 'public' ) )
	ORDER BY
		pg_namespace.nspname
LOOP

	--
	-- berschrift und Beschreibung zusammenstellen
	--
	tldateiinhalt := tldateiinhalt || E'



% ----------------------------------------------------------------------------------------
% ----------------------------------------------------------------------------------------
%			------------------------------------------------------------------
%  ' || zeile_1.nspname || E'		------------------------------------------------------------------
%			------------------------------------------------------------------
% ----------------------------------------------------------------------------------------
% ----------------------------------------------------------------------------------------
\\newpage
\\section{' || zeile_1.nspname || E'}

%
% Beschreibung des Schemas
%
\\noindent ' 
|| zeile_1.description;


	--
	-- Tabellenhierarchie darstellen -
	-- Die nach Ebene sortierten Tabellen durchlaufen
	--
	tmpVarcharListe_1 := NULL; -- Inhalt der Darstellungsbltter aufnehmen
	tmpVarcharListe_2 := NULL; -- die im Darstellungsblatt gltigen Verbindungen aufnehmen

	tmpVarchar_1 := '';	-- aktueller Tabellenname
	tmpVarchar_2 := '';	-- aktuelle Ebenenberschriften

	tmpInteger_1 := 0;	-- aktuelle Ebene
	tmpInteger_2 := 0;	-- lfd. Nr. des Darstellungsblattes der aktuellen Ebene
	tmpInteger_4 := 0;	-- Nr.des ersten Darstellungsblattes des aktuellen Ebenenblockes
	tmpInteger_3 := 0;	-- aktuelle y-Koordinate
	tmpInteger_5 := 0;	-- Spaltenanzahl der vorhergehenden Tabelle
	tmpInteger_6 := 0;	-- Ebenenberschrift

	FOR zeile_2 IN

		SELECT 
			replace( spziel, '.', '-' ) AS zielnodename
 			, ( CAST( ebene AS integer ) % 3 = 0 ) AS ebwechsel
 			, ( CAST( ebene AS integer ) % 3 ) AS modulo
			, CAST( ebene AS integer ) AS ebene
			, spanz
 			, tl.erzeuge__TLdbGlossary(
				intern.gib__stsname( 'schtab', spname )
				, ''
				, beschr_tabelle ) AS tname
			, tl.erzeuge__TLdbGlossary(
				intern.gib__stsname( 'sp', spname )
				, intern.gib__stsname( 'schtab', spname ) || '.'
				, beschr_spalte ) AS spaltenname
			, tl.erzeuge__TLZk( CAST( dtyp AS text ) ) AS dtyp
			, replace( replace( spname, '.', '-' ), '_', '-' ) AS nodename
		FROM 
			intern.gib__Liste_Tabellenpositionen( CAST( zeile_1.nspname AS text ) ) LEFT OUTER JOIN intern.zeige__tabspInformationen ON ( intern.gib__stsname( 'schtab', spname ) = tabname ) LEFT OUTER JOIN intern.zeige__fremdschluessel ON ( spname = spstart ) LEFT OUTER JOIN intern.zeige__spaltenanzahl gibspanz ON ( gibspanz.tabname = intern.gib__stsname( 'schtab', spname ) )
		ORDER BY
		--	Ebenenreihenfolge
		--		3	6	9	...
		--		1	4	7	...
		--		2	5	8	...
		CASE WHEN( CAST( ebene AS integer ) % 3 = 0 ) 
			THEN ( CAST( ebene AS integer ) - 3 ) 
			ELSE ( CAST( ebene AS integer ) ) 
		END
		, intern.gib__stsname( 'schtab', spname )
		, spnr
--
-- ggf. spter Bereinigen, die Reihenfolge 3-1-2 ist nicht mehr notwendig
--
--		ebene

	LOOP

--
-- Test
--
--RAISE NOTICE '%', zeile_2.tname || '.' || zeile_2.spaltenname;


		--
		-- beim Tabellenwechsel >\zeichneTabelle{...}< bernehmen
		--
		IF(
		    NOT( tmpVarchar_1 = zeile_2.tname )
		  )
		THEN

			--
			-- aktuellen Tabellennamen bernehmen
			-- (zum Erkennen des nchsten Tabellenwechsels)
			--
			tmpVarchar_1 := zeile_2.tname;

			--
			-- y-Koordinate auf nchste Zeile setzen
			--
			tmpInteger_3 := tmpInteger_3 - ( ( tmpInteger_5 + 2 ) * 5 );

			--
			-- Ebenenberschrift hochzhlen
			--	- beim ersten Durchlauf
			-- 	- am Ebenenblockwechsel
			--
			IF(
				( tmpVarcharListe_1 IS NULL )
				OR ( zeile_2.ebwechsel )
			  )
			THEN

				tmpInteger_6 := tmpInteger_6 + 1;
				tmpVarchar_2 := CAST( tmpInteger_6 AS text )
							|| ' --- '
							|| CAST( tmpInteger_6 + 2 AS text );

			END IF;

			--
			-- Neues Darstellungsblatt anlegen
			--	-> beim ersten Durchlauf bzw. am Ebenenblockwechsel 
			--	   (bergang Ebenen (6,4,5), (9,7,8), ...)
			--	-> letzte Tabellenspalte pat nicht mehr auf das 
			--	   Darstellungsblatt bei y < 7.5 mm (innerhalb einer Ebene)
			--
 			IF(
				( tmpVarcharListe_1 IS NULL )
				OR ( ( tmpInteger_1 != zeile_2.ebene ) 
					AND ( zeile_2.ebwechsel ) )
 				OR ( ( tmpInteger_1 = zeile_2.ebene )
				    AND ( tmpInteger_3 - ( ( zeile_2.spanz + 1 ) * 5 ) < 7.5 ) )
 			  )
 			THEN

				--
				-- Neues Darstellungsblatt anlegen, wenn ...
				-- 	-> ... die erste Tabelle bernommen wird
				--
				IF(	
					array_dims( tmpVarcharListe_1 ) IS NULL 
				  ) 
				THEN

					tmpVarcharListe_1[1] := '';
					tmpVarcharListe_2 := NULL;
					tmpVarcharListe_2[1] := '';
					tmpInteger_4 := 1;
					tmpInteger_2 := 1;


				--
				-- 	-> ... das Ende der Liste erreicht wurde
				--
				ELSIF(
					tmpInteger_4 = array_upper( tmpVarcharListe_1, 1 )
				  )
				THEN

					tmpVarcharListe_1 := array_append( tmpVarcharListe_1, 
									'' );
					tmpVarcharListe_2 := array_append( tmpVarcharListe_2, 
									'' );

					--
					-- Nr. des ersten Darstellungsblattes des aktuellen
					-- Ebenenblockes bernehmen
					--
					tmpInteger_4 := array_upper( tmpVarcharListe_1, 1 );
					tmpInteger_2 := tmpInteger_4;

				--
				-- ... sonst auf nchstes Darstellungsblatt schalten
				--
				ELSE

					tmpInteger_2 := tmpInteger_2 + 1;

				END IF;

				--
				-- y-Koordinate auf erste Zeile setzen
				--
 				tmpInteger_3 := 157;

				--
				-- Umgebung setzen
				--
 				tmpVarcharListe_1[tmpInteger_2] := E'%
% ----------------------------------------------------------------------------------------
%				----------------------------------------------------------
%  ' || tmpVarchar_2 || E' 			----------------------------------------------------------
%				----------------------------------------------------------
% ----------------------------------------------------------------------------------------
%
\\begin{seiteTabHierarchie}{' || tmpVarchar_2 || '}
 
';

 			END IF;

			--
			-- am Ebenenwechsel 
			--	-> Ebene bernehmen
			--	-> die lfd. Nr. des Darstellungsblattes auf das erste Blatt des 
			--	   aktuellen Ebenenblockes setzen
			--	-> y-Koordinate auf erste Zeile setzen
			--
 			IF(
 				( tmpInteger_1 != zeile_2.ebene )
 			  )
 			THEN

				--
				-- die letzten drei Punkte
				--
				tmpInteger_1 := zeile_2.ebene;
 				tmpInteger_2 := tmpInteger_4;
  				tmpInteger_3 := 157;

 			END IF;

			--
			-- \zeichneTabelle{...}{%
			-- auf dem aktuellen Zeichenblatt bernehmen
			--
			tmpVarcharListe_1[tmpInteger_2] := 
				tmpVarcharListe_1[tmpInteger_2]
				|| '}' || chr( 10 ) || chr( 10 )
				|| E'\\zeichneTabelle{}{'
				|| zeile_2.nodename
				|| '}{'
				|| CASE zeile_2.ebene	WHEN( 1 ) THEN '33mm'
							WHEN( 2 ) THEN '113mm'
							ELSE '193mm' 
			  				END
				|| '}{'
				|| tmpInteger_3 || '.5mm'
				|| '}{'
				|| zeile_2.tname
				|| '}{%' || chr( 10 );
		
			--
			-- aktuelle Spaltenanzahl bernehmen
			--
			tmpInteger_5 := zeile_2.spanz;

		END IF;

		--
		-- Spalten bernehmen
		--
		tmpVarcharListe_1[tmpInteger_2] := 
			tmpVarcharListe_1[tmpInteger_2] 
			|| zeile_2.spaltenname
			|| '/'
			|| zeile_2.dtyp
			|| '/'
			|| zeile_2.nodename
			|| ',%' || chr( 10 );

		--
		-- Hilfszeichenkette fr \zeichneVerbindung{...} zusammenstellen
		--
		IF(
			( zeile_2.zielnodename IS NOT NULL )
		  )
		THEN
			tmpVarcharListe_2[tmpInteger_2] :=
					tmpVarcharListe_2[tmpInteger_2]
					|| '{'
					|| zeile_2.zielnodename
					|| '}|{'
					|| zeile_2.nodename
					|| '}'
					|| CASE WHEN( zeile_2.ebwechsel ) THEN '%' ELSE '' END
					|| chr( 10 );
		END IF;

	END LOOP;

	--
	-- letzten Block abschlieen und Darstellungsbltter bernehmen
	--
	FOR tmpInteger_1 IN 1..array_upper( tmpVarcharListe_1, 1 )
	LOOP

		--
		-- letzten Block abschlieen
		--
		tmpVarcharListe_1[tmpInteger_1] := tmpVarcharListe_1[tmpInteger_1]
			|| chr( 10 ) || E'\\end{seiteTabHierarchie}';

		--
		-- Bereinigen
		--
		tmpVarcharListe_1[tmpInteger_1] := replace( tmpVarcharListe_1[tmpInteger_1]
			, E'}
 
}

\\zeichneTabelle'
			, E'}

\\zeichneTabelle' );

		tmpVarcharListe_1[tmpInteger_1] := replace( tmpVarcharListe_1[tmpInteger_1]
			, E',%
}

\\zeichneTabelle'
			, E'%
}

\\zeichneTabelle' );

		tmpVarcharListe_1[tmpInteger_1] := replace( tmpVarcharListe_1[tmpInteger_1]
				, E',%

\\end{seiteTabHierarchie}'
				, E'%
}

');

		--
		-- Verbindungen vervollstndigen und bernehmen
		--
		tmpVarcharListe_3 := string_to_array( tmpVarcharListe_2[tmpInteger_1], chr( 10 ) );
		FOR tmpInteger_7 IN 1..( CASE WHEN( tmpVarcharListe_3 IS NOT NULL ) THEN array_upper( tmpVarcharListe_3, 1 ) ELSE 1 END - 1 )
		LOOP

			--
			-- \zeichneVerbindung{...} zusammenstellen
			--
			tmpVarcharListe_1[tmpInteger_1] := tmpVarcharListe_1[tmpInteger_1]
				|| E'\\zeichneVerbindung{}'
				|| replace( replace( tmpVarcharListe_3[tmpInteger_7], '|', '' )
					, '%'
					, '' )
--
-- spter korrigieren, wenn Verbindungen zwischen Ebene 3 und 1 bestehen.
-- Dazu das Auftreten von >%< am Ende der Zeichenkette >tmpVarcharListe_3[tmpInteger_7]<
-- auswerten
--
				|| CASE WHEN( 
					position( E'\\zeichneTabelle{}'
						|| split_part( tmpVarcharListe_3[tmpInteger_7]
							, '|'
							, 1 )
					in tmpVarcharListe_1[tmpInteger_1] ) = 0 ) 
				   THEN '{s}' 
				   ELSE '{}' 
				   END
				|| chr( 10 );

		END LOOP;

		--
		-- Darstellungsbltter bernehmen und abschlieen
		--
		tldateiinhalt := tldateiinhalt
			|| tmpVarcharListe_1[tmpInteger_1]
			|| E'
\\end{seiteTabHierarchie}


';

	END LOOP;

	--
	-- Schlssel und Bedingungen darstellen
	--
	tldateiinhalt := tldateiinhalt || E'


%
% Schlssel und Bedingungen
%
\\subsection{Schlssel und Bedingungen}';

	--
	-- Primrschlssel, Fremdschlssel, unique constraint, check constraint initialisieren
	--
	tmpVarchar_2 := E'

%
% Liste der Primrschlssel
%
\\noindent \\textbf{Primrschlssel}
\\begin{description}
';
	tmpVarchar_3 := E'

%
% Liste der Fremdschlssel
%
\\noindent \\textbf{Fremdschlssel}
\\begin{description}
';
	tmpVarchar_4 := E'

%
% Liste der Unique Constraints
%
\\noindent \\textbf{Unique Constraints}
\\begin{description}
';
	tmpVarchar_5 := E'

%
% Liste der Check Constraints
%
\\noindent \\textbf{Check Constraints}
\\begin{description}
';

	--
	-- Primrschlssel, Fremdschlssel, unique constraint, check constraint eintragen
	--
	FOR zeile_2 IN
		SELECT
			CASE pg_constraint.contype	-- Reihenfolge festgelegt
				WHEN 'p' THEN 1		-- 1. Primrschlssel
				WHEN 'f' THEN 2		-- 2. Fremdschlssel
				WHEN 'u' THEN 3		-- 3. unique constraint
				ELSE 4			-- 4. check constraint
			END AS typ
			, pg_constraint.conname AS name
			, pg_namespace.nspname || '.' || pg_class.relname AS tabelle
			, pg_description.description AS beschreibung
			, pg_constraint.consrc AS bedingung
			, pg_constraint.conkey AS spnr
		FROM
			pg_namespace
			, pg_class
			, pg_constraint LEFT OUTER JOIN pg_description ON ( 
						pg_description.objoid = pg_constraint.oid )
		WHERE
			pg_constraint.connamespace = pg_namespace.oid
		AND
			pg_constraint.conrelid = pg_class.oid
		AND
			pg_namespace.nspname = zeile_1.nspname
		ORDER BY
			typ
			, tabelle
			, name
	LOOP

		--
		-- Liste der Spaltennamen setzen
		--
		tmpVarchar_7 := '';

		FOR tmpInteger_2 IN 1..array_upper ( zeile_2.spnr, 1 )
		LOOP

			--
			-- Alle verwendeten Spaltennamen ermitteln ...
			--
			SELECT INTO tmpVarchar_6
				pg_attribute.attname AS spname
			FROM 
				pg_namespace, pg_class, pg_attribute
			WHERE 
				pg_class.relnamespace = pg_namespace.oid
			AND
				pg_attribute.attrelid = pg_class.oid
			AND
				pg_attribute.attnum = zeile_2.spnr[tmpInteger_2]
			AND
				pg_namespace.nspname 
				|| '.' 
				|| pg_class.relname = zeile_2.tabelle;

			--
			-- ... und bernehmen
			--
			tmpVarchar_7 := tmpVarchar_7 
					|| ', ' || zeile_2.tabelle 
					|| '.' || tmpVarchar_6;

		END LOOP;
		--
		-- das fhrende Komma entfernen
		--
		tmpVarchar_7 := substring( tmpVarchar_7 from 3 );

		--
		-- '\item...' setzen
		--
		tmpVarchar_1 := E'  \\item[\\texttt{' 
					|| tl.erzeuge__TLdbGlossary( CAST( 
									zeile_2.name AS text )
									, zeile_2.tabelle
									, zeile_2.beschreibung )
					|| '}] ';

		--
		-- Primrschlssel
		--
		IF ( zeile_2.typ = 1 ) THEN
			tmpVarchar_2 := tmpVarchar_2
						|| tmpVarchar_1
						|| E'fr Spalte \\texttt{'
						|| tmpVarchar_7
						|| '}'
						|| chr( 10 );

		--
		-- Fremdschlssel
		--
		ELSIF ( zeile_2.typ = 2 ) THEN 
			tmpVarchar_3 := tmpVarchar_3
						|| tmpVarchar_1
						|| E'aus Spalte \\texttt{'
						|| tmpVarchar_7
						|| '}'
						|| chr( 10 );

		--
		-- unique constraint
		--
		ELSIF ( zeile_2.typ = 3 ) THEN
			tmpVarchar_4 := tmpVarchar_4
						|| tmpVarchar_1
						|| E'in Tabelle \\texttt{'
						||	CAST( zeile_2.tabelle AS text ) 
						|| E'} fr die Spalte(n) \\texttt{'
						|| tmpVarchar_7
						|| '}'
						|| chr( 10 );

		--
		-- check constraint
		--
		ELSE
			tmpVarchar_5 := tmpVarchar_5
						|| tmpVarchar_1
						|| E'in Tabelle \\texttt{'
						||	CAST( zeile_2.tabelle AS text )
						|| E'} die Bedingung \\texttt{'
						||	CAST( zeile_2.bedingung AS text )
						|| '}'
						|| chr( 10 );

		END IF;

	END LOOP;


	--
	-- Schlssel, Bedingungen, Funktionen bernehmen, wenn sie verwendet wurden
	--
	tmpVarchar_1 := E'\\end{description}';
	IF ( position( E'\\item[' in tmpVarchar_2 ) > 0  ) THEN
		tldateiinhalt := tldateiinhalt || tmpVarchar_2 || tmpVarchar_1;
	END IF;

	IF ( position( E'\\item[' in tmpVarchar_3 ) > 0  ) THEN 
		tldateiinhalt := tldateiinhalt || tmpVarchar_3 || tmpVarchar_1;
	END IF;

	IF ( position( E'\\item[' in tmpVarchar_4 ) > 0  ) THEN 
		tldateiinhalt := tldateiinhalt || tmpVarchar_4 || tmpVarchar_1;
	END IF;

	IF ( position( E'\\item[' in tmpVarchar_5 ) > 0  ) THEN 
		tldateiinhalt := tldateiinhalt || tmpVarchar_5 || tmpVarchar_1;
	END IF;


	--
	-- Funktionen eintragen
	--
	FOR zeile_2 IN
		SELECT 
			-- Sollte die Programmiersprache ausgegeben werden ?
			-- pg_language.lanname AS progsprache
			pg_namespace.nspname || '.' || pg_proc.proname AS fktname
			, pg_proc.proargmodes AS parammodi
			, pg_proc.proargnames AS paramnamen
			, CASE WHEN( pg_proc.proallargtypes IS NULL )
			  THEN pg_proc.proargtypes
			  ELSE pg_proc.proallargtypes 
			  END  AS paramdtypen
			, pg_description.description AS beschreibung
			, pg_proc.proisagg
			-- Sollte der Quelltext ausgegeben werden ?
			-- , pg_proc.prosrc AS quelltext
		FROM 
			pg_namespace, pg_language, pg_proc LEFT OUTER JOIN pg_description ON ( pg_description.objoid = pg_proc.oid )
		WHERE
			pg_proc.pronamespace = pg_namespace.oid
		AND
			pg_proc.prolang = pg_language.oid
		AND
			pg_namespace.nspname = zeile_1.nspname
		ORDER BY
			fktname
	LOOP

		--
		-- Funktionsnamen eintragen
		--
		tmpVarchar_1 := E'

%
% Funktionsbeschreibung
%
\\subsection{' 
				|| zeile_2.fktname
				|| E'}

\\textbf{Funktionsname}\\\\
\\texttt{'
				|| zeile_2.fktname
				|| '(';


		--
		-- Parameterliste und die Beschreibungen der Funktionsparameter/Rckgabewerte 
		-- zusammenstellen
		--
		tmpVarchar_2 := '';
		tmpVarchar_3 := '';
		FOR tmpInteger_2 IN 1..CASE WHEN( array_upper ( zeile_2.paramnamen, 1 ) IS NULL )
						THEN 0 
						ELSE array_upper ( zeile_2.paramnamen, 1 ) 
						END
		LOOP

			--
			-- Alle verwendeten Datentypen ermitteln ...
			--
			SELECT INTO tmpVarchar_4
				CASE WHEN( position( '_' in typname ) = 1 )
				THEN ltrim( typname, '_') || '[]'
				ELSE typname
				END AS dtyp
			FROM
				pg_type
			WHERE
				CASE WHEN( zeile_2.parammodi IS NULL )
				THEN oid = zeile_2.paramdtypen[tmpInteger_2 - 1]
				ELSE oid = zeile_2.paramdtypen[tmpInteger_2]
				END
			ORDER BY
				typname
			;

			--
			-- ... bernehmen und die Parameternamen einschlielich Modus
			--     ergnzen
			--
			tmpVarchar_2 := tmpVarchar_2
						|| ', ';
			IF( zeile_2.parammodi[tmpInteger_2] IS NULL )
			THEN
				tmpVarchar_2 := tmpVarchar_2 || 'IN ';
			ELSE
				tmpVarchar_2 := tmpVarchar_2
						|| CASE zeile_2.parammodi[tmpInteger_2]
							WHEN 'b' THEN 'INOUT '
							WHEN 'i' THEN 'IN '
							WHEN 'o' THEN 'OUT '
						   END;
			END IF;
			tmpVarchar_2 := tmpVarchar_2
						|| zeile_2.paramnamen[tmpInteger_2]
						|| ' '
						|| tmpVarchar_4
						;

			--
			-- Beschreibungen der Funktionsparameter/Rckgabewerte zusammenstellen
			-- (das Trennzeichen einschlielich Position zum extrahieren der 
			--  Beschreibungen ist in >intern.nimm__TLKommentarFunktion(...)< 
			--  definiert)
			--
			tmpVarchar_3 := tmpVarchar_3
						|| E'\\item[\\texttt{'
						|| zeile_2.paramnamen[tmpInteger_2]
						|| '}] '
						|| split_part( zeile_2.beschreibung
								, chr( 2 )
								, tmpInteger_2 * 2 )
						|| chr( 10 );



		END LOOP;

		--
		-- Parameterliste und Beschreibungen der Funktionsparameter bernehmen
		--
		tmpVarchar_1 := tmpVarchar_1 
				|| CASE WHEN( tmpVarchar_2 != '' )
				   THEN substring( tmpVarchar_2 from 2 )
					|| ' '
				   ELSE
					''
				   END
				|| E')}
\\\\
\\\\
\\textbf{Funktionsparameter/Rckgabewert(e)}
\\begin{description}
'
				|| CASE WHEN( tmpVarchar_3 = '' )
				   THEN
					E'\\item[\\texttt{-}]' || chr( 10 )
				   ELSE
					tmpVarchar_3
				   END
				|| E'\\end{description}';

		--
		-- Funktionsbeschreibung bernehmen, das Trennzeichen zum extrahieren 
		-- der Beschreibung ist in >intern.nimm__TLKommentarFunktion(...)< definiert
		--
		tldateiinhalt := tldateiinhalt 
				|| tmpVarchar_1
				|| E'


\\noindent\\textbf{Funktionsbeschreibung}\\\\
'

				-- Beschreibung der Aggregatfunktion bernehmen
				|| CASE WHEN( zeile_2.proisagg ) THEN zeile_2.beschreibung
					ELSE split_part( zeile_2.beschreibung
								, chr( 3 )
								, 2 )
					END;


		--
		-- Beispiele zusammenbauen ...
		-- ( das Trennzeichen zum extrahieren der Beispiele ist 
		-- in >intern.nimm__TLKommentarFunktion(...)< definiert )
		--
		tmpVarchar_1 := '';
		FOR tmpInteger_2 IN 4..array_upper ( string_to_array( zeile_2.beschreibung, chr( 3 ) ), 1 )
		LOOP

			tmpVarchar_1 := tmpVarchar_1 
						|| E'\\texttt{'
						|| split_part( zeile_2.beschreibung, 
								chr( 3 ), 
								tmpInteger_2 )
						|| E'}\\\\\\\\'
						|| chr( 10 );

		END LOOP;

		--
		-- ... und bernehmen
		--
		IF(
			tmpVarchar_1 != ''
		) 
		THEN

			tldateiinhalt := tldateiinhalt 
					|| E'\\noindent
\\\\
\\\\
\\noindent\\textbf{Beispiele}\\\\
'
					|| rtrim( tmpVarchar_1, E'\\' );

		END IF;

	END LOOP;





	--
	-- Sichten eintragen
	--
	FOR zeile_2 IN

		SELECT
			pg_namespace.nspname || '.' || pg_class.relname AS sicht
			, pg_description.description AS beschreibung
		FROM
			pg_namespace
			, pg_class LEFT OUTER JOIN pg_description ON
							( pg_description.objoid = pg_class.oid )
		WHERE
			pg_class.relnamespace = pg_namespace.oid
		AND
			pg_class.relkind = 'v'
		AND
			pg_namespace.nspname = zeile_1.nspname
		ORDER BY
			sicht

	LOOP

		--
		-- Den Namen der Sicht immer auffhren
		--
		tldateiinhalt := tldateiinhalt || E'

%
% Beschreibung der Sicht
%
\\subsection{'
						|| zeile_2.sicht
						|| '}'
						|| chr(10);

		--
		-- Wenn keine Beschreibung existiert, zur nchsten Sicht gehen ...
		--
		IF(
			zeile_2.beschreibung IS NULL
		)
		THEN
			CONTINUE;
		END IF;

		--
		-- ... und wenn eine Beschreibung existiert, die Spalten darstellen ...
		--
		tldateiinhalt := tldateiinhalt	|| E'
\\textbf{Beschreibung der Spalten}
\\begin{description}'
						|| chr( 10 );

		FOR tmpInteger_2 IN 2..array_upper ( string_to_array( zeile_2.beschreibung, chr( 2 ) ), 1 ) - 1 BY 2
		LOOP

			--
			-- Spalten eintragen
			--
			tldateiinhalt := tldateiinhalt
						|| E'\\item[\\texttt{'
						|| split_part( zeile_2.beschreibung
								, chr( 2 )
								, tmpInteger_2 )
						|| '}]'
						|| split_part( zeile_2.beschreibung
								, chr( 2 )
								, tmpInteger_2 + 1 )
						|| chr( 10 );

		END LOOP;
		tldateiinhalt := tldateiinhalt	|| E'\\end{description}'
						|| chr( 10 );

		--
		-- ... bzw. die Beschreibung
		--
		IF(
			( split_part( zeile_2.beschreibung, chr( 3 ), 2 ) != '' )
			OR ( split_part( zeile_2.beschreibung, chr( 3 ), 2 ) IS NOT NULL )
		)
		THEN

			tldateiinhalt := tldateiinhalt	|| E'
\\noindent\\textbf{Beschreibung der Sicht}\\\\
'
						|| split_part( zeile_2.beschreibung
							, chr( 3 )
							, 2 );

		END IF;

	END LOOP;
	
END LOOP;


--
-- Identifikationsnummern der Zielspalten eintragen
--
tmpInteger_1 := 1;
FOR zeile_1 IN

	SELECT DISTINCT

		replace( replace( spziel, '.', '-' ), '_', '-' ) AS nodename
	FROM
		intern.zeige__fremdschluessel

	ORDER BY

		nodename

LOOP

	--
	-- lfd. Nr. der Zielspalten anhand der TL-nodenamen bernehmen
	--
	tldateiinhalt := replace( tldateiinhalt, E'\\zeichneVerbindung{}{'
					|| zeile_1.nodename
					|| '}', E'\\zeichneVerbindung{'
					|| CAST( tmpInteger_1 AS varchar)
					|| '}{'
					|| zeile_1.nodename
					|| '}' );
	tldateiinhalt := replace( tldateiinhalt, E'\\zeichneTabelle{}{'
					|| zeile_1.nodename
					|| '}', E'\\zeichneTabelle{'
					|| CAST( tmpInteger_1 AS varchar)
					|| '}{'
					|| zeile_1.nodename
					|| '}' );

	--
	-- lfd. Nr. der Zielspalten weiterzhlen
	--
	tmpInteger_1 := tmpInteger_1 + 1;

END LOOP;





--------------------------------------------------------------------------------
--					----------------------------------------
-- 6.)	Statischer Teil - Anhang	----------------------------------------
--					----------------------------------------
--------------------------------------------------------------------------------
tldateiinhalt := tldateiinhalt || E'



% ----------------------------------------------------------------------------------------
% ----------------------------------------------------------------------------------------
%		--------------------------------------------------------------------------
%  Anhang	--------------------------------------------------------------------------
%		--------------------------------------------------------------------------
% ----------------------------------------------------------------------------------------
% ----------------------------------------------------------------------------------------
\\cleardoublepage
\\begin{appendix}

  %
  % Lizenz
  %
  \\Lizenz

  %
  % Begriffs-/Abkrzungsverzeichnis
  %
  \\cleardoublepage
  \\begin{landscape}
    \\printglossary
  \\end{landscape}

\\end{appendix}

\\end{document}';


--------------------------------------------------------------------------------
--					----------------------------------------
-- 7.)	Zeilenumbruchzeichen einfgen	----------------------------------------
--	Alle '_' mittels '\_' ersetzen	----------------------------------------
--					----------------------------------------
--------------------------------------------------------------------------------
tldateiinhalt := tl.erzeuge__TLZk( replace( tldateiinhalt, intern.gib__ZU(), E'\n' ) );


--
-- Test
--
--tldateiinhalt := '';


END
$$LANGUAGE 'plpgsql' VOLATILE;
SELECT intern.nimm__TLKommentarFunktion( 'tl.erzeuge__DBModell( OUT tldateiinhalt varchar )', 
ARRAY[
E'Es wird der Inhalt der {\\TeX}/\\LaTeX{}-Datei zurckgegeben, welche das Datenbankmodell enthlt.'
],
E'Ziel der Funktion ist das Erzeugen einer {\\TeX}/\\LaTeX{}-Datei, welche das Datenbankmodell enthlt. Sie wird aus den Kommentaren erzeugt, welche den verschiedenen Datenbankobjekten zugeordnet wurden.
Es werden die Kommentare der Datenbank, Schemas, Tabellen, Spalten, Funktionen, Primr- und Fremdschlssel, sowie die \\texttt{unique} und \\texttt{check constraints} verwendet.\\\\
In den Kommentaren sind $\\backslash$ entsprechend zu doppeln. Unterstrichen werden automatisch $\\backslash$ vorangestellt, weshalb zum momentanen Zeitpunkt keine mathematischen Formeln eingegeben werden knnen.
\\\\
\\\\
Hinweise zur Benutzung:\\\\
Um nicht auf eine separate Ausleseroutine angewiesen zu sein, wird folgende (in \\texttt{psql}) auszufuehrende Handlungsweise empfohlen:\\\\
\\\\
\\texttt{$\\backslash$pset tuples_only $\\backslash$pset format unaligned $\\backslash$pset footer}\\\\
\\texttt{SELECT * FROM tl.erzeuge__DBModell() $\\backslash$o dateiname.tex}\\\\
\\texttt{;}\\\\
\\texttt{$\\backslash$q}\\\\
Alternativ kann in der Kommandozeile\\\\
\\texttt{psql -U micha vf -P tuples_only -P format=unaligned -P footer -c ``SELECT * FROM tl.erzeuge__DBModell()`` -o dateiname.tex}\\\\
eingegeben werden.'
, ARRAY[
E'-- Datenbankmodell ausgeben\\\\SELECT * FROM tl.erzeuge__DBModell();'
]
);
--
-- Standardverhalten:
-- ..................
--
--	-- Datenbankmodell ausgeben
--SELECT * FROM tl.erzeuge__DBModell();
--


-- ---------------------------------------------------------------------------------------
-- ---------------------------------------------------------------------------------------
--					--------------------------------------------------
--	tl.erzeuge__TLdbGlossary(...)	--------------------------------------------------
--					--------------------------------------------------
-- ---------------------------------------------------------------------------------------
-- ---------------------------------------------------------------------------------------
CREATE OR REPLACE FUNCTION tl.erzeuge__TLdbGlossary( begriff varchar, gloPrfx varchar, bechreibung varchar, OUT tldbgl varchar ) AS
$$
BEGIN


--
-- 1.)	Plausibilitt
--	- Der Begriff ist anzugeben !
-- 	- Die Bedingung 2 ist zu erfllen
--
EXECUTE intern.pruefe__dt( 'zk', begriff, NULL, NULL
				, 'tl.erzeuge__TLdbGlossary(...)'
				, 'begriff' );


--
-- 2.)	Wenn die Beschreibung nicht vorhanden ist, dann wird nur der Begriff zurckgegeben
--
IF(
	( length( bechreibung ) = 0 )
	OR ( bechreibung IS NULL )
  ) 
THEN
	tldbgl := begriff;
	RETURN;
END IF;


--
-- 3.)	Den >\dbGlossary-Befehl< erzeugen
--
tldbgl := E'\\dbGlossary{'
		|| CAST( begriff AS text )
		|| '}{'
		|| CAST( gloPrfx AS text )
		|| '}{'
		|| bechreibung
		|| '}';

END
$$LANGUAGE 'plpgsql' VOLATILE;
SELECT intern.nimm__TLKommentarFunktion( 'tl.erzeuge__TLdbGlossary( begriff varchar, gloPrfx varchar, bechreibung varchar, OUT tldbgl varchar )', 
ARRAY[
E'Der im Textdokument und Glossar darzustellende Begriff (darf nicht leer sein).'
, E'Im Glossar wird \\texttt{gloPrfx} dem \\texttt{begriff} vorangestellt (zur Positionierung im Glossar) - darf leer sein.'
, E'Die im Glossar dem \\texttt{begriff} zuzuordnende Beschreibung (darf leer sein).'
, E'Der im TL-Dokument einzusetzende \\texttt{$\\backslash$dbGlossary\{...\}} - Befehl.'
],
E'Ziel der Funktion ist das Erzeugen eines \\texttt{$\\backslash$dbGlossary\{...\}} - Befehls welcher im TL-Dokument verwendet werden kann.\\\\
Sollte \\texttt{bechreibung} leer sein, wird ausschlielich \\texttt{begriff} zurckgegeben.'
, ARRAY[
E'-- Fehlermeldung. Der Parameter \\texttt{begriff} darf nicht leer oder \\texttt{NULL} sein.\\\\SELECT * FROM tl.erzeuge__TLdbGlossary( NULL, '''', '''' );\\\\SELECT * FROM tl.erzeuge__TLdbGlossary( '''', '''', '''' );'
, E'-- Glossareintrag zurckgeben\\\\SELECT * FROM tl.erzeuge__TLdbGlossary( ''cc__intern_alle'', ''intern.alle'', NULL );\\\\SELECT * FROM tl.erzeuge__TLdbGlossary( ''cc__intern_alle'', ''intern.alle'', '''' );\\\\SELECT * FROM tl.erzeuge__TLdbGlossary( ''cc__intern_alle'', ''intern.alle'', ''Es sind die Zeichenketten einzugeben.'' );'
]
);
--
-- Fehlermeldungen
-- ...............
--
--	-- Fehlermeldung. Der Parameter \\texttt{begriff} darf nicht leer oder \\texttt{NULL} sein.
--SELECT * FROM tl.erzeuge__TLdbGlossary( NULL, '', '' );
--SELECT * FROM tl.erzeuge__TLdbGlossary( '', '', '' );
--
--
--
-- Standardverhalten:
-- ..................
--
--	-- Glossareintrag zurckgeben
SELECT * FROM tl.erzeuge__TLdbGlossary( 'cc__intern_alle', 'intern.alle', NULL );
SELECT * FROM tl.erzeuge__TLdbGlossary( 'cc__intern_alle', 'intern.alle', '' );
SELECT * FROM tl.erzeuge__TLdbGlossary( 'cc__intern_alle', 'intern.alle', 'Es sind die Zeichenketten einzugeben.' );
--


-- ---------------------------------------------------------------------------------------
-- ---------------------------------------------------------------------------------------
--				----------------------------------------------------------
--	tl.erzeuge__TLZk(...)	----------------------------------------------------------
--				----------------------------------------------------------
-- ---------------------------------------------------------------------------------------
-- ---------------------------------------------------------------------------------------
CREATE OR REPLACE FUNCTION tl.erzeuge__TLZk( zk varchar, OUT tlzk varchar ) AS
$$
BEGIN


--
-- Alle Zk werden akzeptiert
--
tlzk := zk;


--
-- Leere Zk und NULL werden unbehandelt durchgereicht
--
IF(
	( length( tlzk ) = 0 )
	OR ( tlzk IS NULL )
  ) 
THEN
	RETURN;
END IF;


--
-- Die im TL zu maskierenden Zeichen
--	'_'
--
tlzk := replace( tlzk, '_', E'\\_' );


END
$$LANGUAGE 'plpgsql' VOLATILE;
SELECT intern.nimm__TLKommentarFunktion( 'tl.erzeuge__TLZk( zk varchar, OUT tlzk varchar )', 
ARRAY[
E'Es ist die in {\\TeX}/\\LaTeX{} zu wandelnde Zeichenkette anzugeben.'
, E'Es wird die in {\\TeX}/\\LaTeX{} gewandelte Zeichenkette zurckgegeben.'
],
E'Ziel der Funktion ist das Umwandeln von Zeichenketen in {\\TeX}/\\LaTeX{}-Zeichenketten, welche im Absatzmodus akzeptiert werden knnen.'
, ARRAY[
E'-- Es wird eine Leerzeichenkette bzw. \\texttt{NULL} zurckgegeben\\\\SELECT * FROM tl.erzeuge__TLZk( '''' );\\\\SELECT * FROM tl.erzeuge__TLZk( NULL );'
, E'-- Es wird \\texttt{intern\_abczk\_id} zurckgegeben\\\\SELECT * FROM tl.erzeuge__TLZk( ''intern_abczk_id'' );'
, E'-- Es wird \\texttt{normale Zk} zurckgegeben\\\\SELECT * FROM tl.erzeuge__TLZk( ''normale Zk'' );'
]
);
--
-- Standardverhalten:
-- ..................
--
--	-- Es wird eine Leerzeichenkette bzw. \\texttt{NULL} zurckgegeben
--SELECT * FROM tl.erzeuge__TLZk( '' );
--SELECT * FROM tl.erzeuge__TLZk( NULL );
--
--	-- Es wird \\texttt{intern\_abczk\_id} zurckgegeben
--SELECT * FROM tl.erzeuge__TLZk( 'intern_abczk_id' );
--
--	-- Es wird \\texttt{normale Zk} zurckgegeben
--SELECT * FROM tl.erzeuge__TLZk( 'normale Zk' );
--


-- ---------------------------------------------------------------------------------------
-- ---------------------------------------------------------------------------------------
--					--------------------------------------------------
--	tl.gib__datei(...)		--------------------------------------------------
--					--------------------------------------------------
-- ---------------------------------------------------------------------------------------
-- ---------------------------------------------------------------------------------------
CREATE OR REPLACE FUNCTION tl.gib__datei( dateiname varchar, OUT dateiinhalt varchar ) AS
$$
DECLARE

--------------------------------------------------------------------------------
-- Konstanten
--------------------------------------------------------------------------------

--------------------------------------------------------------------------------
-- lokale Variablen
--------------------------------------------------------------------------------
--
-- FOR-LOOP-Schleifenvariable
--
zeile RECORD;



BEGIN


--
-- 1.)	Plausibilitt
--	- Der Dateiname mu angegeben werden
--
EXECUTE intern.pruefe__dt( 'zk', dateiname, NULL, NULL
				, 'tl.gib__datei(...)'
				, 'dateiname' );


--
-- 2.)	Den Dateiinhalt zurckgeben
--
dateiinhalt := '';
FOR
	zeile
IN
	EXECUTE intern.gib__sqlSELECT( 'COALESCE ( intern.abczk.abczk'
				|| E', replace( intern.restzk.restzk, intern.gib__ZU(), E''\\n'' )'
				|| ', tl.befehl.befname'
				|| ', tl.wort.worte ) AS tl_objekt'
			, ARRAY[ 'tl.pos'
				, 'tl.datei'
				, 'intern.abczk'
				, 'intern.restzk'
				, 'tl.befehl'
				, 'tl.wort']
			, ' AND tl.pos.tl_datei_id = tl.datei.id '
				|| ' AND tl.datei.dname = ''' || dateiname || ''''
				|| ' AND tl.pos.intern_abczk_id = intern.abczk.id'
				|| ' AND tl.pos.intern_restzk_id = intern.restzk.id'
				|| ' AND tl.pos.tl_befehl_id = tl.befehl.id'
				|| ' AND tl.pos.tl_wort_id = tl.wort.id'
				|| ' ORDER BY tl.pos.pos' )
LOOP

	dateiinhalt := dateiinhalt || zeile.tl_objekt;

END LOOP;


END
$$LANGUAGE 'plpgsql' VOLATILE;
SELECT intern.nimm__TLKommentarFunktion( 'tl.gib__datei( dateiname varchar, OUT dateiinhalt varchar )', 
ARRAY[
'Vollstndiger Dateiname (einschl. Dateierweiterung) der auszugebenden TL-Datei'
, 'Vollstndiger Inhalt der auszugebenden TL-Datei'
],
E'Ziel der Funktion ist das Herausgeben des Inhalts der mittels \\texttt{dateiname} spezifizierten {\\TeX}/\\LaTeX{}-Quelltextdatei (TL-Datei).
\\\\
\\\\
Hinweise zur Benutzung:\\\\
Um nicht auf eine separate Ausleseroutine angewiesen zu sein, wird folgende (in \\texttt{psql}) auszufuehrende Handlungsweise empfohlen:
\\\\
\\\\
\\texttt{$\\backslash$pset tuples_only}\\\\
\\texttt{$\\backslash$pset format unaligned}\\\\
\\texttt{$\\backslash$pset footer}\\\\
\\texttt{SELECT * FROM tl.gib__datei( ''dateiname.tex'' ) $\\backslash$o dateiname.tex}\\\\
\\texttt{;}\\\\
\\texttt{$\\backslash$q}
\\\\
\\\\
Alternativ kann in der Kommandozeile\\\\
\\texttt{psql -U micha vf -P tuples_only -P format=unaligned -P footer -c ``SELECT * FROM tl.gib__datei( ''dateiname.tex'' );`` -o dateiname.tex}\\\\
eingegeben werden.'
, ARRAY[
E'-- Fehlermeldung. Der Parameter \\texttt{dateiname} darf nicht leer oder \\texttt{NULL} sein.\\\\SELECT * FROM tl.gib__datei( NULL );'
, E'-- Dateiinhalt einlesen und wieder ausgeben\\\\SELECT intern.nimm__zeile( ''tl.befehl'', ARRAY[''abczk'', ''befname''], ARRAY['''', '' "A''] );\\\\SELECT intern.nimm__zeile( ''tl.befehl'', ARRAY[''befname''], ARRAY[E''$\\backslash$-''] );\\\\SELECT intern.nimm__zeile( ''tl.datei'', ARRAY[''dname''], ARRAY[''dateiname.tex''] );\\\\SELECT * FROM tl.nimm__datei(\\\\E''n$\\backslash$-de$\\backslash$-rung\\\\"An$\\backslash$-de$\\backslash$-rungHo$\\backslash$-sen$\\backslash$-bein\\\\		''''	2006-01-01 \\#1	   nderung\\\\norm-dt_01050_din_en\\\\ $\\backslash$befehl''\\\\, ''dateiname.tex'' );\\\\SELECT * FROM tl.gib__datei( ''dateiname.tex'' );'
]
);
--
-- Fehlermeldungen
-- ...............
--
--	-- Fehlermeldung. Der Parameter \\texttt{dateiname} darf nicht leer oder \\texttt{NULL} sein.
--SELECT * FROM tl.gib__datei( NULL );
--
--
--
-- Standardverhalten:
-- ..................
--
--	-- Dateiinhalt einlesen und wieder ausgeben
--SELECT intern.nimm__zeile( 'tl.befehl', ARRAY['abczk', 'befname'], ARRAY['', '"A'] );
--SELECT intern.nimm__zeile( 'tl.befehl', ARRAY['befname'], ARRAY[E'\\-'] );
--SELECT intern.nimm__zeile( 'tl.datei', ARRAY['dname'], ARRAY['dateiname.tex'] );
--SELECT * FROM tl.nimm__datei( 
--E'n\\-de\\-rung
--"An\\-de\\-rungHo\\-sen\\-bein
--			2006-01-01	   nderung
--norm-dt_01050_din_en
--\\befehl'
-- , 'dateiname.tex' );
--SELECT * FROM tl.gib__datei( 'dateiname.tex' );
--


-- ---------------------------------------------------------------------------------------
-- ---------------------------------------------------------------------------------------
--				----------------------------------------------------------
-- 	tl.gib__ERE_TLBefehl()	----------------------------------------------------------
--				----------------------------------------------------------
-- ---------------------------------------------------------------------------------------
-- ---------------------------------------------------------------------------------------
CREATE OR REPLACE FUNCTION tl.gib__ERE_TLBefehl( OUT ere_tlbefehl varchar ) AS
$$

BEGIN

--
-- 1.)	ERE zur Beschreibung der TL-Befehle, wobei die Vielfalt eingeschrnkt ist:
--	1.1.)	vom ERE erfate TL-Befehle beginnen mit einem \ oder @ oder Buchstaben dem ein 
--		Buchstabe folgen mu.
--		TL-Befehle, welche mit einem Buchstaben beginnen, mssen mindestens ein - _ oder
--		Ziffer enthalten.
--		Bsp.:
--		-> \befehl
--		-> @manual
--		-> abs2def
--		-> norm-dt_01050_din_en
--
--	1.2.)	TL-Zweizeichenbefehle werden ber >tl.gib__ERE_TLZZBefehl()< abgefangen
--
--	1.3.)	TL-Befehle, welche mit - _ oder einer Ziffer beginnen, werden bis zum ersten
--		Buchstabe >intern.gib__ERE_RestZK()< abgebildet (TL-Befehl wird zerteilt).
--
--	1.4.)	Klammern und Sterne welche Teil eines TL-Befehls sein knnen werden mittels 
--		>intern.gib__ERE_RestZK()< abgebildet (TL-Befehl wird zerteilt).
--
ere_tlbefehl :=  E'(?e)^[@\\a-zA-Z][a-zA-Z][a-zA-Z0-9_-]*';

END
$$LANGUAGE 'plpgsql' VOLATILE;
SELECT intern.nimm__TLKommentarFunktion( 'tl.gib__ERE_TLBefehl( OUT ere_tlbefehl varchar )', 
ARRAY[
'Ist der erweiterte regulaere Ausdruck zur Beschreibung eines TL-Befehls'
],
E'Ziel der Funktion ist das Definieren und Zurueckgeben eines erweiterten regulaeren Ausdruckes (ERE), welcher das Textmuster eines {\\TeX}/\\LaTeX{} - Befehls (TL-Befehl) beschreibt.\\\\
TL-Befehle  beginnen mit einem \\ oder @ oder Buchstaben dem ein Buchstabe folgen mu. TL-Befehle, welche mit einem Buchstaben beginnen, mssen mindestens ein - _ oder eine Ziffer enthalten.\\\\
\\\\
TL-Zweizeichenbefehle werden ber \\texttt{tl.gib__ERE_TLZZBefehl()} abgefangen.\\\\
TL-Befehle, welche mit - _ oder einer Ziffer beginnen, werden bis zum ersten Buchstaben \\texttt{intern.gib__ERE_RestZK()} abgebildet (TL-Befehl wird zerteilt).\\\\
Klammern und Sterne welche Teil eines TL-Befehls sein knnen, werden mittels \\texttt{intern.gib__ERE_RestZK()} abgebildet (TL-Befehl wird zerteilt).\\\\
\\\\
Es ist besonders zu beachten, da auch ABCZk (siehe \\texttt{intern.gib__ERE_ABCZK()}) beschrieben werden, solange sie keine deutschen Sonderzeichen (, ...) enthalten ! Das ist von folgenden Routinen abzufangen !'
, ARRAY[
E'-- ERE zurckgeben\\\\SELECT * FROM tl.gib__ERE_TLBefehl();'
, E'-- Es wird \\texttt{test} zurckgegeben\\\\SELECT substring( ''test'' from tl.gib__ERE_TLBefehl() );'
, E'-- Es wird \\texttt{$\\backslash$befehl} zurckgeben\\\\SELECT substring( ''$\\backslash$befehl'' from tl.gib__ERE_TLBefehl() );'
, E'-- Es wird \\texttt{@manual} zurckgeben\\\\SELECT substring( ''@manual'' from tl.gib__ERE_TLBefehl() );'
, E'-- Es wird \\texttt{abs2def} zurckgeben\\\\SELECT substring( ''abs2def'' from tl.gib__ERE_TLBefehl() );'
, E'-- Es wird \\texttt{absdef2} zurckgeben\\\\SELECT substring( ''absdef2'' from tl.gib__ERE_TLBefehl() );'
, E'-- Es wird \\texttt{norm-dt_01050_din_en} zurckgeben\\\\SELECT substring( ''norm-dt_01050_din_en'' from tl.gib__ERE_TLBefehl() );'
, E'-- Es wird eine Leerzeichenkette zurckgeben\\\\SELECT substring( ''$\\backslash$'' from tl.gib__ERE_TLBefehl() );'
, E'-- Es wird eine Leerzeichenkette zurckgeben\\\\SELECT substring( ''$\\backslash$$\\backslash$'' from tl.gib__ERE_TLBefehl() );'
, E'-- Es wird eine Leerzeichenkette zurckgeben\\\\SELECT substring( ''$\\backslash$@befehl'' from tl.gib__ERE_TLBefehl() );'
, E'-- Es wird \\texttt{$\\backslash$bef} zurckgeben (leider)\\\\SELECT substring( ''$\\backslash$bef@befehl'' from tl.gib__ERE_TLBefehl() );'
, E'-- Es wird eine Leerzeichenkette zurckgeben\\\\SELECT substring( ''2absdef'' from tl.gib__ERE_TLBefehl() );'
, E'-- Es wird eine Leerzeichenkette zurckgeben\\\\SELECT substring( ''-no-dt_01050_din_en'' from tl.gib__ERE_TLBefehl() );'
, E'-- Es wird eine Leerzeichenkette zurckgeben\\\\SELECT substring( ''_no-dt_01050_din_en'' from tl.gib__ERE_TLBefehl() );'
, E'-- Es wird eine Leerzeichenkette zurckgeben\\\\SELECT substring( ''2no-dt_01050_din_en'' from tl.gib__ERE_TLBefehl() );'
]
);
--
-- Standardverhalten:
-- ..................
--
--	-- ERE zurckgeben
--SELECT * FROM tl.gib__ERE_TLBefehl();
--
--	-- Es wird \\texttt{test} zurckgegeben
--SELECT substring( 'test' from tl.gib__ERE_TLBefehl() );
--
--	-- Es wird \\texttt{\befehl} zurckgeben
--SELECT substring( E'\\befehl' from tl.gib__ERE_TLBefehl() );
--
--	-- Es wird \\texttt{@manual} zurckgeben
--SELECT substring( '@manual' from tl.gib__ERE_TLBefehl() );
--
--	-- Es wird \\texttt{abs2def} zurckgeben
--SELECT substring( 'abs2def' from tl.gib__ERE_TLBefehl() );
--
--	-- Es wird \\texttt{absdef2} zurckgeben
--SELECT substring( 'absdef2' from tl.gib__ERE_TLBefehl() );
--
--	-- Es wird \\texttt{norm-dt_01050_din_en} zurckgeben
--SELECT substring( 'norm-dt_01050_din_en' from tl.gib__ERE_TLBefehl() );
--
--	-- Es wird eine Leerzeichenkette zurckgeben
--SELECT substring( E'\\' from tl.gib__ERE_TLBefehl() );
--
--	-- Es wird eine Leerzeichenkette zurckgeben
--SELECT substring( E'\\\\' from tl.gib__ERE_TLBefehl() );
--
--	-- Es wird eine Leerzeichenkette zurckgeben
--SELECT substring( E'\\@befehl' from tl.gib__ERE_TLBefehl() );
--
--	-- Es wird \\texttt{\bef} zurckgeben (leider)
--SELECT substring( E'\\bef@befehl' from tl.gib__ERE_TLBefehl() );
--
--	-- Es wird eine Leerzeichenkette zurckgeben
--SELECT substring( '2absdef' from tl.gib__ERE_TLBefehl() );
--
--	-- Es wird eine Leerzeichenkette zurckgeben
--SELECT substring( '-no-dt_01050_din_en' from tl.gib__ERE_TLBefehl() );
--
--	-- Es wird eine Leerzeichenkette zurckgeben
--SELECT substring( '_no-dt_01050_din_en' from tl.gib__ERE_TLBefehl() );
--
--	-- Es wird eine Leerzeichenkette zurckgeben
--SELECT substring( '2no-dt_01050_din_en' from tl.gib__ERE_TLBefehl() );
--


-- ---------------------------------------------------------------------------------------
-- ---------------------------------------------------------------------------------------
--				----------------------------------------------------------
--	tl.gib__ERE_TLWort()	----------------------------------------------------------
--				----------------------------------------------------------
-- ---------------------------------------------------------------------------------------
-- ---------------------------------------------------------------------------------------
CREATE OR REPLACE FUNCTION tl.gib__ERE_TLWort( OUT ere_tlwort varchar ) AS
$$

BEGIN

--
-- 1)	ERE zur Beschreibung eines TL-Wortes
--
ere_tlwort :=  '(?e)^((' 
		|| replace( tl.gib__ERE_TLZZBefehl( true ), '(?e)^', '' )
		|| ')?' 
		|| replace( intern.gib__ERE_Buchstabe( false ), '(?e)^', '' )
		|| '+(' 
		|| replace( tl.gib__ERE_TLZZBefehl( false ), '(?e)^', '' )
		|| replace( intern.gib__ERE_Buchstabe( false ), '(?e)^', '' )
		|| '*)*)';

END
$$LANGUAGE 'plpgsql' VOLATILE;
SELECT intern.nimm__TLKommentarFunktion( 'tl.gib__ERE_TLWort( OUT ere_tlwort varchar )'
, ARRAY[
'Ist der erweiterte regulre Ausdruck zur Beschreibung eines TL-Wortes.'
],
E'Ziel der Funktion ist das Definieren und Zurckgeben eines erweiterten regulren Ausdruckes (ERE), welcher das Textmuster eines TL-Wortes beschreibt.\\\\ 
Ein TL-Wort beginnt mit einem Buchstaben oder mit einem " in Kombination mit dem zulssigen Buchstaben.\\\\
In der Folge setzt es sich aus TL-Zweizeichenbefehlen (siehe \\texttt{tl.gib__ERE_TLZZBefehl()}) und ABCZk (siehe \\texttt{intern.gib__ERE_ABCZK()}) zusammen.\\\\
Es ist besonders zu beachten, da auche ASCII-Wrter (siehe \\texttt{intern.gib__ERE_ABCZK()}) beschrieben werden, solange sie keine deutschen Sonderzeichen (, ...) enthalten ! Das ist von folgenden Routinen abzufangen !'
, ARRAY[
E'-- ERE zurckgeben\\\\SELECT * FROM tl.gib__ERE_TLWort();'
, E'-- Es wird \\texttt{test} zurckgegeben (leider)\\\\SELECT substring( ''test'' from tl.gib__ERE_TLWort() );'
, E'-- Es wird eine Leerzeichenkette zurckgegeben\\\\SELECT substring( E''$\\backslash$Aistfalsch'' from tl.gib__ERE_TLWort() );'
, E'-- Es wird \\texttt{"An\-de\-rung} zurckgegeben\\\\SELECT substring( E''"An\\-de\\-rung'' from tl.gib__ERE_TLWort() );'
, E'-- Es wird \\texttt{n"-de\-rung"a} zurckgegeben\\\\SELECT substring( E''n"-de\\-rung"a'' from tl.gib__ERE_TLWort() );'
, E'-- Es wird \\texttt{n"-de\\-rung"a} zurckgegeben (leider)\\\\SELECT substring( E''n"-de\\-rung"a'' from tl.gib__ERE_TLWort() );'
, E'-- Es wird \\texttt{"Amann} zurckgegeben\\\\SELECT substring( ''"Amann'' from tl.gib__ERE_TLWort() );'
]
);
--
-- Standardverhalten:
-- ..................
--
--	-- ERE zurckgeben
--SELECT * FROM tl.gib__ERE_TLWort();
--
--	-- Es wird \\texttt{test} zurckgegeben (leider)
--SELECT substring( 'test' from tl.gib__ERE_TLWort() );
--
--	-- Es wird eine Leerzeichenkette zurckgegeben
--SELECT substring( E'\\Aistfalsch' from tl.gib__ERE_TLWort() );
--
--	-- Es wird \\texttt{"An\-de\-rung} zurckgegeben
--SELECT substring( E'"An\\-de\\-rung' from tl.gib__ERE_TLWort() );
--
--	-- Es wird \\texttt{n"-de\-rung"a} zurckgegeben
--SELECT substring( E'n"-de\\-rung"a' from tl.gib__ERE_TLWort() );
--
--	-- Es wird \\texttt{n"-de\\-rung"a} zurckgegeben (leider)
--SELECT substring( E'n"-de\\-rung"a' from tl.gib__ERE_TLWort() );
--
--	-- Es wird \\texttt{"Amann} zurckgegeben
--SELECT substring( '"Amann' from tl.gib__ERE_TLWort() );
--


-- ---------------------------------------------------------------------------------------
-- ---------------------------------------------------------------------------------------
--					--------------------------------------------------
--	tl.gib__ERE_TLZZBefehl()	--------------------------------------------------
--					--------------------------------------------------
-- ---------------------------------------------------------------------------------------
-- ---------------------------------------------------------------------------------------
CREATE OR REPLACE FUNCTION tl.gib__ERE_TLZZBefehl( istAnfang boolean, OUT ere_tlzzbefehl varchar ) AS
$$

BEGIN

--
-- 1)	ERE zur Beschreibung eines TL-Zweizeichenbefehls (es ist egal, ob '\' oder '\\' 
--	verwendet wird, beides funktioniert)
--
ere_tlzzbefehl := '"][AaOoUu';


IF(
    istAnfang
  )
THEN
	--
	-- Anfang eines TL-Befehls
	--
	ere_tlzzbefehl := '(?e)^[' || ere_tlzzbefehl || ']';
ELSE
	--
	-- Rest eines TL-Befehls
	--
	ere_tlzzbefehl :=  E'(?e)^[\\' || ere_tlzzbefehl || '-]';
END IF;

END
$$LANGUAGE 'plpgsql' VOLATILE;
SELECT intern.nimm__TLKommentarFunktion( 'tl.gib__ERE_TLZZBefehl( istAnfang boolean, OUT ere_tlzzbefehl varchar )'
, ARRAY[
E'Der erweiterte regulre Ausdruck des Anfangs eines TL-Zweizeichenbefehls soll zurckgegeben werden'
, E'Ist der erweiterte regulre Ausdruck zur Beschreibung eines TL-Zweizeichenbefehls.'
],
E'Ziel der Funktion ist das Definieren und Zurckgeben eines erweiterten regulren Ausdruckes (ERE), welcher das Textmuster eines TL-Zweizeichenbefehls beschreibt. Die folgenden TL-Zweizeichenbefehle werden vom ERE erfat:
\\begin{itemize}
  \\item "A
  \\item "a
  \\item "O
  \\item "o
  \\item "U
  \\item "u
  \\item "-
  \\item \\-
\\end{itemize}
'
, ARRAY[
E'-- ERE zurckgeben\\\\SELECT * FROM tl.gib__ERE_TLZZBefehl( true );\\\\SELECT * FROM tl.gib__ERE_TLZZBefehl( false );'
, E'-- Leerzeichenkette zurckgeben\\\\SELECT substring( E''\\-'' from tl.gib__ERE_TLZZBefehl( true ) );'
, E'-- \\texttt{"u} zurckgeben\\\\SELECT substring( ''"u'' from tl.gib__ERE_TLZZBefehl( true ) );'
, E'-- \\texttt{\\-} zurckgeben\\\\SELECT substring( E''\\-'' from tl.gib__ERE_TLZZBefehl( false ) );'
]
);
--
-- Standardverhalten:
-- ..................
--
--	-- ERE zurckgeben
--SELECT * FROM tl.gib__ERE_TLZZBefehl( true );
--SELECT * FROM tl.gib__ERE_TLZZBefehl( false );
--
--	-- Leerzeichenkette zurckgeben
--SELECT substring( E'\\-' from tl.gib__ERE_TLZZBefehl( true ) );
--
--	-- \\texttt{"u} zurckgeben
--SELECT substring( '"u' from tl.gib__ERE_TLZZBefehl( true ) );
--
--	-- \\texttt{\\-} zurckgeben
--SELECT substring( E'\\-' from tl.gib__ERE_TLZZBefehl( false ) );
--


-- ---------------------------------------------------------------------------------------
-- ---------------------------------------------------------------------------------------
--					--------------------------------------------------
-- 	tl.gib__Liste_TLZZBefehl(...)	--------------------------------------------------
--					--------------------------------------------------
-- ---------------------------------------------------------------------------------------
-- ---------------------------------------------------------------------------------------
CREATE OR REPLACE FUNCTION tl.gib__Liste_TLZZBefehl( tlwort varchar, OUT listeTLZZBefehl varchar[] ) AS
$$
DECLARE
--------------------------------------------------------------------------------
-- Konstanten
--------------------------------------------------------------------------------

--------------------------------------------------------------------------------
-- lokale Variablen
--------------------------------------------------------------------------------
--
-- Hilfsvariable zum Aufnehmen einzelner Texte
--
hilfsVarchar varchar;
--
-- Hilfsvariable zum extrahieren der TL-Zweizeichenbefehle
--
hilfsTLWort varchar DEFAULT tlwort;



BEGIN

--
-- 1)	Liste der im TL-Wort >tlwort< enthaltenen TL-Zweizeichenbefehle erstellen und 
--	zurckgeben.
--	Mehrfach auftretende TL-Zweizeichenbefehle werden nur einmal zurckgegeben, da sie im
--	Schritt 1.4) nachdem sie gefunden und bnommen wurden, gelscht werden.
--
LOOP

	--
	-- 1.1)	TL-Zweizeichenbefehl extrahieren
	-- 	Es wird das erste Aufreten eines TL-Zweizeichenbefehls gesucht und (daher er in
	-- 	der Klammer steht) zurckgegeben.
	--	
	hilfsVarchar := substring( hilfsTLWort from intern.gib__ERE_Buchstabe( true ) || '*(' || replace( tl.gib__ERE_TLZZBefehl( false ), '(?e)^', '' ) || ')' );

	--
	-- 1.2)	Schleife verlassen, wenn kein TL-Zweizeichenbefehl gefunden werden konnte
	--
	EXIT WHEN ( hilfsVarchar IS NULL );

	--
	-- 1.3)	TL-Zweizeichenbefehl der Liste des Rckgabewertes anhngen
	--
	IF( array_dims( listeTLZZBefehl ) IS NULL ) 
	THEN
		listeTLZZBefehl[1] := hilfsVarchar;
	ELSE
		listeTLZZBefehl := array_append( listeTLZZBefehl, hilfsVarchar );
	END IF;

	--
	-- 1.4)	den aktuell gefundenen TL-Zweizeichenbefehl im bergebenen TL-Wort lschen
	--
	hilfsTLWort := replace( hilfsTLWort, hilfsVarchar, '' );

END LOOP;

END
$$LANGUAGE 'plpgsql' VOLATILE;
SELECT intern.nimm__TLKommentarFunktion( 'tl.gib__Liste_TLZZBefehl( tlwort varchar, OUT listeTLZZBefehl varchar[] )', 
ARRAY[
E'Es ist das Wort anzugeben, aus welchem die TL-Zweizeichenbefehle extrahiert werden sollen. ACHTUNG ! Das ''$\\backslash$'' ist doppelt anzugeben (zu maskieren). Bsp.: \\texttt{tl.gib__Liste_TLZZBefehl( ''"An\\-de\\-rung'' )}'
, E'Es wird die Liste der gefundenen TL-Zweizeichenbefehle als \\texttt{ARRAY} vom Typ \\texttt{VARCHAR} zurckgegeben. Sollte kein TL-Zweizeichenbefehl in \\texttt{tlwort} enthalten oder \\texttt{tlwort} leer sein, wird \\texttt{NULL} zurckgegeben.'
],
'Ziel der Funktion ist das Extrahieren von TL-Zweizeichenbefehlen aus einem Wort. Das Wort besteht ausschlielich aus Buchstaben und (ggf.) aus TL-Zweizeichenbefehlen. Es wird nicht geprft, ob die extrahierten TL-Zweizeichenbefehle im System vorhanden sind.'
, ARRAY[
E'-- Es wird \\texttt{NULL} zurckgegeben\\\\SELECT * FROM tl.gib__Liste_TLZZBefehl( NULL );'
, E'-- Es wird \\texttt{NULL} zurckgegeben\\\\SELECT * FROM tl.gib__Liste_TLZZBefehl( '''' );'
, E'-- Es wird \\texttt{NULL} zurckgegeben\\\\SELECT * FROM tl.gib__Liste_TLZZBefehl( ''nderung'' );'
, E'-- Es wird \\texttt{"A} zurckgegeben\\\\SELECT * FROM tl.gib__Liste_TLZZBefehl( ''"Anderung'' );'
, E'-- Es wird \\texttt{"A \\-} zurckgegeben\\\\SELECT * FROM tl.gib__Liste_TLZZBefehl( E''"An\\-de\\-rung'' );'
, E'-- Es wird \\texttt{\\-} zurckgegeben\\\\SELECT * FROM tl.gib__Liste_TLZZBefehl( E''n\\-de\\-rung'' );'
]
);
--
-- Standardverhalten:
-- ..................
--
--	-- Es wird \\texttt{NULL} zurckgegeben
--SELECT * FROM tl.gib__Liste_TLZZBefehl( NULL );
--
--	-- Es wird \\texttt{NULL} zurckgegeben
--SELECT * FROM tl.gib__Liste_TLZZBefehl( '' );
--
--	-- Es wird \\texttt{NULL} zurckgegeben
--SELECT * FROM tl.gib__Liste_TLZZBefehl( 'nderung' );
--
--	-- Es wird \\texttt{"A} zurckgegeben
--SELECT * FROM tl.gib__Liste_TLZZBefehl( '"Anderung' );
--
--	-- Es wird \\texttt{"A \\-} zurckgegeben
--SELECT * FROM tl.gib__Liste_TLZZBefehl( E'"An\\-de\\-rung' );
--
--	-- Es wird \\texttt{\\-} zurckgegeben
--SELECT * FROM tl.gib__Liste_TLZZBefehl( E'n\\-de\\-rung' );
--


-- ---------------------------------------------------------------------------------------
-- ---------------------------------------------------------------------------------------
--					--------------------------------------------------
--	tl.ist__TLWort(...)		--------------------------------------------------
--					--------------------------------------------------
-- ---------------------------------------------------------------------------------------
-- ---------------------------------------------------------------------------------------
CREATE OR REPLACE FUNCTION tl.ist__TLWort( tlwort varchar, OUT istTLWort boolean ) AS
$$
DECLARE


BEGIN


--
-- 1.)	Die bergebene Zk ist kein TL-Wort
--
istTLWort := false;


--
-- 2.)	Ein TL-Wort liegt vor
--	>tl.gib__ERE_TLWort()< akzeptiert momentan auch AbcZk, weshalb der zustzliche Test
--	mittels >intern.ist__abczk(...)< erforderlich ist
--
IF(
	( length( substring( tlwort from tl.gib__ERE_TLWort() ) ) = length( tlwort ) )
	AND NOT intern.ist__abczk( tlwort )
  ) 
THEN
	istTLWort := true;
END IF;


END
$$LANGUAGE 'plpgsql' VOLATILE;
SELECT intern.nimm__TLKommentarFunktion( 'tl.ist__TLWort( tlwort varchar, OUT istTLWort boolean )', 
ARRAY[
E'Es ist das zu testende Wort anzugeben. ACHTUNG ! Das ''$\\backslash$'' ist doppelt anzugeben (zu maskieren). Bsp.: \\texttt{tl.ist__TLWort( ''"An\\-de\\-rung'' )}'
, E'Wenn \\texttt{istTLWort = false} dann ist \\texttt{tlwort} kein TL-Wort. Wenn \\texttt{istTLWort = true} dann ist  ein TL-Wort'
],
E'Ziel der Funktion ist das Prfen, ob die bergebene Zeichenkette \\texttt{tlwort} als TL-Wort interpretiert werden kann.\\\\
TL-Worte bestehen ausschlielich aus AbcZk in Kombination mit mindestens einem TL-Zweizeichenbefehl (Definition und Gltigkeit siehe \\texttt{tl.gib__ERE_TLWort()} unter der Bedingung, da \\texttt{intern.ist__abczk( tlwort ) = false} ist).'
, ARRAY[
E'-- Es wird \\texttt{false} zurckgegeben\\\\SELECT * FROM tl.ist__TLWort( '''' );'
, E'-- Es wird \\texttt{false} zurckgegeben\\\\SELECT * FROM tl.ist__TLWort( NULL );'
, E'-- Es wird \\texttt{false} zurckgegeben\\\\SELECT * FROM tl.ist__TLWort( ''Hosenbein'' );'
, E'-- Es wird \\texttt{false} zurckgegeben\\\\SELECT * FROM tl.ist__TLWort( ''"An\\-de\\-rung__'' );'
, E'-- Es wird \\texttt{true} zurckgegeben\\\\SELECT * FROM tl.ist__TLWort( ''"An\\-de\\-rung'' );'
, E'-- Es wird \\texttt{true} zurckgegeben\\\\SELECT * FROM tl.ist__TLWort( ''"Anderung'' );'
, E'-- Es wird \\texttt{true} zurckgegeben\\\\SELECT * FROM tl.ist__TLWort( ''Ho\\-sen\\-bein'' );'
]
);
--
-- Standardverhalten:
-- ..................
--
--	-- Es wird \\texttt{false} zurckgegeben
--SELECT * FROM tl.ist__TLWort( '' );
--
--	-- Es wird \\texttt{false} zurckgegeben
--SELECT * FROM tl.ist__TLWort( NULL );
--
--	-- Es wird \\texttt{false} zurckgegeben
--SELECT * FROM tl.ist__TLWort( 'Hosenbein' );
--
--	-- Es wird \\texttt{false} zurckgegeben
--SELECT * FROM tl.ist__TLWort( E'"An\\-de\\-rung__' );
--
--	-- Es wird \\texttt{true} zurckgegeben
--SELECT * FROM tl.ist__TLWort( E'"An\\-de\\-rung' );
--
--	-- Es wird \\texttt{true} zurckgegeben
--SELECT * FROM tl.ist__TLWort( '"Anderung' );
--
--	-- Es wird \\texttt{true} zurckgegeben
--SELECT * FROM tl.ist__TLWort( E'Ho\\-sen\\-bein' );
--


-- ---------------------------------------------------------------------------------------
-- ---------------------------------------------------------------------------------------
--					--------------------------------------------------
--	tl.nimm__datei(...)		--------------------------------------------------
--					--------------------------------------------------
-- ---------------------------------------------------------------------------------------
-- ---------------------------------------------------------------------------------------
CREATE OR REPLACE FUNCTION tl.nimm__datei( dateiinhalt varchar, dateiname varchar, OUT tlDateiId varchar ) AS
$$
DECLARE

--------------------------------------------------------------------------------
-- Konstanten
--------------------------------------------------------------------------------

--------------------------------------------------------------------------------
-- lokale Variablen
--------------------------------------------------------------------------------
--
-- Hilfsvariable fr Integer
--
hilfInteger integer;
--
-- Laufvariable
--
lauf integer:= 0;
--
-- FOR-IN-LOOP-Schleifenvariable
--
zeile RECORD;



BEGIN


--
-- 1.)	Plausibilitt
--	- Die Inhalt der bergebenen TL-Datei darf nicht leer sein.
--	- Der Dateiname mu angegeben werden
--
EXECUTE intern.pruefe__dt( 'zk', dateiinhalt, NULL, NULL
				, 'tl.nimm__datei(...)'
				, 'dateiinhalt' );
EXECUTE intern.pruefe__dt( 'zk', dateiname, NULL, NULL
				, 'tl.nimm__datei(...)'
				, 'dateiname' );



--
-- 2.)	Id des Dateinamen ermitteln und ggf. Fehlermeldung ausgeben
--
EXECUTE 
	intern.gib__sqlSELECT( 	'id', 
				ARRAY['tl.datei'], 
				' AND tl.datei.dname = ''' || dateiname || '''' )
INTO tlDateiId;
IF(
    tlDateiId IS NULL
  )
THEN
	RAISE EXCEPTION 'tl.nimm__datei(...)	Der uebergebene Dateiname ( >%', dateiname || '< ) konnte in >tl.datei.dname< nicht gefunden werden. Bitte lese ihn manuell ein. Das Einlesen wird abgebrochen.';
END IF;



--
-- 3.)	Alle Eintrge zu >tl.datei.id< in >tl.pos< lschen
--
EXECUTE 
	intern.gib__sqlSELECT( 	'id', 
				ARRAY['tl.pos'], 
				' AND tl.pos.tl_datei_id = ' || tlDateiId )
INTO hilfInteger;
IF(
	hilfInteger IS NOT NULL
  )
THEN
	PERFORM intern.loesche__zeile( 	'tl.pos', 
					'tl.pos.tl_datei_id = ' || tlDateiId,
					'true' );
END IF;


--
-- 4.)	Den Dateiinhalt in >tl.pos< abbilden (einlesen)
--
FOR
	zeile
IN
	SELECT * FROM tl.nimm_erkannte__Liste_TLObjekte( dateiinhalt )
LOOP

	lauf := lauf + 1;
	EXECUTE 
		'SELECT intern.nimm__zeile( ''tl.pos'', ARRAY[''pos'', '''
		|| replace( zeile.tabName, '.', '_' ) || '_id'
		|| ''', ''tl_datei_id''], ARRAY['''
		|| CAST( lauf AS varchar )
		|| ''', '''
		|| CAST( zeile.tabNameId AS varchar )
		|| ''', '''
		|| tlDateiId
		|| '''] )';

END LOOP;


END
$$LANGUAGE 'plpgsql' VOLATILE;
SELECT intern.nimm__TLKommentarFunktion( 'tl.nimm__datei( dateiinhalt varchar, dateiname varchar, OUT tlDateiId varchar )', 
ARRAY[
E'Vollstndiger Inhalt der einzulesenden TL-Datei (auch Zusatzmodule wie \\texttt{bibtex})'
, E'Vollstndiger Dateiname (einschl. Dateierweiterung) der einzulesenden TL-Datei'
, 'Es wird die Identifikationsnummer des Namens der Datei zurckgegeben, deren Inhalt eingelesen wurde.'
],
E'Ziel der Funktion ist das Einlesen des Inhalts der mittels \\texttt{dateiname} spezifizierten {\\TeX}/\\LaTeX{}-Quelltextdatei (TL-Datei). Auch Quelltextdateien von TL-Zusatzpaketen (z.B. \\texttt{bibtex}) werden als TL-Dateien interpretiert.
Die Funktion extrahiert aus dem bergebenen TL-Dateiinhalt die enthaltenen TL-Objekte (siehe \\texttt{tl.nimm_erkannte__Liste_TLObjekte(...)}) und liest sie in \\texttt{tl.pos} ein. 
\\\\
Das Konzept zum extrahieren der TL-Objekte kann der Beschreibung zu \\texttt{tl.nimm_erkannte__Liste_TLObjekte(...)} entnommen werden
\\\\
\\\\
Hinweise zur Benutzung:\\\\
Um nicht auf eine separate Einleseroutine angewiesen zu sein, wird folgende (in \\texttt{psql} auszufhrende Handlungsweise empfohlen):
\\begin{enumerate}
  \\item Es ist sichergestellt, da die einzulesende TL-Datei im {\\TeX}/\\LaTeX{} fehlerfrei compiliert werden kann
  \\item Es ist eine Kopie der einzulesenen TL-Datei anzulegen
  \\item In der Kopie sind alle \\texttt{$\\backslash$} \\\\ mittels \\texttt{$\\backslash$$\\backslash$} \\\\ und alle \\texttt{''} \\\\ mittels \\texttt{''''} \\\\ zu ersetzen
  \\item Dem ersten Zeichen in der Kopie ist der SQL-Teilbefehl \\\\ \\texttt{SELECT * FROM tl.nimm__datei( E''} \\\\ voranzustellen
  \\item Dem letzten Zeichen in der Kopie mit dem Dateinamen \\texttt{dateiname.tex} ist der SQL-Teilbefehl \\\\ \\texttt{'', ''dateiname.tex'');} \\\\ hizuzufgen
  \\item Im Postgres-Kommandozeilenprogramm \\texttt{psql} ist mittels des Befehls \\\\ \\texttt{$\\backslash$i dateiname.tex} \\\\ die in den beschriebenen Schritten modifizierte Kopie einzulesen
\\end{enumerate}'
, ARRAY[
E'-- Fehlermeldung. Der Parameter \\texttt{dateiinhalt} darf nicht leer oder \\texttt{NULL} sein.\\\\SELECT * FROM tl.nimm__datei( '''', ''dateiname.tex'' );'
, E'-- Fehlermeldung. Der Parameter \\texttt{dateiname} darf nicht leer oder \\texttt{NULL} sein.\\\\SELECT * FROM tl.nimm__datei( ''ttt'', NULL );'
, E'-- Fehlermeldung. Der Dateiname mu im System vorhanden sein.\\\\SELECT * FROM tl.nimm__datei( ''ttt'', ''Unbekannter Dateiname.tex'' );'
, E'-- Dateiinhalt einlesen und wieder ausgeben\\\\SELECT intern.nimm__zeile( ''tl.befehl'', ARRAY[''abczk'', ''befname''], ARRAY['''', '' "A''] );\\\\SELECT intern.nimm__zeile( ''tl.befehl'', ARRAY[''befname''], ARRAY[E''$\\backslash$-''] );\\\\SELECT intern.nimm__zeile( ''tl.datei'', ARRAY[''dname''], ARRAY[''dateiname.tex''] );\\\\SELECT * FROM tl.nimm__datei(\\\\E''n$\\backslash$-de$\\backslash$-rung\\\\"An$\\backslash$-de$\\backslash$-rungHo$\\backslash$-sen$\\backslash$-bein\\\\		''''	2006-01-01 \\#1	   nderung\\\\norm-dt_01050_din_en\\\\ $\\backslash$befehl''\\\\, ''dateiname.tex'' );\\\\SELECT * FROM tl.gib__datei( ''dateiname.tex'' );'
]
);
--
-- Fehlermeldungen
-- ...............
--
--	-- Fehlermeldung. Der Parameter \\texttt{dateiinhalt} darf nicht leer oder \\texttt{NULL} sein.
--SELECT * FROM tl.nimm__datei( '', 'dateiname.tex' );
--
--	-- Fehlermeldung. Der Parameter \\texttt{dateiname} darf nicht leer oder \\texttt{NULL} sein.
--SELECT * FROM tl.nimm__datei( 'ttt', NULL );
--
--	-- Fehlermeldung. Der Dateiname mu im System vorhanden sein.
--SELECT * FROM tl.nimm__datei( 'ttt', 'Unbekannter Dateiname.tex' );
--
--
--
-- Standardverhalten:
-- ..................
--
--	-- Dateiinhalt einlesen und wieder ausgeben
--SELECT intern.nimm__zeile( 'tl.befehl', ARRAY['abczk', 'befname'], ARRAY['', '"A'] );
--SELECT intern.nimm__zeile( 'tl.befehl', ARRAY['befname'], ARRAY[E'\\-'] );
--SELECT intern.nimm__zeile( 'tl.datei', ARRAY['dname'], ARRAY['dateiname.tex'] );
--SELECT * FROM tl.nimm__datei( 
--E'n\\-de\\-rung
--"An\\-de\\-rungHo\\-sen\\-bein
--		''	2006-01-01 #1	   nderung
--norm-dt_01050_din_en
--\\befehl'
--, 'dateiname.tex' );
--SELECT * FROM tl.gib__datei( 'dateiname.tex' );
--


-- ---------------------------------------------------------------------------------------
-- ---------------------------------------------------------------------------------------
--						------------------------------------------
-- 	tl.nimm_erkannte__Liste_TLObjekte(...)	------------------------------------------
--						------------------------------------------
-- ---------------------------------------------------------------------------------------
-- ---------------------------------------------------------------------------------------
CREATE OR REPLACE FUNCTION tl.nimm_erkannte__Liste_TLObjekte( dateiinhalt varchar, OUT tabName varchar, OUT tabNameId varchar ) RETURNS SETOF RECORD AS
$$
DECLARE
--------------------------------------------------------------------------------
-- Konstanten
--------------------------------------------------------------------------------
--
-- Gesamtzahl der Zeichen im Dateiinhalt
--
anzZDInhalt CONSTANT integer := length( dateiinhalt );
--
-- Tabellenname fr AbcZk
--
tnInternAbcZK CONSTANT varchar := 'intern.abczk.abczk';
--
-- Tabellenname fr RestZk
--
tnInternRestZK CONSTANT varchar := 'intern.restzk.restzk';
--
-- Tabellenname fr TL-Befehl
--
tnTlBefehl CONSTANT varchar := 'tl.befehl.befname';
--
-- Tabellenname fr TL-Wort
--
tnTlWort CONSTANT varchar := 'tl.wort.worte';

--------------------------------------------------------------------------------
-- lokale Variablen
--------------------------------------------------------------------------------
--
-- momentaner Startpunkt in >dateiinhalt< zum Extrahieren des nchsten TL-Objektes
--
momStart integer := 1;
--
-- aktuelles TL-Objekt ist ein TL-Befehl
--
tlOtlBefehl varchar;
--
-- aktuelles TL-Objekt wird in DB eingelesen
--
tlODB varchar;
--
-- aktuelles TL-Objekt ist ein TL-Wort
--
tlOtlWort varchar;
--
-- temporre Ganzzahlvariable
--
tmpInteger integer;



BEGIN


--
-- 1.)	Wenn der Inhalt der bergebenen TL-Datei leer ist, brauchen keine weiteren Aktionen 
--	durchgefhrt werden.
--
IF(
    anzZDInhalt = 0
  ) 
THEN
	RETURN;
END IF;


--
-- 2.)	Zeile zerlegen, analysieren, und TL-Objekte in >tl.inhalt< abbilden
--
WHILE( 
	momStart < anzZDInhalt
)LOOP

	--
	-- 2.1)	Die mglichen aktuell gltigen TL-Objekte mittels ERE extrahieren.
	--
	--	- AbcZk und RestZK haben  keine berschneidungen, d.h. wenn einer eine ZK 
	--	  hat dann ist der andere Leer -> es kann >tlODB< gemeinsam verwendet werden.
	--
	--	- AbcZk und RestZK knnen berschneidungen mit TL-Befehl und/oder TL-Wort
	--	  haben.
	--
	--	2.1.1) AbcZk - Zeichenkette, welche ausschliesslich aus Buchstaben besteht
	--	2.1.2) RestZK - Zeichenkette, welche keine Buchstaben enthlt
	--	2.1.3) TL-Befehl
	--	2.1.4) TL-Wort
	--
	-- 2.1.1)  knnte vorliegen, deshalb AbcZk-Tabelle zuordnen
	--
	tlODB := substring( substr( dateiinhalt, momStart ) from intern.gib__ERE_ABCZK() );
	tabName := tnInternAbcZK;
	IF(
    		tlODB IS NULL
	  ) 
	THEN
		-- 2.1.2) knnte vorliegen, deshalb RestZK-Tabelle zuordnen
		tlODB := replace( substring( substr( dateiinhalt, momStart ) from intern.gib__ERE_RestZK() ), E'\n', intern.gib__ZU() );
		tabName := tnInternRestZK;
	END IF;

	-- 2.1.3)
	tlOtlBefehl := substring( substr( dateiinhalt, momStart ) from tl.gib__ERE_TLBefehl() );
	IF( tlOtlBefehl IS NULL ) THEN tlOtlBefehl := ''; END IF;

	-- 2.1.4)
	tlOtlWort := substring( substr( dateiinhalt, momStart ) from tl.gib__ERE_TLWort() );
	IF( tlOtlWort IS NULL ) THEN tlOtlWort := ''; END IF;

	--
	-- 2.2)	In >tlODB< mu immer ein Wert stehen, da die Gesamtheit der zulssigen Zeichen
	--	mittels >intern.gib__ERE_ABCZK()< und >intern.gib__ERE_RestZK()< abgebildet
	--	wird.
	--	Sollte ein weiteres Zeichen gefunden werden, wird die Bearbeitung abgebrochen
	--
	IF( 
		tlODB IS NULL 
	) THEN 
		RAISE EXCEPTION 'tl.nimm_erkannte__Liste_TLObjekte(...)	Der uebergebene Dateiinhalt >dateiinhalt< enthaelt ein unzulaessiges Zeichen. Das Einlesen wird abgebrochen ! dateiinhalt: >%', dateiinhalt || '<';
	END IF;

	--
	-- 2.3)	Das zum Einlesen gueltige TL-Objekt bestimmen und den Startpunkt fr die weitere
	--	Analyse festlegen (berschneidungen auflsen)
	--
	--	2.3.1)	RestZK berschneidet sich mit TL-Befehl und TL-Wort, wenn am Ende ein 
	--		[\@"] gelesen wurde
	--
	--	2.3.2)	TL-Befehl und TL-Wort berschneiden sich vollstndig mit der 
	--		AbcZk / RestZK, wenn eine ZK vorliegt, welche ausschlielich aus 
	--		Buchstaben [A-Za-z] / aus restlichen Zeichen z.B. [\@"-] besteht
	--
	--	2.3.3)	TL-Befehl, TL-Wort und AbcZk / RestZK berschneiden sich dann 
	--		teilweise, wenn TL-Befehl / TL-Wort mit Buchstaben [A-Za-z] / mit 
	--		restlichen Zeichen z.B. [\@"-] beginnen
	--
	IF (
		( length( tlOtlBefehl ) <= length( tlODB ) )
		  AND ( length( tlOtlWort ) <= length( tlODB ) )
		  AND ( tabName = tnInternRestZK )
	) THEN
		--
		-- Die Lnge von >tlODB< bestimmen
		--
		tmpInteger := length( tlODB );

		--
		-- 2.3.1)
		-- Wenn eine RestZK vorliegt, dann knnte das erste Zeichen eines folgenden 
		-- TL-Befehls (\ @) oder TL-Wortes (") gelesen worden sein.
		--
		IF( 
			( ( tmpInteger - length( rtrim( tlODB, '@') ) ) > 0 )
			OR ( ( tmpInteger - length( rtrim( tlODB, E'\\') ) ) % 2 = 1  )
			OR ( ( tmpInteger - length( rtrim( tlODB, '"') ) ) > 0 )
		) THEN
			--
			-- Ein TL-Befehl oder TL-Wort folgt tatschlich
			--
			IF (
				( substring( substr( dateiinhalt, momStart - 1 ) from tl.gib__ERE_TLBefehl() ) IS NOT NULL )
				OR ( substring( substr( dateiinhalt, momStart - 1 ) from tl.gib__ERE_TLWort() ) IS NOT NULL )
			) THEN
				--
				-- letztes Zeichen in >tlODB< lschen
				--
				tlODB := substring( tlODB for tmpInteger - 1 );
			END IF;
		END IF;

	--
	-- 2.3.3)
	--
	ELSIF (
		( length( tlODB ) < length( tlOtlBefehl ) )
		AND ( length( tlOtlWort ) < length( tlOtlBefehl ) )
	) THEN 
		--
		-- Ein TL-Befehl liegt vor, wenn >tlOtlBefehl< die lngste ZK enthlt
		--
		tlODB := tlOtlBefehl;
		tabName := tnTlBefehl;

	--
	-- 2.3.3)
	--
	ELSIF (
		( length( tlODB ) < length( tlOtlWort ) )
		AND ( length( tlOtlBefehl ) < length( tlOtlWort ) )
	) THEN
		--
		-- Ein TL-Wort liegt vor, wenn >tlOtlWort< die lngste ZK enthlt
		--
		tlODB := tlOtlWort;
		tabName := tnTlWort;
	END IF;

	--
	-- den Startpunkt fr die weitere Analyse festlegen
	--
	momStart := momStart + length( tlODB );


	--
	-- 2.4)	TL-Objekt in DB einlesen
	--
	-- 2.4.1) TL-Wort einlesen
	--
	IF (
		tabName = tnTlWort
	) THEN
		EXECUTE 
			'SELECT tl.nimm__TLWort( E''' 
			|| replace( replace( tlODB, E'\\', E'\\\\' ), '''', '''''' )
			|| ''', NULL )'
		INTO tabNameId;

	--
	-- 2.4.2) restliche TL-Objekte einlesen
	--
	ELSE
		EXECUTE 
			'SELECT intern.nimm__zeile( ''' 
			|| substring( tabName from '(?e)^[a-z]+[.][a-z]+' )
			|| ''', ARRAY['''
			|| split_part( tabName, '.', 3 )
			|| '''] , ARRAY[E'''
			|| replace( replace( tlODB, E'\\', E'\\\\' ), '''', '''''' )
			|| '''] )'
		INTO tabNameId;

	END IF;



--RAISE NOTICE '%', tabName || '\t' || tlODB;

	--
	-- 2.5)	aktuelle Werte zurckgeben
	--
	tabName := substring( tabName from '(?e)^[a-z]+[.][a-z]+' );
	RETURN NEXT;

END LOOP;

END
$$LANGUAGE 'plpgsql' VOLATILE;
SELECT intern.nimm__TLKommentarFunktion( 'tl.nimm_erkannte__Liste_TLObjekte( dateiinhalt varchar, OUT tabName varchar, OUT tabNameId varchar )', 
ARRAY[
'Vollstndiger Inhalt der einzulesenden TL-Datei'
, 'Name der Tabelle, in die das erkannte TL-Objekt eingelesen wurde'
, E'\\texttt{id} des erkannten TL-Objektes'
],
E'Ziel der Funktion ist das Zerlegen des Inhaltes \\texttt{dateiinhalt} einer TL-Datei in TL-Objekte mittels Erweiterter Regulaerer Ausdruecke (ERE). Die erkannten TL-Objekte werden bei Bedarf in die Datenbank eingelesen.\\\\
\\\\
Aus dem bergebenen TL-Dateiinhalt extrahiert die Funktion 
\\begin{itemize}
  \\item AbcZk welche bei Bedarf in \\texttt{intern.abczk} (Gueltigkeit siehe \\texttt{intern.gib__ERE_ABCZK()}),
  \\item RestZk welche bei Bedarf in \\texttt{intern.restzk} (Gueltigkeit siehe \\texttt{intern.gib__ERE_RestZK()}),
  \\item TL-Befehle welche bei Bedarf in \\texttt{tl.befehl} (Gueltigkeit siehe \\texttt{tl.gib__ERE_TLBefehl()}) und
  \\item TL-Worte welche bei Bedarf in \\texttt{tl.wort} (Gueltigkeit siehe \\texttt{tl.gib__ERE_TLWort()})
eingelesen werden.
\\end{itemize}
Die im TL-Wort auftretenden TL-Zweizeichenbefehle mssen im System vorhanden sein.\\\\
\\\\
Smtliche Zeichenketten, welche nicht diesen Kategorien zuordenbar sind, werden zerlegt und dann entsprechend eingelesen. Zum Beispiel werden TL-Variablennamen, welche ausschliesslich aus Buchstaben bestehen, in \\texttt{intern.abczk} und nicht in \\texttt{tl.befehl} eingelesen. Die Ursache liegt in der Unfhigkeit der Funktion, eine Kontextprfung durchzufuehren.\\\\
\\\\
Mit dem Verzicht des Einlesens von Wortgruppen (siehe \\texttt{spr.wgruppe}) mssen mehrsprachige Texte mittels TL-Paketen gesetzt werden (z.B. \\texttt{babel}). Ursache ist auch hier, die Unfhigkeit eine Kontextprfung durchzufhren.'
, ARRAY[
E'-- Es wird keine Zeile zurckgegeben und nichts eingelesen\\\\SELECT * FROM tl.nimm_erkannte__Liste_TLObjekte( '' );\\\\0'
, E'-- Es wird die Zeichenkette analysiert, die TL-Objekte eingelesen und zurckgegeben\\\\SELECT * FROM tl.nimm_erkannte__Liste_TLObjekte( ''n\\-de\\-rung "An\\-de\\-rungHo\\-sen\\-bein 2006-01-01 \\#1 nderung norm-dt_01050_din_en $\\backslash$befehl'' );'
]
);
--
-- Standardverhalten:
-- ..................
--
--	-- Es wird keine Zeile zurckgegeben und nichts eingelesen
--SELECT * FROM tl.nimm_erkannte__Liste_TLObjekte( NULL );
--SELECT * FROM tl.nimm_erkannte__Liste_TLObjekte( '' );
--
--	-- Es wird die Zeichenkette analysiert, die TL-Objekte eingelesen und zurckgegeben
--SELECT intern.nimm__zeile( 'tl.befehl', ARRAY['abczk', 'befname'], ARRAY['', '"A'] );
--SELECT intern.nimm__zeile( 'tl.befehl', ARRAY['befname'], ARRAY[E'\\-'] );
--SELECT * FROM tl.nimm_erkannte__Liste_TLObjekte( 
--E'n\\-de\\-rung
--"An\\-de\\-rungHo\\-sen\\-bein
--			2006-01-01 #1	   nderung
--norm-dt_01050_din_en
--\\befehl'
-- );
--


-- ---------------------------------------------------------------------------------------
-- ---------------------------------------------------------------------------------------
--					--------------------------------------------------
--	tl.nimm__TLWort(...)		--------------------------------------------------
--					--------------------------------------------------
-- ---------------------------------------------------------------------------------------
-- ---------------------------------------------------------------------------------------
CREATE OR REPLACE FUNCTION tl.nimm__TLWort( tlWort varchar, tlWortId_korr varchar, OUT tlWortId varchar ) AS
$$
DECLARE
--------------------------------------------------------------------------------
-- Konstanten
--------------------------------------------------------------------------------

--------------------------------------------------------------------------------
-- lokale Variablen
--------------------------------------------------------------------------------
--
-- Identifikationsnummer der AbcZk
--
internAbczkId varchar;


BEGIN

--
-- 1.)	Es mu ein TL-Wort vorliegen
--
IF(
    NOT tl.ist__TLWort( tlWort )
  )
THEN
	RAISE EXCEPTION 'tl.nimm__TLWort(...)	Die uebergebene Zeichenkette ( >%', tlWort || '< ) ist kein TL-Wort. Bitte ueberpruefe die Syntax anhand der Hinweise in >tl.ist__TLWort(...)<. Das Einlesen wird abgebrochen.';
END IF;


--
-- 2.) AbcZk-Wort erzeugen, in >intern.abczk.abczk< einlesen und >intern.abczk.id< bernehmen.
--
EXECUTE 
	'SELECT intern.nimm__zeile( ''intern.abczk''
				, ARRAY[''abczk'']
				, ARRAY[' 
				|| quote_literal( tl.erzeuge__ABCZk( tlWort ) )
				|| '] )'
INTO internAbczkId;


--
-- 3.)	TL-Wort einfgen
--
-- 3.1)	>id< im System automatisch ermitteln
--
IF(
	( tlWortId_korr = '0' )
	OR ( tlWortId_korr IS NULL )
  ) 
THEN

	EXECUTE 
		'SELECT intern.nimm__zeile( ''tl.wort''
					, ARRAY[''intern_abczk_id'', ''worte'']
					, ARRAY[' 
					|| quote_literal( internAbczkId )
					|| ' , '
					|| quote_literal( tlWort )
					|| '] )'
	INTO tlWortId;

--
-- 3.2)	Vorgegebene >tlWortId_korr< verwenden
--
ELSE

	EXECUTE 
		'SELECT intern.nimm__zeile( ''tl.wort''
					, ARRAY[''id'', ''intern_abczk_id'', ''worte'']
					, ARRAY[' 
					|| quote_literal( tlWortId_korr )
					|| ' , '
					|| quote_literal( internAbczkId )
					|| ' , '
					|| quote_literal( tlWort )
					|| '] )'
	INTO tlWortId;

END IF;

END
$$LANGUAGE 'plpgsql' VOLATILE;
SELECT intern.nimm__TLKommentarFunktion( 'tl.nimm__TLWort( tlWort varchar, tlWortId_korr varchar, OUT tlWortId varchar )', 
ARRAY[
E'Einzulesendes TL-Wort. ACHTUNG ! Das ''$\\backslash$'' ist doppelt anzugeben (zu maskieren). Bsp.: \\texttt{tl.nimm__TLWort( ''Ho\\\\-sen\\\\-bein'', true )}'
, E'Wird eine im System vorhandene \\texttt{tl.wort.id} benannt, so wird das im System vorhandene TL-Wort berschrieben. Soll ein Wort hinzugefgt werden, so ist entweder ''0'' oder \\texttt{NULL} anzugeben.'
, 'Es wird die Identifikationsnummer des eingelesenen TL-Wortes zurueckgegeben.'
],
E'Ziel der Funktion ist das Einlesen des bergebenen TL-Wortes \\texttt{tlWort} in die Tabelle \\texttt{tl.wort}. Das gltige Textmuster eines TL-Wortes kann der Funktion \\texttt{tl.ist__TLWort(...)} entnommen werden.\\\\
Die im TL-Wort enthaltenen TL-Zweizeichenbefehle werden extrahiert, deren AbcZk-Bedeutung aus \\texttt{tl.befehl.abczk} ausgelesen und im TL-Wort an Stelle der TL-Zweizeichenbefehle eingesetzt. Die auf diese Weise erzeugte AbcZk wird in \\texttt{intern.abczk} eingelesen und mit dem in \\texttt{tl.wort} eingelesenen TL-Wort verknpft.\\\\
Wird eine mittels \\texttt{tlWortId_korr} bergebene \\texttt{tl.wort.id} im System gefunden, so wird das im System vorhandene TL-Wort berschrieben. Andernfalls wird \\texttt{tlWort} mit der vorgegebenen \\texttt{tlWortId_korr} im System eingefgt.
'
, ARRAY[
E'-- Fehlermeldung. Es liegt kein TL-Wort vor\\\\SELECT * FROM tl.nimm__TLWort( '''', NULL );\\\\SELECT * FROM tl.nimm__TLWort( ''Hosenbain'', NULL ); -- Fehlermeldung'
, E'-- Test\\\\SELECT intern.nimm__zeile( ''tl.befehl'', ARRAY[''abczk'', ''befname''], ARRAY['''', ''"A''] );\\\\SELECT intern.nimm__zeile( ''tl.befehl'', ARRAY[''befname''], ARRAY[E''\\-''] );'
, E'-- \\texttt{id} automatisch zuordnen\\\\SELECT * FROM tl.nimm__TLWort( ''"An\\-de\\-rung'', NULL );'
, E'-- neuer Eintrag mit \\texttt{id=99}\\\\SELECT * FROM tl.nimm__TLWort( ''Ho\\-sen\\-bein'', ''99'' );'
, E'-- vorhandene \\texttt{id=99} berschreiben\\\\SELECT * FROM tl.nimm__TLWort( ''Ho\\-sen\\-beine'', ''99'' );'
, E'-- Test\\\\SELECT * FROM tl.wort;\\\\SELECT * FROM intern.abczk WHERE abczk = ''nderung'';\\\\SELECT * FROM intern.abczk WHERE abczk = ''Hosenbeine'';'
]
);
--
-- Fehlermeldungen
-- ...............
--
--	-- Fehlermeldung. Es liegt kein TL-Wort vor
--SELECT * FROM tl.nimm__TLWort( '', NULL );
--SELECT * FROM tl.nimm__TLWort( 'Hosenbain', NULL ); -- Fehlermeldung
--
--
--
-- Standardverhalten:
-- ..................
--
--	-- Test
--SELECT intern.nimm__zeile( 'tl.befehl', ARRAY['abczk', 'befname'], ARRAY['', '"A'] );
--SELECT intern.nimm__zeile( 'tl.befehl', ARRAY['befname'], ARRAY[E'\\-'] );
--
--	-- \\texttt{id} automatisch zuordnen
--SELECT * FROM tl.nimm__TLWort( E'"An\\-de\\-rung', NULL );
--
--	-- neuer Eintrag mit \\texttt{id=99}
--SELECT * FROM tl.nimm__TLWort( E'Ho\\-sen\\-bein', '99' );
--
--	-- vorhandene \\texttt{id=99} berschreiben
--SELECT * FROM tl.nimm__TLWort( E'Ho\\-sen\\-beine', '99' );
--
--	-- Test
--SELECT * FROM tl.wort;
--SELECT * FROM intern.abczk WHERE abczk = 'nderung';
--SELECT * FROM intern.abczk WHERE abczk = 'Hosenbeine';
--
